
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "auto_examples\09_satellite_channel_modelling.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_auto_examples_09_satellite_channel_modelling.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_auto_examples_09_satellite_channel_modelling.py:


Satellite Channel Modelling
======================================================

This example uses the frequency domain :func:`lyceanem.models.frequency_domain.calculate_scattering` function to
predict the scattering parameters for the frequency and environment included in the model. This allows the effects of antenna polarisation,

.. GENERATED FROM PYTHON SOURCE LINES 14-16

Define Map and Ground Station Location and list of Satellites using skyfield API to load starlink satellites.
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. GENERATED FROM PYTHON SOURCE LINES 16-48

.. code-block:: default


    import folium

    interest_center = [51.458729, -2.602153]  # location of Bristol Physics Observatory

    m = folium.Map(
        location=[
            interest_center[0],
            interest_center[1],
        ],
        zoom_start=6,
        tiles="Stamen Terrain",
    )

    import numpy as np
    import copy

    from skyfield.api import load, EarthSatellite, wgs84

    BristolPhysicsObservatory = wgs84.latlon(interest_center[0], interest_center[1], 0)

    receiver = BristolPhysicsObservatory

    # Build the time range `t` over which to plot, plus other values.

    ts = load.timescale()

    time_points = 2 * 60  # track over 10 minutes
    # change over time
    t = ts.utc(2022, 12, 15, 13, 4, range(0, time_points))
    timebase = t.utc_datetime()








.. GENERATED FROM PYTHON SOURCE LINES 49-57

GeoJSON
~~~~~~~~
The Folium plugin `TimestampedGeoJson`_ will be used to plot our tracks using timestamped
GeoJSONs. As a result, we want to convert our data into `GeoJSON format`_. Firstly, we create
our feature collection which we will append our features to.

.. _GeoJSON format: https://geojson.org/
.. _TimestampedGeoJson:  https://python-visualization.github.io/folium/plugins.html

.. GENERATED FROM PYTHON SOURCE LINES 57-63

.. code-block:: default


    geo_features = list()
    geo_json = {
        "type": "FeatureCollection",
        "features": geo_features,
    }







.. GENERATED FROM PYTHON SOURCE LINES 64-68

Plotting Tracks of Satellites visible to Physics Observatory
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Now we append our tracks to our feature collection list. We define `colour_iter` which will
allow us to cycle through different colours when mapping our tracks.

.. GENERATED FROM PYTHON SOURCE LINES 68-100

.. code-block:: default


    from collections import defaultdict
    from itertools import cycle

    colour_iter = iter(
        cycle(
            [
                "red",
                "blue",
                "green",
                "purple",
                "orange",
                "darkred",
                "#0909FF",
                "#F70D1A",
                "#FF6700",
                "lightgreen",
                "#0AFFFF",
                "#12AD2B",
                "#E2F516",
                "#FFFF00",
                "#F52887",
            ]
        )
    )
    colour = defaultdict(lambda: next(colour_iter))

    trail_Size = 7  # trail_Size is the number of timestamps we want track to trail for
    from io import BytesIO
    import base64









.. GENERATED FROM PYTHON SOURCE LINES 101-104

Define Starlinks Tracks
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Convinience function to limit the tracks to a set number of the nearest N satellites.

.. GENERATED FROM PYTHON SOURCE LINES 104-360

.. code-block:: default


    def starlink_tracks(pointofinterest, timebase, num_satellites=5):
        starlink_url = "https://celestrak.com/NORAD/elements/supplemental/starlink.txt"
        starlinks = load.tle_file(starlink_url)
        tracks = []
        for sat in starlinks:
            pos = sat.at(timebase)
            tracks.append(pos)
            latcheck = np.any(np.isnan(wgs84.subpoint_of(pos).latitude.degrees))
            loncheck = np.any(np.isnan(wgs84.subpoint_of(pos).longitude.degrees))
            if latcheck | loncheck:
                tracks.pop(-1)
                print("caught one")

        distance_trim = np.full((len(tracks), len(timebase)), np.inf)
        for track in range(len(tracks)):
            lat = wgs84.subpoint_of(tracks[track]).latitude
            lon = wgs84.subpoint_of(tracks[track]).longitude
            relative_measure = (starlinks[track] - pointofinterest).at(timebase)
            alt, az, distance1 = relative_measure.altaz()
            altitude = alt.degrees
            azimuth = az.degrees
            relative_range = distance1.km
            plot_points = []
            plot_times = []
            az_trim = []
            alt_trim = []
            range_trim = []
            for point in range(len(lat.degrees)):
                if altitude[point] >= 0.0:
                    distance_trim[track, point] = relative_range[point]

        def get_indices_of_k_smallest(arr, k):
            idx = np.argpartition(arr.ravel(), k)
            return tuple(np.array(np.unravel_index(idx, arr.shape))[:, range(min(k, 0), max(k, 0))])


        indexholder = np.zeros((num_satellites, len(timebase)), dtype=int)
        for point in range(len(timebase)):
            indexholder[:, point] = get_indices_of_k_smallest(distance_trim[:, point], num_satellites)[0]

        return starlinks, indexholder

    starlinks, indexholder = starlink_tracks(BristolPhysicsObservatory, t, num_satellites=20)

    tracks = []
    for sat in starlinks:
        pos = sat.at(t)
        tracks.append(pos)
        latcheck = np.any(np.isnan(wgs84.subpoint_of(pos).latitude.degrees))
        loncheck = np.any(np.isnan(wgs84.subpoint_of(pos).longitude.degrees))
        if latcheck | loncheck:
            tracks.pop(-1)
            print("caught one")

    for track in range(len(tracks)):
        lat = wgs84.subpoint_of(tracks[track]).latitude
        lon = wgs84.subpoint_of(tracks[track]).longitude
        relative_measure = (starlinks[track] - BristolPhysicsObservatory).at(t)
        alt, az, distance = relative_measure.altaz()
        altitude = alt.degrees
        azimuth = az.degrees
        relative_range = distance.km
        plot_points = []
        plot_times = []
        az_trim = []
        alt_trim = []
        range_trim = []
        for point in range(len(lat.degrees)):
            if altitude[point] >= 0.0 and np.any(np.isin(track, indexholder[:, point])):
                plot_points.append((lon.degrees[point], lat.degrees[point]))
                plot_times.append(timebase[point].strftime("%Y-%m-%d %H:%M:%S"))
                az_trim.append(azimuth[point])
                alt_trim.append(altitude[point])
                range_trim.append(relative_range[point])

        for time_index, time in enumerate(plot_times):
            geo_features.append(
                {
                    "type": "Feature",
                    "properties": {
                        "name": starlinks[track].name,
                        "style": {"color": colour[track], "weight": 6},
                        "times": [time] * len(plot_points[: time_index + 1][-trail_Size:]),
                    },
                    "geometry": {
                        "type": "LineString",
                        "coordinates": plot_points[: time_index + 1][-trail_Size:],
                    },
                }
            )
            geo_features.append(
                {
                    "type": "Feature",
                    "properties": {
                        "icon": "marker",
                        "iconstyle": {
                            "iconUrl": f"http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png",
                            "iconSize": [24, 24],
                            "fillOpacity": 1,
                            "popupAnchor": [1, -17],
                        },
                        "popup": "Satellite: " + starlinks[track].name + "<dd>"
                                                                         "Latitude: "
                                 + "%s" % float("%.8g" % plot_points[time_index][0])
                                 + "<dd>"
                                   "Longitude: "
                                 + "%s" % float("%.8g" % plot_points[time_index][1])
                                 + "<dd>"  # rounding 8 sigfigs
                                   "Azimuth: "
                                 + "%s" % float("%.8g" % az_trim[time_index])
                                 + "°"
                                 + "<dd>"
                                   "Altitude: "
                                 + "%s" % float("%.8g" % alt_trim[time_index])
                                 + "°"
                                 + "<dd>"
                                   "Slant Range: "
                                 + "%s" % float("%.8g" % range_trim[time_index])
                                 + "km",
                        "name": starlinks[track].name,
                        "style": {"color": "black", "weight": 2},
                        "times": [time],
                    },
                    "geometry": {
                        "type": "MultiPoint",
                        "coordinates": [plot_points[time_index]],
                    },
                }
            )

    # plot receiver
    r_track = []
    for time in range(len(t)):
        pos = BristolPhysicsObservatory.at(t)
        r_track.append(pos)

    for track in range(len(r_track)):
        lat = wgs84.subpoint_of(r_track[track]).latitude
        lon = wgs84.subpoint_of(r_track[track]).longitude
        relative_measure = (receiver - BristolPhysicsObservatory).at(t)
        alt, az, distance = relative_measure.altaz()
        altitude = alt.degrees
        azimuth = az.degrees
        relative_range = distance.km
        plot_points = []
        plot_times = []
        az_trim = []
        alt_trim = []
        range_trim = []
        for point in range(len(lat.degrees)):
            # if altitude[point] >= 0.0:
            plot_points.append((lon.degrees[point], lat.degrees[point]))
            plot_times.append(timebase[point].strftime("%Y-%m-%d %H:%M:%S"))
            az_trim.append(azimuth[point])
            alt_trim.append(altitude[point])
            range_trim.append(relative_range[point])

        for time_index, time in enumerate(plot_times):
            geo_features.append(
                {
                    "type": "Feature",
                    "properties": {
                        "name": "Ground Station at Bristol Physics Observatory",
                        "style": {"color": colour[track], "weight": 6},
                        "times": [time] * len(plot_points[: time_index + 1][-trail_Size:]),
                    },
                    "geometry": {
                        "type": "LineString",
                        "coordinates": plot_points[: time_index + 1][-trail_Size:],
                    },
                }
            )
            geo_features.append(
                {
                    "type": "Feature",
                    "properties": {
                        "icon": "marker",
                        "iconstyle": {
                            "iconUrl": f"https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg",
                            "iconSize": [64, 32],
                            "fillOpacity": 1,
                            "popupAnchor": [1, -17],
                        },
                        "popup": "Ground Station at Bristol Physics Observatory" + "<dd>"
                                                                                   "Latitude: "
                                 + "%s" % float("%.8g" % plot_points[time_index][0])
                                 + "<dd>"
                                   "Longitude: "
                                 + "%s" % float("%.8g" % plot_points[time_index][1])
                                 + "<dd>"  # rounding 8 sigfigs
                                   "Azimuth: "
                                 + "%s" % float("%.8g" % az_trim[time_index])
                                 + "°"
                                 + "<dd>"
                                   "Altitude: "
                                 + "%s" % float("%.8g" % alt_trim[time_index])
                                 + "°"
                                 + "<dd>"
                                   "Slant Range: "
                                 + "%s" % float("%.8g" % range_trim[time_index])
                                 + "km",
                        "name": "Ground Station at Bristol Physics Observatory",
                        "style": {"color": "black", "weight": 2},
                        "times": [time],
                    },
                    "geometry": {
                        "type": "MultiPoint",
                        "coordinates": [plot_points[time_index]],
                    },
                }
            )

    from folium.plugins import TimestampedGeoJson, Fullscreen

    Fullscreen().add_to(m)

    import numpy as np
    import matplotlib.pyplot as plt
    from geopandas import GeoDataFrame
    from shapely.geometry import Polygon, MultiPolygon


    def collec_to_gdf(collec_poly):
        """Transform a `matplotlib.contour.QuadContourSet` to a GeoDataFrame"""
        polygons, colors = [], []
        for i, polygon in enumerate(collec_poly.collections):
            mpoly = []
            for path in polygon.get_paths():
                try:
                    path.should_simplify = False
                    poly = path.to_polygons()
                    # Each polygon should contain an exterior ring + maybe hole(s):
                    exterior, holes = [], []
                    if len(poly) > 0 and len(poly[0]) > 3:
                        # The first of the list is the exterior ring :
                        exterior = poly[0]
                        # Other(s) are hole(s):
                        if len(poly) > 1:
                            holes = [h for h in poly[1:] if len(h) > 3]
                    mpoly.append(Polygon(exterior, holes))
                except:
                    print('Warning: Geometry error when making polygon #{}'
                          .format(i))
            if len(mpoly) > 1:
                mpoly = MultiPolygon(mpoly)
                polygons.append(mpoly)
                colors.append(polygon.get_facecolor().tolist()[0])
            elif len(mpoly) == 1:
                polygons.append(mpoly[0])
                colors.append(polygon.get_facecolor().tolist()[0])
        return GeoDataFrame(
            geometry=polygons,
            data={'RGBA': colors},
            crs={'init': 'epsg:4326'})








.. GENERATED FROM PYTHON SOURCE LINES 361-363

The Results
~~~~~~~~~~~~~~

.. GENERATED FROM PYTHON SOURCE LINES 363-373

.. code-block:: default


    TimestampedGeoJson(
        data=geo_json,
        transition_time=200,
        auto_play=True,
        add_last_point=False,
        period="PT1S",
        duration="PT0S",
    ).add_to(m)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none


    <folium.plugins.timestamped_geo_json.TimestampedGeoJson object at 0x0000020C6F7FFA60>



.. GENERATED FROM PYTHON SOURCE LINES 374-382

.. code-block:: default



    m










.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    <div style="width:100%;"><div style="position:relative;width:100%;height:0;padding-bottom:60%;"><span style="color:#565656">Make this Notebook Trusted to load map: File -> Trust Notebook</span><iframe srcdoc="&lt;!DOCTYPE html&gt;
    &lt;html&gt;
    &lt;head&gt;
    
        &lt;meta http-equiv=&quot;content-type&quot; content=&quot;text/html; charset=UTF-8&quot; /&gt;
    
            &lt;script&gt;
                L_NO_TOUCH = false;
                L_DISABLE_3D = false;
            &lt;/script&gt;
    
        &lt;style&gt;html, body {width: 100%;height: 100%;margin: 0;padding: 0;}&lt;/style&gt;
        &lt;style&gt;#map {position:absolute;top:0;bottom:0;right:0;left:0;}&lt;/style&gt;
        &lt;script src=&quot;https://cdn.jsdelivr.net/npm/leaflet@1.9.3/dist/leaflet.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://code.jquery.com/jquery-1.12.4.min.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://cdn.jsdelivr.net/npm/bootstrap@5.2.2/dist/js/bootstrap.bundle.min.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://cdnjs.cloudflare.com/ajax/libs/Leaflet.awesome-markers/2.0.2/leaflet.awesome-markers.js&quot;&gt;&lt;/script&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/leaflet@1.9.3/dist/leaflet.css&quot;/&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/bootstrap@5.2.2/dist/css/bootstrap.min.css&quot;/&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://netdna.bootstrapcdn.com/bootstrap/3.0.0/css/bootstrap.min.css&quot;/&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/@fortawesome/fontawesome-free@6.2.0/css/all.min.css&quot;/&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdnjs.cloudflare.com/ajax/libs/Leaflet.awesome-markers/2.0.2/leaflet.awesome-markers.css&quot;/&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/gh/python-visualization/folium/folium/templates/leaflet.awesome.rotate.min.css&quot;/&gt;
    
                &lt;meta name=&quot;viewport&quot; content=&quot;width=device-width,
                    initial-scale=1.0, maximum-scale=1.0, user-scalable=no&quot; /&gt;
                &lt;style&gt;
                    #map_e013d3d35704f37c274470336957f0ae {
                        position: relative;
                        width: 100.0%;
                        height: 100.0%;
                        left: 0.0%;
                        top: 0.0%;
                    }
                    .leaflet-container { font-size: 1rem; }
                &lt;/style&gt;
        
        &lt;script src=&quot;https://cdnjs.cloudflare.com/ajax/libs/leaflet.fullscreen/1.4.2/Control.FullScreen.min.js&quot;&gt;&lt;/script&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdnjs.cloudflare.com/ajax/libs/leaflet.fullscreen/1.4.2/Control.FullScreen.min.css&quot;/&gt;
        &lt;script src=&quot;https://cdnjs.cloudflare.com/ajax/libs/jquery/2.0.0/jquery.min.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.10.2/jquery-ui.min.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://cdn.jsdelivr.net/npm/iso8601-js-period@0.2.1/iso8601.min.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://cdn.jsdelivr.net/npm/leaflet-timedimension@1.1.1/dist/leaflet.timedimension.min.js&quot;&gt;&lt;/script&gt;
        &lt;script src=&quot;https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.18.1/moment.min.js&quot;&gt;&lt;/script&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdnjs.cloudflare.com/ajax/libs/highlight.js/8.4/styles/default.min.css&quot;/&gt;
        &lt;link rel=&quot;stylesheet&quot; href=&quot;https://cdn.jsdelivr.net/npm/leaflet-timedimension@1.1.1/dist/leaflet.timedimension.control.css&quot;/&gt;
    &lt;/head&gt;
    &lt;body&gt;
    
    
                &lt;div class=&quot;folium-map&quot; id=&quot;map_e013d3d35704f37c274470336957f0ae&quot; &gt;&lt;/div&gt;
        
    &lt;/body&gt;
    &lt;script&gt;
    
    
                var map_e013d3d35704f37c274470336957f0ae = L.map(
                    &quot;map_e013d3d35704f37c274470336957f0ae&quot;,
                    {
                        center: [51.458729, -2.602153],
                        crs: L.CRS.EPSG3857,
                        zoom: 6,
                        zoomControl: true,
                        preferCanvas: false,
                    }
                );

            

        
    
                var tile_layer_c3dfacb259d0b95cf0715895e29a79b6 = L.tileLayer(
                    &quot;https://stamen-tiles-{s}.a.ssl.fastly.net/terrain/{z}/{x}/{y}.jpg&quot;,
                    {&quot;attribution&quot;: &quot;Map tiles by \u003ca target=\&quot;_blank\&quot; href=\&quot;http://stamen.com\&quot;\u003eStamen Design\u003c/a\u003e, under \u003ca target=\&quot;_blank\&quot; href=\&quot;http://creativecommons.org/licenses/by/3.0\&quot;\u003eCC BY 3.0\u003c/a\u003e. Data by \u0026copy; \u003ca target=\&quot;_blank\&quot; href=\&quot;http://openstreetmap.org\&quot;\u003eOpenStreetMap\u003c/a\u003e, under \u003ca target=\&quot;_blank\&quot; href=\&quot;http://creativecommons.org/licenses/by-sa/3.0\&quot;\u003eCC BY SA\u003c/a\u003e.&quot;, &quot;detectRetina&quot;: false, &quot;maxNativeZoom&quot;: 18, &quot;maxZoom&quot;: 18, &quot;minZoom&quot;: 0, &quot;noWrap&quot;: false, &quot;opacity&quot;: 1, &quot;subdomains&quot;: &quot;abc&quot;, &quot;tms&quot;: false}
                ).addTo(map_e013d3d35704f37c274470336957f0ae);
        
    
                L.control.fullscreen(
                    {&quot;forceSeparateButton&quot;: false, &quot;position&quot;: &quot;topleft&quot;, &quot;title&quot;: &quot;Full Screen&quot;, &quot;titleCancel&quot;: &quot;Exit Full Screen&quot;}
                ).addTo(map_e013d3d35704f37c274470336957f0ae);
        
    
                L.Control.TimeDimensionCustom = L.Control.TimeDimension.extend({
                    _getDisplayDateFormat: function(date){
                        var newdate = new moment(date);
                        console.log(newdate)
                        return newdate.format(&quot;YYYY-MM-DD HH:mm:ss&quot;);
                    }
                });
                map_e013d3d35704f37c274470336957f0ae.timeDimension = L.timeDimension(
                    {
                        period: &quot;PT1S&quot;,
                    }
                );
                var timeDimensionControl = new L.Control.TimeDimensionCustom(
                    {&quot;autoPlay&quot;: true, &quot;loopButton&quot;: false, &quot;maxSpeed&quot;: 10, &quot;minSpeed&quot;: 0.1, &quot;playerOptions&quot;: {&quot;loop&quot;: true, &quot;startOver&quot;: true, &quot;transitionTime&quot;: 200}, &quot;position&quot;: &quot;bottomleft&quot;, &quot;speedSlider&quot;: true, &quot;timeSliderDragUpdate&quot;: false}
                );
                map_e013d3d35704f37c274470336957f0ae.addControl(this.timeDimensionControl);

                var geoJsonLayer = L.geoJson({&quot;type&quot;: &quot;FeatureCollection&quot;, &quot;features&quot;: [{&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.1779945&lt;dd&gt;Longitude: 48.539912&lt;dd&gt;Azimuth: 131.60429\u00b0&lt;dd&gt;Altitude: 46.123523\u00b0&lt;dd&gt;Slant Range: 739.01812km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884], [2.2595164556765237, 48.566613730139196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.2595165&lt;dd&gt;Longitude: 48.566614&lt;dd&gt;Azimuth: 130.83414\u00b0&lt;dd&gt;Altitude: 45.983702\u00b0&lt;dd&gt;Slant Range: 740.52552km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2595164556765237, 48.566613730139196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884], [2.2595164556765237, 48.566613730139196], [2.3411284577323404, 48.593251621763244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.3411285&lt;dd&gt;Longitude: 48.593252&lt;dd&gt;Azimuth: 130.07114\u00b0&lt;dd&gt;Altitude: 45.838922\u00b0&lt;dd&gt;Slant Range: 742.09609km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3411284577323404, 48.593251621763244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884], [2.2595164556765237, 48.566613730139196], [2.3411284577323404, 48.593251621763244], [2.422830467421055, 48.6198255080418]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.4228305&lt;dd&gt;Longitude: 48.619826&lt;dd&gt;Azimuth: 129.31546\u00b0&lt;dd&gt;Altitude: 45.689324\u00b0&lt;dd&gt;Slant Range: 743.72941km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.422830467421055, 48.6198255080418]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884], [2.2595164556765237, 48.566613730139196], [2.3411284577323404, 48.593251621763244], [2.422830467421055, 48.6198255080418], [2.504622446579218, 48.64633526325161]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.5046224&lt;dd&gt;Longitude: 48.646335&lt;dd&gt;Azimuth: 128.56727\u00b0&lt;dd&gt;Altitude: 45.535049\u00b0&lt;dd&gt;Slant Range: 745.42508km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.504622446579218, 48.64633526325161]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884], [2.2595164556765237, 48.566613730139196], [2.3411284577323404, 48.593251621763244], [2.422830467421055, 48.6198255080418], [2.504622446579218, 48.64633526325161], [2.586504355784846, 48.672780761656504]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.5865044&lt;dd&gt;Longitude: 48.672781&lt;dd&gt;Azimuth: 127.8267\u00b0&lt;dd&gt;Altitude: 45.37624\u00b0&lt;dd&gt;Slant Range: 747.18267km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.586504355784846, 48.672780761656504]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.177994498147302, 48.539911958875884], [2.2595164556765237, 48.566613730139196], [2.3411284577323404, 48.593251621763244], [2.422830467421055, 48.6198255080418], [2.504622446579218, 48.64633526325161], [2.586504355784846, 48.672780761656504], [2.6684761543304276, 48.69916187750608]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.6684762&lt;dd&gt;Longitude: 48.699162&lt;dd&gt;Azimuth: 127.09389\u00b0&lt;dd&gt;Altitude: 45.213043\u00b0&lt;dd&gt;Slant Range: 749.00174km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.6684761543304276, 48.69916187750608]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2595164556765237, 48.566613730139196], [2.3411284577323404, 48.593251621763244], [2.422830467421055, 48.6198255080418], [2.504622446579218, 48.64633526325161], [2.586504355784846, 48.672780761656504], [2.6684761543304276, 48.69916187750608], [2.750537800245922, 48.72547848504113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.7505378&lt;dd&gt;Longitude: 48.725478&lt;dd&gt;Azimuth: 126.36895\u00b0&lt;dd&gt;Altitude: 45.045602\u00b0&lt;dd&gt;Slant Range: 750.88184km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.750537800245922, 48.72547848504113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3411284577323404, 48.593251621763244], [2.422830467421055, 48.6198255080418], [2.504622446579218, 48.64633526325161], [2.586504355784846, 48.672780761656504], [2.6684761543304276, 48.69916187750608], [2.750537800245922, 48.72547848504113], [2.83268925025543, 48.75173045849143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.8326893&lt;dd&gt;Longitude: 48.75173&lt;dd&gt;Azimuth: 125.65198\u00b0&lt;dd&gt;Altitude: 44.874065\u00b0&lt;dd&gt;Slant Range: 752.82251km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.83268925025543, 48.75173045849143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.422830467421055, 48.6198255080418], [2.504622446579218, 48.64633526325161], [2.586504355784846, 48.672780761656504], [2.6684761543304276, 48.69916187750608], [2.750537800245922, 48.72547848504113], [2.83268925025543, 48.75173045849143], [2.9149304598169374, 48.777917672082516]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.9149305&lt;dd&gt;Longitude: 48.777918&lt;dd&gt;Azimuth: 124.94309\u00b0&lt;dd&gt;Altitude: 44.698577\u00b0&lt;dd&gt;Slant Range: 754.82328km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9149304598169374, 48.777917672082516]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.504622446579218, 48.64633526325161], [2.586504355784846, 48.672780761656504], [2.6684761543304276, 48.69916187750608], [2.750537800245922, 48.72547848504113], [2.83268925025543, 48.75173045849143], [2.9149304598169374, 48.777917672082516], [2.9972613830719608, 48.804040000033126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 2.9972614&lt;dd&gt;Longitude: 48.80404&lt;dd&gt;Azimuth: 124.24233\u00b0&lt;dd&gt;Altitude: 44.519287\u00b0&lt;dd&gt;Slant Range: 756.88368km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9972613830719608, 48.804040000033126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.586504355784846, 48.672780761656504], [2.6684761543304276, 48.69916187750608], [2.750537800245922, 48.72547848504113], [2.83268925025543, 48.75173045849143], [2.9149304598169374, 48.777917672082516], [2.9972613830719608, 48.804040000033126], [3.07968197287875, 48.83009731656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.079682&lt;dd&gt;Longitude: 48.830097&lt;dd&gt;Azimuth: 123.5498\u00b0&lt;dd&gt;Altitude: 44.336339\u00b0&lt;dd&gt;Slant Range: 759.00321km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.07968197287875, 48.83009731656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.6684761543304276, 48.69916187750608], [2.750537800245922, 48.72547848504113], [2.83268925025543, 48.75173045849143], [2.9149304598169374, 48.777917672082516], [2.9972613830719608, 48.804040000033126], [3.07968197287875, 48.83009731656], [3.16219218078069, 48.85608949587875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.1621922&lt;dd&gt;Longitude: 48.856089&lt;dd&gt;Azimuth: 122.86554\u00b0&lt;dd&gt;Altitude: 44.14988\u00b0&lt;dd&gt;Slant Range: 761.18139km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.16219218078069, 48.85608949587875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.750537800245922, 48.72547848504113], [2.83268925025543, 48.75173045849143], [2.9149304598169374, 48.777917672082516], [2.9972613830719608, 48.804040000033126], [3.07968197287875, 48.83009731656], [3.16219218078069, 48.85608949587875], [3.244791957010853, 48.88201641220617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.244792&lt;dd&gt;Longitude: 48.882016&lt;dd&gt;Azimuth: 122.18959\u00b0&lt;dd&gt;Altitude: 43.960057\u00b0&lt;dd&gt;Slant Range: 763.41769km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.244791957010853, 48.88201641220617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.83268925025543, 48.75173045849143], [2.9149304598169374, 48.777917672082516], [2.9972613830719608, 48.804040000033126], [3.07968197287875, 48.83009731656], [3.16219218078069, 48.85608949587875], [3.244791957010853, 48.88201641220617], [3.3274812504903704, 48.90787793976106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.3274813&lt;dd&gt;Longitude: 48.907878&lt;dd&gt;Azimuth: 121.522\u00b0&lt;dd&gt;Altitude: 43.767012\u00b0&lt;dd&gt;Slant Range: 765.71163km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3274812504903704, 48.90787793976106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9149304598169374, 48.777917672082516], [2.9972613830719608, 48.804040000033126], [3.07968197287875, 48.83009731656], [3.16219218078069, 48.85608949587875], [3.244791957010853, 48.88201641220617], [3.3274812504903704, 48.90787793976106], [3.410260008817288, 48.933673952769226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.41026&lt;dd&gt;Longitude: 48.933674&lt;dd&gt;Azimuth: 120.86279\u00b0&lt;dd&gt;Altitude: 43.57089\u00b0&lt;dd&gt;Slant Range: 768.06266km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.410260008817288, 48.933673952769226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9972613830719608, 48.804040000033126], [3.07968197287875, 48.83009731656], [3.16219218078069, 48.85608949587875], [3.244791957010853, 48.88201641220617], [3.3274812504903704, 48.90787793976106], [3.410260008817288, 48.933673952769226], [3.493128178261351, 48.95940432546102]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.4931282&lt;dd&gt;Longitude: 48.959404&lt;dd&gt;Azimuth: 120.21198\u00b0&lt;dd&gt;Altitude: 43.371831\u00b0&lt;dd&gt;Slant Range: 770.47028km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.493128178261351, 48.95940432546102]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.07968197287875, 48.83009731656], [3.16219218078069, 48.85608949587875], [3.244791957010853, 48.88201641220617], [3.3274812504903704, 48.90787793976106], [3.410260008817288, 48.933673952769226], [3.493128178261351, 48.95940432546102], [3.5760857037584812, 48.98506893207674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.5760857&lt;dd&gt;Longitude: 48.985069&lt;dd&gt;Azimuth: 119.56957\u00b0&lt;dd&gt;Altitude: 43.169977\u00b0&lt;dd&gt;Slant Range: 772.93394km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5760857037584812, 48.98506893207674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.16219218078069, 48.85608949587875], [3.244791957010853, 48.88201641220617], [3.3274812504903704, 48.90787793976106], [3.410260008817288, 48.933673952769226], [3.493128178261351, 48.95940432546102], [3.5760857037584812, 48.98506893207674], [3.6591325289153067, 49.01066764686841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.6591325&lt;dd&gt;Longitude: 49.010668&lt;dd&gt;Azimuth: 118.93557\u00b0&lt;dd&gt;Altitude: 42.965466\u00b0&lt;dd&gt;Slant Range: 775.45311km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6591325289153067, 49.01066764686841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.244791957010853, 48.88201641220617], [3.3274812504903704, 48.90787793976106], [3.410260008817288, 48.933673952769226], [3.493128178261351, 48.95940432546102], [3.5760857037584812, 48.98506893207674], [3.6591325289153067, 49.01066764686841], [3.742268595987687, 49.0362003441]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.7422686&lt;dd&gt;Longitude: 49.0362&lt;dd&gt;Azimuth: 118.30995\u00b0&lt;dd&gt;Altitude: 42.758434\u00b0&lt;dd&gt;Slant Range: 778.02725km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.742268595987687, 49.0362003441]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.3274812504903704, 48.90787793976106], [3.410260008817288, 48.933673952769226], [3.493128178261351, 48.95940432546102], [3.5760857037584812, 48.98506893207674], [3.6591325289153067, 49.01066764686841], [3.742268595987687, 49.0362003441], [3.8254938458888033, 49.06166689805043]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.8254938&lt;dd&gt;Longitude: 49.061667&lt;dd&gt;Azimuth: 117.69271\u00b0&lt;dd&gt;Altitude: 42.549015\u00b0&lt;dd&gt;Slant Range: 780.65582km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8254938458888033, 49.06166689805043]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.410260008817288, 48.933673952769226], [3.493128178261351, 48.95940432546102], [3.5760857037584812, 48.98506893207674], [3.6591325289153067, 49.01066764686841], [3.742268595987687, 49.0362003441], [3.8254938458888033, 49.06166689805043], [3.908808218178805, 49.08706718301738]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.9088082&lt;dd&gt;Longitude: 49.087067&lt;dd&gt;Azimuth: 117.08382\u00b0&lt;dd&gt;Altitude: 42.337343\u00b0&lt;dd&gt;Slant Range: 783.33825km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.908808218178805, 49.08706718301738]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.493128178261351, 48.95940432546102], [3.5760857037584812, 48.98506893207674], [3.6591325289153067, 49.01066764686841], [3.742268595987687, 49.0362003441], [3.8254938458888033, 49.06166689805043], [3.908808218178805, 49.08706718301738], [3.992211651063203, 49.112401073316036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 3.9922117&lt;dd&gt;Longitude: 49.112401&lt;dd&gt;Azimuth: 116.48325\u00b0&lt;dd&gt;Altitude: 42.123547\u00b0&lt;dd&gt;Slant Range: 786.07401km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.992211651063203, 49.112401073316036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5760857037584812, 48.98506893207674], [3.6591325289153067, 49.01066764686841], [3.742268595987687, 49.0362003441], [3.8254938458888033, 49.06166689805043], [3.908808218178805, 49.08706718301738], [3.992211651063203, 49.112401073316036], [4.07570408137748, 49.1376684432828]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.0757041&lt;dd&gt;Longitude: 49.137668&lt;dd&gt;Azimuth: 115.89096\u00b0&lt;dd&gt;Altitude: 41.907753\u00b0&lt;dd&gt;Slant Range: 788.86252km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.07570408137748, 49.1376684432828]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6591325289153067, 49.01066764686841], [3.742268595987687, 49.0362003441], [3.8254938458888033, 49.06166689805043], [3.908808218178805, 49.08706718301738], [3.992211651063203, 49.112401073316036], [4.07570408137748, 49.1376684432828], [4.159285444593676, 49.162869167278366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.1592854&lt;dd&gt;Longitude: 49.162869&lt;dd&gt;Azimuth: 115.3069\u00b0&lt;dd&gt;Altitude: 41.690088\u00b0&lt;dd&gt;Slant Range: 791.70322km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.159285444593676, 49.162869167278366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.742268595987687, 49.0362003441], [3.8254938458888033, 49.06166689805043], [3.908808218178805, 49.08706718301738], [3.992211651063203, 49.112401073316036], [4.07570408137748, 49.1376684432828], [4.159285444593676, 49.162869167278366], [4.242955674811489, 49.188003119688034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.2429557&lt;dd&gt;Longitude: 49.188003&lt;dd&gt;Azimuth: 114.73103\u00b0&lt;dd&gt;Altitude: 41.470674\u00b0&lt;dd&gt;Slant Range: 794.59557km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.242955674811489, 49.188003119688034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8254938458888033, 49.06166689805043], [3.908808218178805, 49.08706718301738], [3.992211651063203, 49.112401073316036], [4.07570408137748, 49.1376684432828], [4.159285444593676, 49.162869167278366], [4.242955674811489, 49.188003119688034], [4.326714704756104, 49.21307017492581]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.3267147&lt;dd&gt;Longitude: 49.21307&lt;dd&gt;Azimuth: 114.16329\u00b0&lt;dd&gt;Altitude: 41.249629\u00b0&lt;dd&gt;Slant Range: 797.53898km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.326714704756104, 49.21307017492581]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.908808218178805, 49.08706718301738], [3.992211651063203, 49.112401073316036], [4.07570408137748, 49.1376684432828], [4.159285444593676, 49.162869167278366], [4.242955674811489, 49.188003119688034], [4.326714704756104, 49.21307017492581], [4.410562465758279, 49.23807020743338]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.4105625&lt;dd&gt;Longitude: 49.23807&lt;dd&gt;Azimuth: 113.60361\u00b0&lt;dd&gt;Altitude: 41.027071\u00b0&lt;dd&gt;Slant Range: 800.5329km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.410562465758279, 49.23807020743338]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.992211651063203, 49.112401073316036], [4.07570408137748, 49.1376684432828], [4.159285444593676, 49.162869167278366], [4.242955674811489, 49.188003119688034], [4.326714704756104, 49.21307017492581], [4.410562465758279, 49.23807020743338], [4.4944988877777705, 49.263003091685995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.4944989&lt;dd&gt;Longitude: 49.263003&lt;dd&gt;Azimuth: 113.05194\u00b0&lt;dd&gt;Altitude: 40.803113\u00b0&lt;dd&gt;Slant Range: 803.57675km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.4944988877777705, 49.263003091685995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.07570408137748, 49.1376684432828], [4.159285444593676, 49.162869167278366], [4.242955674811489, 49.188003119688034], [4.326714704756104, 49.21307017492581], [4.410562465758279, 49.23807020743338], [4.4944988877777705, 49.263003091685995], [4.578523899366803, 49.28786870219229]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.5785239&lt;dd&gt;Longitude: 49.287869&lt;dd&gt;Azimuth: 112.50821\u00b0&lt;dd&gt;Altitude: 40.577867\u00b0&lt;dd&gt;Slant Range: 806.66998km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.578523899366803, 49.28786870219229]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.159285444593676, 49.162869167278366], [4.242955674811489, 49.188003119688034], [4.326714704756104, 49.21307017492581], [4.410562465758279, 49.23807020743338], [4.4944988877777705, 49.263003091685995], [4.578523899366803, 49.28786870219229], [4.662637427687798, 49.31266691349628]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1109&lt;dd&gt;Latitude: 4.6626374&lt;dd&gt;Longitude: 49.312667&lt;dd&gt;Azimuth: 111.97234\u00b0&lt;dd&gt;Altitude: 40.35144\u00b0&lt;dd&gt;Slant Range: 809.81199km&quot;, &quot;name&quot;: &quot;STARLINK-1109&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.662637427687798, 49.31266691349628]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 1.6501109&lt;dd&gt;Longitude: 52.978279&lt;dd&gt;Azimuth: 58.134912\u00b0&lt;dd&gt;Altitude: 56.089592\u00b0&lt;dd&gt;Slant Range: 654.34516km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745], [1.7494103090431257, 52.971829107334976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 1.7494103&lt;dd&gt;Longitude: 52.971829&lt;dd&gt;Azimuth: 58.774133\u00b0&lt;dd&gt;Altitude: 55.639062\u00b0&lt;dd&gt;Slant Range: 657.45508km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7494103090431257, 52.971829107334976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745], [1.7494103090431257, 52.971829107334976], [1.8486787697211287, 52.965289608522994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 1.8486788&lt;dd&gt;Longitude: 52.96529&lt;dd&gt;Azimuth: 59.392999\u00b0&lt;dd&gt;Altitude: 55.189302\u00b0&lt;dd&gt;Slant Range: 660.62402km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8486787697211287, 52.965289608522994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745], [1.7494103090431257, 52.971829107334976], [1.8486787697211287, 52.965289608522994], [1.947915820550901, 52.95866024086713]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 1.9479158&lt;dd&gt;Longitude: 52.95866&lt;dd&gt;Azimuth: 59.992337\u00b0&lt;dd&gt;Altitude: 54.740542\u00b0&lt;dd&gt;Slant Range: 663.85113km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.947915820550901, 52.95866024086713]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745], [1.7494103090431257, 52.971829107334976], [1.8486787697211287, 52.965289608522994], [1.947915820550901, 52.95866024086713], [2.0471210505659494, 52.95194105312535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.0471211&lt;dd&gt;Longitude: 52.951941&lt;dd&gt;Azimuth: 60.572942\u00b0&lt;dd&gt;Altitude: 54.292997\u00b0&lt;dd&gt;Slant Range: 667.13556km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0471210505659494, 52.95194105312535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745], [1.7494103090431257, 52.971829107334976], [1.8486787697211287, 52.965289608522994], [1.947915820550901, 52.95866024086713], [2.0471210505659494, 52.95194105312535], [2.14629404973321, 52.94513209468042]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.146294&lt;dd&gt;Longitude: 52.945132&lt;dd&gt;Azimuth: 61.135572\u00b0&lt;dd&gt;Altitude: 53.846866\u00b0&lt;dd&gt;Slant Range: 670.47648km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.14629404973321, 52.94513209468042]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6501108503922348, 52.978278689171745], [1.7494103090431257, 52.971829107334976], [1.8486787697211287, 52.965289608522994], [1.947915820550901, 52.95866024086713], [2.0471210505659494, 52.95194105312535], [2.14629404973321, 52.94513209468042], [2.245434408957603, 52.938233415537795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.2454344&lt;dd&gt;Longitude: 52.938233&lt;dd&gt;Azimuth: 61.680953\u00b0&lt;dd&gt;Altitude: 53.402335\u00b0&lt;dd&gt;Slant Range: 673.87302km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.245434408957603, 52.938233415537795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7494103090431257, 52.971829107334976], [1.8486787697211287, 52.965289608522994], [1.947915820550901, 52.95866024086713], [2.0471210505659494, 52.95194105312535], [2.14629404973321, 52.94513209468042], [2.245434408957603, 52.938233415537795], [2.344541720102463, 52.931245066324266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.3445417&lt;dd&gt;Longitude: 52.931245&lt;dd&gt;Azimuth: 62.20978\u00b0&lt;dd&gt;Altitude: 52.959576\u00b0&lt;dd&gt;Slant Range: 677.32436km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.344541720102463, 52.931245066324266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8486787697211287, 52.965289608522994], [1.947915820550901, 52.95866024086713], [2.0471210505659494, 52.95194105312535], [2.14629404973321, 52.94513209468042], [2.245434408957603, 52.938233415537795], [2.344541720102463, 52.931245066324266], [2.443615575977354, 52.92416709828605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.4436156&lt;dd&gt;Longitude: 52.924167&lt;dd&gt;Azimuth: 62.722715\u00b0&lt;dd&gt;Altitude: 52.518749\u00b0&lt;dd&gt;Slant Range: 680.82966km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.443615575977354, 52.92416709828605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.947915820550901, 52.95866024086713], [2.0471210505659494, 52.95194105312535], [2.14629404973321, 52.94513209468042], [2.245434408957603, 52.938233415537795], [2.344541720102463, 52.931245066324266], [2.443615575977354, 52.92416709828605], [2.5426555703821623, 52.916999563286865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.5426556&lt;dd&gt;Longitude: 52.917&lt;dd&gt;Azimuth: 63.220394\u00b0&lt;dd&gt;Altitude: 52.080002\u00b0&lt;dd&gt;Slant Range: 684.38807km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.5426555703821623, 52.916999563286865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0471210505659494, 52.95194105312535], [2.14629404973321, 52.94513209468042], [2.245434408957603, 52.938233415537795], [2.344541720102463, 52.931245066324266], [2.443615575977354, 52.92416709828605], [2.5426555703821623, 52.916999563286865], [2.641661298080762, 52.90974251380634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.6416613&lt;dd&gt;Longitude: 52.909743&lt;dd&gt;Azimuth: 63.703422\u00b0&lt;dd&gt;Altitude: 51.643471\u00b0&lt;dd&gt;Slant Range: 687.99879km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.641661298080762, 52.90974251380634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.14629404973321, 52.94513209468042], [2.245434408957603, 52.938233415537795], [2.344541720102463, 52.931245066324266], [2.443615575977354, 52.92416709828605], [2.5426555703821623, 52.916999563286865], [2.641661298080762, 52.90974251380634], [2.740632354848392, 52.902396002937714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.7406324&lt;dd&gt;Longitude: 52.902396&lt;dd&gt;Azimuth: 64.172377\u00b0&lt;dd&gt;Altitude: 51.209281\u00b0&lt;dd&gt;Slant Range: 691.66097km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.740632354848392, 52.902396002937714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.245434408957603, 52.938233415537795], [2.344541720102463, 52.931245066324266], [2.443615575977354, 52.92416709828605], [2.5426555703821623, 52.916999563286865], [2.641661298080762, 52.90974251380634], [2.740632354848392, 52.902396002937714], [2.839568337455501, 52.89496008438633]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.8395683&lt;dd&gt;Longitude: 52.89496&lt;dd&gt;Azimuth: 64.627812\u00b0&lt;dd&gt;Altitude: 50.777549\u00b0&lt;dd&gt;Slant Range: 695.37382km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.839568337455501, 52.89496008438633]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.344541720102463, 52.931245066324266], [2.443615575977354, 52.92416709828605], [2.5426555703821623, 52.916999563286865], [2.641661298080762, 52.90974251380634], [2.740632354848392, 52.902396002937714], [2.839568337455501, 52.89496008438633], [2.9384688436828337, 52.88743481246786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 2.9384688&lt;dd&gt;Longitude: 52.887435&lt;dd&gt;Azimuth: 65.070255\u00b0&lt;dd&gt;Altitude: 50.348381\u00b0&lt;dd&gt;Slant Range: 699.1365km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9384688436828337, 52.88743481246786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.443615575977354, 52.92416709828605], [2.5426555703821623, 52.916999563286865], [2.641661298080762, 52.90974251380634], [2.740632354848392, 52.902396002937714], [2.839568337455501, 52.89496008438633], [2.9384688436828337, 52.88743481246786], [3.0373334723473593, 52.87982024210605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.0373335&lt;dd&gt;Longitude: 52.87982&lt;dd&gt;Azimuth: 65.500208\u00b0&lt;dd&gt;Altitude: 49.921873\u00b0&lt;dd&gt;Slant Range: 702.94823km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0373334723473593, 52.87982024210605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.5426555703821623, 52.916999563286865], [2.641661298080762, 52.90974251380634], [2.740632354848392, 52.902396002937714], [2.839568337455501, 52.89496008438633], [2.9384688436828337, 52.88743481246786], [3.0373334723473593, 52.87982024210605], [3.1361618232930613, 52.87211642883075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.1361618&lt;dd&gt;Longitude: 52.872116&lt;dd&gt;Azimuth: 65.918154\u00b0&lt;dd&gt;Altitude: 49.498115\u00b0&lt;dd&gt;Slant Range: 706.80819km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.1361618232930613, 52.87211642883075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.641661298080762, 52.90974251380634], [2.740632354848392, 52.902396002937714], [2.839568337455501, 52.89496008438633], [2.9384688436828337, 52.88743481246786], [3.0373334723473593, 52.87982024210605], [3.1361618232930613, 52.87211642883075], [3.2349534974137857, 52.864323428776316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.2349535&lt;dd&gt;Longitude: 52.864323&lt;dd&gt;Azimuth: 66.324551\u00b0&lt;dd&gt;Altitude: 49.077188\u00b0&lt;dd&gt;Slant Range: 710.71561km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.2349534974137857, 52.864323428776316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.740632354848392, 52.902396002937714], [2.839568337455501, 52.89496008438633], [2.9384688436828337, 52.88743481246786], [3.0373334723473593, 52.87982024210605], [3.1361618232930613, 52.87211642883075], [3.2349534974137857, 52.864323428776316], [3.33370809665571, 52.85644129867942]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.3337081&lt;dd&gt;Longitude: 52.856441&lt;dd&gt;Azimuth: 66.719838\u00b0&lt;dd&gt;Altitude: 48.659165\u00b0&lt;dd&gt;Slant Range: 714.6697km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.33370809665571, 52.85644129867942]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.839568337455501, 52.89496008438633], [2.9384688436828337, 52.88743481246786], [3.0373334723473593, 52.87982024210605], [3.1361618232930613, 52.87211642883075], [3.2349534974137857, 52.864323428776316], [3.33370809665571, 52.85644129867942], [3.4324252240336777, 52.84847009587722]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.4324252&lt;dd&gt;Longitude: 52.84847&lt;dd&gt;Azimuth: 67.104433\u00b0&lt;dd&gt;Altitude: 48.244111\u00b0&lt;dd&gt;Slant Range: 718.66968km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4324252240336777, 52.84847009587722]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9384688436828337, 52.88743481246786], [3.0373334723473593, 52.87982024210605], [3.1361618232930613, 52.87211642883075], [3.2349534974137857, 52.864323428776316], [3.33370809665571, 52.85644129867942], [3.4324252240336777, 52.84847009587722], [3.5311044836335146, 52.840409878305266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.5311045&lt;dd&gt;Longitude: 52.84041&lt;dd&gt;Azimuth: 67.478736\u00b0&lt;dd&gt;Altitude: 47.832088\u00b0&lt;dd&gt;Slant Range: 722.71479km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5311044836335146, 52.840409878305266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0373334723473593, 52.87982024210605], [3.1361618232930613, 52.87211642883075], [3.2349534974137857, 52.864323428776316], [3.33370809665571, 52.85644129867942], [3.4324252240336777, 52.84847009587722], [3.5311044836335146, 52.840409878305266], [3.6297454806364797, 52.8322607044951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.6297455&lt;dd&gt;Longitude: 52.832261&lt;dd&gt;Azimuth: 67.843131\u00b0&lt;dd&gt;Altitude: 47.423146\u00b0&lt;dd&gt;Slant Range: 726.80427km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6297454806364797, 52.8322607044951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.1361618232930613, 52.87211642883075], [3.2349534974137857, 52.864323428776316], [3.33370809665571, 52.85644129867942], [3.4324252240336777, 52.84847009587722], [3.5311044836335146, 52.840409878305266], [3.6297454806364797, 52.8322607044951], [3.7283478213097503, 52.82402263357281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.7283478&lt;dd&gt;Longitude: 52.824023&lt;dd&gt;Azimuth: 68.19798\u00b0&lt;dd&gt;Altitude: 47.017335\u00b0&lt;dd&gt;Slant Range: 730.93737km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.7283478213097503, 52.82402263357281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.2349534974137857, 52.864323428776316], [3.33370809665571, 52.85644129867942], [3.4324252240336777, 52.84847009587722], [3.5311044836335146, 52.840409878305266], [3.6297454806364797, 52.8322607044951], [3.7283478213097503, 52.82402263357281], [3.8269111130336975, 52.815695725256894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.8269111&lt;dd&gt;Longitude: 52.815696&lt;dd&gt;Azimuth: 68.543635\u00b0&lt;dd&gt;Altitude: 46.614696\u00b0&lt;dd&gt;Slant Range: 735.11335km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8269111130336975, 52.815695725256894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.33370809665571, 52.85644129867942], [3.4324252240336777, 52.84847009587722], [3.5311044836335146, 52.840409878305266], [3.6297454806364797, 52.8322607044951], [3.7283478213097503, 52.82402263357281], [3.8269111130336975, 52.815695725256894], [3.9254349642981974, 52.80728003985588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 3.925435&lt;dd&gt;Longitude: 52.80728&lt;dd&gt;Azimuth: 68.880427\u00b0&lt;dd&gt;Altitude: 46.215265\u00b0&lt;dd&gt;Slant Range: 739.33149km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9254349642981974, 52.80728003985588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4324252240336777, 52.84847009587722], [3.5311044836335146, 52.840409878305266], [3.6297454806364797, 52.8322607044951], [3.7283478213097503, 52.82402263357281], [3.8269111130336975, 52.815695725256894], [3.9254349642981974, 52.80728003985588], [4.023918984721205, 52.798775638266214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.023919&lt;dd&gt;Longitude: 52.798776&lt;dd&gt;Azimuth: 69.208676\u00b0&lt;dd&gt;Altitude: 45.819073\u00b0&lt;dd&gt;Slant Range: 743.59105km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.023918984721205, 52.798775638266214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5311044836335146, 52.840409878305266], [3.6297454806364797, 52.8322607044951], [3.7283478213097503, 52.82402263357281], [3.8269111130336975, 52.815695725256894], [3.9254349642981974, 52.80728003985588], [4.023918984721205, 52.798775638266214], [4.122362785052495, 52.790182581970775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.1223628&lt;dd&gt;Longitude: 52.790183&lt;dd&gt;Azimuth: 69.528686\u00b0&lt;dd&gt;Altitude: 45.426148\u00b0&lt;dd&gt;Slant Range: 747.89132km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.122362785052495, 52.790182581970775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6297454806364797, 52.8322607044951], [3.7283478213097503, 52.82402263357281], [3.8269111130336975, 52.815695725256894], [3.9254349642981974, 52.80728003985588], [4.023918984721205, 52.798775638266214], [4.122362785052495, 52.790182581970775], [4.220765977192693, 52.78150093303567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.220766&lt;dd&gt;Longitude: 52.781501&lt;dd&gt;Azimuth: 69.840749\u00b0&lt;dd&gt;Altitude: 45.036513\u00b0&lt;dd&gt;Slant Range: 752.23161km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.220765977192693, 52.78150093303567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.7283478213097503, 52.82402263357281], [3.8269111130336975, 52.815695725256894], [3.9254349642981974, 52.80728003985588], [4.023918984721205, 52.798775638266214], [4.122362785052495, 52.790182581970775], [4.220765977192693, 52.78150093303567], [4.319128174184602, 52.772730754109325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.3191282&lt;dd&gt;Longitude: 52.772731&lt;dd&gt;Azimuth: 70.145143\u00b0&lt;dd&gt;Altitude: 44.650185\u00b0&lt;dd&gt;Slant Range: 756.61121km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.319128174184602, 52.772730754109325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8269111130336975, 52.815695725256894], [3.9254349642981974, 52.80728003985588], [4.023918984721205, 52.798775638266214], [4.122362785052495, 52.790182581970775], [4.220765977192693, 52.78150093303567], [4.319128174184602, 52.772730754109325], [4.417448990248974, 52.76387210841926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.417449&lt;dd&gt;Longitude: 52.763872&lt;dd&gt;Azimuth: 70.442137\u00b0&lt;dd&gt;Altitude: 44.267179\u00b0&lt;dd&gt;Slant Range: 761.02946km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.417448990248974, 52.76387210841926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9254349642981974, 52.80728003985588], [4.023918984721205, 52.798775638266214], [4.122362785052495, 52.790182581970775], [4.220765977192693, 52.78150093303567], [4.319128174184602, 52.772730754109325], [4.417448990248974, 52.76387210841926], [4.515728040763416, 52.754925059770585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.515728&lt;dd&gt;Longitude: 52.754925&lt;dd&gt;Azimuth: 70.731984\u00b0&lt;dd&gt;Altitude: 43.887508\u00b0&lt;dd&gt;Slant Range: 765.48566km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.515728040763416, 52.754925059770585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.023918984721205, 52.798775638266214], [4.122362785052495, 52.790182581970775], [4.220765977192693, 52.78150093303567], [4.319128174184602, 52.772730754109325], [4.417448990248974, 52.76387210841926], [4.515728040763416, 52.754925059770585], [4.613964942297458, 52.745889672543555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.6139649&lt;dd&gt;Longitude: 52.74589&lt;dd&gt;Azimuth: 71.01493\u00b0&lt;dd&gt;Altitude: 43.511177\u00b0&lt;dd&gt;Slant Range: 769.97916km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.613964942297458, 52.745889672543555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.122362785052495, 52.790182581970775], [4.220765977192693, 52.78150093303567], [4.319128174184602, 52.772730754109325], [4.417448990248974, 52.76387210841926], [4.515728040763416, 52.754925059770585], [4.613964942297458, 52.745889672543555], [4.712159312602801, 52.73676601169144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.7121593&lt;dd&gt;Longitude: 52.736766&lt;dd&gt;Azimuth: 71.291208\u00b0&lt;dd&gt;Altitude: 43.138193\u00b0&lt;dd&gt;Slant Range: 774.50931km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.712159312602801, 52.73676601169144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.220765977192693, 52.78150093303567], [4.319128174184602, 52.772730754109325], [4.417448990248974, 52.76387210841926], [4.515728040763416, 52.754925059770585], [4.613964942297458, 52.745889672543555], [4.712159312602801, 52.73676601169144], [4.81031077064243, 52.72755414273811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.8103108&lt;dd&gt;Longitude: 52.727554&lt;dd&gt;Azimuth: 71.561043\u00b0&lt;dd&gt;Altitude: 42.768556\u00b0&lt;dd&gt;Slant Range: 779.07545km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.81031077064243, 52.72755414273811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.319128174184602, 52.772730754109325], [4.417448990248974, 52.76387210841926], [4.515728040763416, 52.754925059770585], [4.613964942297458, 52.745889672543555], [4.712159312602801, 52.73676601169144], [4.81031077064243, 52.72755414273811], [4.908418936573565, 52.71825413177618]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 4.9084189&lt;dd&gt;Longitude: 52.718254&lt;dd&gt;Azimuth: 71.82465\u00b0&lt;dd&gt;Altitude: 42.402266\u00b0&lt;dd&gt;Slant Range: 783.67696km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.908418936573565, 52.71825413177618]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.417448990248974, 52.76387210841926], [4.515728040763416, 52.754925059770585], [4.613964942297458, 52.745889672543555], [4.712159312602801, 52.73676601169144], [4.81031077064243, 52.72755414273811], [4.908418936573565, 52.71825413177618], [5.006483431784196, 52.708866045464056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 5.0064834&lt;dd&gt;Longitude: 52.708866&lt;dd&gt;Azimuth: 72.082235\u00b0&lt;dd&gt;Altitude: 42.039319\u00b0&lt;dd&gt;Slant Range: 788.31321km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.006483431784196, 52.708866045464056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.515728040763416, 52.754925059770585], [4.613964942297458, 52.745889672543555], [4.712159312602801, 52.73676601169144], [4.81031077064243, 52.72755414273811], [4.908418936573565, 52.71825413177618], [5.006483431784196, 52.708866045464056], [5.104503878875507, 52.699389951024806]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 5.1045039&lt;dd&gt;Longitude: 52.69939&lt;dd&gt;Azimuth: 72.333995\u00b0&lt;dd&gt;Altitude: 41.67971\u00b0&lt;dd&gt;Slant Range: 792.98358km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.104503878875507, 52.699389951024806]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.613964942297458, 52.745889672543555], [4.712159312602801, 52.73676601169144], [4.81031077064243, 52.72755414273811], [4.908418936573565, 52.71825413177618], [5.006483431784196, 52.708866045464056], [5.104503878875507, 52.699389951024806], [5.202479901694568, 52.689825916242654]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1120&lt;dd&gt;Latitude: 5.2024799&lt;dd&gt;Longitude: 52.689826&lt;dd&gt;Azimuth: 72.580121\u00b0&lt;dd&gt;Altitude: 41.323429\u00b0&lt;dd&gt;Slant Range: 797.68748km&quot;, &quot;name&quot;: &quot;STARLINK-1120&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.202479901694568, 52.689825916242654]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.9442712&lt;dd&gt;Longitude: 52.150223&lt;dd&gt;Azimuth: 281.51505\u00b0&lt;dd&gt;Altitude: 43.66193\u00b0&lt;dd&gt;Slant Range: 768.14244km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335], [-9.848815119942019, 52.13656743897019]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.8488151&lt;dd&gt;Longitude: 52.136567&lt;dd&gt;Azimuth: 281.41812\u00b0&lt;dd&gt;Altitude: 44.066453\u00b0&lt;dd&gt;Slant Range: 763.34321km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.848815119942019, 52.13656743897019]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335], [-9.848815119942019, 52.13656743897019], [-9.753420078456285, 52.12282745611779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.7534201&lt;dd&gt;Longitude: 52.122827&lt;dd&gt;Azimuth: 281.31853\u00b0&lt;dd&gt;Altitude: 44.475602\u00b0&lt;dd&gt;Slant Range: 758.57794km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.753420078456285, 52.12282745611779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335], [-9.848815119942019, 52.13656743897019], [-9.753420078456285, 52.12282745611779], [-9.65808638419701, 52.10900354069461]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.6580864&lt;dd&gt;Longitude: 52.109004&lt;dd&gt;Azimuth: 281.21616\u00b0&lt;dd&gt;Altitude: 44.889426\u00b0&lt;dd&gt;Slant Range: 753.84728km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.65808638419701, 52.10900354069461]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335], [-9.848815119942019, 52.13656743897019], [-9.753420078456285, 52.12282745611779], [-9.65808638419701, 52.10900354069461], [-9.562814341542387, 52.09509578559048]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.5628143&lt;dd&gt;Longitude: 52.095096&lt;dd&gt;Azimuth: 281.11089\u00b0&lt;dd&gt;Altitude: 45.307974\u00b0&lt;dd&gt;Slant Range: 749.1519km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.562814341542387, 52.09509578559048]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335], [-9.848815119942019, 52.13656743897019], [-9.753420078456285, 52.12282745611779], [-9.65808638419701, 52.10900354069461], [-9.562814341542387, 52.09509578559048], [-9.46760425328893, 52.081104284122965]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.4676043&lt;dd&gt;Longitude: 52.081104&lt;dd&gt;Azimuth: 281.00262\u00b0&lt;dd&gt;Altitude: 45.731293\u00b0&lt;dd&gt;Slant Range: 744.49246km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.46760425328893, 52.081104284122965]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.944271202726123, 52.150223396792335], [-9.848815119942019, 52.13656743897019], [-9.753420078456285, 52.12282745611779], [-9.65808638419701, 52.10900354069461], [-9.562814341542387, 52.09509578559048], [-9.46760425328893, 52.081104284122965], [-9.372456420677, 52.06702913003428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.3724564&lt;dd&gt;Longitude: 52.067029&lt;dd&gt;Azimuth: 280.89121\u00b0&lt;dd&gt;Altitude: 46.159428\u00b0&lt;dd&gt;Slant Range: 739.86966km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.372456420677, 52.06702913003428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.848815119942019, 52.13656743897019], [-9.753420078456285, 52.12282745611779], [-9.65808638419701, 52.10900354069461], [-9.562814341542387, 52.09509578559048], [-9.46760425328893, 52.081104284122965], [-9.372456420677, 52.06702913003428], [-9.277371143356982, 52.05287041748847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.2773711&lt;dd&gt;Longitude: 52.05287&lt;dd&gt;Azimuth: 280.77653\u00b0&lt;dd&gt;Altitude: 46.592424\u00b0&lt;dd&gt;Slant Range: 735.28418km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.277371143356982, 52.05287041748847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.753420078456285, 52.12282745611779], [-9.65808638419701, 52.10900354069461], [-9.562814341542387, 52.09509578559048], [-9.46760425328893, 52.081104284122965], [-9.372456420677, 52.06702913003428], [-9.277371143356982, 52.05287041748847], [-9.18234871941054, 52.03862824106892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.1823487&lt;dd&gt;Longitude: 52.038628&lt;dd&gt;Azimuth: 280.65844\u00b0&lt;dd&gt;Altitude: 47.030326\u00b0&lt;dd&gt;Slant Range: 730.73673km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.18234871941054, 52.03862824106892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.65808638419701, 52.10900354069461], [-9.562814341542387, 52.09509578559048], [-9.46760425328893, 52.081104284122965], [-9.372456420677, 52.06702913003428], [-9.277371143356982, 52.05287041748847], [-9.18234871941054, 52.03862824106892], [-9.087389445334702, 52.024302695775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -9.0873894&lt;dd&gt;Longitude: 52.024303&lt;dd&gt;Azimuth: 280.5368\u00b0&lt;dd&gt;Altitude: 47.473177\u00b0&lt;dd&gt;Slant Range: 726.22804km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.087389445334702, 52.024302695775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.562814341542387, 52.09509578559048], [-9.46760425328893, 52.081104284122965], [-9.372456420677, 52.06702913003428], [-9.277371143356982, 52.05287041748847], [-9.18234871941054, 52.03862824106892], [-9.087389445334702, 52.024302695775], [-8.992493616032691, 52.00989387701955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.9924936&lt;dd&gt;Longitude: 52.009894&lt;dd&gt;Azimuth: 280.41143\u00b0&lt;dd&gt;Altitude: 47.921016\u00b0&lt;dd&gt;Slant Range: 721.75884km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.992493616032691, 52.00989387701955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.46760425328893, 52.081104284122965], [-9.372456420677, 52.06702913003428], [-9.277371143356982, 52.05287041748847], [-9.18234871941054, 52.03862824106892], [-9.087389445334702, 52.024302695775], [-8.992493616032691, 52.00989387701955], [-8.89766152482584, 51.99540188062594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.8976615&lt;dd&gt;Longitude: 51.995402&lt;dd&gt;Azimuth: 280.28218\u00b0&lt;dd&gt;Altitude: 48.373883\u00b0&lt;dd&gt;Slant Range: 717.32986km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.89766152482584, 51.99540188062594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.372456420677, 52.06702913003428], [-9.277371143356982, 52.05287041748847], [-9.18234871941054, 52.03862824106892], [-9.087389445334702, 52.024302695775], [-8.992493616032691, 52.00989387701955], [-8.89766152482584, 51.99540188062594], [-8.802893463434604, 51.98082680282502]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.8028935&lt;dd&gt;Longitude: 51.980827&lt;dd&gt;Azimuth: 280.14887\u00b0&lt;dd&gt;Altitude: 48.831816\u00b0&lt;dd&gt;Slant Range: 712.94187km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.802893463434604, 51.98082680282502]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.277371143356982, 52.05287041748847], [-9.18234871941054, 52.03862824106892], [-9.087389445334702, 52.024302695775], [-8.992493616032691, 52.00989387701955], [-8.89766152482584, 51.99540188062594], [-8.802893463434604, 51.98082680282502], [-8.708189721986683, 51.96616874025253]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.7081897&lt;dd&gt;Longitude: 51.966169&lt;dd&gt;Azimuth: 280.01131\u00b0&lt;dd&gt;Altitude: 49.29485\u00b0&lt;dd&gt;Slant Range: 708.59563km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.708189721986683, 51.96616874025253]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.18234871941054, 52.03862824106892], [-9.087389445334702, 52.024302695775], [-8.992493616032691, 52.00989387701955], [-8.89766152482584, 51.99540188062594], [-8.802893463434604, 51.98082680282502], [-8.708189721986683, 51.96616874025253], [-8.613550589006733, 51.95142778994652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.6135506&lt;dd&gt;Longitude: 51.951428&lt;dd&gt;Azimuth: 279.86929\u00b0&lt;dd&gt;Altitude: 49.763018\u00b0&lt;dd&gt;Slant Range: 704.29191km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.613550589006733, 51.95142778994652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.087389445334702, 52.024302695775], [-8.992493616032691, 52.00989387701955], [-8.89766152482584, 51.99540188062594], [-8.802893463434604, 51.98082680282502], [-8.708189721986683, 51.96616874025253], [-8.613550589006733, 51.95142778994652], [-8.518976351414018, 51.9366040493432]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.5189764&lt;dd&gt;Longitude: 51.936604&lt;dd&gt;Azimuth: 279.72262\u00b0&lt;dd&gt;Altitude: 50.236352\u00b0&lt;dd&gt;Slant Range: 700.03152km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.518976351414018, 51.9366040493432]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.992493616032691, 52.00989387701955], [-8.89766152482584, 51.99540188062594], [-8.802893463434604, 51.98082680282502], [-8.708189721986683, 51.96616874025253], [-8.613550589006733, 51.95142778994652], [-8.518976351414018, 51.9366040493432], [-8.424467294521667, 51.9216976162759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.4244673&lt;dd&gt;Longitude: 51.921698&lt;dd&gt;Azimuth: 279.57105\u00b0&lt;dd&gt;Altitude: 50.714879\u00b0&lt;dd&gt;Slant Range: 695.81524km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.424467294521667, 51.9216976162759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.89766152482584, 51.99540188062594], [-8.802893463434604, 51.98082680282502], [-8.708189721986683, 51.96616874025253], [-8.613550589006733, 51.95142778994652], [-8.518976351414018, 51.9366040493432], [-8.424467294521667, 51.9216976162759], [-8.330023702034172, 51.90670858897062]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.3300237&lt;dd&gt;Longitude: 51.906709&lt;dd&gt;Azimuth: 279.41436\u00b0&lt;dd&gt;Altitude: 51.198626\u00b0&lt;dd&gt;Slant Range: 691.64389km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.330023702034172, 51.90670858897062]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.802893463434604, 51.98082680282502], [-8.708189721986683, 51.96616874025253], [-8.613550589006733, 51.95142778994652], [-8.518976351414018, 51.9366040493432], [-8.424467294521667, 51.9216976162759], [-8.330023702034172, 51.90670858897062], [-8.235645856034285, 51.89163706604395]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.2356459&lt;dd&gt;Longitude: 51.891637&lt;dd&gt;Azimuth: 279.25227\u00b0&lt;dd&gt;Altitude: 51.687615\u00b0&lt;dd&gt;Slant Range: 687.51829km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.235645856034285, 51.89163706604395]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.708189721986683, 51.96616874025253], [-8.613550589006733, 51.95142778994652], [-8.518976351414018, 51.9366040493432], [-8.424467294521667, 51.9216976162759], [-8.330023702034172, 51.90670858897062], [-8.235645856034285, 51.89163706604395], [-8.14133403699612, 51.87648314650004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.141334&lt;dd&gt;Longitude: 51.876483&lt;dd&gt;Azimuth: 279.08453\u00b0&lt;dd&gt;Altitude: 52.181866\u00b0&lt;dd&gt;Slant Range: 683.43928km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.14133403699612, 51.87648314650004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.613550589006733, 51.95142778994652], [-8.518976351414018, 51.9366040493432], [-8.424467294521667, 51.9216976162759], [-8.330023702034172, 51.90670858897062], [-8.235645856034285, 51.89163706604395], [-8.14133403699612, 51.87648314650004], [-8.047088523772391, 51.86124692972759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -8.0470885&lt;dd&gt;Longitude: 51.861247&lt;dd&gt;Azimuth: 278.91083\u00b0&lt;dd&gt;Altitude: 52.681394\u00b0&lt;dd&gt;Slant Range: 679.4077km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.047088523772391, 51.86124692972759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.518976351414018, 51.9366040493432], [-8.424467294521667, 51.9216976162759], [-8.330023702034172, 51.90670858897062], [-8.235645856034285, 51.89163706604395], [-8.14133403699612, 51.87648314650004], [-8.047088523772391, 51.86124692972759], [-7.9529095935900145, 51.84592851549689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.9529096&lt;dd&gt;Longitude: 51.845929&lt;dd&gt;Azimuth: 278.73087\u00b0&lt;dd&gt;Altitude: 53.186212\u00b0&lt;dd&gt;Slant Range: 675.42441km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.9529095935900145, 51.84592851549689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.424467294521667, 51.9216976162759], [-8.330023702034172, 51.90670858897062], [-8.235645856034285, 51.89163706604395], [-8.14133403699612, 51.87648314650004], [-8.047088523772391, 51.86124692972759], [-7.9529095935900145, 51.84592851549689], [-7.858797522053519, 51.830528003957575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.8587975&lt;dd&gt;Longitude: 51.830528&lt;dd&gt;Azimuth: 278.5443\u00b0&lt;dd&gt;Altitude: 53.696328\u00b0&lt;dd&gt;Slant Range: 671.49026km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.858797522053519, 51.830528003957575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.330023702034172, 51.90670858897062], [-8.235645856034285, 51.89163706604395], [-8.14133403699612, 51.87648314650004], [-8.047088523772391, 51.86124692972759], [-7.9529095935900145, 51.84592851549689], [-7.858797522053519, 51.830528003957575], [-7.764752583140235, 51.81504549563446]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.7647526&lt;dd&gt;Longitude: 51.815045&lt;dd&gt;Azimuth: 278.35077\u00b0&lt;dd&gt;Altitude: 54.211746\u00b0&lt;dd&gt;Slant Range: 667.60613km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.764752583140235, 51.81504549563446]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.235645856034285, 51.89163706604395], [-8.14133403699612, 51.87648314650004], [-8.047088523772391, 51.86124692972759], [-7.9529095935900145, 51.84592851549689], [-7.858797522053519, 51.830528003957575], [-7.764752583140235, 51.81504549563446], [-7.670775049190628, 51.799481091425996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.670775&lt;dd&gt;Longitude: 51.799481&lt;dd&gt;Azimuth: 278.14989\u00b0&lt;dd&gt;Altitude: 54.732466\u00b0&lt;dd&gt;Slant Range: 663.7729km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.670775049190628, 51.799481091425996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.14133403699612, 51.87648314650004], [-8.047088523772391, 51.86124692972759], [-7.9529095935900145, 51.84592851549689], [-7.858797522053519, 51.830528003957575], [-7.764752583140235, 51.81504549563446], [-7.670775049190628, 51.799481091425996], [-7.576865190923667, 51.78383489260057]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.5768652&lt;dd&gt;Longitude: 51.783835&lt;dd&gt;Azimuth: 277.94125\u00b0&lt;dd&gt;Altitude: 55.258481\u00b0&lt;dd&gt;Slant Range: 659.99147km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.576865190923667, 51.78383489260057]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.047088523772391, 51.86124692972759], [-7.9529095935900145, 51.84592851549689], [-7.858797522053519, 51.830528003957575], [-7.764752583140235, 51.81504549563446], [-7.670775049190628, 51.799481091425996], [-7.576865190923667, 51.78383489260057], [-7.483023277412444, 51.768107000793655]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.4830233&lt;dd&gt;Longitude: 51.768107&lt;dd&gt;Azimuth: 277.72441\u00b0&lt;dd&gt;Altitude: 55.789781\u00b0&lt;dd&gt;Slant Range: 656.26273km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.483023277412444, 51.768107000793655]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.9529095935900145, 51.84592851549689], [-7.858797522053519, 51.830528003957575], [-7.764752583140235, 51.81504549563446], [-7.670775049190628, 51.799481091425996], [-7.576865190923667, 51.78383489260057], [-7.483023277412444, 51.768107000793655], [-7.389249576100618, 51.752297518005165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.3892496&lt;dd&gt;Longitude: 51.752298&lt;dd&gt;Azimuth: 277.49887\u00b0&lt;dd&gt;Altitude: 56.326349\u00b0&lt;dd&gt;Slant Range: 652.5876km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.389249576100618, 51.752297518005165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.858797522053519, 51.830528003957575], [-7.764752583140235, 51.81504549563446], [-7.670775049190628, 51.799481091425996], [-7.576865190923667, 51.78383489260057], [-7.483023277412444, 51.768107000793655], [-7.389249576100618, 51.752297518005165], [-7.295544352782232, 51.73640654659644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.2955444&lt;dd&gt;Longitude: 51.736407&lt;dd&gt;Azimuth: 277.26413\u00b0&lt;dd&gt;Altitude: 56.868162\u00b0&lt;dd&gt;Slant Range: 648.96698km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.295544352782232, 51.73640654659644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.764752583140235, 51.81504549563446], [-7.670775049190628, 51.799481091425996], [-7.576865190923667, 51.78383489260057], [-7.483023277412444, 51.768107000793655], [-7.389249576100618, 51.752297518005165], [-7.295544352782232, 51.73640654659644], [-7.2019078716208265, 51.720434189287126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.2019079&lt;dd&gt;Longitude: 51.720434&lt;dd&gt;Azimuth: 277.01963\u00b0&lt;dd&gt;Altitude: 57.415192\u00b0&lt;dd&gt;Slant Range: 645.4018km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.2019078716208265, 51.720434189287126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.670775049190628, 51.799481091425996], [-7.576865190923667, 51.78383489260057], [-7.483023277412444, 51.768107000793655], [-7.389249576100618, 51.752297518005165], [-7.295544352782232, 51.73640654659644], [-7.2019078716208265, 51.720434189287126], [-7.108340395128441, 51.70438054915279]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.1083404&lt;dd&gt;Longitude: 51.704381&lt;dd&gt;Azimuth: 276.76476\u00b0&lt;dd&gt;Altitude: 57.967401\u00b0&lt;dd&gt;Slant Range: 641.89299km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.108340395128441, 51.70438054915279]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.576865190923667, 51.78383489260057], [-7.483023277412444, 51.768107000793655], [-7.389249576100618, 51.752297518005165], [-7.295544352782232, 51.73640654659644], [-7.2019078716208265, 51.720434189287126], [-7.108340395128441, 51.70438054915279], [-7.014842184175141, 51.68824572962133]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -7.0148422&lt;dd&gt;Longitude: 51.688246&lt;dd&gt;Azimuth: 276.49887\u00b0&lt;dd&gt;Altitude: 58.524745\u00b0&lt;dd&gt;Slant Range: 638.44148km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.014842184175141, 51.68824572962133]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.483023277412444, 51.768107000793655], [-7.389249576100618, 51.752297518005165], [-7.295544352782232, 51.73640654659644], [-7.2019078716208265, 51.720434189287126], [-7.108340395128441, 51.70438054915279], [-7.014842184175141, 51.68824572962133], [-6.921413497979692, 51.67202983447055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.9214135&lt;dd&gt;Longitude: 51.67203&lt;dd&gt;Azimuth: 276.22126\u00b0&lt;dd&gt;Altitude: 59.087174\u00b0&lt;dd&gt;Slant Range: 635.0482km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.921413497979692, 51.67202983447055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.389249576100618, 51.752297518005165], [-7.295544352782232, 51.73640654659644], [-7.2019078716208265, 51.720434189287126], [-7.108340395128441, 51.70438054915279], [-7.014842184175141, 51.68824572962133], [-6.921413497979692, 51.67202983447055], [-6.828054594116213, 51.65573296782499]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.8280546&lt;dd&gt;Longitude: 51.655733&lt;dd&gt;Azimuth: 275.93114\u00b0&lt;dd&gt;Altitude: 59.654625\u00b0&lt;dd&gt;Slant Range: 631.71411km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.828054594116213, 51.65573296782499]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.295544352782232, 51.73640654659644], [-7.2019078716208265, 51.720434189287126], [-7.108340395128441, 51.70438054915279], [-7.014842184175141, 51.68824572962133], [-6.921413497979692, 51.67202983447055], [-6.828054594116213, 51.65573296782499], [-6.73476572850175, 51.6393552341533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.7347657&lt;dd&gt;Longitude: 51.639355&lt;dd&gt;Azimuth: 275.62768\u00b0&lt;dd&gt;Altitude: 60.22703\u00b0&lt;dd&gt;Slant Range: 628.44014km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.73476572850175, 51.6393552341533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.2019078716208265, 51.720434189287126], [-7.108340395128441, 51.70438054915279], [-7.014842184175141, 51.68824572962133], [-6.921413497979692, 51.67202983447055], [-6.828054594116213, 51.65573296782499], [-6.73476572850175, 51.6393552341533], [-6.641547155401016, 51.62289673826475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.6415472&lt;dd&gt;Longitude: 51.622897&lt;dd&gt;Azimuth: 275.30998\u00b0&lt;dd&gt;Altitude: 60.804307\u00b0&lt;dd&gt;Slant Range: 625.22725km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.641547155401016, 51.62289673826475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.108340395128441, 51.70438054915279], [-7.014842184175141, 51.68824572962133], [-6.921413497979692, 51.67202983447055], [-6.828054594116213, 51.65573296782499], [-6.73476572850175, 51.6393552341533], [-6.641547155401016, 51.62289673826475], [-6.5483991274358235, 51.606357585307386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.5483991&lt;dd&gt;Longitude: 51.606358&lt;dd&gt;Azimuth: 274.97703\u00b0&lt;dd&gt;Altitude: 61.386367\u00b0&lt;dd&gt;Slant Range: 622.07638km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.5483991274358235, 51.606357585307386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.014842184175141, 51.68824572962133], [-6.921413497979692, 51.67202983447055], [-6.828054594116213, 51.65573296782499], [-6.73476572850175, 51.6393552341533], [-6.641547155401016, 51.62289673826475], [-6.5483991274358235, 51.606357585307386], [-6.45532189555367, 51.58973788076345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.4553219&lt;dd&gt;Longitude: 51.589738&lt;dd&gt;Azimuth: 274.62775\u00b0&lt;dd&gt;Altitude: 61.973106\u00b0&lt;dd&gt;Slant Range: 618.98849km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.45532189555367, 51.58973788076345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.921413497979692, 51.67202983447055], [-6.828054594116213, 51.65573296782499], [-6.73476572850175, 51.6393552341533], [-6.641547155401016, 51.62289673826475], [-6.5483991274358235, 51.606357585307386], [-6.45532189555367, 51.58973788076345], [-6.362315709060321, 51.57303773044831]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.3623157&lt;dd&gt;Longitude: 51.573038&lt;dd&gt;Azimuth: 274.26094\u00b0&lt;dd&gt;Altitude: 62.564409\u00b0&lt;dd&gt;Slant Range: 615.96452km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.362315709060321, 51.57303773044831]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.828054594116213, 51.65573296782499], [-6.73476572850175, 51.6393552341533], [-6.641547155401016, 51.62289673826475], [-6.5483991274358235, 51.606357585307386], [-6.45532189555367, 51.58973788076345], [-6.362315709060321, 51.57303773044831], [-6.269380815595396, 51.556257240506255]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.2693808&lt;dd&gt;Longitude: 51.556257&lt;dd&gt;Azimuth: 273.8753\u00b0&lt;dd&gt;Altitude: 63.160146\u00b0&lt;dd&gt;Slant Range: 613.00543km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.269380815595396, 51.556257240506255]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.73476572850175, 51.6393552341533], [-6.641547155401016, 51.62289673826475], [-6.5483991274358235, 51.606357585307386], [-6.45532189555367, 51.58973788076345], [-6.362315709060321, 51.57303773044831], [-6.269380815595396, 51.556257240506255], [-6.176517461138869, 51.539396517407944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.1765175&lt;dd&gt;Longitude: 51.539397&lt;dd&gt;Azimuth: 273.4694\u00b0&lt;dd&gt;Altitude: 63.760175\u00b0&lt;dd&gt;Slant Range: 610.11216km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.176517461138869, 51.539396517407944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.641547155401016, 51.62289673826475], [-6.5483991274358235, 51.606357585307386], [-6.45532189555367, 51.58973788076345], [-6.362315709060321, 51.57303773044831], [-6.269380815595396, 51.556257240506255], [-6.176517461138869, 51.539396517407944], [-6.083725890012988, 51.522455667947675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -6.0837259&lt;dd&gt;Longitude: 51.522456&lt;dd&gt;Azimuth: 273.04164\u00b0&lt;dd&gt;Altitude: 64.364333\u00b0&lt;dd&gt;Slant Range: 607.28566km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.083725890012988, 51.522455667947675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.5483991274358235, 51.606357585307386], [-6.45532189555367, 51.58973788076345], [-6.362315709060321, 51.57303773044831], [-6.269380815595396, 51.556257240506255], [-6.176517461138869, 51.539396517407944], [-6.083725890012988, 51.522455667947675], [-5.991006344879444, 51.50543479924026]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.9910063&lt;dd&gt;Longitude: 51.505435&lt;dd&gt;Azimuth: 272.59028\u00b0&lt;dd&gt;Altitude: 64.972444\u00b0&lt;dd&gt;Slant Range: 604.52687km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.991006344879444, 51.50543479924026]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.45532189555367, 51.58973788076345], [-6.362315709060321, 51.57303773044831], [-6.269380815595396, 51.556257240506255], [-6.176517461138869, 51.539396517407944], [-6.083725890012988, 51.522455667947675], [-5.991006344879444, 51.50543479924026], [-5.898359066728663, 51.48833401871811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.8983591&lt;dd&gt;Longitude: 51.488334&lt;dd&gt;Azimuth: 272.11339\u00b0&lt;dd&gt;Altitude: 65.584309\u00b0&lt;dd&gt;Slant Range: 601.83672km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.898359066728663, 51.48833401871811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.362315709060321, 51.57303773044831], [-6.269380815595396, 51.556257240506255], [-6.176517461138869, 51.539396517407944], [-6.083725890012988, 51.522455667947675], [-5.991006344879444, 51.50543479924026], [-5.898359066728663, 51.48833401871811], [-5.805784294898883, 51.47115343412882]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.8057843&lt;dd&gt;Longitude: 51.471153&lt;dd&gt;Azimuth: 271.60883\u00b0&lt;dd&gt;Altitude: 66.199709\u00b0&lt;dd&gt;Slant Range: 599.21614km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.805784294898883, 51.47115343412882]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.269380815595396, 51.556257240506255], [-6.176517461138869, 51.539396517407944], [-6.083725890012988, 51.522455667947675], [-5.991006344879444, 51.50543479924026], [-5.898359066728663, 51.48833401871811], [-5.805784294898883, 51.47115343412882], [-5.713282267051153, 51.453893153530885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.7132823&lt;dd&gt;Longitude: 51.453893&lt;dd&gt;Azimuth: 271.07423\u00b0&lt;dd&gt;Altitude: 66.8184\u00b0&lt;dd&gt;Slant Range: 596.66605km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.713282267051153, 51.453893153530885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.176517461138869, 51.539396517407944], [-6.083725890012988, 51.522455667947675], [-5.991006344879444, 51.50543479924026], [-5.898359066728663, 51.48833401871811], [-5.805784294898883, 51.47115343412882], [-5.713282267051153, 51.453893153530885], [-5.620853219196852, 51.436553285292746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.6208532&lt;dd&gt;Longitude: 51.436553&lt;dd&gt;Azimuth: 270.50693\u00b0&lt;dd&gt;Altitude: 67.440113\u00b0&lt;dd&gt;Slant Range: 594.18736km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.620853219196852, 51.436553285292746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.083725890012988, 51.522455667947675], [-5.991006344879444, 51.50543479924026], [-5.898359066728663, 51.48833401871811], [-5.805784294898883, 51.47115343412882], [-5.713282267051153, 51.453893153530885], [-5.620853219196852, 51.436553285292746], [-5.528497385665662, 51.41913393808833]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.5284974&lt;dd&gt;Longitude: 51.419134&lt;dd&gt;Azimuth: 269.90399\u00b0&lt;dd&gt;Altitude: 68.064548\u00b0&lt;dd&gt;Slant Range: 591.78097km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.528497385665662, 51.41913393808833]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.991006344879444, 51.50543479924026], [-5.898359066728663, 51.48833401871811], [-5.805784294898883, 51.47115343412882], [-5.713282267051153, 51.453893153530885], [-5.620853219196852, 51.436553285292746], [-5.528497385665662, 51.41913393808833], [-5.436214999131111, 51.401635220894555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.436215&lt;dd&gt;Longitude: 51.401635&lt;dd&gt;Azimuth: 269.26211\u00b0&lt;dd&gt;Altitude: 68.691372\u00b0&lt;dd&gt;Slant Range: 589.44777km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.436214999131111, 51.401635220894555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.898359066728663, 51.48833401871811], [-5.805784294898883, 51.47115343412882], [-5.713282267051153, 51.453893153530885], [-5.620853219196852, 51.436553285292746], [-5.528497385665662, 51.41913393808833], [-5.436214999131111, 51.401635220894555], [-5.344006290594673, 51.38405724298896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.3440063&lt;dd&gt;Longitude: 51.384057&lt;dd&gt;Azimuth: 268.57759\u00b0&lt;dd&gt;Altitude: 69.320216\u00b0&lt;dd&gt;Slant Range: 587.18863km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.344006290594673, 51.38405724298896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.805784294898883, 51.47115343412882], [-5.713282267051153, 51.453893153530885], [-5.620853219196852, 51.436553285292746], [-5.528497385665662, 51.41913393808833], [-5.436214999131111, 51.401635220894555], [-5.344006290594673, 51.38405724298896], [-5.251871489395611, 51.366400113945986]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.2518715&lt;dd&gt;Longitude: 51.3664&lt;dd&gt;Azimuth: 267.84628\u00b0&lt;dd&gt;Altitude: 69.950668\u00b0&lt;dd&gt;Slant Range: 585.00441km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.251871489395611, 51.366400113945986]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.713282267051153, 51.453893153530885], [-5.620853219196852, 51.436553285292746], [-5.528497385665662, 51.41913393808833], [-5.436214999131111, 51.401635220894555], [-5.344006290594673, 51.38405724298896], [-5.251871489395611, 51.366400113945986], [-5.159810823196299, 51.34866394363447]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.1598108&lt;dd&gt;Longitude: 51.348664&lt;dd&gt;Azimuth: 267.0635\u00b0&lt;dd&gt;Altitude: 70.582267\u00b0&lt;dd&gt;Slant Range: 582.89597km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.159810823196299, 51.34866394363447]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.620853219196852, 51.436553285292746], [-5.528497385665662, 51.41913393808833], [-5.436214999131111, 51.401635220894555], [-5.344006290594673, 51.38405724298896], [-5.251871489395611, 51.366400113945986], [-5.159810823196299, 51.34866394363447], [-5.067824518003951, 51.330848842215275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -5.0678245&lt;dd&gt;Longitude: 51.330849&lt;dd&gt;Azimuth: 266.22396\u00b0&lt;dd&gt;Altitude: 71.214497\u00b0&lt;dd&gt;Slant Range: 580.86412km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.067824518003951, 51.330848842215275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.528497385665662, 51.41913393808833], [-5.436214999131111, 51.401635220894555], [-5.344006290594673, 51.38405724298896], [-5.251871489395611, 51.366400113945986], [-5.159810823196299, 51.34866394363447], [-5.067824518003951, 51.330848842215275], [-4.975912798142756, 51.312954920136924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.9759128&lt;dd&gt;Longitude: 51.312955&lt;dd&gt;Azimuth: 265.32171\u00b0&lt;dd&gt;Altitude: 71.846781\u00b0&lt;dd&gt;Slant Range: 578.90967km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.975912798142756, 51.312954920136924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.436214999131111, 51.401635220894555], [-5.344006290594673, 51.38405724298896], [-5.251871489395611, 51.366400113945986], [-5.159810823196299, 51.34866394363447], [-5.067824518003951, 51.330848842215275], [-4.975912798142756, 51.312954920136924], [-4.884075886282384, 51.29498228813453]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.8840759&lt;dd&gt;Longitude: 51.294982&lt;dd&gt;Azimuth: 264.34998\u00b0&lt;dd&gt;Altitude: 72.478466\u00b0&lt;dd&gt;Slant Range: 577.03342km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.884075886282384, 51.29498228813453]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.344006290594673, 51.38405724298896], [-5.251871489395611, 51.366400113945986], [-5.159810823196299, 51.34866394363447], [-5.067824518003951, 51.330848842215275], [-4.975912798142756, 51.312954920136924], [-4.884075886282384, 51.29498228813453], [-4.792314003414615, 51.27693105722539]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.792314&lt;dd&gt;Longitude: 51.276931&lt;dd&gt;Azimuth: 263.30107\u00b0&lt;dd&gt;Altitude: 73.108817\u00b0&lt;dd&gt;Slant Range: 575.23614km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.792314003414615, 51.27693105722539]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.251871489395611, 51.366400113945986], [-5.159810823196299, 51.34866394363447], [-5.067824518003951, 51.330848842215275], [-4.975912798142756, 51.312954920136924], [-4.884075886282384, 51.29498228813453], [-4.792314003414615, 51.27693105722539], [-4.7006273688694336, 51.25880133870698]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.7006274&lt;dd&gt;Longitude: 51.258801&lt;dd&gt;Azimuth: 262.16626\u00b0&lt;dd&gt;Altitude: 73.736996\u00b0&lt;dd&gt;Slant Range: 573.51856km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.7006273688694336, 51.25880133870698]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.159810823196299, 51.34866394363447], [-5.067824518003951, 51.330848842215275], [-4.975912798142756, 51.312954920136924], [-4.884075886282384, 51.29498228813453], [-4.792314003414615, 51.27693105722539], [-4.7006273688694336, 51.25880133870698], [-4.609016200303086, 51.24059324415349]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.6090162&lt;dd&gt;Longitude: 51.240593&lt;dd&gt;Azimuth: 260.93558\u00b0&lt;dd&gt;Altitude: 74.362052\u00b0&lt;dd&gt;Slant Range: 571.8814km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.609016200303086, 51.24059324415349]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.067824518003951, 51.330848842215275], [-4.975912798142756, 51.312954920136924], [-4.884075886282384, 51.29498228813453], [-4.792314003414615, 51.27693105722539], [-4.7006273688694336, 51.25880133870698], [-4.609016200303086, 51.24059324415349], [-4.517480713707701, 51.22230688541387]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.5174807&lt;dd&gt;Longitude: 51.222307&lt;dd&gt;Azimuth: 259.5977\u00b0&lt;dd&gt;Altitude: 74.982897\u00b0&lt;dd&gt;Slant Range: 570.32537km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.517480713707701, 51.22230688541387]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.975912798142756, 51.312954920136924], [-4.884075886282384, 51.29498228813453], [-4.792314003414615, 51.27693105722539], [-4.7006273688694336, 51.25880133870698], [-4.609016200303086, 51.24059324415349], [-4.517480713707701, 51.22230688541387], [-4.426021123407324, 51.203942374607365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.4260211&lt;dd&gt;Longitude: 51.203942&lt;dd&gt;Azimuth: 258.13968\u00b0&lt;dd&gt;Altitude: 75.598279\u00b0&lt;dd&gt;Slant Range: 568.85112km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.426021123407324, 51.203942374607365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.884075886282384, 51.29498228813453], [-4.792314003414615, 51.27693105722539], [-4.7006273688694336, 51.25880133870698], [-4.609016200303086, 51.24059324415349], [-4.517480713707701, 51.22230688541387], [-4.426021123407324, 51.203942374607365], [-4.33463764205552, 51.18549982412264]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.3346376&lt;dd&gt;Longitude: 51.1855&lt;dd&gt;Azimuth: 256.5468\u00b0&lt;dd&gt;Altitude: 76.206759\u00b0&lt;dd&gt;Slant Range: 567.45931km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.33463764205552, 51.18549982412264]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.792314003414615, 51.27693105722539], [-4.7006273688694336, 51.25880133870698], [-4.609016200303086, 51.24059324415349], [-4.517480713707701, 51.22230688541387], [-4.426021123407324, 51.203942374607365], [-4.33463764205552, 51.18549982412264], [-4.24333048064021, 51.166979346612564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.2433305&lt;dd&gt;Longitude: 51.166979&lt;dd&gt;Azimuth: 254.80235\u00b0&lt;dd&gt;Altitude: 76.806666\u00b0&lt;dd&gt;Slant Range: 566.15053km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.24333048064021, 51.166979346612564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.7006273688694336, 51.25880133870698], [-4.609016200303086, 51.24059324415349], [-4.517480713707701, 51.22230688541387], [-4.426021123407324, 51.203942374607365], [-4.33463764205552, 51.18549982412264], [-4.24333048064021, 51.166979346612564], [-4.152099848487819, 51.14838105499402]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.1520998&lt;dd&gt;Longitude: 51.148381&lt;dd&gt;Azimuth: 252.88742\u00b0&lt;dd&gt;Altitude: 77.396064\u00b0&lt;dd&gt;Slant Range: 564.92537km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.152099848487819, 51.14838105499402]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.609016200303086, 51.24059324415349], [-4.517480713707701, 51.22230688541387], [-4.426021123407324, 51.203942374607365], [-4.33463764205552, 51.18549982412264], [-4.24333048064021, 51.166979346612564], [-4.152099848487819, 51.14838105499402], [-4.060945953251904, 51.12970506244256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -4.060946&lt;dd&gt;Longitude: 51.129705&lt;dd&gt;Azimuth: 250.78076\u00b0&lt;dd&gt;Altitude: 77.972698\u00b0&lt;dd&gt;Slant Range: 563.78437km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.060945953251904, 51.12970506244256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.517480713707701, 51.22230688541387], [-4.426021123407324, 51.203942374607365], [-4.33463764205552, 51.18549982412264], [-4.24333048064021, 51.166979346612564], [-4.152099848487819, 51.14838105499402], [-4.060945953251904, 51.12970506244256], [-3.9698690009228175, 51.11095148239112]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.969869&lt;dd&gt;Longitude: 51.110951&lt;dd&gt;Azimuth: 248.4588\u00b0&lt;dd&gt;Altitude: 78.533938\u00b0&lt;dd&gt;Slant Range: 562.72805km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9698690009228175, 51.11095148239112]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.426021123407324, 51.203942374607365], [-4.33463764205552, 51.18549982412264], [-4.24333048064021, 51.166979346612564], [-4.152099848487819, 51.14838105499402], [-4.060945953251904, 51.12970506244256], [-3.9698690009228175, 51.11095148239112], [-3.878869195830435, 51.0921204285265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.8788692&lt;dd&gt;Longitude: 51.09212&lt;dd&gt;Azimuth: 245.89574\u00b0&lt;dd&gt;Altitude: 79.076719\u00b0&lt;dd&gt;Slant Range: 561.75688km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.878869195830435, 51.0921204285265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.33463764205552, 51.18549982412264], [-4.24333048064021, 51.166979346612564], [-4.152099848487819, 51.14838105499402], [-4.060945953251904, 51.12970506244256], [-3.9698690009228175, 51.11095148239112], [-3.878869195830435, 51.0921204285265], [-3.787946740629422, 51.073212014786584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.7879467&lt;dd&gt;Longitude: 51.073212&lt;dd&gt;Azimuth: 243.06409\u00b0&lt;dd&gt;Altitude: 79.597474\u00b0&lt;dd&gt;Slant Range: 560.87131km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.787946740629422, 51.073212014786584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.24333048064021, 51.166979346612564], [-4.152099848487819, 51.14838105499402], [-4.060945953251904, 51.12970506244256], [-3.9698690009228175, 51.11095148239112], [-3.878869195830435, 51.0921204285265], [-3.787946740629422, 51.073212014786584], [-3.6971018363292316, 51.05422635535757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.6971018&lt;dd&gt;Longitude: 51.054226&lt;dd&gt;Azimuth: 239.9356\u00b0&lt;dd&gt;Altitude: 80.092075\u00b0&lt;dd&gt;Slant Range: 560.07175km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6971018363292316, 51.05422635535757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.152099848487819, 51.14838105499402], [-4.060945953251904, 51.12970506244256], [-3.9698690009228175, 51.11095148239112], [-3.878869195830435, 51.0921204285265], [-3.787946740629422, 51.073212014786584], [-3.6971018363292316, 51.05422635535757], [-3.606334682260924, 51.03516356467148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.6063347&lt;dd&gt;Longitude: 51.035164&lt;dd&gt;Azimuth: 236.48297\u00b0&lt;dd&gt;Altitude: 80.555785\u00b0&lt;dd&gt;Slant Range: 559.35857km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.606334682260924, 51.03516356467148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.060945953251904, 51.12970506244256], [-3.9698690009228175, 51.11095148239112], [-3.878869195830435, 51.0921204285265], [-3.787946740629422, 51.073212014786584], [-3.6971018363292316, 51.05422635535757], [-3.606334682260924, 51.03516356467148], [-3.5156454761024625, 51.016023757402166]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.5156455&lt;dd&gt;Longitude: 51.016024&lt;dd&gt;Azimuth: 232.68245\u00b0&lt;dd&gt;Altitude: 80.983247\u00b0&lt;dd&gt;Slant Range: 558.73209km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.5156454761024625, 51.016023757402166]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9698690009228175, 51.11095148239112], [-3.878869195830435, 51.0921204285265], [-3.787946740629422, 51.073212014786584], [-3.6971018363292316, 51.05422635535757], [-3.606334682260924, 51.03516356467148], [-3.5156454761024625, 51.016023757402166], [-3.4250344138691413, 50.996807048464085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.4250344&lt;dd&gt;Longitude: 50.996807&lt;dd&gt;Azimuth: 228.51757\u00b0&lt;dd&gt;Altitude: 81.368527\u00b0&lt;dd&gt;Slant Range: 558.19262km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4250344138691413, 50.996807048464085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.878869195830435, 51.0921204285265], [-3.787946740629422, 51.073212014786584], [-3.6971018363292316, 51.05422635535757], [-3.606334682260924, 51.03516356467148], [-3.5156454761024625, 51.016023757402166], [-3.4250344138691413, 50.996807048464085], [-3.3345016899199242, 50.97751355300804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.3345017&lt;dd&gt;Longitude: 50.977514&lt;dd&gt;Azimuth: 223.98397\u00b0&lt;dd&gt;Altitude: 81.705252\u00b0&lt;dd&gt;Slant Range: 557.7404km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3345016899199242, 50.97751355300804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.787946740629422, 51.073212014786584], [-3.6971018363292316, 51.05422635535757], [-3.606334682260924, 51.03516356467148], [-3.5156454761024625, 51.016023757402166], [-3.4250344138691413, 50.996807048464085], [-3.3345016899199242, 50.97751355300804], [-3.2440474969519992, 50.95814338641919]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.2440475&lt;dd&gt;Longitude: 50.958143&lt;dd&gt;Azimuth: 219.09484\u00b0&lt;dd&gt;Altitude: 81.98687\u00b0&lt;dd&gt;Slant Range: 557.37564km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2440474969519992, 50.95814338641919]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6971018363292316, 51.05422635535757], [-3.606334682260924, 51.03516356467148], [-3.5156454761024625, 51.016023757402166], [-3.4250344138691413, 50.996807048464085], [-3.3345016899199242, 50.97751355300804], [-3.2440474969519992, 50.95814338641919], [-3.15367202600948, 50.938696664313696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.153672&lt;dd&gt;Longitude: 50.938697&lt;dd&gt;Azimuth: 213.88597\u00b0&lt;dd&gt;Altitude: 82.207044\u00b0&lt;dd&gt;Slant Range: 557.09853km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.15367202600948, 50.938696664313696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.606334682260924, 51.03516356467148], [-3.5156454761024625, 51.016023757402166], [-3.4250344138691413, 50.996807048464085], [-3.3345016899199242, 50.97751355300804], [-3.2440474969519992, 50.95814338641919], [-3.15367202600948, 50.938696664313696], [-3.063375466479716, 50.91917350253685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -3.0633755&lt;dd&gt;Longitude: 50.919174&lt;dd&gt;Azimuth: 208.41868\u00b0&lt;dd&gt;Altitude: 82.360184\u00b0&lt;dd&gt;Slant Range: 556.90918km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.063375466479716, 50.91917350253685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.5156454761024625, 51.016023757402166], [-3.4250344138691413, 50.996807048464085], [-3.3345016899199242, 50.97751355300804], [-3.2440474969519992, 50.95814338641919], [-3.15367202600948, 50.938696664313696], [-3.063375466479716, 50.91917350253685], [-2.9731580060975684, 50.89957401715849]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.973158&lt;dd&gt;Longitude: 50.899574&lt;dd&gt;Azimuth: 202.77886\u00b0&lt;dd&gt;Altitude: 82.442021\u00b0&lt;dd&gt;Slant Range: 556.8077km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9731580060975684, 50.89957401715849]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4250344138691413, 50.996807048464085], [-3.3345016899199242, 50.97751355300804], [-3.2440474969519992, 50.95814338641919], [-3.15367202600948, 50.938696664313696], [-3.063375466479716, 50.91917350253685], [-2.9731580060975684, 50.89957401715849], [-2.8830198309411594, 50.87989832447228]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.8830198&lt;dd&gt;Longitude: 50.879898&lt;dd&gt;Azimuth: 197.0708\u00b0&lt;dd&gt;Altitude: 82.450131\u00b0&lt;dd&gt;Slant Range: 556.79413km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8830198309411594, 50.87989832447228]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3345016899199242, 50.97751355300804], [-3.2440474969519992, 50.95814338641919], [-3.15367202600948, 50.938696664313696], [-3.063375466479716, 50.91917350253685], [-2.9731580060975684, 50.89957401715849], [-2.8830198309411594, 50.87989832447228], [-2.792961125442815, 50.86014654099141]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.7929611&lt;dd&gt;Longitude: 50.860147&lt;dd&gt;Azimuth: 191.40655\u00b0&lt;dd&gt;Altitude: 82.384268\u00b0&lt;dd&gt;Slant Range: 556.86847km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.792961125442815, 50.86014654099141]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2440474969519992, 50.95814338641919], [-3.15367202600948, 50.938696664313696], [-3.063375466479716, 50.91917350253685], [-2.9731580060975684, 50.89957401715849], [-2.8830198309411594, 50.87989832447228], [-2.792961125442815, 50.86014654099141], [-2.7029820723846867, 50.84031878344637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.7029821&lt;dd&gt;Longitude: 50.840319&lt;dd&gt;Azimuth: 185.89317\u00b0&lt;dd&gt;Altitude: 82.246391\u00b0&lt;dd&gt;Slant Range: 557.03069km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7029820723846867, 50.84031878344637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.15367202600948, 50.938696664313696], [-3.063375466479716, 50.91917350253685], [-2.9731580060975684, 50.89957401715849], [-2.8830198309411594, 50.87989832447228], [-2.792961125442815, 50.86014654099141], [-2.7029820723846867, 50.84031878344637], [-2.613082852899415, 50.82041516878214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.6130829&lt;dd&gt;Longitude: 50.820415&lt;dd&gt;Azimuth: 180.62129\u00b0&lt;dd&gt;Altitude: 82.040399\u00b0&lt;dd&gt;Slant Range: 557.28072km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.613082852899415, 50.82041516878214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.063375466479716, 50.91917350253685], [-2.9731580060975684, 50.89957401715849], [-2.8830198309411594, 50.87989832447228], [-2.792961125442815, 50.86014654099141], [-2.7029820723846867, 50.84031878344637], [-2.613082852899415, 50.82041516878214], [-2.52326364647285, 50.80043581415517]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.5232636&lt;dd&gt;Longitude: 50.800436&lt;dd&gt;Azimuth: 175.65788\u00b0&lt;dd&gt;Altitude: 81.771641\u00b0&lt;dd&gt;Slant Range: 557.61843km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.52326364647285, 50.80043581415517]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9731580060975684, 50.89957401715849], [-2.8830198309411594, 50.87989832447228], [-2.792961125442815, 50.86014654099141], [-2.7029820723846867, 50.84031878344637], [-2.613082852899415, 50.82041516878214], [-2.52326364647285, 50.80043581415517], [-2.433524630951458, 50.780380836930824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.4335246&lt;dd&gt;Longitude: 50.780381&lt;dd&gt;Azimuth: 171.04422\u00b0&lt;dd&gt;Altitude: 81.446334\u00b0&lt;dd&gt;Slant Range: 558.04367km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.433524630951458, 50.780380836930824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8830198309411594, 50.87989832447228], [-2.792961125442815, 50.86014654099141], [-2.7029820723846867, 50.84031878344637], [-2.613082852899415, 50.82041516878214], [-2.52326364647285, 50.80043581415517], [-2.433524630951458, 50.780380836930824], [-2.3438659825331327, 50.760250354681034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.343866&lt;dd&gt;Longitude: 50.76025&lt;dd&gt;Azimuth: 166.79808\u00b0&lt;dd&gt;Altitude: 81.071023\u00b0&lt;dd&gt;Slant Range: 558.55623km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3438659825331327, 50.760250354681034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.792961125442815, 50.86014654099141], [-2.7029820723846867, 50.84031878344637], [-2.613082852899415, 50.82041516878214], [-2.52326364647285, 50.80043581415517], [-2.433524630951458, 50.780380836930824], [-2.3438659825331327, 50.760250354681034], [-2.254287875778166, 50.74004448517998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.2542879&lt;dd&gt;Longitude: 50.740044&lt;dd&gt;Azimuth: 162.91847\u00b0&lt;dd&gt;Altitude: 80.652143\u00b0&lt;dd&gt;Slant Range: 559.15588km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.254287875778166, 50.74004448517998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7029820723846867, 50.84031878344637], [-2.613082852899415, 50.82041516878214], [-2.52326364647285, 50.80043581415517], [-2.433524630951458, 50.780380836930824], [-2.3438659825331327, 50.760250354681034], [-2.254287875778166, 50.74004448517998], [-2.1647904836133156, 50.71976334640357]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.1647905&lt;dd&gt;Longitude: 50.719763&lt;dd&gt;Azimuth: 159.39116\u00b0&lt;dd&gt;Altitude: 80.195741\u00b0&lt;dd&gt;Slant Range: 559.84234km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.1647904836133156, 50.71976334640357]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.613082852899415, 50.82041516878214], [-2.52326364647285, 50.80043581415517], [-2.433524630951458, 50.780380836930824], [-2.3438659825331327, 50.760250354681034], [-2.254287875778166, 50.74004448517998], [-2.1647904836133156, 50.71976334640357], [-2.075373977317812, 50.699407056524656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -2.075374&lt;dd&gt;Longitude: 50.699407&lt;dd&gt;Azimuth: 156.19363\u00b0&lt;dd&gt;Altitude: 79.707307\u00b0&lt;dd&gt;Slant Range: 560.61528km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.075373977317812, 50.699407056524656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.52326364647285, 50.80043581415517], [-2.433524630951458, 50.780380836930824], [-2.3438659825331327, 50.760250354681034], [-2.254287875778166, 50.74004448517998], [-2.1647904836133156, 50.71976334640357], [-2.075373977317812, 50.699407056524656], [-1.9860385265469964, 50.67897573391154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.9860385&lt;dd&gt;Longitude: 50.678976&lt;dd&gt;Azimuth: 153.2991\u00b0&lt;dd&gt;Altitude: 79.191713\u00b0&lt;dd&gt;Slant Range: 561.47435km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9860385265469964, 50.67897573391154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.433524630951458, 50.780380836930824], [-2.3438659825331327, 50.760250354681034], [-2.254287875778166, 50.74004448517998], [-2.1647904836133156, 50.71976334640357], [-2.075373977317812, 50.699407056524656], [-1.9860385265469964, 50.67897573391154], [-1.8967842993170292, 50.658469497124734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.8967843&lt;dd&gt;Longitude: 50.658469&lt;dd&gt;Azimuth: 150.67935\u00b0&lt;dd&gt;Altitude: 78.653218\u00b0&lt;dd&gt;Slant Range: 562.41915km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8967842993170292, 50.658469497124734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3438659825331327, 50.760250354681034], [-2.254287875778166, 50.74004448517998], [-2.1647904836133156, 50.71976334640357], [-2.075373977317812, 50.699407056524656], [-1.9860385265469964, 50.67897573391154], [-1.8967842993170292, 50.658469497124734], [-1.8076114620192385, 50.63788846491423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.8076115&lt;dd&gt;Longitude: 50.637888&lt;dd&gt;Azimuth: 148.30662\u00b0&lt;dd&gt;Altitude: 78.095508\u00b0&lt;dd&gt;Slant Range: 563.44925km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8076114620192385, 50.63788846491423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.254287875778166, 50.74004448517998], [-2.1647904836133156, 50.71976334640357], [-2.075373977317812, 50.699407056524656], [-1.9860385265469964, 50.67897573391154], [-1.8967842993170292, 50.658469497124734], [-1.8076114620192385, 50.63788846491423], [-1.7185201794099194, 50.61723275621675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.7185202&lt;dd&gt;Longitude: 50.617233&lt;dd&gt;Azimuth: 146.15469\u00b0&lt;dd&gt;Altitude: 77.521752\u00b0&lt;dd&gt;Slant Range: 564.56418km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7185201794099194, 50.61723275621675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.1647904836133156, 50.71976334640357], [-2.075373977317812, 50.699407056524656], [-1.9860385265469964, 50.67897573391154], [-1.8967842993170292, 50.658469497124734], [-1.8076114620192385, 50.63788846491423], [-1.7185201794099194, 50.61723275621675], [-1.629510614633029, 50.59650249015367]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.6295106&lt;dd&gt;Longitude: 50.596502&lt;dd&gt;Azimuth: 144.19947\u00b0&lt;dd&gt;Altitude: 76.934672\u00b0&lt;dd&gt;Slant Range: 565.76345km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.629510614633029, 50.59650249015367]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.075373977317812, 50.699407056524656], [-1.9860385265469964, 50.67897573391154], [-1.8967842993170292, 50.658469497124734], [-1.8076114620192385, 50.63788846491423], [-1.7185201794099194, 50.61723275621675], [-1.629510614633029, 50.59650249015367], [-1.5405829291917648, 50.57569778602683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.5405829&lt;dd&gt;Longitude: 50.575698&lt;dd&gt;Azimuth: 142.4192\u00b0&lt;dd&gt;Altitude: 76.336599\u00b0&lt;dd&gt;Slant Range: 567.0465km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5405829291917648, 50.57569778602683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9860385265469964, 50.67897573391154], [-1.8967842993170292, 50.658469497124734], [-1.8076114620192385, 50.63788846491423], [-1.7185201794099194, 50.61723275621675], [-1.629510614633029, 50.59650249015367], [-1.5405829291917648, 50.57569778602683], [-1.4517372829839594, 50.55481876331773]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.4517373&lt;dd&gt;Longitude: 50.554819&lt;dd&gt;Azimuth: 140.79447\u00b0&lt;dd&gt;Altitude: 75.729536\u00b0&lt;dd&gt;Slant Range: 568.41279km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4517372829839594, 50.55481876331773]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8967842993170292, 50.658469497124734], [-1.8076114620192385, 50.63788846491423], [-1.7185201794099194, 50.61723275621675], [-1.629510614633029, 50.59650249015367], [-1.5405829291917648, 50.57569778602683], [-1.4517372829839594, 50.55481876331773], [-1.3629738342782627, 50.53386554168316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.3629738&lt;dd&gt;Longitude: 50.533866&lt;dd&gt;Azimuth: 139.3081\u00b0&lt;dd&gt;Altitude: 75.115208\u00b0&lt;dd&gt;Slant Range: 569.86169km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3629738342782627, 50.53386554168316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8076114620192385, 50.63788846491423], [-1.7185201794099194, 50.61723275621675], [-1.629510614633029, 50.59650249015367], [-1.5405829291917648, 50.57569778602683], [-1.4517372829839594, 50.55481876331773], [-1.3629738342782627, 50.53386554168316], [-1.2742927397390529, 50.51283824095342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.2742927&lt;dd&gt;Longitude: 50.512838&lt;dd&gt;Azimuth: 137.94494\u00b0&lt;dd&gt;Altitude: 74.495104\u00b0&lt;dd&gt;Slant Range: 571.3926km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2742927397390529, 50.51283824095342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7185201794099194, 50.61723275621675], [-1.629510614633029, 50.59650249015367], [-1.5405829291917648, 50.57569778602683], [-1.4517372829839594, 50.55481876331773], [-1.3629738342782627, 50.53386554168316], [-1.2742927397390529, 50.51283824095342], [-1.1856941544043005, 50.491736981129336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.1856942&lt;dd&gt;Longitude: 50.491737&lt;dd&gt;Azimuth: 136.69168\u00b0&lt;dd&gt;Altitude: 73.870513\u00b0&lt;dd&gt;Slant Range: 573.00484km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1856941544043005, 50.491736981129336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.629510614633029, 50.59650249015367], [-1.5405829291917648, 50.57569778602683], [-1.4517372829839594, 50.55481876331773], [-1.3629738342782627, 50.53386554168316], [-1.2742927397390529, 50.51283824095342], [-1.1856941544043005, 50.491736981129336], [-1.097178231714217, 50.470561882380096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.0971782&lt;dd&gt;Longitude: 50.470562&lt;dd&gt;Azimuth: 135.53665\u00b0&lt;dd&gt;Altitude: 73.242557\u00b0&lt;dd&gt;Slant Range: 574.69773km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.097178231714217, 50.470561882380096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5405829291917648, 50.57569778602683], [-1.4517372829839594, 50.55481876331773], [-1.3629738342782627, 50.53386554168316], [-1.2742927397390529, 50.51283824095342], [-1.1856941544043005, 50.491736981129336], [-1.097178231714217, 50.470561882380096], [-1.0087451234917912, 50.44931306503915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -1.0087451&lt;dd&gt;Longitude: 50.449313&lt;dd&gt;Azimuth: 134.46961\u00b0&lt;dd&gt;Altitude: 72.612218\u00b0&lt;dd&gt;Slant Range: 576.47055km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0087451234917912, 50.44931306503915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4517372829839594, 50.55481876331773], [-1.3629738342782627, 50.53386554168316], [-1.2742927397390529, 50.51283824095342], [-1.1856941544043005, 50.491736981129336], [-1.097178231714217, 50.470561882380096], [-1.0087451234917912, 50.44931306503915], [-0.9203949799595573, 50.42799064960352]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.92039498&lt;dd&gt;Longitude: 50.427991&lt;dd&gt;Azimuth: 133.48157\u00b0&lt;dd&gt;Altitude: 71.980356\u00b0&lt;dd&gt;Slant Range: 578.32258km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9203949799595573, 50.42799064960352]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3629738342782627, 50.53386554168316], [-1.2742927397390529, 50.51283824095342], [-1.1856941544043005, 50.491736981129336], [-1.097178231714217, 50.470561882380096], [-1.0087451234917912, 50.44931306503915], [-0.9203949799595573, 50.42799064960352], [-0.8321279497380928, 50.406594756729646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.83212795&lt;dd&gt;Longitude: 50.406595&lt;dd&gt;Azimuth: 132.56462\u00b0&lt;dd&gt;Altitude: 71.347729\u00b0&lt;dd&gt;Slant Range: 580.25305km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8321279497380928, 50.406594756729646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2742927397390529, 50.51283824095342], [-1.1856941544043005, 50.491736981129336], [-1.097178231714217, 50.470561882380096], [-1.0087451234917912, 50.44931306503915], [-0.9203949799595573, 50.42799064960352], [-0.8321279497380928, 50.406594756729646], [-0.7439441798509803, 50.38512550723132]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.74394418&lt;dd&gt;Longitude: 50.385126&lt;dd&gt;Azimuth: 131.7118\u00b0&lt;dd&gt;Altitude: 70.715005\u00b0&lt;dd&gt;Slant Range: 582.26118km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7439441798509803, 50.38512550723132]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1856941544043005, 50.491736981129336], [-1.097178231714217, 50.470561882380096], [-1.0087451234917912, 50.44931306503915], [-0.9203949799595573, 50.42799064960352], [-0.8321279497380928, 50.406594756729646], [-0.7439441798509803, 50.38512550723132], [-0.6558438157173273, 50.36358302207694]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.65584382&lt;dd&gt;Longitude: 50.363583&lt;dd&gt;Azimuth: 130.91698\u00b0&lt;dd&gt;Altitude: 70.082781\u00b0&lt;dd&gt;Slant Range: 584.34616km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6558438157173273, 50.36358302207694]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.097178231714217, 50.470561882380096], [-1.0087451234917912, 50.44931306503915], [-0.9203949799595573, 50.42799064960352], [-0.8321279497380928, 50.406594756729646], [-0.7439441798509803, 50.38512550723132], [-0.6558438157173273, 50.36358302207694], [-0.567827001172198, 50.34196742238688]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.567827&lt;dd&gt;Longitude: 50.341967&lt;dd&gt;Azimuth: 130.17473\u00b0&lt;dd&gt;Altitude: 69.451585\u00b0&lt;dd&gt;Slant Range: 586.50718km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.567827001172198, 50.34196742238688]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0087451234917912, 50.44931306503915], [-0.9203949799595573, 50.42799064960352], [-0.8321279497380928, 50.406594756729646], [-0.7439441798509803, 50.38512550723132], [-0.6558438157173273, 50.36358302207694], [-0.567827001172198, 50.34196742238688], [-0.4798938784535852, 50.32027882943084]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.47989388&lt;dd&gt;Longitude: 50.320279&lt;dd&gt;Azimuth: 129.48026\u00b0&lt;dd&gt;Altitude: 68.821888\u00b0&lt;dd&gt;Slant Range: 588.74339km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4798938784535852, 50.32027882943084]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9203949799595573, 50.42799064960352], [-0.8321279497380928, 50.406594756729646], [-0.7439441798509803, 50.38512550723132], [-0.6558438157173273, 50.36358302207694], [-0.567827001172198, 50.34196742238688], [-0.4798938784535852, 50.32027882943084], [-0.39204458821968785, 50.29851736462576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.39204459&lt;dd&gt;Longitude: 50.298517&lt;dd&gt;Azimuth: 128.82929\u00b0&lt;dd&gt;Altitude: 68.194115\u00b0&lt;dd&gt;Slant Range: 591.05394km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.39204458821968785, 50.29851736462576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8321279497380928, 50.406594756729646], [-0.7439441798509803, 50.38512550723132], [-0.6558438157173273, 50.36358302207694], [-0.567827001172198, 50.34196742238688], [-0.4798938784535852, 50.32027882943084], [-0.39204458821968785, 50.29851736462576], [-0.3042792695355521, 50.276683149531735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.30427927&lt;dd&gt;Longitude: 50.276683&lt;dd&gt;Azimuth: 128.21805\u00b0&lt;dd&gt;Altitude: 67.568645\u00b0&lt;dd&gt;Slant Range: 593.43796km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3042792695355521, 50.276683149531735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7439441798509803, 50.38512550723132], [-0.6558438157173273, 50.36358302207694], [-0.567827001172198, 50.34196742238688], [-0.4798938784535852, 50.32027882943084], [-0.39204458821968785, 50.29851736462576], [-0.3042792695355521, 50.276683149531735], [-0.21659805989457223, 50.25477630585144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.21659806&lt;dd&gt;Longitude: 50.254776&lt;dd&gt;Azimuth: 127.64314\u00b0&lt;dd&gt;Altitude: 66.945818\u00b0&lt;dd&gt;Slant Range: 595.89456km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.21659805989457223, 50.25477630585144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6558438157173273, 50.36358302207694], [-0.567827001172198, 50.34196742238688], [-0.4798938784535852, 50.32027882943084], [-0.39204458821968785, 50.29851736462576], [-0.3042792695355521, 50.276683149531735], [-0.21659805989457223, 50.25477630585144], [-0.1290010952079818, 50.23279695542598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.1290011&lt;dd&gt;Longitude: 50.232797&lt;dd&gt;Azimuth: 127.10154\u00b0&lt;dd&gt;Altitude: 66.325941\u00b0&lt;dd&gt;Slant Range: 598.42285km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.1290010952079818, 50.23279695542598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.567827001172198, 50.34196742238688], [-0.4798938784535852, 50.32027882943084], [-0.39204458821968785, 50.29851736462576], [-0.3042792695355521, 50.276683149531735], [-0.21659805989457223, 50.25477630585144], [-0.1290010952079818, 50.23279695542598], [-0.04148850980867063, 50.21074522023272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: -0.04148851&lt;dd&gt;Longitude: 50.210745&lt;dd&gt;Azimuth: 126.59055\u00b0&lt;dd&gt;Altitude: 65.709292\u00b0&lt;dd&gt;Slant Range: 601.02192km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.04148850980867063, 50.21074522023272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4798938784535852, 50.32027882943084], [-0.39204458821968785, 50.29851736462576], [-0.3042792695355521, 50.276683149531735], [-0.21659805989457223, 50.25477630585144], [-0.1290010952079818, 50.23279695542598], [-0.04148850980867063, 50.21074522023272], [0.045939563534337584, 50.18862122238301]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.045939564&lt;dd&gt;Longitude: 50.188621&lt;dd&gt;Azimuth: 126.10773\u00b0&lt;dd&gt;Altitude: 65.096119\u00b0&lt;dd&gt;Slant Range: 603.69086km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.045939563534337584, 50.18862122238301]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.39204458821968785, 50.29851736462576], [-0.3042792695355521, 50.276683149531735], [-0.21659805989457223, 50.25477630585144], [-0.1290010952079818, 50.23279695542598], [-0.04148850980867063, 50.21074522023272], [0.045939563534337584, 50.18862122238301], [0.13328299362099943, 50.16642508411949]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.13328299&lt;dd&gt;Longitude: 50.166425&lt;dd&gt;Azimuth: 125.65088\u00b0&lt;dd&gt;Altitude: 64.486648\u00b0&lt;dd&gt;Slant Range: 606.42873km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.13328299362099943, 50.16642508411949]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3042792695355521, 50.276683149531735], [-0.21659805989457223, 50.25477630585144], [-0.1290010952079818, 50.23279695542598], [-0.04148850980867063, 50.21074522023272], [0.045939563534337584, 50.18862122238301], [0.13328299362099943, 50.16642508411949], [0.22054165081844535, 50.14415692781316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.22054165&lt;dd&gt;Longitude: 50.144157&lt;dd&gt;Azimuth: 125.21804\u00b0&lt;dd&gt;Altitude: 63.881081\u00b0&lt;dd&gt;Slant Range: 609.23461km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.22054165081844535, 50.14415692781316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.21659805989457223, 50.25477630585144], [-0.1290010952079818, 50.23279695542598], [-0.04148850980867063, 50.21074522023272], [0.045939563534337584, 50.18862122238301], [0.13328299362099943, 50.16642508411949], [0.22054165081844535, 50.14415692781316], [0.30771540705344796, 50.12181687596181]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.30771541&lt;dd&gt;Longitude: 50.121817&lt;dd&gt;Azimuth: 124.80743\u00b0&lt;dd&gt;Altitude: 63.279603\u00b0&lt;dd&gt;Slant Range: 612.10756km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.30771540705344796, 50.12181687596181]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.1290010952079818, 50.23279695542598], [-0.04148850980867063, 50.21074522023272], [0.045939563534337584, 50.18862122238301], [0.13328299362099943, 50.16642508411949], [0.22054165081844535, 50.14415692781316], [0.30771540705344796, 50.12181687596181], [0.3948041358055267, 50.09940505118577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.39480414&lt;dd&gt;Longitude: 50.099405&lt;dd&gt;Azimuth: 124.41741\u00b0&lt;dd&gt;Altitude: 62.682376\u00b0&lt;dd&gt;Slant Range: 615.04663km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3948041358055267, 50.09940505118577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.04148850980867063, 50.21074522023272], [0.045939563534337584, 50.18862122238301], [0.13328299362099943, 50.16642508411949], [0.22054165081844535, 50.14415692781316], [0.30771540705344796, 50.12181687596181], [0.3948041358055267, 50.09940505118577], [0.4818077121138941, 50.07692157622755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.48180771&lt;dd&gt;Longitude: 50.076922&lt;dd&gt;Azimuth: 124.04653\u00b0&lt;dd&gt;Altitude: 62.089551\u00b0&lt;dd&gt;Slant Range: 618.05088km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.4818077121138941, 50.07692157622755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.045939563534337584, 50.18862122238301], [0.13328299362099943, 50.16642508411949], [0.22054165081844535, 50.14415692781316], [0.30771540705344796, 50.12181687596181], [0.3948041358055267, 50.09940505118577], [0.4818077121138941, 50.07692157622755], [0.5687260125652934, 50.05436657394731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1174&lt;dd&gt;Latitude: 0.56872601&lt;dd&gt;Longitude: 50.054367&lt;dd&gt;Azimuth: 123.69345\u00b0&lt;dd&gt;Altitude: 61.501258\u00b0&lt;dd&gt;Slant Range: 621.11935km&quot;, &quot;name&quot;: &quot;STARLINK-1174&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5687260125652934, 50.05436657394731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -9.3742396&lt;dd&gt;Longitude: 48.130106&lt;dd&gt;Azimuth: 235.40932\u00b0&lt;dd&gt;Altitude: 38.068168\u00b0&lt;dd&gt;Slant Range: 842.97121km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988], [-9.294078053878444, 48.15775417668079]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -9.2940781&lt;dd&gt;Longitude: 48.157754&lt;dd&gt;Azimuth: 235.27196\u00b0&lt;dd&gt;Altitude: 38.403663\u00b0&lt;dd&gt;Slant Range: 837.82984km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.294078053878444, 48.15775417668079]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988], [-9.294078053878444, 48.15775417668079], [-9.213826103498864, 48.18534001045429]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -9.2138261&lt;dd&gt;Longitude: 48.18534&lt;dd&gt;Azimuth: 235.13154\u00b0&lt;dd&gt;Altitude: 38.742737\u00b0&lt;dd&gt;Slant Range: 832.71534km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.213826103498864, 48.18534001045429]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988], [-9.294078053878444, 48.15775417668079], [-9.213826103498864, 48.18534001045429], [-9.133483723381742, 48.2128637305925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -9.1334837&lt;dd&gt;Longitude: 48.212864&lt;dd&gt;Azimuth: 234.98795\u00b0&lt;dd&gt;Altitude: 39.085427\u00b0&lt;dd&gt;Slant Range: 827.62821km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.133483723381742, 48.2128637305925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988], [-9.294078053878444, 48.15775417668079], [-9.213826103498864, 48.18534001045429], [-9.133483723381742, 48.2128637305925], [-9.053050933258909, 48.24032521181463]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -9.0530509&lt;dd&gt;Longitude: 48.240325&lt;dd&gt;Azimuth: 234.84109\u00b0&lt;dd&gt;Altitude: 39.431772\u00b0&lt;dd&gt;Slant Range: 822.56897km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.053050933258909, 48.24032521181463]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988], [-9.294078053878444, 48.15775417668079], [-9.213826103498864, 48.18534001045429], [-9.133483723381742, 48.2128637305925], [-9.053050933258909, 48.24032521181463], [-8.972527754035898, 48.267724328798344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.9725278&lt;dd&gt;Longitude: 48.267724&lt;dd&gt;Azimuth: 234.69086\u00b0&lt;dd&gt;Altitude: 39.78181\u00b0&lt;dd&gt;Slant Range: 817.53813km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.972527754035898, 48.267724328798344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.374239555972862, 48.13010635450988], [-9.294078053878444, 48.15775417668079], [-9.213826103498864, 48.18534001045429], [-9.133483723381742, 48.2128637305925], [-9.053050933258909, 48.24032521181463], [-8.972527754035898, 48.267724328798344], [-8.891914207826519, 48.295060956182006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.8919142&lt;dd&gt;Longitude: 48.295061&lt;dd&gt;Azimuth: 234.53714\u00b0&lt;dd&gt;Altitude: 40.135579\u00b0&lt;dd&gt;Slant Range: 812.53624km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.891914207826519, 48.295060956182006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.294078053878444, 48.15775417668079], [-9.213826103498864, 48.18534001045429], [-9.133483723381742, 48.2128637305925], [-9.053050933258909, 48.24032521181463], [-8.972527754035898, 48.267724328798344], [-8.891914207826519, 48.295060956182006], [-8.811210317924695, 48.322334968565286]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.8112103&lt;dd&gt;Longitude: 48.322335&lt;dd&gt;Azimuth: 234.37981\u00b0&lt;dd&gt;Altitude: 40.493116\u00b0&lt;dd&gt;Slant Range: 807.56383km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.811210317924695, 48.322334968565286]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.213826103498864, 48.18534001045429], [-9.133483723381742, 48.2128637305925], [-9.053050933258909, 48.24032521181463], [-8.972527754035898, 48.267724328798344], [-8.891914207826519, 48.295060956182006], [-8.811210317924695, 48.322334968565286], [-8.73041610883378, 48.349546240512915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.7304161&lt;dd&gt;Longitude: 48.349546&lt;dd&gt;Azimuth: 234.21874\u00b0&lt;dd&gt;Altitude: 40.854456\u00b0&lt;dd&gt;Slant Range: 802.62145km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.73041610883378, 48.349546240512915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.133483723381742, 48.2128637305925], [-9.053050933258909, 48.24032521181463], [-8.972527754035898, 48.267724328798344], [-8.891914207826519, 48.295060956182006], [-8.811210317924695, 48.322334968565286], [-8.73041610883378, 48.349546240512915], [-8.649531606262117, 48.376694646553915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.6495316&lt;dd&gt;Longitude: 48.376695&lt;dd&gt;Azimuth: 234.05382\u00b0&lt;dd&gt;Altitude: 41.219636\u00b0&lt;dd&gt;Slant Range: 797.70968km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.649531606262117, 48.376694646553915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.053050933258909, 48.24032521181463], [-8.972527754035898, 48.267724328798344], [-8.891914207826519, 48.295060956182006], [-8.811210317924695, 48.322334968565286], [-8.73041610883378, 48.349546240512915], [-8.649531606262117, 48.376694646553915], [-8.56855683713318, 48.403780061185586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.5685568&lt;dd&gt;Longitude: 48.40378&lt;dd&gt;Azimuth: 233.8849\u00b0&lt;dd&gt;Altitude: 41.58869\u00b0&lt;dd&gt;Slant Range: 792.82909km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.56855683713318, 48.403780061185586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.972527754035898, 48.267724328798344], [-8.891914207826519, 48.295060956182006], [-8.811210317924695, 48.322334968565286], [-8.73041610883378, 48.349546240512915], [-8.649531606262117, 48.376694646553915], [-8.56855683713318, 48.403780061185586], [-8.48749182958546, 48.4308023588737]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.4874918&lt;dd&gt;Longitude: 48.430802&lt;dd&gt;Azimuth: 233.71184\u00b0&lt;dd&gt;Altitude: 41.961651\u00b0&lt;dd&gt;Slant Range: 787.98026km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.48749182958546, 48.4308023588737]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.891914207826519, 48.295060956182006], [-8.811210317924695, 48.322334968565286], [-8.73041610883378, 48.349546240512915], [-8.649531606262117, 48.376694646553915], [-8.56855683713318, 48.403780061185586], [-8.48749182958546, 48.4308023588737], [-8.406336612984743, 48.45776141405545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.4063366&lt;dd&gt;Longitude: 48.457761&lt;dd&gt;Azimuth: 233.53449\u00b0&lt;dd&gt;Altitude: 42.338552\u00b0&lt;dd&gt;Slant Range: 783.16378km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.406336612984743, 48.45776141405545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.811210317924695, 48.322334968565286], [-8.73041610883378, 48.349546240512915], [-8.649531606262117, 48.376694646553915], [-8.56855683713318, 48.403780061185586], [-8.48749182958546, 48.4308023588737], [-8.406336612984743, 48.45776141405545], [-8.325091217923918, 48.484657101139774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.3250912&lt;dd&gt;Longitude: 48.484657&lt;dd&gt;Azimuth: 233.3527\u00b0&lt;dd&gt;Altitude: 42.719425\u00b0&lt;dd&gt;Slant Range: 778.38027km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.325091217923918, 48.484657101139774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.73041610883378, 48.349546240512915], [-8.649531606262117, 48.376694646553915], [-8.56855683713318, 48.403780061185586], [-8.48749182958546, 48.4308023588737], [-8.406336612984743, 48.45776141405545], [-8.325091217923918, 48.484657101139774], [-8.243755676233084, 48.51148929451144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.2437557&lt;dd&gt;Longitude: 48.511489&lt;dd&gt;Azimuth: 233.16631\u00b0&lt;dd&gt;Altitude: 43.104299\u00b0&lt;dd&gt;Slant Range: 773.63033km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.243755676233084, 48.51148929451144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.649531606262117, 48.376694646553915], [-8.56855683713318, 48.403780061185586], [-8.48749182958546, 48.4308023588737], [-8.406336612984743, 48.45776141405545], [-8.325091217923918, 48.484657101139774], [-8.243755676233084, 48.51148929451144], [-8.162330020978178, 48.53825786853009]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.16233&lt;dd&gt;Longitude: 48.538258&lt;dd&gt;Azimuth: 232.97514\u00b0&lt;dd&gt;Altitude: 43.493203\u00b0&lt;dd&gt;Slant Range: 768.9146km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.162330020978178, 48.53825786853009]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.56855683713318, 48.403780061185586], [-8.48749182958546, 48.4308023588737], [-8.406336612984743, 48.45776141405545], [-8.325091217923918, 48.484657101139774], [-8.243755676233084, 48.51148929451144], [-8.162330020978178, 48.53825786853009], [-8.080814286476167, 48.56496269753414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -8.0808143&lt;dd&gt;Longitude: 48.564963&lt;dd&gt;Azimuth: 232.77902\u00b0&lt;dd&gt;Altitude: 43.886165\u00b0&lt;dd&gt;Slant Range: 764.23372km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.080814286476167, 48.56496269753414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.48749182958546, 48.4308023588737], [-8.406336612984743, 48.45776141405545], [-8.325091217923918, 48.484657101139774], [-8.243755676233084, 48.51148929451144], [-8.162330020978178, 48.53825786853009], [-8.080814286476167, 48.56496269753414], [-7.9992085082941475, 48.5916036558421]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.9992085&lt;dd&gt;Longitude: 48.591604&lt;dd&gt;Azimuth: 232.57776\u00b0&lt;dd&gt;Altitude: 44.283209\u00b0&lt;dd&gt;Slant Range: 759.58832km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.9992085082941475, 48.5916036558421]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.406336612984743, 48.45776141405545], [-8.325091217923918, 48.484657101139774], [-8.243755676233084, 48.51148929451144], [-8.162330020978178, 48.53825786853009], [-8.080814286476167, 48.56496269753414], [-7.9992085082941475, 48.5916036558421], [-7.917512723254573, 48.61818061775378]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.9175127&lt;dd&gt;Longitude: 48.618181&lt;dd&gt;Azimuth: 232.37117\u00b0&lt;dd&gt;Altitude: 44.684359\u00b0&lt;dd&gt;Slant Range: 754.97909km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.917512723254573, 48.61818061775378]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.325091217923918, 48.484657101139774], [-8.243755676233084, 48.51148929451144], [-8.162330020978178, 48.53825786853009], [-8.080814286476167, 48.56496269753414], [-7.9992085082941475, 48.5916036558421], [-7.917512723254573, 48.61818061775378], [-7.835726969441379, 48.644693457552975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.835727&lt;dd&gt;Longitude: 48.644693&lt;dd&gt;Azimuth: 232.15903\u00b0&lt;dd&gt;Altitude: 45.089637\u00b0&lt;dd&gt;Slant Range: 750.40667km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.835726969441379, 48.644693457552975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.243755676233084, 48.51148929451144], [-8.162330020978178, 48.53825786853009], [-8.080814286476167, 48.56496269753414], [-7.9992085082941475, 48.5916036558421], [-7.917512723254573, 48.61818061775378], [-7.835726969441379, 48.644693457552975], [-7.753851286210724, 48.671142049508994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.7538513&lt;dd&gt;Longitude: 48.671142&lt;dd&gt;Azimuth: 231.94113\u00b0&lt;dd&gt;Altitude: 45.499062\u00b0&lt;dd&gt;Slant Range: 745.87177km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.753851286210724, 48.671142049508994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.162330020978178, 48.53825786853009], [-8.080814286476167, 48.56496269753414], [-7.9992085082941475, 48.5916036558421], [-7.917512723254573, 48.61818061775378], [-7.835726969441379, 48.644693457552975], [-7.753851286210724, 48.671142049508994], [-7.671885714185569, 48.697526267877876]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.6718857&lt;dd&gt;Longitude: 48.697526&lt;dd&gt;Azimuth: 231.71725\u00b0&lt;dd&gt;Altitude: 45.91265\u00b0&lt;dd&gt;Slant Range: 741.37506km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.671885714185569, 48.697526267877876]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.080814286476167, 48.56496269753414], [-7.9992085082941475, 48.5916036558421], [-7.917512723254573, 48.61818061775378], [-7.835726969441379, 48.644693457552975], [-7.753851286210724, 48.671142049508994], [-7.671885714185569, 48.697526267877876], [-7.589830295270535, 48.723845986906205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.5898303&lt;dd&gt;Longitude: 48.723846&lt;dd&gt;Azimuth: 231.48713\u00b0&lt;dd&gt;Altitude: 46.330417\u00b0&lt;dd&gt;Slant Range: 736.91726km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.589830295270535, 48.723845986906205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.9992085082941475, 48.5916036558421], [-7.917512723254573, 48.61818061775378], [-7.835726969441379, 48.644693457552975], [-7.753851286210724, 48.671142049508994], [-7.671885714185569, 48.697526267877876], [-7.589830295270535, 48.723845986906205], [-7.507685072658624, 48.75010108083042]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.5076851&lt;dd&gt;Longitude: 48.750101&lt;dd&gt;Azimuth: 231.25054\u00b0&lt;dd&gt;Altitude: 46.752372\u00b0&lt;dd&gt;Slant Range: 732.49909km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.507685072658624, 48.75010108083042]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.917512723254573, 48.61818061775378], [-7.835726969441379, 48.644693457552975], [-7.753851286210724, 48.671142049508994], [-7.671885714185569, 48.697526267877876], [-7.589830295270535, 48.723845986906205], [-7.507685072658624, 48.75010108083042], [-7.425450090821573, 48.77629142388085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.4254501&lt;dd&gt;Longitude: 48.776291&lt;dd&gt;Azimuth: 231.0072\u00b0&lt;dd&gt;Altitude: 47.178526\u00b0&lt;dd&gt;Slant Range: 728.12125km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.425450090821573, 48.77629142388085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.835726969441379, 48.644693457552975], [-7.753851286210724, 48.671142049508994], [-7.671885714185569, 48.697526267877876], [-7.589830295270535, 48.723845986906205], [-7.507685072658624, 48.75010108083042], [-7.425450090821573, 48.77629142388085], [-7.343125395536139, 48.802416890282515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.3431254&lt;dd&gt;Longitude: 48.802417&lt;dd&gt;Azimuth: 230.75683\u00b0&lt;dd&gt;Altitude: 47.608883\u00b0&lt;dd&gt;Slant Range: 723.7845km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.343125395536139, 48.802416890282515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.753851286210724, 48.671142049508994], [-7.671885714185569, 48.697526267877876], [-7.589830295270535, 48.723845986906205], [-7.507685072658624, 48.75010108083042], [-7.425450090821573, 48.77629142388085], [-7.343125395536139, 48.802416890282515], [-7.260711033870993, 48.8284773542577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.260711&lt;dd&gt;Longitude: 48.828477&lt;dd&gt;Azimuth: 230.49915\u00b0&lt;dd&gt;Altitude: 48.043444\u00b0&lt;dd&gt;Slant Range: 719.48958km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.260711033870993, 48.8284773542577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.671885714185569, 48.697526267877876], [-7.589830295270535, 48.723845986906205], [-7.507685072658624, 48.75010108083042], [-7.425450090821573, 48.77629142388085], [-7.343125395536139, 48.802416890282515], [-7.260711033870993, 48.8284773542577], [-7.178207054206418, 48.85447269002733]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.1782071&lt;dd&gt;Longitude: 48.854473&lt;dd&gt;Azimuth: 230.23384\u00b0&lt;dd&gt;Altitude: 48.482208\u00b0&lt;dd&gt;Slant Range: 715.23725km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.178207054206418, 48.85447269002733]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.589830295270535, 48.723845986906205], [-7.507685072658624, 48.75010108083042], [-7.425450090821573, 48.77629142388085], [-7.343125395536139, 48.802416890282515], [-7.260711033870993, 48.8284773542577], [-7.178207054206418, 48.85447269002733], [-7.095613506225707, 48.88040277181351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.0956135&lt;dd&gt;Longitude: 48.880403&lt;dd&gt;Azimuth: 229.96056\u00b0&lt;dd&gt;Altitude: 48.925169\u00b0&lt;dd&gt;Slant Range: 711.02828km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.095613506225707, 48.88040277181351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.507685072658624, 48.75010108083042], [-7.425450090821573, 48.77629142388085], [-7.343125395536139, 48.802416890282515], [-7.260711033870993, 48.8284773542577], [-7.178207054206418, 48.85447269002733], [-7.095613506225707, 48.88040277181351], [-7.012930440940503, 48.9062674738404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -7.0129304&lt;dd&gt;Longitude: 48.906267&lt;dd&gt;Azimuth: 229.67898\u00b0&lt;dd&gt;Altitude: 49.372316\u00b0&lt;dd&gt;Slant Range: 706.86344km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.012930440940503, 48.9062674738404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.425450090821573, 48.77629142388085], [-7.343125395536139, 48.802416890282515], [-7.260711033870993, 48.8284773542577], [-7.178207054206418, 48.85447269002733], [-7.095613506225707, 48.88040277181351], [-7.012930440940503, 48.9062674738404], [-6.930157910666529, 48.9320666703383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.9301579&lt;dd&gt;Longitude: 48.932067&lt;dd&gt;Azimuth: 229.38873\u00b0&lt;dd&gt;Altitude: 49.823633\u00b0&lt;dd&gt;Slant Range: 702.74353km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.930157910666529, 48.9320666703383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.343125395536139, 48.802416890282515], [-7.260711033870993, 48.8284773542577], [-7.178207054206418, 48.85447269002733], [-7.095613506225707, 48.88040277181351], [-7.012930440940503, 48.9062674738404], [-6.930157910666529, 48.9320666703383], [-6.847295969060075, 48.95780023554315]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.847296&lt;dd&gt;Longitude: 48.9578&lt;dd&gt;Azimuth: 229.08942\u00b0&lt;dd&gt;Altitude: 50.279102\u00b0&lt;dd&gt;Slant Range: 698.66934km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.847295969060075, 48.95780023554315]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.260711033870993, 48.8284773542577], [-7.178207054206418, 48.85447269002733], [-7.095613506225707, 48.88040277181351], [-7.012930440940503, 48.9062674738404], [-6.930157910666529, 48.9320666703383], [-6.847295969060075, 48.95780023554315], [-6.764344671099163, 48.98346804370026]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.7643447&lt;dd&gt;Longitude: 48.983468&lt;dd&gt;Azimuth: 228.78064\u00b0&lt;dd&gt;Altitude: 50.738695\u00b0&lt;dd&gt;Slant Range: 694.64169km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.764344671099163, 48.98346804370026]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.178207054206418, 48.85447269002733], [-7.095613506225707, 48.88040277181351], [-7.012930440940503, 48.9062674738404], [-6.930157910666529, 48.9320666703383], [-6.847295969060075, 48.95780023554315], [-6.764344671099163, 48.98346804370026], [-6.681304073108925, 49.009069969065735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.6813041&lt;dd&gt;Longitude: 49.00907&lt;dd&gt;Azimuth: 228.46196\u00b0&lt;dd&gt;Altitude: 51.202381\u00b0&lt;dd&gt;Slant Range: 690.66139km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.681304073108925, 49.009069969065735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.095613506225707, 48.88040277181351], [-7.012930440940503, 48.9062674738404], [-6.930157910666529, 48.9320666703383], [-6.847295969060075, 48.95780023554315], [-6.764344671099163, 48.98346804370026], [-6.681304073108925, 49.009069969065735], [-6.598174232742842, 49.03460588590879]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.5981742&lt;dd&gt;Longitude: 49.034606&lt;dd&gt;Azimuth: 228.13292\u00b0&lt;dd&gt;Altitude: 51.670124\u00b0&lt;dd&gt;Slant Range: 686.72927km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.598174232742842, 49.03460588590879]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.012930440940503, 48.9062674738404], [-6.930157910666529, 48.9320666703383], [-6.847295969060075, 48.95780023554315], [-6.764344671099163, 48.98346804370026], [-6.681304073108925, 49.009069969065735], [-6.598174232742842, 49.03460588590879], [-6.514955209014428, 49.060075668512646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.5149552&lt;dd&gt;Longitude: 49.060076&lt;dd&gt;Azimuth: 227.79303\u00b0&lt;dd&gt;Altitude: 52.141879\u00b0&lt;dd&gt;Slant Range: 682.84617km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.514955209014428, 49.060075668512646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.930157910666529, 48.9320666703383], [-6.847295969060075, 48.95780023554315], [-6.764344671099163, 48.98346804370026], [-6.681304073108925, 49.009069969065735], [-6.598174232742842, 49.03460588590879], [-6.514955209014428, 49.060075668512646], [-6.431647062279389, 49.08547919117903]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.4316471&lt;dd&gt;Longitude: 49.085479&lt;dd&gt;Azimuth: 227.44179\u00b0&lt;dd&gt;Altitude: 52.617594\u00b0&lt;dd&gt;Slant Range: 679.01293km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.431647062279389, 49.08547919117903]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.847295969060075, 48.95780023554315], [-6.764344671099163, 48.98346804370026], [-6.681304073108925, 49.009069969065735], [-6.598174232742842, 49.03460588590879], [-6.514955209014428, 49.060075668512646], [-6.431647062279389, 49.08547919117903], [-6.348249854255421, 49.1108163282272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.3482499&lt;dd&gt;Longitude: 49.110816&lt;dd&gt;Azimuth: 227.07864\u00b0&lt;dd&gt;Altitude: 53.09721\u00b0&lt;dd&gt;Slant Range: 675.23041km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.348249854255421, 49.1108163282272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.764344671099163, 48.98346804370026], [-6.681304073108925, 49.009069969065735], [-6.598174232742842, 49.03460588590879], [-6.514955209014428, 49.060075668512646], [-6.431647062279389, 49.08547919117903], [-6.348249854255421, 49.1108163282272], [-6.264763648022237, 49.13608695399841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.2647636&lt;dd&gt;Longitude: 49.136087&lt;dd&gt;Azimuth: 226.703\u00b0&lt;dd&gt;Altitude: 53.580661\u00b0&lt;dd&gt;Slant Range: 671.49946km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.264763648022237, 49.13608695399841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.681304073108925, 49.009069969065735], [-6.598174232742842, 49.03460588590879], [-6.514955209014428, 49.060075668512646], [-6.431647062279389, 49.08547919117903], [-6.348249854255421, 49.1108163282272], [-6.264763648022237, 49.13608695399841], [-6.181188508028791, 49.1612909428568]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.1811885&lt;dd&gt;Longitude: 49.161291&lt;dd&gt;Azimuth: 226.31427\u00b0&lt;dd&gt;Altitude: 54.06787\u00b0&lt;dd&gt;Slant Range: 667.82095km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.181188508028791, 49.1612909428568]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.598174232742842, 49.03460588590879], [-6.514955209014428, 49.060075668512646], [-6.431647062279389, 49.08547919117903], [-6.348249854255421, 49.1108163282272], [-6.264763648022237, 49.13608695399841], [-6.181188508028791, 49.1612909428568], [-6.097524500089053, 49.18642816919197]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.0975245&lt;dd&gt;Longitude: 49.186428&lt;dd&gt;Azimuth: 225.91178\u00b0&lt;dd&gt;Altitude: 54.558753\u00b0&lt;dd&gt;Slant Range: 664.19577km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.097524500089053, 49.18642816919197]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.514955209014428, 49.060075668512646], [-6.431647062279389, 49.08547919117903], [-6.348249854255421, 49.1108163282272], [-6.264763648022237, 49.13608695399841], [-6.181188508028791, 49.1612909428568], [-6.097524500089053, 49.18642816919197], [-6.013771691403284, 49.21149850742067]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -6.0137717&lt;dd&gt;Longitude: 49.211499&lt;dd&gt;Azimuth: 225.49483\u00b0&lt;dd&gt;Altitude: 55.053214\u00b0&lt;dd&gt;Slant Range: 660.62479km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.013771691403284, 49.21149850742067]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.431647062279389, 49.08547919117903], [-6.348249854255421, 49.1108163282272], [-6.264763648022237, 49.13608695399841], [-6.181188508028791, 49.1612909428568], [-6.097524500089053, 49.18642816919197], [-6.013771691403284, 49.21149850742067], [-5.929930150546712, 49.2365018319896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.9299302&lt;dd&gt;Longitude: 49.236502&lt;dd&gt;Azimuth: 225.0627\u00b0&lt;dd&gt;Altitude: 55.551147\u00b0&lt;dd&gt;Slant Range: 657.1089km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.929930150546712, 49.2365018319896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.348249854255421, 49.1108163282272], [-6.264763648022237, 49.13608695399841], [-6.181188508028791, 49.1612909428568], [-6.097524500089053, 49.18642816919197], [-6.013771691403284, 49.21149850742067], [-5.929930150546712, 49.2365018319896], [-5.845999947489808, 49.2614380173763]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.8459999&lt;dd&gt;Longitude: 49.261438&lt;dd&gt;Azimuth: 224.6146\u00b0&lt;dd&gt;Altitude: 56.052436\u00b0&lt;dd&gt;Slant Range: 653.64899km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.845999947489808, 49.2614380173763]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.264763648022237, 49.13608695399841], [-6.181188508028791, 49.1612909428568], [-6.097524500089053, 49.18642816919197], [-6.013771691403284, 49.21149850742067], [-5.929930150546712, 49.2365018319896], [-5.845999947489808, 49.2614380173763], [-5.761981153586181, 49.286306938093226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.7619812&lt;dd&gt;Longitude: 49.286307&lt;dd&gt;Azimuth: 224.14968\u00b0&lt;dd&gt;Altitude: 56.55695\u00b0&lt;dd&gt;Slant Range: 650.24595km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.761981153586181, 49.286306938093226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.181188508028791, 49.1612909428568], [-6.097524500089053, 49.18642816919197], [-6.013771691403284, 49.21149850742067], [-5.929930150546712, 49.2365018319896], [-5.845999947489808, 49.2614380173763], [-5.761981153586181, 49.286306938093226], [-5.677873841595393, 49.31110846868776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.6778738&lt;dd&gt;Longitude: 49.311108&lt;dd&gt;Azimuth: 223.66705\u00b0&lt;dd&gt;Altitude: 57.064547\u00b0&lt;dd&gt;Slant Range: 646.9007km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.677873841595393, 49.31110846868776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.097524500089053, 49.18642816919197], [-6.013771691403284, 49.21149850742067], [-5.929930150546712, 49.2365018319896], [-5.845999947489808, 49.2614380173763], [-5.761981153586181, 49.286306938093226], [-5.677873841595393, 49.31110846868776], [-5.593678085674599, 49.33584248374591]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.5936781&lt;dd&gt;Longitude: 49.335842&lt;dd&gt;Azimuth: 223.16577\u00b0&lt;dd&gt;Altitude: 57.575069\u00b0&lt;dd&gt;Slant Range: 643.61414km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.593678085674599, 49.33584248374591]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.013771691403284, 49.21149850742067], [-5.929930150546712, 49.2365018319896], [-5.845999947489808, 49.2614380173763], [-5.761981153586181, 49.286306938093226], [-5.677873841595393, 49.31110846868776], [-5.593678085674599, 49.33584248374591], [-5.509393961384462, 49.36050885789388]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.509394&lt;dd&gt;Longitude: 49.360509&lt;dd&gt;Azimuth: 222.64481\u00b0&lt;dd&gt;Altitude: 58.088346\u00b0&lt;dd&gt;Slant Range: 640.38717km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.509393961384462, 49.36050885789388]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.929930150546712, 49.2365018319896], [-5.845999947489808, 49.2614380173763], [-5.761981153586181, 49.286306938093226], [-5.677873841595393, 49.31110846868776], [-5.593678085674599, 49.33584248374591], [-5.509393961384462, 49.36050885789388], [-5.425021545703898, 49.38510746580029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.4250215&lt;dd&gt;Longitude: 49.385107&lt;dd&gt;Azimuth: 222.1031\u00b0&lt;dd&gt;Altitude: 58.604188\u00b0&lt;dd&gt;Slant Range: 637.2207km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.425021545703898, 49.38510746580029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.845999947489808, 49.2614380173763], [-5.761981153586181, 49.286306938093226], [-5.677873841595393, 49.31110846868776], [-5.593678085674599, 49.33584248374591], [-5.509393961384462, 49.36050885789388], [-5.425021545703898, 49.38510746580029], [-5.340560917026787, 49.40963818217847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.3405609&lt;dd&gt;Longitude: 49.409638&lt;dd&gt;Azimuth: 221.53948\u00b0&lt;dd&gt;Altitude: 59.122389\u00b0&lt;dd&gt;Slant Range: 634.11564km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.340560917026787, 49.40963818217847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.761981153586181, 49.286306938093226], [-5.677873841595393, 49.31110846868776], [-5.593678085674599, 49.33584248374591], [-5.509393961384462, 49.36050885789388], [-5.425021545703898, 49.38510746580029], [-5.340560917026787, 49.40963818217847], [-5.2560121551657115, 49.434100881788744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.2560122&lt;dd&gt;Longitude: 49.434101&lt;dd&gt;Azimuth: 220.95272\u00b0&lt;dd&gt;Altitude: 59.642726\u00b0&lt;dd&gt;Slant Range: 631.0729km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.2560121551657115, 49.434100881788744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.677873841595393, 49.31110846868776], [-5.593678085674599, 49.33584248374591], [-5.509393961384462, 49.36050885789388], [-5.425021545703898, 49.38510746580029], [-5.340560917026787, 49.40963818217847], [-5.2560121551657115, 49.434100881788744], [-5.171375341360538, 49.458495439439766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.1713753&lt;dd&gt;Longitude: 49.458495&lt;dd&gt;Azimuth: 220.34151\u00b0&lt;dd&gt;Altitude: 60.164953\u00b0&lt;dd&gt;Slant Range: 628.09339km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.171375341360538, 49.458495439439766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.593678085674599, 49.33584248374591], [-5.509393961384462, 49.36050885789388], [-5.425021545703898, 49.38510746580029], [-5.340560917026787, 49.40963818217847], [-5.2560121551657115, 49.434100881788744], [-5.171375341360538, 49.458495439439766], [-5.086650558285714, 49.482821729992864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.0866506&lt;dd&gt;Longitude: 49.482822&lt;dd&gt;Azimuth: 219.70444\u00b0&lt;dd&gt;Altitude: 60.688805\u00b0&lt;dd&gt;Slant Range: 625.17801km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.086650558285714, 49.482821729992864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.509393961384462, 49.36050885789388], [-5.425021545703898, 49.38510746580029], [-5.340560917026787, 49.40963818217847], [-5.2560121551657115, 49.434100881788744], [-5.171375341360538, 49.458495439439766], [-5.086650558285714, 49.482821729992864], [-5.001837890045156, 49.50707962836154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -5.0018379&lt;dd&gt;Longitude: 49.50708&lt;dd&gt;Azimuth: 219.04001\u00b0&lt;dd&gt;Altitude: 61.213991\u00b0&lt;dd&gt;Slant Range: 622.32768km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.001837890045156, 49.50707962836154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.425021545703898, 49.38510746580029], [-5.340560917026787, 49.40963818217847], [-5.2560121551657115, 49.434100881788744], [-5.171375341360538, 49.458495439439766], [-5.086650558285714, 49.482821729992864], [-5.001837890045156, 49.50707962836154], [-4.916937422185988, 49.5312690095159]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1597&lt;dd&gt;Latitude: -4.9169374&lt;dd&gt;Longitude: 49.531269&lt;dd&gt;Azimuth: 218.34663\u00b0&lt;dd&gt;Altitude: 61.740198\u00b0&lt;dd&gt;Slant Range: 619.54329km&quot;, &quot;name&quot;: &quot;STARLINK-1597&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.916937422185988, 49.5312690095159]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -11.289266&lt;dd&gt;Longitude: 52.221859&lt;dd&gt;Azimuth: 281.47568\u00b0&lt;dd&gt;Altitude: 38.501399\u00b0&lt;dd&gt;Slant Range: 837.75385km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609], [-11.193425304298447, 52.234973948452634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -11.193425&lt;dd&gt;Longitude: 52.234974&lt;dd&gt;Azimuth: 281.66653\u00b0&lt;dd&gt;Altitude: 38.833469\u00b0&lt;dd&gt;Slant Range: 832.75565km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.193425304298447, 52.234973948452634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609], [-11.193425304298447, 52.234973948452634], [-11.097525491781468, 52.248003802875125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -11.097525&lt;dd&gt;Longitude: 52.248004&lt;dd&gt;Azimuth: 281.86142\u00b0&lt;dd&gt;Altitude: 39.16885\u00b0&lt;dd&gt;Slant Range: 827.78591km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.097525491781468, 52.248003802875125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609], [-11.193425304298447, 52.234973948452634], [-11.097525491781468, 52.248003802875125], [-11.001567303430352, 52.2609488661072]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -11.001567&lt;dd&gt;Longitude: 52.260949&lt;dd&gt;Azimuth: 282.06049\u00b0&lt;dd&gt;Altitude: 39.507568\u00b0&lt;dd&gt;Slant Range: 822.84513km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.001567303430352, 52.2609488661072]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609], [-11.193425304298447, 52.234973948452634], [-11.097525491781468, 52.248003802875125], [-11.001567303430352, 52.2609488661072], [-10.90555105973415, 52.27380904994925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.905551&lt;dd&gt;Longitude: 52.273809&lt;dd&gt;Azimuth: 282.26386\u00b0&lt;dd&gt;Altitude: 39.849647\u00b0&lt;dd&gt;Slant Range: 817.93386km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.90555105973415, 52.27380904994925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609], [-11.193425304298447, 52.234973948452634], [-11.097525491781468, 52.248003802875125], [-11.001567303430352, 52.2609488661072], [-10.90555105973415, 52.27380904994925], [-10.809477082687025, 52.286584266661585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.809477&lt;dd&gt;Longitude: 52.286584&lt;dd&gt;Azimuth: 282.47168\u00b0&lt;dd&gt;Altitude: 40.195113\u00b0&lt;dd&gt;Slant Range: 813.05262km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.809477082687025, 52.286584266661585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.289266422020482, 52.22185939149609], [-11.193425304298447, 52.234973948452634], [-11.097525491781468, 52.248003802875125], [-11.001567303430352, 52.2609488661072], [-10.90555105973415, 52.27380904994925], [-10.809477082687025, 52.286584266661585], [-10.713345695800168, 52.299274428966406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.713346&lt;dd&gt;Longitude: 52.299274&lt;dd&gt;Azimuth: 282.68409\u00b0&lt;dd&gt;Altitude: 40.543988\u00b0&lt;dd&gt;Slant Range: 808.20198km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.713345695800168, 52.299274428966406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.193425304298447, 52.234973948452634], [-11.097525491781468, 52.248003802875125], [-11.001567303430352, 52.2609488661072], [-10.90555105973415, 52.27380904994925], [-10.809477082687025, 52.286584266661585], [-10.713345695800168, 52.299274428966406], [-10.617157224076571, 52.31187945005175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.617157&lt;dd&gt;Longitude: 52.311879&lt;dd&gt;Azimuth: 282.90125\u00b0&lt;dd&gt;Altitude: 40.896293\u00b0&lt;dd&gt;Slant Range: 803.38248km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.617157224076571, 52.31187945005175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.097525491781468, 52.248003802875125], [-11.001567303430352, 52.2609488661072], [-10.90555105973415, 52.27380904994925], [-10.809477082687025, 52.286584266661585], [-10.713345695800168, 52.299274428966406], [-10.617157224076571, 52.31187945005175], [-10.52091199402758, 52.32439924357279]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.520912&lt;dd&gt;Longitude: 52.324399&lt;dd&gt;Azimuth: 283.12331\u00b0&lt;dd&gt;Altitude: 41.252048\u00b0&lt;dd&gt;Slant Range: 798.59471km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.52091199402758, 52.32439924357279]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.001567303430352, 52.2609488661072], [-10.90555105973415, 52.27380904994925], [-10.809477082687025, 52.286584266661585], [-10.713345695800168, 52.299274428966406], [-10.617157224076571, 52.31187945005175], [-10.52091199402758, 52.32439924357279], [-10.424610333647792, 52.336833723656035]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.42461&lt;dd&gt;Longitude: 52.336834&lt;dd&gt;Azimuth: 283.35043\u00b0&lt;dd&gt;Altitude: 41.611272\u00b0&lt;dd&gt;Slant Range: 793.83923km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.424610333647792, 52.336833723656035]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.90555105973415, 52.27380904994925], [-10.809477082687025, 52.286584266661585], [-10.713345695800168, 52.299274428966406], [-10.617157224076571, 52.31187945005175], [-10.52091199402758, 52.32439924357279], [-10.424610333647792, 52.336833723656035], [-10.328252572419315, 52.34918280490068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.328253&lt;dd&gt;Longitude: 52.349183&lt;dd&gt;Azimuth: 283.58279\u00b0&lt;dd&gt;Altitude: 41.973982\u00b0&lt;dd&gt;Slant Range: 789.11664km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.328252572419315, 52.34918280490068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.809477082687025, 52.286584266661585], [-10.713345695800168, 52.299274428966406], [-10.617157224076571, 52.31187945005175], [-10.52091199402758, 52.32439924357279], [-10.424610333647792, 52.336833723656035], [-10.328252572419315, 52.34918280490068], [-10.231839041308046, 52.361446402382235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.231839&lt;dd&gt;Longitude: 52.361446&lt;dd&gt;Azimuth: 283.82056\u00b0&lt;dd&gt;Altitude: 42.340193\u00b0&lt;dd&gt;Slant Range: 784.42753km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.231839041308046, 52.361446402382235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.713345695800168, 52.299274428966406], [-10.617157224076571, 52.31187945005175], [-10.52091199402758, 52.32439924357279], [-10.424610333647792, 52.336833723656035], [-10.328252572419315, 52.34918280490068], [-10.231839041308046, 52.361446402382235], [-10.13537007275457, 52.37362443165486]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.13537&lt;dd&gt;Longitude: 52.373624&lt;dd&gt;Azimuth: 284.06394\u00b0&lt;dd&gt;Altitude: 42.709919\u00b0&lt;dd&gt;Slant Range: 779.77252km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.13537007275457, 52.37362443165486]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.617157224076571, 52.31187945005175], [-10.52091199402758, 52.32439924357279], [-10.424610333647792, 52.336833723656035], [-10.328252572419315, 52.34918280490068], [-10.231839041308046, 52.361446402382235], [-10.13537007275457, 52.37362443165486], [-10.038846000664357, 52.38571680875423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -10.038846&lt;dd&gt;Longitude: 52.385717&lt;dd&gt;Azimuth: 284.31312\u00b0&lt;dd&gt;Altitude: 43.083169\u00b0&lt;dd&gt;Slant Range: 775.15222km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.038846000664357, 52.38571680875423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.52091199402758, 52.32439924357279], [-10.424610333647792, 52.336833723656035], [-10.328252572419315, 52.34918280490068], [-10.231839041308046, 52.361446402382235], [-10.13537007275457, 52.37362443165486], [-10.038846000664357, 52.38571680875423], [-9.942267160407459, 52.397723450199756]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -9.9422672&lt;dd&gt;Longitude: 52.397723&lt;dd&gt;Azimuth: 284.56829\u00b0&lt;dd&gt;Altitude: 43.459954\u00b0&lt;dd&gt;Slant Range: 770.56727km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.942267160407459, 52.397723450199756]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.424610333647792, 52.336833723656035], [-10.328252572419315, 52.34918280490068], [-10.231839041308046, 52.361446402382235], [-10.13537007275457, 52.37362443165486], [-10.038846000664357, 52.38571680875423], [-9.942267160407459, 52.397723450199756], [-9.845633888815174, 52.409644272998165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -9.8456339&lt;dd&gt;Longitude: 52.409644&lt;dd&gt;Azimuth: 284.82969\u00b0&lt;dd&gt;Altitude: 43.840281\u00b0&lt;dd&gt;Slant Range: 766.0183km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.845633888815174, 52.409644272998165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.328252572419315, 52.34918280490068], [-10.231839041308046, 52.361446402382235], [-10.13537007275457, 52.37362443165486], [-10.038846000664357, 52.38571680875423], [-9.942267160407459, 52.397723450199756], [-9.845633888815174, 52.409644272998165], [-9.748946524162596, 52.42147919464501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -9.7489465&lt;dd&gt;Longitude: 52.421479&lt;dd&gt;Azimuth: 285.09751\u00b0&lt;dd&gt;Altitude: 44.224152\u00b0&lt;dd&gt;Slant Range: 761.50596km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.748946524162596, 52.42147919464501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.231839041308046, 52.361446402382235], [-10.13537007275457, 52.37362443165486], [-10.038846000664357, 52.38571680875423], [-9.942267160407459, 52.397723450199756], [-9.845633888815174, 52.409644272998165], [-9.748946524162596, 52.42147919464501], [-9.65220540617317, 52.433228133128196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1616&lt;dd&gt;Latitude: -9.6522054&lt;dd&gt;Longitude: 52.433228&lt;dd&gt;Azimuth: 285.37201\u00b0&lt;dd&gt;Altitude: 44.611569\u00b0&lt;dd&gt;Slant Range: 757.03092km&quot;, &quot;name&quot;: &quot;STARLINK-1616&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.65220540617317, 52.433228133128196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.5353522&lt;dd&gt;Longitude: 48.09771&lt;dd&gt;Azimuth: 235.86189\u00b0&lt;dd&gt;Altitude: 37.616647\u00b0&lt;dd&gt;Slant Range: 853.90479km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923], [-9.45530305014259, 48.1253565732957]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.4553031&lt;dd&gt;Longitude: 48.125357&lt;dd&gt;Azimuth: 235.73087\u00b0&lt;dd&gt;Altitude: 37.946074\u00b0&lt;dd&gt;Slant Range: 848.72765km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.45530305014259, 48.1253565732957]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923], [-9.45530305014259, 48.1253565732957], [-9.375163690176686, 48.15294116146178]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.3751637&lt;dd&gt;Longitude: 48.152941&lt;dd&gt;Azimuth: 235.59698\u00b0&lt;dd&gt;Altitude: 38.278999\u00b0&lt;dd&gt;Slant Range: 843.57654km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.375163690176686, 48.15294116146178]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923], [-9.45530305014259, 48.1253565732957], [-9.375163690176686, 48.15294116146178], [-9.294934127253917, 48.18046379372457]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.2949341&lt;dd&gt;Longitude: 48.180464&lt;dd&gt;Azimuth: 235.46012\u00b0&lt;dd&gt;Altitude: 38.615461\u00b0&lt;dd&gt;Slant Range: 838.45193km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.294934127253917, 48.18046379372457]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923], [-9.45530305014259, 48.1253565732957], [-9.375163690176686, 48.15294116146178], [-9.294934127253917, 48.18046379372457], [-9.214614380661137, 48.20792434520837]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.2146144&lt;dd&gt;Longitude: 48.207924&lt;dd&gt;Azimuth: 235.32021\u00b0&lt;dd&gt;Altitude: 38.9555\u00b0&lt;dd&gt;Slant Range: 833.35433km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.214614380661137, 48.20792434520837]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923], [-9.45530305014259, 48.1253565732957], [-9.375163690176686, 48.15294116146178], [-9.294934127253917, 48.18046379372457], [-9.214614380661137, 48.20792434520837], [-9.13420447087547, 48.235322690994934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.1342045&lt;dd&gt;Longitude: 48.235323&lt;dd&gt;Azimuth: 235.17713\u00b0&lt;dd&gt;Altitude: 39.299152\u00b0&lt;dd&gt;Slant Range: 828.28424km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.13420447087547, 48.235322690994934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.535352189022385, 48.09771015405923], [-9.45530305014259, 48.1253565732957], [-9.375163690176686, 48.15294116146178], [-9.294934127253917, 48.18046379372457], [-9.214614380661137, 48.20792434520837], [-9.13420447087547, 48.235322690994934], [-9.053704419548328, 48.26265870612742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -9.0537044&lt;dd&gt;Longitude: 48.262659&lt;dd&gt;Azimuth: 235.03079\u00b0&lt;dd&gt;Altitude: 39.646457\u00b0&lt;dd&gt;Slant Range: 823.24216km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.053704419548328, 48.26265870612742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.45530305014259, 48.1253565732957], [-9.375163690176686, 48.15294116146178], [-9.294934127253917, 48.18046379372457], [-9.214614380661137, 48.20792434520837], [-9.13420447087547, 48.235322690994934], [-9.053704419548328, 48.26265870612742], [-8.973114249523038, 48.28993226560945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.9731142&lt;dd&gt;Longitude: 48.289932&lt;dd&gt;Azimuth: 234.88107\u00b0&lt;dd&gt;Altitude: 39.997452\u00b0&lt;dd&gt;Slant Range: 818.22863km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.973114249523038, 48.28993226560945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.375163690176686, 48.15294116146178], [-9.294934127253917, 48.18046379372457], [-9.214614380661137, 48.20792434520837], [-9.13420447087547, 48.235322690994934], [-9.053704419548328, 48.26265870612742], [-8.973114249523038, 48.28993226560945], [-8.892433984837826, 48.317143244408825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.892434&lt;dd&gt;Longitude: 48.317143&lt;dd&gt;Azimuth: 234.72787\u00b0&lt;dd&gt;Altitude: 40.352173\u00b0&lt;dd&gt;Slant Range: 813.24418km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.892433984837826, 48.317143244408825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.294934127253917, 48.18046379372457], [-9.214614380661137, 48.20792434520837], [-9.13420447087547, 48.235322690994934], [-9.053704419548328, 48.26265870612742], [-8.973114249523038, 48.28993226560945], [-8.892433984837826, 48.317143244408825], [-8.8116636507324, 48.34429151745832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.8116637&lt;dd&gt;Longitude: 48.344292&lt;dd&gt;Azimuth: 234.57107\u00b0&lt;dd&gt;Altitude: 40.710658\u00b0&lt;dd&gt;Slant Range: 808.28935km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.8116636507324, 48.34429151745832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.214614380661137, 48.20792434520837], [-9.13420447087547, 48.235322690994934], [-9.053704419548328, 48.26265870612742], [-8.973114249523038, 48.28993226560945], [-8.892433984837826, 48.317143244408825], [-8.8116636507324, 48.34429151745832], [-8.730803273643817, 48.37137695965776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.7308033&lt;dd&gt;Longitude: 48.371377&lt;dd&gt;Azimuth: 234.41053\u00b0&lt;dd&gt;Altitude: 41.072942\u00b0&lt;dd&gt;Slant Range: 803.3647km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.730803273643817, 48.37137695965776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.13420447087547, 48.235322690994934], [-9.053704419548328, 48.26265870612742], [-8.973114249523038, 48.28993226560945], [-8.892433984837826, 48.317143244408825], [-8.8116636507324, 48.34429151745832], [-8.730803273643817, 48.37137695965776], [-8.64985288122852, 48.39839944587563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.6498529&lt;dd&gt;Longitude: 48.398399&lt;dd&gt;Azimuth: 234.24614\u00b0&lt;dd&gt;Altitude: 41.43906\u00b0&lt;dd&gt;Slant Range: 798.47078km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.64985288122852, 48.39839944587563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.053704419548328, 48.26265870612742], [-8.973114249523038, 48.28993226560945], [-8.892433984837826, 48.317143244408825], [-8.8116636507324, 48.34429151745832], [-8.730803273643817, 48.37137695965776], [-8.64985288122852, 48.39839944587563], [-8.568812502352339, 48.42535885095115]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.5688125&lt;dd&gt;Longitude: 48.425359&lt;dd&gt;Azimuth: 234.07775\u00b0&lt;dd&gt;Altitude: 41.809045\u00b0&lt;dd&gt;Slant Range: 793.60818km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.568812502352339, 48.42535885095115]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.973114249523038, 48.28993226560945], [-8.892433984837826, 48.317143244408825], [-8.8116636507324, 48.34429151745832], [-8.730803273643817, 48.37137695965776], [-8.64985288122852, 48.39839944587563], [-8.568812502352339, 48.42535885095115], [-8.48768216711034, 48.45225504969486]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.4876822&lt;dd&gt;Longitude: 48.452255&lt;dd&gt;Azimuth: 233.90522\u00b0&lt;dd&gt;Altitude: 42.182932\u00b0&lt;dd&gt;Slant Range: 788.77747km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.48768216711034, 48.45225504969486]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.892433984837826, 48.317143244408825], [-8.8116636507324, 48.34429151745832], [-8.730803273643817, 48.37137695965776], [-8.64985288122852, 48.39839944587563], [-8.568812502352339, 48.42535885095115], [-8.48768216711034, 48.45225504969486], [-8.406461906815439, 48.47908791689274]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.4064619&lt;dd&gt;Longitude: 48.479088&lt;dd&gt;Azimuth: 233.72841\u00b0&lt;dd&gt;Altitude: 42.560752\u00b0&lt;dd&gt;Slant Range: 783.97926km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.406461906815439, 48.47908791689274]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.8116636507324, 48.34429151745832], [-8.730803273643817, 48.37137695965776], [-8.64985288122852, 48.39839944587563], [-8.568812502352339, 48.42535885095115], [-8.48768216711034, 48.45225504969486], [-8.406461906815439, 48.47908791689274], [-8.325151754021734, 48.50585732730545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.3251518&lt;dd&gt;Longitude: 48.505857&lt;dd&gt;Azimuth: 233.54716\u00b0&lt;dd&gt;Altitude: 42.942535\u00b0&lt;dd&gt;Slant Range: 779.21415km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.325151754021734, 48.50585732730545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.730803273643817, 48.37137695965776], [-8.64985288122852, 48.39839944587563], [-8.568812502352339, 48.42535885095115], [-8.48768216711034, 48.45225504969486], [-8.406461906815439, 48.47908791689274], [-8.325151754021734, 48.50585732730545], [-8.243751742517354, 48.53256315567175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.2437517&lt;dd&gt;Longitude: 48.532563&lt;dd&gt;Azimuth: 233.36131\u00b0&lt;dd&gt;Altitude: 43.328312\u00b0&lt;dd&gt;Slant Range: 774.48274km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.243751742517354, 48.53256315567175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.64985288122852, 48.39839944587563], [-8.568812502352339, 48.42535885095115], [-8.48768216711034, 48.45225504969486], [-8.406461906815439, 48.47908791689274], [-8.325151754021734, 48.50585732730545], [-8.243751742517354, 48.53256315567175], [-8.162261907330176, 48.55920527670986]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.1622619&lt;dd&gt;Longitude: 48.559205&lt;dd&gt;Azimuth: 233.17068\u00b0&lt;dd&gt;Altitude: 43.71811\u00b0&lt;dd&gt;Slant Range: 769.78568km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.162261907330176, 48.55920527670986]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.568812502352339, 48.42535885095115], [-8.48768216711034, 48.45225504969486], [-8.406461906815439, 48.47908791689274], [-8.325151754021734, 48.50585732730545], [-8.243751742517354, 48.53256315567175], [-8.162261907330176, 48.55920527670986], [-8.080682284743311, 48.58578356511917]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -8.0806823&lt;dd&gt;Longitude: 48.585784&lt;dd&gt;Azimuth: 232.9751\u00b0&lt;dd&gt;Altitude: 44.111956\u00b0&lt;dd&gt;Slant Range: 765.1236km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.080682284743311, 48.58578356511917]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.48768216711034, 48.45225504969486], [-8.406461906815439, 48.47908791689274], [-8.325151754021734, 48.50585732730545], [-8.243751742517354, 48.53256315567175], [-8.162261907330176, 48.55920527670986], [-8.080682284743311, 48.58578356511917], [-7.999012912292568, 48.612297895582415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -7.9990129&lt;dd&gt;Longitude: 48.612298&lt;dd&gt;Azimuth: 232.77438\u00b0&lt;dd&gt;Altitude: 44.509874\u00b0&lt;dd&gt;Slant Range: 760.49714km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.999012912292568, 48.612297895582415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.406461906815439, 48.47908791689274], [-8.325151754021734, 48.50585732730545], [-8.243751742517354, 48.53256315567175], [-8.162261907330176, 48.55920527670986], [-8.080682284743311, 48.58578356511917], [-7.999012912292568, 48.612297895582415], [-7.91725382877102, 48.63874814276732]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -7.9172538&lt;dd&gt;Longitude: 48.638748&lt;dd&gt;Azimuth: 232.56832\u00b0&lt;dd&gt;Altitude: 44.911887\u00b0&lt;dd&gt;Slant Range: 755.90697km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.91725382877102, 48.63874814276732]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.325151754021734, 48.50585732730545], [-8.243751742517354, 48.53256315567175], [-8.162261907330176, 48.55920527670986], [-8.080682284743311, 48.58578356511917], [-7.999012912292568, 48.612297895582415], [-7.91725382877102, 48.63874814276732], [-7.835405074237347, 48.665134181327836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -7.8354051&lt;dd&gt;Longitude: 48.665134&lt;dd&gt;Azimuth: 232.35672\u00b0&lt;dd&gt;Altitude: 45.318016\u00b0&lt;dd&gt;Slant Range: 751.35376km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.835405074237347, 48.665134181327836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.243751742517354, 48.53256315567175], [-8.162261907330176, 48.55920527670986], [-8.080682284743311, 48.58578356511917], [-7.999012912292568, 48.612297895582415], [-7.91725382877102, 48.63874814276732], [-7.835405074237347, 48.665134181327836], [-7.75346669002563, 48.691455885907835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -7.7534667&lt;dd&gt;Longitude: 48.691456&lt;dd&gt;Azimuth: 232.13935\u00b0&lt;dd&gt;Altitude: 45.72828\u00b0&lt;dd&gt;Slant Range: 746.83818km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.75346669002563, 48.691455885907835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.162261907330176, 48.55920527670986], [-8.080682284743311, 48.58578356511917], [-7.999012912292568, 48.612297895582415], [-7.91725382877102, 48.63874814276732], [-7.835405074237347, 48.665134181327836], [-7.75346669002563, 48.691455885907835], [-7.67143871873777, 48.71771313114076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -7.6714387&lt;dd&gt;Longitude: 48.717713&lt;dd&gt;Azimuth: 231.916\u00b0&lt;dd&gt;Altitude: 46.142694\u00b0&lt;dd&gt;Slant Range: 742.36093km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.67143871873777, 48.71771313114076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.080682284743311, 48.58578356511917], [-7.999012912292568, 48.612297895582415], [-7.91725382877102, 48.63874814276732], [-7.835405074237347, 48.665134181327836], [-7.75346669002563, 48.691455885907835], [-7.67143871873777, 48.71771313114076], [-7.589321204262166, 48.743905791652935]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1628&lt;dd&gt;Latitude: -7.5893212&lt;dd&gt;Longitude: 48.743906&lt;dd&gt;Azimuth: 231.68641\u00b0&lt;dd&gt;Altitude: 46.561272\u00b0&lt;dd&gt;Slant Range: 737.92271km&quot;, &quot;name&quot;: &quot;STARLINK-1628&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.589321204262166, 48.743905791652935]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1726&lt;dd&gt;Latitude: 1.9713905&lt;dd&gt;Longitude: 46.831893&lt;dd&gt;Azimuth: 145.29132\u00b0&lt;dd&gt;Altitude: 37.98509\u00b0&lt;dd&gt;Slant Range: 843.68501km&quot;, &quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462], [2.04750833676468, 46.86218588176947]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1726&lt;dd&gt;Latitude: 2.0475083&lt;dd&gt;Longitude: 46.862186&lt;dd&gt;Azimuth: 144.66335\u00b0&lt;dd&gt;Altitude: 37.977102\u00b0&lt;dd&gt;Slant Range: 843.8204km&quot;, &quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.04750833676468, 46.86218588176947]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462], [2.04750833676468, 46.86218588176947], [2.1237162940549332, 46.89242234119068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1726&lt;dd&gt;Latitude: 2.1237163&lt;dd&gt;Longitude: 46.892422&lt;dd&gt;Azimuth: 144.03581\u00b0&lt;dd&gt;Altitude: 37.965367\u00b0&lt;dd&gt;Slant Range: 844.01404km&quot;, &quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1237162940549332, 46.89242234119068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462], [2.04750833676468, 46.86218588176947], [2.1237162940549332, 46.89242234119068], [2.20001443567838, 46.92260221595891]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1726&lt;dd&gt;Latitude: 2.2000144&lt;dd&gt;Longitude: 46.922602&lt;dd&gt;Azimuth: 143.40883\u00b0&lt;dd&gt;Altitude: 37.949894\u00b0&lt;dd&gt;Slant Range: 844.26589km&quot;, &quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.20001443567838, 46.92260221595891]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462], [2.04750833676468, 46.86218588176947], [2.1237162940549332, 46.89242234119068], [2.20001443567838, 46.92260221595891], [2.2764027890729532, 46.95272538421702]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1726&lt;dd&gt;Latitude: 2.2764028&lt;dd&gt;Longitude: 46.952725&lt;dd&gt;Azimuth: 142.78257\u00b0&lt;dd&gt;Altitude: 37.930695\u00b0&lt;dd&gt;Slant Range: 844.5759km&quot;, &quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2764027890729532, 46.95272538421702]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9713905354420345, 46.8318929594462], [2.04750833676468, 46.86218588176947], [2.1237162940549332, 46.89242234119068], [2.20001443567838, 46.92260221595891], [2.2764027890729532, 46.95272538421702], [2.3528813807501794, 46.98279172400072]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1726&lt;dd&gt;Latitude: 2.3528814&lt;dd&gt;Longitude: 46.982792&lt;dd&gt;Azimuth: 142.15717\u00b0&lt;dd&gt;Altitude: 37.907784\u00b0&lt;dd&gt;Slant Range: 844.944km&quot;, &quot;name&quot;: &quot;STARLINK-1726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3528813807501794, 46.98279172400072]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -9.3153061&lt;dd&gt;Longitude: 49.557267&lt;dd&gt;Azimuth: 248.66362\u00b0&lt;dd&gt;Altitude: 43.091689\u00b0&lt;dd&gt;Slant Range: 773.94017km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667], [-9.230217146369283, 49.58130999649358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -9.2302171&lt;dd&gt;Longitude: 49.58131&lt;dd&gt;Azimuth: 248.62444\u00b0&lt;dd&gt;Altitude: 43.493337\u00b0&lt;dd&gt;Slant Range: 769.06656km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.230217146369283, 49.58130999649358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667], [-9.230217146369283, 49.58130999649358], [-9.145040720891238, 49.605284061815716]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -9.1450407&lt;dd&gt;Longitude: 49.605284&lt;dd&gt;Azimuth: 248.58415\u00b0&lt;dd&gt;Altitude: 43.89969\u00b0&lt;dd&gt;Slant Range: 764.22569km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.145040720891238, 49.605284061815716]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667], [-9.230217146369283, 49.58130999649358], [-9.145040720891238, 49.605284061815716], [-9.059776870091241, 49.629189090191865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -9.0597769&lt;dd&gt;Longitude: 49.629189&lt;dd&gt;Azimuth: 248.54269\u00b0&lt;dd&gt;Altitude: 44.310804\u00b0&lt;dd&gt;Slant Range: 759.4182km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.059776870091241, 49.629189090191865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667], [-9.230217146369283, 49.58130999649358], [-9.145040720891238, 49.605284061815716], [-9.059776870091241, 49.629189090191865], [-8.97442568700619, 49.65302495691837]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.9744257&lt;dd&gt;Longitude: 49.653025&lt;dd&gt;Azimuth: 248.50002\u00b0&lt;dd&gt;Altitude: 44.726737\u00b0&lt;dd&gt;Slant Range: 754.64473km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.97442568700619, 49.65302495691837]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667], [-9.230217146369283, 49.58130999649358], [-9.145040720891238, 49.605284061815716], [-9.059776870091241, 49.629189090191865], [-8.97442568700619, 49.65302495691837], [-8.888987266135707, 49.67679153736145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.8889873&lt;dd&gt;Longitude: 49.676792&lt;dd&gt;Azimuth: 248.45609\u00b0&lt;dd&gt;Altitude: 45.147543\u00b0&lt;dd&gt;Slant Range: 749.90594km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.888987266135707, 49.67679153736145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.315306054957103, 49.55726701899667], [-9.230217146369283, 49.58130999649358], [-9.145040720891238, 49.605284061815716], [-9.059776870091241, 49.629189090191865], [-8.97442568700619, 49.65302495691837], [-8.888987266135707, 49.67679153736145], [-8.803461703457918, 49.70048870695974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.8034617&lt;dd&gt;Longitude: 49.700489&lt;dd&gt;Azimuth: 248.41085\u00b0&lt;dd&gt;Altitude: 45.573277\u00b0&lt;dd&gt;Slant Range: 745.2025km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.803461703457918, 49.70048870695974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.230217146369283, 49.58130999649358], [-9.145040720891238, 49.605284061815716], [-9.059776870091241, 49.629189090191865], [-8.97442568700619, 49.65302495691837], [-8.888987266135707, 49.67679153736145], [-8.803461703457918, 49.70048870695974], [-8.717849096419009, 49.72411634122585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.7178491&lt;dd&gt;Longitude: 49.724116&lt;dd&gt;Azimuth: 248.36425\u00b0&lt;dd&gt;Altitude: 46.003995\u00b0&lt;dd&gt;Slant Range: 740.53509km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.717849096419009, 49.72411634122585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.145040720891238, 49.605284061815716], [-9.059776870091241, 49.629189090191865], [-8.97442568700619, 49.65302495691837], [-8.888987266135707, 49.67679153736145], [-8.803461703457918, 49.70048870695974], [-8.717849096419009, 49.72411634122585], [-8.632149543958406, 49.74767431574989]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.6321495&lt;dd&gt;Longitude: 49.747674&lt;dd&gt;Azimuth: 248.31622\u00b0&lt;dd&gt;Altitude: 46.43975\u00b0&lt;dd&gt;Slant Range: 735.90438km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.632149543958406, 49.74767431574989]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.059776870091241, 49.629189090191865], [-8.97442568700619, 49.65302495691837], [-8.888987266135707, 49.67679153736145], [-8.803461703457918, 49.70048870695974], [-8.717849096419009, 49.72411634122585], [-8.632149543958406, 49.74767431574989], [-8.546363146487085, 49.77116250620085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.5463631&lt;dd&gt;Longitude: 49.771163&lt;dd&gt;Azimuth: 248.2667\u00b0&lt;dd&gt;Altitude: 46.880597\u00b0&lt;dd&gt;Slant Range: 731.3111km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.546363146487085, 49.77116250620085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.97442568700619, 49.65302495691837], [-8.888987266135707, 49.67679153736145], [-8.803461703457918, 49.70048870695974], [-8.717849096419009, 49.72411634122585], [-8.632149543958406, 49.74767431574989], [-8.546363146487085, 49.77116250620085], [-8.460490005919482, 49.794580788329746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.46049&lt;dd&gt;Longitude: 49.794581&lt;dd&gt;Azimuth: 248.21562\u00b0&lt;dd&gt;Altitude: 47.326587\u00b0&lt;dd&gt;Slant Range: 726.75594km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.460490005919482, 49.794580788329746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.888987266135707, 49.67679153736145], [-8.803461703457918, 49.70048870695974], [-8.717849096419009, 49.72411634122585], [-8.632149543958406, 49.74767431574989], [-8.546363146487085, 49.77116250620085], [-8.460490005919482, 49.794580788329746], [-8.374530225652174, 49.81792903797093]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.3745302&lt;dd&gt;Longitude: 49.817929&lt;dd&gt;Azimuth: 248.16293\u00b0&lt;dd&gt;Altitude: 47.777772\u00b0&lt;dd&gt;Slant Range: 722.23965km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.374530225652174, 49.81792903797093]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.803461703457918, 49.70048870695974], [-8.717849096419009, 49.72411634122585], [-8.632149543958406, 49.74767431574989], [-8.546363146487085, 49.77116250620085], [-8.460490005919482, 49.794580788329746], [-8.374530225652174, 49.81792903797093], [-8.288483910587106, 49.84120713104561]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.2884839&lt;dd&gt;Longitude: 49.841207&lt;dd&gt;Azimuth: 248.10853\u00b0&lt;dd&gt;Altitude: 48.234204\u00b0&lt;dd&gt;Slant Range: 717.76295km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.288483910587106, 49.84120713104561]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.717849096419009, 49.72411634122585], [-8.632149543958406, 49.74767431574989], [-8.546363146487085, 49.77116250620085], [-8.460490005919482, 49.794580788329746], [-8.374530225652174, 49.81792903797093], [-8.288483910587106, 49.84120713104561], [-8.202351167128919, 49.86441494356367]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.2023512&lt;dd&gt;Longitude: 49.864415&lt;dd&gt;Azimuth: 248.05236\u00b0&lt;dd&gt;Altitude: 48.69593\u00b0&lt;dd&gt;Slant Range: 713.32659km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.202351167128919, 49.86441494356367]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.632149543958406, 49.74767431574989], [-8.546363146487085, 49.77116250620085], [-8.460490005919482, 49.794580788329746], [-8.374530225652174, 49.81792903797093], [-8.288483910587106, 49.84120713104561], [-8.202351167128919, 49.86441494356367], [-8.116132103180885, 49.887552351626276]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.1161321&lt;dd&gt;Longitude: 49.887552&lt;dd&gt;Azimuth: 247.99433\u00b0&lt;dd&gt;Altitude: 49.163\u00b0&lt;dd&gt;Slant Range: 708.93135km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.116132103180885, 49.887552351626276]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.546363146487085, 49.77116250620085], [-8.460490005919482, 49.794580788329746], [-8.374530225652174, 49.81792903797093], [-8.288483910587106, 49.84120713104561], [-8.202351167128919, 49.86441494356367], [-8.116132103180885, 49.887552351626276], [-8.02982682816762, 49.91061923142759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -8.0298268&lt;dd&gt;Longitude: 49.910619&lt;dd&gt;Azimuth: 247.93436\u00b0&lt;dd&gt;Altitude: 49.63546\u00b0&lt;dd&gt;Slant Range: 704.57799km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.02982682816762, 49.91061923142759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.460490005919482, 49.794580788329746], [-8.374530225652174, 49.81792903797093], [-8.288483910587106, 49.84120713104561], [-8.202351167128919, 49.86441494356367], [-8.116132103180885, 49.887552351626276], [-8.02982682816762, 49.91061923142759], [-7.943435453019542, 49.93361545925847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.9434355&lt;dd&gt;Longitude: 49.933615&lt;dd&gt;Azimuth: 247.87233\u00b0&lt;dd&gt;Altitude: 50.113356\u00b0&lt;dd&gt;Slant Range: 700.2673km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.943435453019542, 49.93361545925847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.374530225652174, 49.81792903797093], [-8.288483910587106, 49.84120713104561], [-8.202351167128919, 49.86441494356367], [-8.116132103180885, 49.887552351626276], [-8.02982682816762, 49.91061923142759], [-7.943435453019542, 49.93361545925847], [-7.856958090191907, 49.95654091150788]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.8569581&lt;dd&gt;Longitude: 49.956541&lt;dd&gt;Azimuth: 247.80817\u00b0&lt;dd&gt;Altitude: 50.59673\u00b0&lt;dd&gt;Slant Range: 696.00007km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.856958090191907, 49.95654091150788]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.288483910587106, 49.84120713104561], [-8.202351167128919, 49.86441494356367], [-8.116132103180885, 49.887552351626276], [-8.02982682816762, 49.91061923142759], [-7.943435453019542, 49.93361545925847], [-7.856958090191907, 49.95654091150788], [-7.77039485365732, 49.97939546466577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.7703949&lt;dd&gt;Longitude: 49.979395&lt;dd&gt;Azimuth: 247.74176\u00b0&lt;dd&gt;Altitude: 51.085625\u00b0&lt;dd&gt;Slant Range: 691.77712km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.77039485365732, 49.97939546466577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.202351167128919, 49.86441494356367], [-8.116132103180885, 49.887552351626276], [-8.02982682816762, 49.91061923142759], [-7.943435453019542, 49.93361545925847], [-7.856958090191907, 49.95654091150788], [-7.77039485365732, 49.97939546466577], [-7.683745858919966, 50.00217899532543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.6837459&lt;dd&gt;Longitude: 50.002179&lt;dd&gt;Azimuth: 247.67298\u00b0&lt;dd&gt;Altitude: 51.580081\u00b0&lt;dd&gt;Slant Range: 687.59926km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.683745858919966, 50.00217899532543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.116132103180885, 49.887552351626276], [-8.02982682816762, 49.91061923142759], [-7.943435453019542, 49.93361545925847], [-7.856958090191907, 49.95654091150788], [-7.77039485365732, 49.97939546466577], [-7.683745858919966, 50.00217899532543], [-7.597011223008661, 50.024891380186055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.5970112&lt;dd&gt;Longitude: 50.024891&lt;dd&gt;Azimuth: 247.60171\u00b0&lt;dd&gt;Altitude: 52.080134\u00b0&lt;dd&gt;Slant Range: 683.46733km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.597011223008661, 50.024891380186055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.02982682816762, 49.91061923142759], [-7.943435453019542, 49.93361545925847], [-7.856958090191907, 49.95654091150788], [-7.77039485365732, 49.97939546466577], [-7.683745858919966, 50.00217899532543], [-7.597011223008661, 50.024891380186055], [-7.510191064495398, 50.047532496054515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.5101911&lt;dd&gt;Longitude: 50.047532&lt;dd&gt;Azimuth: 247.52782\u00b0&lt;dd&gt;Altitude: 52.585821\u00b0&lt;dd&gt;Slant Range: 679.38218km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.510191064495398, 50.047532496054515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.943435453019542, 49.93361545925847], [-7.856958090191907, 49.95654091150788], [-7.77039485365732, 49.97939546466577], [-7.683745858919966, 50.00217899532543], [-7.597011223008661, 50.024891380186055], [-7.510191064495398, 50.047532496054515], [-7.423285503476929, 50.070102219849545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.4232855&lt;dd&gt;Longitude: 50.070102&lt;dd&gt;Azimuth: 247.45117\u00b0&lt;dd&gt;Altitude: 53.097173\u00b0&lt;dd&gt;Slant Range: 675.34464km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.423285503476929, 50.070102219849545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.856958090191907, 49.95654091150788], [-7.77039485365732, 49.97939546466577], [-7.683745858919966, 50.00217899532543], [-7.597011223008661, 50.024891380186055], [-7.510191064495398, 50.047532496054515], [-7.423285503476929, 50.070102219849545], [-7.3362946616039, 50.09260042860202]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.3362947&lt;dd&gt;Longitude: 50.0926&lt;dd&gt;Azimuth: 247.37162\u00b0&lt;dd&gt;Altitude: 53.614221\u00b0&lt;dd&gt;Slant Range: 671.35559km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.3362946616039, 50.09260042860202]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.77039485365732, 49.97939546466577], [-7.683745858919966, 50.00217899532543], [-7.597011223008661, 50.024891380186055], [-7.510191064495398, 50.047532496054515], [-7.423285503476929, 50.070102219849545], [-7.3362946616039, 50.09260042860202], [-7.249218662068353, 50.115026999459275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.2492187&lt;dd&gt;Longitude: 50.115027&lt;dd&gt;Azimuth: 247.28899\u00b0&lt;dd&gt;Altitude: 54.136992\u00b0&lt;dd&gt;Slant Range: 667.4159km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.249218662068353, 50.115026999459275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.683745858919966, 50.00217899532543], [-7.597011223008661, 50.024891380186055], [-7.510191064495398, 50.047532496054515], [-7.423285503476929, 50.070102219849545], [-7.3362946616039, 50.09260042860202], [-7.249218662068353, 50.115026999459275], [-7.162057629609988, 50.137381809686566]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.1620576&lt;dd&gt;Longitude: 50.137382&lt;dd&gt;Azimuth: 247.20311\u00b0&lt;dd&gt;Altitude: 54.66551\u00b0&lt;dd&gt;Slant Range: 663.52645km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.162057629609988, 50.137381809686566]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.597011223008661, 50.024891380186055], [-7.510191064495398, 50.047532496054515], [-7.423285503476929, 50.070102219849545], [-7.3362946616039, 50.09260042860202], [-7.249218662068353, 50.115026999459275], [-7.162057629609988, 50.137381809686566], [-7.074811690520821, 50.159664736670166]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -7.0748117&lt;dd&gt;Longitude: 50.159665&lt;dd&gt;Azimuth: 247.1138\u00b0&lt;dd&gt;Altitude: 55.199797\u00b0&lt;dd&gt;Slant Range: 659.68814km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.074811690520821, 50.159664736670166]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.510191064495398, 50.047532496054515], [-7.423285503476929, 50.070102219849545], [-7.3362946616039, 50.09260042860202], [-7.249218662068353, 50.115026999459275], [-7.162057629609988, 50.137381809686566], [-7.074811690520821, 50.159664736670166], [-6.987480972654773, 50.18187565791954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.987481&lt;dd&gt;Longitude: 50.181876&lt;dd&gt;Azimuth: 247.02085\u00b0&lt;dd&gt;Altitude: 55.739868\u00b0&lt;dd&gt;Slant Range: 655.90187km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.987480972654773, 50.18187565791954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.423285503476929, 50.070102219849545], [-7.3362946616039, 50.09260042860202], [-7.249218662068353, 50.115026999459275], [-7.162057629609988, 50.137381809686566], [-7.074811690520821, 50.159664736670166], [-6.987480972654773, 50.18187565791954], [-6.900065605415638, 50.20401445106992]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.9000656&lt;dd&gt;Longitude: 50.204014&lt;dd&gt;Azimuth: 246.92405\u00b0&lt;dd&gt;Altitude: 56.285739\u00b0&lt;dd&gt;Slant Range: 652.16854km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.900065605415638, 50.20401445106992]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.3362946616039, 50.09260042860202], [-7.249218662068353, 50.115026999459275], [-7.162057629609988, 50.137381809686566], [-7.074811690520821, 50.159664736670166], [-6.987480972654773, 50.18187565791954], [-6.900065605415638, 50.20401445106992], [-6.812565719782474, 50.226080993885134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.8125657&lt;dd&gt;Longitude: 50.226081&lt;dd&gt;Azimuth: 246.82316\u00b0&lt;dd&gt;Altitude: 56.837419\u00b0&lt;dd&gt;Slant Range: 648.48908km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.812565719782474, 50.226080993885134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.249218662068353, 50.115026999459275], [-7.162057629609988, 50.137381809686566], [-7.074811690520821, 50.159664736670166], [-6.987480972654773, 50.18187565791954], [-6.900065605415638, 50.20401445106992], [-6.812565719782474, 50.226080993885134], [-6.724981448291387, 50.248075164259895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.7249814&lt;dd&gt;Longitude: 50.248075&lt;dd&gt;Azimuth: 246.71792\u00b0&lt;dd&gt;Altitude: 57.394914\u00b0&lt;dd&gt;Slant Range: 644.86442km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.724981448291387, 50.248075164259895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.162057629609988, 50.137381809686566], [-7.074811690520821, 50.159664736670166], [-6.987480972654773, 50.18187565791954], [-6.900065605415638, 50.20401445106992], [-6.812565719782474, 50.226080993885134], [-6.724981448291387, 50.248075164259895], [-6.6373129250574605, 50.269996840222205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.6373129&lt;dd&gt;Longitude: 50.269997&lt;dd&gt;Azimuth: 246.60806\u00b0&lt;dd&gt;Altitude: 57.958224\u00b0&lt;dd&gt;Slant Range: 641.29548km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.6373129250574605, 50.269996840222205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.074811690520821, 50.159664736670166], [-6.987480972654773, 50.18187565791954], [-6.900065605415638, 50.20401445106992], [-6.812565719782474, 50.226080993885134], [-6.724981448291387, 50.248075164259895], [-6.6373129250574605, 50.269996840222205], [-6.54956028575779, 50.29184589993637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.5495603&lt;dd&gt;Longitude: 50.291846&lt;dd&gt;Azimuth: 246.49328\u00b0&lt;dd&gt;Altitude: 58.527347\u00b0&lt;dd&gt;Slant Range: 637.7832km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.54956028575779, 50.29184589993637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.987480972654773, 50.18187565791954], [-6.900065605415638, 50.20401445106992], [-6.812565719782474, 50.226080993885134], [-6.724981448291387, 50.248075164259895], [-6.6373129250574605, 50.269996840222205], [-6.54956028575779, 50.29184589993637], [-6.461723667659137, 50.31362222170549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.4617237&lt;dd&gt;Longitude: 50.313622&lt;dd&gt;Azimuth: 246.37324\u00b0&lt;dd&gt;Altitude: 59.102274\u00b0&lt;dd&gt;Slant Range: 634.32854km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.461723667659137, 50.31362222170549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.900065605415638, 50.20401445106992], [-6.812565719782474, 50.226080993885134], [-6.724981448291387, 50.248075164259895], [-6.6373129250574605, 50.269996840222205], [-6.54956028575779, 50.29184589993637], [-6.461723667659137, 50.31362222170549], [-6.37380320959864, 50.33532568397368]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.3738032&lt;dd&gt;Longitude: 50.335326&lt;dd&gt;Azimuth: 246.24759\u00b0&lt;dd&gt;Altitude: 59.682991\u00b0&lt;dd&gt;Slant Range: 630.93243km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.37380320959864, 50.33532568397368]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.812565719782474, 50.226080993885134], [-6.724981448291387, 50.248075164259895], [-6.6373129250574605, 50.269996840222205], [-6.54956028575779, 50.29184589993637], [-6.461723667659137, 50.31362222170549], [-6.37380320959864, 50.33532568397368], [-6.2857990520032345, 50.35695616532898]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.2857991&lt;dd&gt;Longitude: 50.356956&lt;dd&gt;Azimuth: 246.11593\u00b0&lt;dd&gt;Altitude: 60.269479\u00b0&lt;dd&gt;Slant Range: 627.59584km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.2857990520032345, 50.35695616532898]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.724981448291387, 50.248075164259895], [-6.6373129250574605, 50.269996840222205], [-6.54956028575779, 50.29184589993637], [-6.461723667659137, 50.31362222170549], [-6.37380320959864, 50.33532568397368], [-6.2857990520032345, 50.35695616532898], [-6.1977113368798005, 50.3785135445062]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.1977113&lt;dd&gt;Longitude: 50.378514&lt;dd&gt;Azimuth: 245.97785\u00b0&lt;dd&gt;Altitude: 60.861714\u00b0&lt;dd&gt;Slant Range: 624.31972km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.1977113368798005, 50.3785135445062]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.6373129250574605, 50.269996840222205], [-6.54956028575779, 50.29184589993637], [-6.461723667659137, 50.31362222170549], [-6.37380320959864, 50.33532568397368], [-6.2857990520032345, 50.35695616532898], [-6.1977113368798005, 50.3785135445062], [-6.109540207834684, 50.39999770038835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.1095402&lt;dd&gt;Longitude: 50.399998&lt;dd&gt;Azimuth: 245.83287\u00b0&lt;dd&gt;Altitude: 61.459665\u00b0&lt;dd&gt;Slant Range: 621.10504km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.109540207834684, 50.39999770038835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.54956028575779, 50.29184589993637], [-6.461723667659137, 50.31362222170549], [-6.37380320959864, 50.33532568397368], [-6.2857990520032345, 50.35695616532898], [-6.1977113368798005, 50.3785135445062], [-6.109540207834684, 50.39999770038835], [-6.0212858100533335, 50.42140851201159]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -6.0212858&lt;dd&gt;Longitude: 50.421409&lt;dd&gt;Azimuth: 245.68047\u00b0&lt;dd&gt;Altitude: 62.063294\u00b0&lt;dd&gt;Slant Range: 617.95275km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.0212858100533335, 50.42140851201159]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.461723667659137, 50.31362222170549], [-6.37380320959864, 50.33532568397368], [-6.2857990520032345, 50.35695616532898], [-6.1977113368798005, 50.3785135445062], [-6.109540207834684, 50.39999770038835], [-6.0212858100533335, 50.42140851201159], [-5.932948290325347, 50.44274585856496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.9329483&lt;dd&gt;Longitude: 50.442746&lt;dd&gt;Azimuth: 245.52009\u00b0&lt;dd&gt;Altitude: 62.672556\u00b0&lt;dd&gt;Slant Range: 614.86381km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.932948290325347, 50.44274585856496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.37380320959864, 50.33532568397368], [-6.2857990520032345, 50.35695616532898], [-6.1977113368798005, 50.3785135445062], [-6.109540207834684, 50.39999770038835], [-6.0212858100533335, 50.42140851201159], [-5.932948290325347, 50.44274585856496], [-5.844527797042861, 50.46400961939535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.8445278&lt;dd&gt;Longitude: 50.46401&lt;dd&gt;Azimuth: 245.3511\u00b0&lt;dd&gt;Altitude: 63.287401\u00b0&lt;dd&gt;Slant Range: 611.8392km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.844527797042861, 50.46400961939535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.2857990520032345, 50.35695616532898], [-6.1977113368798005, 50.3785135445062], [-6.109540207834684, 50.39999770038835], [-6.0212858100533335, 50.42140851201159], [-5.932948290325347, 50.44274585856496], [-5.844527797042861, 50.46400961939535], [-5.756024480187807, 50.485199674008975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.7560245&lt;dd&gt;Longitude: 50.4852&lt;dd&gt;Azimuth: 245.17279\u00b0&lt;dd&gt;Altitude: 63.90777\u00b0&lt;dd&gt;Slant Range: 608.87987km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.756024480187807, 50.485199674008975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.1977113368798005, 50.3785135445062], [-6.109540207834684, 50.39999770038835], [-6.0212858100533335, 50.42140851201159], [-5.932948290325347, 50.44274585856496], [-5.844527797042861, 50.46400961939535], [-5.756024480187807, 50.485199674008975], [-5.667438491355878, 50.506315902074505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.6674385&lt;dd&gt;Longitude: 50.506316&lt;dd&gt;Azimuth: 244.98441\u00b0&lt;dd&gt;Altitude: 64.533596\u00b0&lt;dd&gt;Slant Range: 605.98678km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.667438491355878, 50.506315902074505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.109540207834684, 50.39999770038835], [-6.0212858100533335, 50.42140851201159], [-5.932948290325347, 50.44274585856496], [-5.844527797042861, 50.46400961939535], [-5.756024480187807, 50.485199674008975], [-5.667438491355878, 50.506315902074505], [-5.578769983745488, 50.527358183425356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.57877&lt;dd&gt;Longitude: 50.527358&lt;dd&gt;Azimuth: 244.78509\u00b0&lt;dd&gt;Altitude: 65.164802\u00b0&lt;dd&gt;Slant Range: 603.16089km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.578769983745488, 50.527358183425356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.0212858100533335, 50.42140851201159], [-5.932948290325347, 50.44274585856496], [-5.844527797042861, 50.46400961939535], [-5.756024480187807, 50.485199674008975], [-5.667438491355878, 50.506315902074505], [-5.578769983745488, 50.527358183425356], [-5.490019112163954, 50.54832639806275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.4900191&lt;dd&gt;Longitude: 50.548326&lt;dd&gt;Azimuth: 244.57387\u00b0&lt;dd&gt;Altitude: 65.801306\u00b0&lt;dd&gt;Slant Range: 600.40315km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.490019112163954, 50.54832639806275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.932948290325347, 50.44274585856496], [-5.844527797042861, 50.46400961939535], [-5.756024480187807, 50.485199674008975], [-5.667438491355878, 50.506315902074505], [-5.578769983745488, 50.527358183425356], [-5.490019112163954, 50.54832639806275], [-5.401186033034618, 50.56922042615796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.401186&lt;dd&gt;Longitude: 50.56922&lt;dd&gt;Azimuth: 244.34967\u00b0&lt;dd&gt;Altitude: 66.443011\u00b0&lt;dd&gt;Slant Range: 597.7145km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.401186033034618, 50.56922042615796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.844527797042861, 50.46400961939535], [-5.756024480187807, 50.485199674008975], [-5.667438491355878, 50.506315902074505], [-5.578769983745488, 50.527358183425356], [-5.490019112163954, 50.54832639806275], [-5.401186033034618, 50.56922042615796], [-5.312270904396137, 50.590040148055515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.3122709&lt;dd&gt;Longitude: 50.59004&lt;dd&gt;Azimuth: 244.1113\u00b0&lt;dd&gt;Altitude: 67.089816\u00b0&lt;dd&gt;Slant Range: 595.09589km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.312270904396137, 50.590040148055515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.756024480187807, 50.485199674008975], [-5.667438491355878, 50.506315902074505], [-5.578769983745488, 50.527358183425356], [-5.490019112163954, 50.54832639806275], [-5.401186033034618, 50.56922042615796], [-5.312270904396137, 50.590040148055515], [-5.223273885897423, 50.610785444275386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.2232739&lt;dd&gt;Longitude: 50.610785&lt;dd&gt;Azimuth: 243.85739\u00b0&lt;dd&gt;Altitude: 67.741603\u00b0&lt;dd&gt;Slant Range: 592.54825km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.223273885897423, 50.610785444275386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.667438491355878, 50.506315902074505], [-5.578769983745488, 50.527358183425356], [-5.490019112163954, 50.54832639806275], [-5.401186033034618, 50.56922042615796], [-5.312270904396137, 50.590040148055515], [-5.223273885897423, 50.610785444275386], [-5.134195138816335, 50.63145619551616]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.1341951&lt;dd&gt;Longitude: 50.631456&lt;dd&gt;Azimuth: 243.58639\u00b0&lt;dd&gt;Altitude: 68.398245\u00b0&lt;dd&gt;Slant Range: 590.07249km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.134195138816335, 50.63145619551616]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.578769983745488, 50.527358183425356], [-5.490019112163954, 50.54832639806275], [-5.401186033034618, 50.56922042615796], [-5.312270904396137, 50.590040148055515], [-5.223273885897423, 50.610785444275386], [-5.134195138816335, 50.63145619551616], [-5.045034826045468, 50.65205228265726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -5.0450348&lt;dd&gt;Longitude: 50.652052&lt;dd&gt;Azimuth: 243.29658\u00b0&lt;dd&gt;Altitude: 69.059604\u00b0&lt;dd&gt;Slant Range: 587.66954km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.045034826045468, 50.65205228265726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.490019112163954, 50.54832639806275], [-5.401186033034618, 50.56922042615796], [-5.312270904396137, 50.590040148055515], [-5.223273885897423, 50.610785444275386], [-5.134195138816335, 50.63145619551616], [-5.045034826045468, 50.65205228265726], [-4.955793112112698, 50.67257358676211]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.9557931&lt;dd&gt;Longitude: 50.672574&lt;dd&gt;Azimuth: 242.98595\u00b0&lt;dd&gt;Altitude: 69.725524\u00b0&lt;dd&gt;Slant Range: 585.34028km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.955793112112698, 50.67257358676211]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.401186033034618, 50.56922042615796], [-5.312270904396137, 50.590040148055515], [-5.223273885897423, 50.610785444275386], [-5.134195138816335, 50.63145619551616], [-5.045034826045468, 50.65205228265726], [-4.955793112112698, 50.67257358676211], [-4.866470163159899, 50.693019989080625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.8664702&lt;dd&gt;Longitude: 50.69302&lt;dd&gt;Azimuth: 242.65223\u00b0&lt;dd&gt;Altitude: 70.395836\u00b0&lt;dd&gt;Slant Range: 583.08561km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.866470163159899, 50.693019989080625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.312270904396137, 50.590040148055515], [-5.223273885897423, 50.610785444275386], [-5.134195138816335, 50.63145619551616], [-5.045034826045468, 50.65205228265726], [-4.955793112112698, 50.67257358676211], [-4.866470163159899, 50.693019989080625], [-4.777066146968632, 50.71339137105194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.7770661&lt;dd&gt;Longitude: 50.713391&lt;dd&gt;Azimuth: 242.29279\u00b0&lt;dd&gt;Altitude: 71.070354\u00b0&lt;dd&gt;Slant Range: 580.90639km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.777066146968632, 50.71339137105194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.223273885897423, 50.610785444275386], [-5.134195138816335, 50.63145619551616], [-5.045034826045468, 50.65205228265726], [-4.955793112112698, 50.67257358676211], [-4.866470163159899, 50.693019989080625], [-4.777066146968632, 50.71339137105194], [-4.687581232947327, 50.73368761430703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.6875812&lt;dd&gt;Longitude: 50.733688&lt;dd&gt;Azimuth: 241.9046\u00b0&lt;dd&gt;Altitude: 71.748873\u00b0&lt;dd&gt;Slant Range: 578.80348km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.687581232947327, 50.73368761430703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.134195138816335, 50.63145619551616], [-5.045034826045468, 50.65205228265726], [-4.955793112112698, 50.67257358676211], [-4.866470163159899, 50.693019989080625], [-4.777066146968632, 50.71339137105194], [-4.687581232947327, 50.73368761430703], [-4.598015592142727, 50.753908600671735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.5980156&lt;dd&gt;Longitude: 50.753909&lt;dd&gt;Azimuth: 241.48416\u00b0&lt;dd&gt;Altitude: 72.431164\u00b0&lt;dd&gt;Slant Range: 576.77771km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.598015592142727, 50.753908600671735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.045034826045468, 50.65205228265726], [-4.955793112112698, 50.67257358676211], [-4.866470163159899, 50.693019989080625], [-4.777066146968632, 50.71339137105194], [-4.687581232947327, 50.73368761430703], [-4.598015592142727, 50.753908600671735], [-4.508369397229156, 50.77405421216948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.5083694&lt;dd&gt;Longitude: 50.774054&lt;dd&gt;Azimuth: 241.02735\u00b0&lt;dd&gt;Altitude: 73.116977\u00b0&lt;dd&gt;Slant Range: 574.82991km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.508369397229156, 50.77405421216948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.955793112112698, 50.67257358676211], [-4.866470163159899, 50.693019989080625], [-4.777066146968632, 50.71339137105194], [-4.687581232947327, 50.73368761430703], [-4.598015592142727, 50.753908600671735], [-4.508369397229156, 50.77405421216948], [-4.418642822529332, 50.794124331023745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.4186428&lt;dd&gt;Longitude: 50.794124&lt;dd&gt;Azimuth: 240.52934\u00b0&lt;dd&gt;Altitude: 73.806032\u00b0&lt;dd&gt;Slant Range: 572.96088km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.418642822529332, 50.794124331023745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.866470163159899, 50.693019989080625], [-4.777066146968632, 50.71339137105194], [-4.687581232947327, 50.73368761430703], [-4.598015592142727, 50.753908600671735], [-4.508369397229156, 50.77405421216948], [-4.418642822529332, 50.794124331023745], [-4.328836043995456, 50.81411883966113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.328836&lt;dd&gt;Longitude: 50.814119&lt;dd&gt;Azimuth: 239.98443\u00b0&lt;dd&gt;Altitude: 74.498013\u00b0&lt;dd&gt;Slant Range: 571.17137km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.328836043995456, 50.81411883966113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.777066146968632, 50.71339137105194], [-4.687581232947327, 50.73368761430703], [-4.598015592142727, 50.753908600671735], [-4.508369397229156, 50.77405421216948], [-4.418642822529332, 50.794124331023745], [-4.328836043995456, 50.81411883966113], [-4.238949239229398, 50.834037620714156]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.2389492&lt;dd&gt;Longitude: 50.834038&lt;dd&gt;Azimuth: 239.38583\u00b0&lt;dd&gt;Altitude: 75.192569\u00b0&lt;dd&gt;Slant Range: 569.46216km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.238949239229398, 50.834037620714156]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.687581232947327, 50.73368761430703], [-4.598015592142727, 50.753908600671735], [-4.508369397229156, 50.77405421216948], [-4.418642822529332, 50.794124331023745], [-4.328836043995456, 50.81411883966113], [-4.238949239229398, 50.834037620714156], [-4.148982587474063, 50.853880557023146]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.1489826&lt;dd&gt;Longitude: 50.853881&lt;dd&gt;Azimuth: 238.72539\u00b0&lt;dd&gt;Altitude: 75.889297\u00b0&lt;dd&gt;Slant Range: 567.83396km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.148982587474063, 50.853880557023146]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.598015592142727, 50.753908600671735], [-4.508369397229156, 50.77405421216948], [-4.418642822529332, 50.794124331023745], [-4.328836043995456, 50.81411883966113], [-4.238949239229398, 50.834037620714156], [-4.148982587474063, 50.853880557023146], [-4.058936269617344, 50.873647531640906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -4.0589363&lt;dd&gt;Longitude: 50.873648&lt;dd&gt;Azimuth: 237.99328\u00b0&lt;dd&gt;Altitude: 76.587737\u00b0&lt;dd&gt;Slant Range: 566.28747km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.058936269617344, 50.873647531640906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.508369397229156, 50.77405421216948], [-4.418642822529332, 50.794124331023745], [-4.328836043995456, 50.81411883966113], [-4.238949239229398, 50.834037620714156], [-4.148982587474063, 50.853880557023146], [-4.058936269617344, 50.873647531640906], [-3.9688104681950116, 50.893338427833356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.9688105&lt;dd&gt;Longitude: 50.893338&lt;dd&gt;Azimuth: 237.17751\u00b0&lt;dd&gt;Altitude: 77.287355\u00b0&lt;dd&gt;Slant Range: 564.82337km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9688104681950116, 50.893338427833356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.418642822529332, 50.794124331023745], [-4.328836043995456, 50.81411883966113], [-4.238949239229398, 50.834037620714156], [-4.148982587474063, 50.853880557023146], [-4.058936269617344, 50.873647531640906], [-3.9688104681950116, 50.893338427833356], [-3.878605367389681, 50.912953129083746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.8786054&lt;dd&gt;Longitude: 50.912953&lt;dd&gt;Azimuth: 236.26334\u00b0&lt;dd&gt;Altitude: 77.987526\u00b0&lt;dd&gt;Slant Range: 563.44231km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.878605367389681, 50.912953129083746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.328836043995456, 50.81411883966113], [-4.238949239229398, 50.834037620714156], [-4.148982587474063, 50.853880557023146], [-4.058936269617344, 50.873647531640906], [-3.9688104681950116, 50.893338427833356], [-3.878605367389681, 50.912953129083746], [-3.788321153039712, 50.93249151909501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.7883212&lt;dd&gt;Longitude: 50.932492&lt;dd&gt;Azimuth: 235.23247\u00b0&lt;dd&gt;Altitude: 78.687503\u00b0&lt;dd&gt;Slant Range: 562.14488km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.788321153039712, 50.93249151909501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.238949239229398, 50.834037620714156], [-4.148982587474063, 50.853880557023146], [-4.058936269617344, 50.873647531640906], [-3.9688104681950116, 50.893338427833356], [-3.878605367389681, 50.912953129083746], [-3.788321153039712, 50.93249151909501], [-3.697958012626335, 50.951953481792565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.697958&lt;dd&gt;Longitude: 50.951953&lt;dd&gt;Azimuth: 234.06194\u00b0&lt;dd&gt;Altitude: 79.386387\u00b0&lt;dd&gt;Slant Range: 560.93169km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.697958012626335, 50.951953481792565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.148982587474063, 50.853880557023146], [-4.058936269617344, 50.873647531640906], [-3.9688104681950116, 50.893338427833356], [-3.878605367389681, 50.912953129083746], [-3.788321153039712, 50.93249151909501], [-3.697958012626335, 50.951953481792565], [-3.607516135292022, 50.97133890132705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.6075161&lt;dd&gt;Longitude: 50.971339&lt;dd&gt;Azimuth: 232.72262\u00b0&lt;dd&gt;Altitude: 80.083071\u00b0&lt;dd&gt;Slant Range: 559.80327km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.607516135292022, 50.97133890132705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.058936269617344, 50.873647531640906], [-3.9688104681950116, 50.893338427833356], [-3.878605367389681, 50.912953129083746], [-3.788321153039712, 50.93249151909501], [-3.697958012626335, 50.951953481792565], [-3.607516135292022, 50.97133890132705], [-3.5169957118321173, 50.990647662077464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.5169957&lt;dd&gt;Longitude: 50.990648&lt;dd&gt;Azimuth: 231.17713\u00b0&lt;dd&gt;Altitude: 80.776167\u00b0&lt;dd&gt;Slant Range: 558.76013km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.5169957118321173, 50.990647662077464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9688104681950116, 50.893338427833356], [-3.878605367389681, 50.912953129083746], [-3.788321153039712, 50.93249151909501], [-3.697958012626335, 50.951953481792565], [-3.607516135292022, 50.97133890132705], [-3.5169957118321173, 50.990647662077464], [-3.426396934697531, 51.00987964865325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.4263969&lt;dd&gt;Longitude: 51.00988&lt;dd&gt;Azimuth: 229.37692\u00b0&lt;dd&gt;Altitude: 81.463903\u00b0&lt;dd&gt;Slant Range: 557.80277km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.426396934697531, 51.00987964865325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.878605367389681, 50.912953129083746], [-3.788321153039712, 50.93249151909501], [-3.697958012626335, 50.951953481792565], [-3.607516135292022, 50.97133890132705], [-3.5169957118321173, 50.990647662077464], [-3.426396934697531, 51.00987964865325], [-3.3357199979929613, 51.02903474589835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.33572&lt;dd&gt;Longitude: 51.029035&lt;dd&gt;Azimuth: 227.25815\u00b0&lt;dd&gt;Altitude: 82.143963\u00b0&lt;dd&gt;Slant Range: 556.93162km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3357199979929613, 51.02903474589835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.788321153039712, 50.93249151909501], [-3.697958012626335, 50.951953481792565], [-3.607516135292022, 50.97133890132705], [-3.5169957118321173, 50.990647662077464], [-3.426396934697531, 51.00987964865325], [-3.3357199979929613, 51.02903474589835], [-3.2449650974904545, 51.04811283889263]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.2449651&lt;dd&gt;Longitude: 51.048113&lt;dd&gt;Azimuth: 224.73594\u00b0&lt;dd&gt;Altitude: 82.813257\u00b0&lt;dd&gt;Slant Range: 556.14708km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2449650974904545, 51.04811283889263]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.697958012626335, 50.951953481792565], [-3.607516135292022, 50.97133890132705], [-3.5169957118321173, 50.990647662077464], [-3.426396934697531, 51.00987964865325], [-3.3357199979929613, 51.02903474589835], [-3.2449650974904545, 51.04811283889263], [-3.1541324306077008, 51.067113812955704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.1541324&lt;dd&gt;Longitude: 51.067114&lt;dd&gt;Azimuth: 221.69641\u00b0&lt;dd&gt;Altitude: 83.467559\u00b0&lt;dd&gt;Slant Range: 555.44954km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1541324306077008, 51.067113812955704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.607516135292022, 50.97133890132705], [-3.5169957118321173, 50.990647662077464], [-3.426396934697531, 51.00987964865325], [-3.3357199979929613, 51.02903474589835], [-3.2449650974904545, 51.04811283889263], [-3.1541324306077008, 51.067113812955704], [-3.0632221964421564, 51.0860375536495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -3.0632222&lt;dd&gt;Longitude: 51.086038&lt;dd&gt;Azimuth: 217.98625\u00b0&lt;dd&gt;Altitude: 84.100973\u00b0&lt;dd&gt;Slant Range: 554.8393km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0632221964421564, 51.0860375536495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.5169957118321173, 50.990647662077464], [-3.426396934697531, 51.00987964865325], [-3.3357199979929613, 51.02903474589835], [-3.2449650974904545, 51.04811283889263], [-3.1541324306077008, 51.067113812955704], [-3.0632221964421564, 51.0860375536495], [-2.9722345957346317, 51.104883946780944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.9722346&lt;dd&gt;Longitude: 51.104884&lt;dd&gt;Azimuth: 213.40054\u00b0&lt;dd&gt;Altitude: 84.705103\u00b0&lt;dd&gt;Slant Range: 554.31667km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9722345957346317, 51.104883946780944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.426396934697531, 51.00987964865325], [-3.3357199979929613, 51.02903474589835], [-3.2449650974904545, 51.04811283889263], [-3.1541324306077008, 51.067113812955704], [-3.0632221964421564, 51.0860375536495], [-2.9722345957346317, 51.104883946780944], [-2.8811698309001814, 51.12365287840495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.8811698&lt;dd&gt;Longitude: 51.123653&lt;dd&gt;Azimuth: 207.67353\u00b0&lt;dd&gt;Altitude: 85.26786\u00b0&lt;dd&gt;Slant Range: 553.88189km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8811698309001814, 51.12365287840495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3357199979929613, 51.02903474589835], [-3.2449650974904545, 51.04811283889263], [-3.1541324306077008, 51.067113812955704], [-3.0632221964421564, 51.0860375536495], [-2.9722345957346317, 51.104883946780944], [-2.8811698309001814, 51.12365287840495], [-2.790028106009606, 51.14234423482748]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.7900281&lt;dd&gt;Longitude: 51.142344&lt;dd&gt;Azimuth: 200.48743\u00b0&lt;dd&gt;Altitude: 85.771882\u00b0&lt;dd&gt;Slant Range: 553.53517km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.790028106009606, 51.14234423482748]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2449650974904545, 51.04811283889263], [-3.1541324306077008, 51.067113812955704], [-3.0632221964421564, 51.0860375536495], [-2.9722345957346317, 51.104883946780944], [-2.8811698309001814, 51.12365287840495], [-2.790028106009606, 51.14234423482748], [-2.698809626806499, 51.1609579026076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.6988096&lt;dd&gt;Longitude: 51.160958&lt;dd&gt;Azimuth: 191.53499\u00b0&lt;dd&gt;Altitude: 86.193046\u00b0&lt;dd&gt;Slant Range: 553.27668km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.698809626806499, 51.1609579026076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1541324306077008, 51.067113812955704], [-3.0632221964421564, 51.0860375536495], [-2.9722345957346317, 51.104883946780944], [-2.8811698309001814, 51.12365287840495], [-2.790028106009606, 51.14234423482748], [-2.698809626806499, 51.1609579026076], [-2.6075146006911165, 51.179493768561414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.6075146&lt;dd&gt;Longitude: 51.179494&lt;dd&gt;Azimuth: 180.69129\u00b0&lt;dd&gt;Altitude: 86.500718\u00b0&lt;dd&gt;Slant Range: 553.10653km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6075146006911165, 51.179493768561414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0632221964421564, 51.0860375536495], [-2.9722345957346317, 51.104883946780944], [-2.8811698309001814, 51.12365287840495], [-2.790028106009606, 51.14234423482748], [-2.698809626806499, 51.1609579026076], [-2.6075146006911165, 51.179493768561414], [-2.5161432367352363, 51.197951719764305]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.5161432&lt;dd&gt;Longitude: 51.197952&lt;dd&gt;Azimuth: 168.2939\u00b0&lt;dd&gt;Altitude: 86.662946\u00b0&lt;dd&gt;Slant Range: 553.02481km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5161432367352363, 51.197951719764305]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9722345957346317, 51.104883946780944], [-2.8811698309001814, 51.12365287840495], [-2.790028106009606, 51.14234423482748], [-2.698809626806499, 51.1609579026076], [-2.6075146006911165, 51.179493768561414], [-2.5161432367352363, 51.197951719764305], [-2.424695745671673, 51.21633164355393]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.4246957&lt;dd&gt;Longitude: 51.216332&lt;dd&gt;Azimuth: 155.30074\u00b0&lt;dd&gt;Altitude: 86.658286\u00b0&lt;dd&gt;Slant Range: 553.03156km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.424695745671673, 51.21633164355393]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8811698309001814, 51.12365287840495], [-2.790028106009606, 51.14234423482748], [-2.698809626806499, 51.1609579026076], [-2.6075146006911165, 51.179493768561414], [-2.5161432367352363, 51.197951719764305], [-2.424695745671673, 51.21633164355393], [-2.3331723399066733, 51.234633427533005]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.3331723&lt;dd&gt;Longitude: 51.234633&lt;dd&gt;Azimuth: 142.96909\u00b0&lt;dd&gt;Altitude: 86.487414\u00b0&lt;dd&gt;Slant Range: 553.12678km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3331723399066733, 51.234633427533005]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.790028106009606, 51.14234423482748], [-2.698809626806499, 51.1609579026076], [-2.6075146006911165, 51.179493768561414], [-2.5161432367352363, 51.197951719764305], [-2.424695745671673, 51.21633164355393], [-2.3331723399066733, 51.234633427533005], [-2.2415732335035763, 51.25285695957243]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.2415732&lt;dd&gt;Longitude: 51.252857&lt;dd&gt;Azimuth: 132.22598\u00b0&lt;dd&gt;Altitude: 86.172721\u00b0&lt;dd&gt;Slant Range: 553.31041km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2415732335035763, 51.25285695957243]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.698809626806499, 51.1609579026076], [-2.6075146006911165, 51.179493768561414], [-2.5161432367352363, 51.197951719764305], [-2.424695745671673, 51.21633164355393], [-2.3331723399066733, 51.234633427533005], [-2.2415732335035763, 51.25285695957243], [-2.149898642203426, 51.271002127813496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.1498986&lt;dd&gt;Longitude: 51.271002&lt;dd&gt;Azimuth: 123.37654\u00b0&lt;dd&gt;Altitude: 85.746345\u00b0&lt;dd&gt;Slant Range: 553.58238km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.149898642203426, 51.271002127813496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6075146006911165, 51.179493768561414], [-2.5161432367352363, 51.197951719764305], [-2.424695745671673, 51.21633164355393], [-2.3331723399066733, 51.234633427533005], [-2.2415732335035763, 51.25285695957243], [-2.149898642203426, 51.271002127813496], [-2.0581487834086873, 51.28906882067221]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -2.0581488&lt;dd&gt;Longitude: 51.289069&lt;dd&gt;Azimuth: 116.27913\u00b0&lt;dd&gt;Altitude: 85.238643\u00b0&lt;dd&gt;Slant Range: 553.94255km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0581487834086873, 51.28906882067221]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5161432367352363, 51.197951719764305], [-2.424695745671673, 51.21633164355393], [-2.3331723399066733, 51.234633427533005], [-2.2415732335035763, 51.25285695957243], [-2.149898642203426, 51.271002127813496], [-2.0581487834086873, 51.28906882067221], [-1.966323876192582, 51.30705692684029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.9663239&lt;dd&gt;Longitude: 51.307057&lt;dd&gt;Azimuth: 110.62269\u00b0&lt;dd&gt;Altitude: 84.673344\u00b0&lt;dd&gt;Slant Range: 554.39074km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.966323876192582, 51.30705692684029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.424695745671673, 51.21633164355393], [-2.3331723399066733, 51.234633427533005], [-2.2415732335035763, 51.25285695957243], [-2.149898642203426, 51.271002127813496], [-2.0581487834086873, 51.28906882067221], [-1.966323876192582, 51.30705692684029], [-1.8744241412932388, 51.32496633528946]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.8744241&lt;dd&gt;Longitude: 51.324966&lt;dd&gt;Azimuth: 106.09137\u00b0&lt;dd&gt;Altitude: 84.067478\u00b0&lt;dd&gt;Slant Range: 554.92675km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8744241412932388, 51.32496633528946]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3331723399066733, 51.234633427533005], [-2.2415732335035763, 51.25285695957243], [-2.149898642203426, 51.271002127813496], [-2.0581487834086873, 51.28906882067221], [-1.966323876192582, 51.30705692684029], [-1.8744241412932388, 51.32496633528946], [-1.7824498011219354, 51.34279693527398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.7824498&lt;dd&gt;Longitude: 51.342797&lt;dd&gt;Azimuth: 102.42283\u00b0&lt;dd&gt;Altitude: 83.432895\u00b0&lt;dd&gt;Slant Range: 555.55032km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7824498011219354, 51.34279693527398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.2415732335035763, 51.25285695957243], [-2.149898642203426, 51.271002127813496], [-2.0581487834086873, 51.28906882067221], [-1.966323876192582, 51.30705692684029], [-1.8744241412932388, 51.32496633528946], [-1.7824498011219354, 51.34279693527398], [-1.6904010797499198, 51.36054861633319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.6904011&lt;dd&gt;Longitude: 51.360549&lt;dd&gt;Azimuth: 99.41528\u00b0&lt;dd&gt;Altitude: 82.777824\u00b0&lt;dd&gt;Slant Range: 556.26115km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6904010797499198, 51.36054861633319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.149898642203426, 51.271002127813496], [-2.0581487834086873, 51.28906882067221], [-1.966323876192582, 51.30705692684029], [-1.8744241412932388, 51.32496633528946], [-1.7824498011219354, 51.34279693527398], [-1.6904010797499198, 51.36054861633319], [-1.5982782029239813, 51.37822126829477]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.5982782&lt;dd&gt;Longitude: 51.378221&lt;dd&gt;Azimuth: 96.917872\u00b0&lt;dd&gt;Altitude: 82.108054\u00b0&lt;dd&gt;Slant Range: 557.05891km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5982782029239813, 51.37822126829477]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0581487834086873, 51.28906882067221], [-1.966323876192582, 51.30705692684029], [-1.8744241412932388, 51.32496633528946], [-1.7824498011219354, 51.34279693527398], [-1.6904010797499198, 51.36054861633319], [-1.5982782029239813, 51.37822126829477], [-1.5060813980574437, 51.39581478127767]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.5060814&lt;dd&gt;Longitude: 51.395815&lt;dd&gt;Azimuth: 94.81858\u00b0&lt;dd&gt;Altitude: 81.427733\u00b0&lt;dd&gt;Slant Range: 557.94322km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5060813980574437, 51.39581478127767]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.966323876192582, 51.30705692684029], [-1.8744241412932388, 51.32496633528946], [-1.7824498011219354, 51.34279693527398], [-1.6904010797499198, 51.36054861633319], [-1.5982782029239813, 51.37822126829477], [-1.5060813980574437, 51.39581478127767], [-1.4138108942262209, 51.4133290456944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.4138109&lt;dd&gt;Longitude: 51.413329&lt;dd&gt;Azimuth: 93.033862\u00b0&lt;dd&gt;Altitude: 80.739903\u00b0&lt;dd&gt;Slant Range: 558.91368km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4138108942262209, 51.4133290456944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8744241412932388, 51.32496633528946], [-1.7824498011219354, 51.34279693527398], [-1.6904010797499198, 51.36054861633319], [-1.5982782029239813, 51.37822126829477], [-1.5060813980574437, 51.39581478127767], [-1.4138108942262209, 51.4133290456944], [-1.321466922177978, 51.430763952255255]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.3214669&lt;dd&gt;Longitude: 51.430764&lt;dd&gt;Azimuth: 91.500851\u00b0&lt;dd&gt;Altitude: 80.046843\u00b0&lt;dd&gt;Slant Range: 559.96983km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.321466922177978, 51.430763952255255]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7824498011219354, 51.34279693527398], [-1.6904010797499198, 51.36054861633319], [-1.5982782029239813, 51.37822126829477], [-1.5060813980574437, 51.39581478127767], [-1.4138108942262209, 51.4133290456944], [-1.321466922177978, 51.430763952255255], [-1.2290497143251322, 51.44811939196942]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.2290497&lt;dd&gt;Longitude: 51.448119&lt;dd&gt;Azimuth: 90.171697\u00b0&lt;dd&gt;Altitude: 79.350301\u00b0&lt;dd&gt;Slant Range: 561.11119km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2290497143251322, 51.44811939196942]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6904010797499198, 51.36054861633319], [-1.5982782029239813, 51.37822126829477], [-1.5060813980574437, 51.39581478127767], [-1.4138108942262209, 51.4133290456944], [-1.321466922177978, 51.430763952255255], [-1.2290497143251322, 51.44811939196942], [-1.1365595047488752, 51.46539525614945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.1365595&lt;dd&gt;Longitude: 51.465395&lt;dd&gt;Azimuth: 89.009539\u00b0&lt;dd&gt;Altitude: 78.651646\u00b0&lt;dd&gt;Slant Range: 562.33724km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1365595047488752, 51.46539525614945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5982782029239813, 51.37822126829477], [-1.5060813980574437, 51.39581478127767], [-1.4138108942262209, 51.4133290456944], [-1.321466922177978, 51.430763952255255], [-1.2290497143251322, 51.44811939196942], [-1.1365595047488752, 51.46539525614945], [-1.0439965291901132, 51.482591436413436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -1.0439965&lt;dd&gt;Longitude: 51.482591&lt;dd&gt;Azimuth: 87.98564\u00b0&lt;dd&gt;Altitude: 77.951971\u00b0&lt;dd&gt;Slant Range: 563.64742km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0439965291901132, 51.482591436413436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5060813980574437, 51.39581478127767], [-1.4138108942262209, 51.4133290456944], [-1.321466922177978, 51.430763952255255], [-1.2290497143251322, 51.44811939196942], [-1.1365595047488752, 51.46539525614945], [-1.0439965291901132, 51.482591436413436], [-0.9513610250655996, 51.499707824687874]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.95136103&lt;dd&gt;Longitude: 51.499708&lt;dd&gt;Azimuth: 87.077329\u00b0&lt;dd&gt;Altitude: 77.252166\u00b0&lt;dd&gt;Slant Range: 565.04114km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9513610250655996, 51.499707824687874]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4138108942262209, 51.4133290456944], [-1.321466922177978, 51.430763952255255], [-1.2290497143251322, 51.44811939196942], [-1.1365595047488752, 51.46539525614945], [-1.0439965291901132, 51.482591436413436], [-0.9513610250655996, 51.499707824687874], [-0.8586532314432284, 51.516744313210886]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.85865323&lt;dd&gt;Longitude: 51.516744&lt;dd&gt;Azimuth: 86.266526\u00b0&lt;dd&gt;Altitude: 76.552969\u00b0&lt;dd&gt;Slant Range: 566.5178km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8586532314432284, 51.516744313210886]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.321466922177978, 51.430763952255255], [-1.2290497143251322, 51.44811939196942], [-1.1365595047488752, 51.46539525614945], [-1.0439965291901132, 51.482591436413436], [-0.9513610250655996, 51.499707824687874], [-0.8586532314432284, 51.516744313210886], [-0.7658733890638142, 51.533700794535115]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.76587339&lt;dd&gt;Longitude: 51.533701&lt;dd&gt;Azimuth: 85.538661\u00b0&lt;dd&gt;Altitude: 75.854999\u00b0&lt;dd&gt;Slant Range: 568.07673km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7658733890638142, 51.533700794535115]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2290497143251322, 51.44811939196942], [-1.1365595047488752, 51.46539525614945], [-1.0439965291901132, 51.482591436413436], [-0.9513610250655996, 51.499707824687874], [-0.8586532314432284, 51.516744313210886], [-0.7658733890638142, 51.533700794535115], [-0.6730217403264621, 51.55057716152997]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.67302174&lt;dd&gt;Longitude: 51.550577&lt;dd&gt;Azimuth: 84.881879\u00b0&lt;dd&gt;Altitude: 75.158785\u00b0&lt;dd&gt;Slant Range: 569.71727km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6730217403264621, 51.55057716152997]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1365595047488752, 51.46539525614945], [-1.0439965291901132, 51.482591436413436], [-0.9513610250655996, 51.499707824687874], [-0.8586532314432284, 51.516744313210886], [-0.7658733890638142, 51.533700794535115], [-0.6730217403264621, 51.55057716152997], [-0.5800985292967606, 51.56737330738598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.58009853&lt;dd&gt;Longitude: 51.567373&lt;dd&gt;Azimuth: 84.286444\u00b0&lt;dd&gt;Altitude: 74.464784\u00b0&lt;dd&gt;Slant Range: 571.4387km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5800985292967606, 51.56737330738598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0439965291901132, 51.482591436413436], [-0.9513610250655996, 51.499707824687874], [-0.8586532314432284, 51.516744313210886], [-0.7658733890638142, 51.533700794535115], [-0.6730217403264621, 51.55057716152997], [-0.5800985292967606, 51.56737330738598], [-0.48710400169360135, 51.584089125615854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.487104&lt;dd&gt;Longitude: 51.584089&lt;dd&gt;Azimuth: 83.744299\u00b0&lt;dd&gt;Altitude: 73.773392\u00b0&lt;dd&gt;Slant Range: 573.2403km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.48710400169360135, 51.584089125615854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9513610250655996, 51.499707824687874], [-0.8586532314432284, 51.516744313210886], [-0.7658733890638142, 51.533700794535115], [-0.6730217403264621, 51.55057716152997], [-0.5800985292967606, 51.56737330738598], [-0.48710400169360135, 51.584089125615854], [-0.39403840490205416, 51.600724510059]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.3940384&lt;dd&gt;Longitude: 51.600725&lt;dd&gt;Azimuth: 83.248716\u00b0&lt;dd&gt;Altitude: 73.084962\u00b0&lt;dd&gt;Slant Range: 575.12132km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.39403840490205416, 51.600724510059]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8586532314432284, 51.516744313210886], [-0.7658733890638142, 51.533700794535115], [-0.6730217403264621, 51.55057716152997], [-0.5800985292967606, 51.56737330738598], [-0.48710400169360135, 51.584089125615854], [-0.39403840490205416, 51.600724510059], [-0.3009019879621205, 51.61727935488358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.30090199&lt;dd&gt;Longitude: 51.617279&lt;dd&gt;Azimuth: 82.794045\u00b0&lt;dd&gt;Altitude: 72.399802\u00b0&lt;dd&gt;Slant Range: 577.08096km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3009019879621205, 51.61727935488358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7658733890638142, 51.533700794535115], [-0.6730217403264621, 51.55057716152997], [-0.5800985292967606, 51.56737330738598], [-0.48710400169360135, 51.584089125615854], [-0.39403840490205416, 51.600724510059], [-0.3009019879621205, 51.61727935488358], [-0.20769500156959853, 51.63375355458977]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.207695&lt;dd&gt;Longitude: 51.633754&lt;dd&gt;Azimuth: 82.375501\u00b0&lt;dd&gt;Altitude: 71.718193\u00b0&lt;dd&gt;Slant Range: 579.11844km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.20769500156959853, 51.63375355458977]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6730217403264621, 51.55057716152997], [-0.5800985292967606, 51.56737330738598], [-0.48710400169360135, 51.584089125615854], [-0.39403840490205416, 51.600724510059], [-0.3009019879621205, 51.61727935488358], [-0.20769500156959853, 51.63375355458977], [-0.11441769808119759, 51.65014700401209]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.1144177&lt;dd&gt;Longitude: 51.650147&lt;dd&gt;Azimuth: 81.989012\u00b0&lt;dd&gt;Altitude: 71.040383\u00b0&lt;dd&gt;Slant Range: 581.23292km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.11441769808119759, 51.65014700401209]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5800985292967606, 51.56737330738598], [-0.48710400169360135, 51.584089125615854], [-0.39403840490205416, 51.600724510059], [-0.3009019879621205, 51.61727935488358], [-0.20769500156959853, 51.63375355458977], [-0.11441769808119759, 51.65014700401209], [-0.021070331504640213, 51.66645959832362]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: -0.021070332&lt;dd&gt;Longitude: 51.66646&lt;dd&gt;Azimuth: 81.631089\u00b0&lt;dd&gt;Altitude: 70.366597\u00b0&lt;dd&gt;Slant Range: 583.42358km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.021070331504640213, 51.66645959832362]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.48710400169360135, 51.584089125615854], [-0.39403840490205416, 51.600724510059], [-0.3009019879621205, 51.61727935488358], [-0.20769500156959853, 51.63375355458977], [-0.11441769808119759, 51.65014700401209], [-0.021070331504640213, 51.66645959832362], [0.07234684250182132, 51.682691233037154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.072346843&lt;dd&gt;Longitude: 51.682691&lt;dd&gt;Azimuth: 81.298729\u00b0&lt;dd&gt;Altitude: 69.697039\u00b0&lt;dd&gt;Slant Range: 585.68956km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.07234684250182132, 51.682691233037154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.39403840490205416, 51.600724510059], [-0.3009019879621205, 51.61727935488358], [-0.20769500156959853, 51.63375355458977], [-0.11441769808119759, 51.65014700401209], [-0.021070331504640213, 51.66645959832362], [0.07234684250182132, 51.682691233037154], [0.1658335666252066, 51.69884180400983]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.16583357&lt;dd&gt;Longitude: 51.698842&lt;dd&gt;Azimuth: 80.98933\u00b0&lt;dd&gt;Altitude: 69.031894\u00b0&lt;dd&gt;Slant Range: 588.02997km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.1658335666252066, 51.69884180400983]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3009019879621205, 51.61727935488358], [-0.20769500156959853, 51.63375355458977], [-0.11441769808119759, 51.65014700401209], [-0.021070331504640213, 51.66645959832362], [0.07234684250182132, 51.682691233037154], [0.1658335666252066, 51.69884180400983], [0.2593895819053387, 51.71491120744469]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.25938958&lt;dd&gt;Longitude: 51.714911&lt;dd&gt;Azimuth: 80.700631\u00b0&lt;dd&gt;Altitude: 68.371329\u00b0&lt;dd&gt;Slant Range: 590.44393km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.2593895819053387, 51.71491120744469]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.20769500156959853, 51.63375355458977], [-0.11441769808119759, 51.65014700401209], [-0.021070331504640213, 51.66645959832362], [0.07234684250182132, 51.682691233037154], [0.1658335666252066, 51.69884180400983], [0.2593895819053387, 51.71491120744469], [0.3530146277310783, 51.730899339894464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.35301463&lt;dd&gt;Longitude: 51.730899&lt;dd&gt;Azimuth: 80.430655\u00b0&lt;dd&gt;Altitude: 67.715498\u00b0&lt;dd&gt;Slant Range: 592.93055km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3530146277310783, 51.730899339894464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.11441769808119759, 51.65014700401209], [-0.021070331504640213, 51.66645959832362], [0.07234684250182132, 51.682691233037154], [0.1658335666252066, 51.69884180400983], [0.2593895819053387, 51.71491120744469], [0.3530146277310783, 51.730899339894464], [0.44670844185095965, 51.7468060982641]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.44670844&lt;dd&gt;Longitude: 51.746806&lt;dd&gt;Azimuth: 80.177669\u00b0&lt;dd&gt;Altitude: 67.064538\u00b0&lt;dd&gt;Slant Range: 595.4889km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.44670844185095965, 51.7468060982641]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.021070331504640213, 51.66645959832362], [0.07234684250182132, 51.682691233037154], [0.1658335666252066, 51.69884180400983], [0.2593895819053387, 51.71491120744469], [0.3530146277310783, 51.730899339894464], [0.44670844185095965, 51.7468060982641], [0.5404707603632924, 51.76263137981375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.54047076&lt;dd&gt;Longitude: 51.762631&lt;dd&gt;Azimuth: 79.940145\u00b0&lt;dd&gt;Altitude: 66.418576\u00b0&lt;dd&gt;Slant Range: 598.11807km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5404707603632924, 51.76263137981375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.07234684250182132, 51.682691233037154], [0.1658335666252066, 51.69884180400983], [0.2593895819053387, 51.71491120744469], [0.3530146277310783, 51.730899339894464], [0.44670844185095965, 51.7468060982641], [0.5404707603632924, 51.76263137981375], [0.6343013177282227, 51.77837508216174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.63430132&lt;dd&gt;Longitude: 51.778375&lt;dd&gt;Azimuth: 79.716731\u00b0&lt;dd&gt;Altitude: 65.777725\u00b0&lt;dd&gt;Slant Range: 600.81712km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6343013177282227, 51.77837508216174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.1658335666252066, 51.69884180400983], [0.2593895819053387, 51.71491120744469], [0.3530146277310783, 51.730899339894464], [0.44670844185095965, 51.7468060982641], [0.5404707603632924, 51.76263137981375], [0.6343013177282227, 51.77837508216174], [0.7281998467701245, 51.794037103287536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.72819985&lt;dd&gt;Longitude: 51.794037&lt;dd&gt;Azimuth: 79.506229\u00b0&lt;dd&gt;Altitude: 65.14209\u00b0&lt;dd&gt;Slant Range: 603.58511km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7281998467701245, 51.794037103287536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.2593895819053387, 51.71491120744469], [0.3530146277310783, 51.730899339894464], [0.44670844185095965, 51.7468060982641], [0.5404707603632924, 51.76263137981375], [0.6343013177282227, 51.77837508216174], [0.7281998467701245, 51.794037103287536], [0.8221660786667603, 51.809617341534015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.82216608&lt;dd&gt;Longitude: 51.809617&lt;dd&gt;Azimuth: 79.307572\u00b0&lt;dd&gt;Altitude: 64.511762\u00b0&lt;dd&gt;Slant Range: 606.4211km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8221660786667603, 51.809617341534015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3530146277310783, 51.730899339894464], [0.44670844185095965, 51.7468060982641], [0.5404707603632924, 51.76263137981375], [0.6343013177282227, 51.77837508216174], [0.7281998467701245, 51.794037103287536], [0.8221660786667603, 51.809617341534015], [0.9161997429668381, 51.82511569561179]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 0.91619974&lt;dd&gt;Longitude: 51.825116&lt;dd&gt;Azimuth: 79.119805\u00b0&lt;dd&gt;Altitude: 63.886825\u00b0&lt;dd&gt;Slant Range: 609.32412km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9161997429668381, 51.82511569561179]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.44670844185095965, 51.7468060982641], [0.5404707603632924, 51.76263137981375], [0.6343013177282227, 51.77837508216174], [0.7281998467701245, 51.794037103287536], [0.8221660786667603, 51.809617341534015], [0.9161997429668381, 51.82511569561179], [1.0103005675835994, 51.84053206460043]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 1.0103006&lt;dd&gt;Longitude: 51.840532&lt;dd&gt;Azimuth: 78.942076\u00b0&lt;dd&gt;Altitude: 63.267353\u00b0&lt;dd&gt;Slant Range: 612.29323km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0103005675835994, 51.84053206460043]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5404707603632924, 51.76263137981375], [0.6343013177282227, 51.77837508216174], [0.7281998467701245, 51.794037103287536], [0.8221660786667603, 51.809617341534015], [0.9161997429668381, 51.82511569561179], [1.0103005675835994, 51.84053206460043], [1.1044682788043352, 51.855866347952634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 1.1044683&lt;dd&gt;Longitude: 51.855866&lt;dd&gt;Azimuth: 78.773615\u00b0&lt;dd&gt;Altitude: 62.653413\u00b0&lt;dd&gt;Slant Range: 615.32747km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1044682788043352, 51.855866347952634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6343013177282227, 51.77837508216174], [0.7281998467701245, 51.794037103287536], [0.8221660786667603, 51.809617341534015], [0.9161997429668381, 51.82511569561179], [1.0103005675835994, 51.84053206460043], [1.1044682788043352, 51.855866347952634], [1.1987026012782485, 51.871118445496435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 1.1987026&lt;dd&gt;Longitude: 51.871118&lt;dd&gt;Azimuth: 78.613733\u00b0&lt;dd&gt;Altitude: 62.045062\u00b0&lt;dd&gt;Slant Range: 618.42586km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1987026012782485, 51.871118445496435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7281998467701245, 51.794037103287536], [0.8221660786667603, 51.809617341534015], [0.9161997429668381, 51.82511569561179], [1.0103005675835994, 51.84053206460043], [1.1044682788043352, 51.855866347952634], [1.1987026012782485, 51.871118445496435], [1.2930032580417727, 51.88628825743859]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 1.2930033&lt;dd&gt;Longitude: 51.886288&lt;dd&gt;Azimuth: 78.461803\u00b0&lt;dd&gt;Altitude: 61.44235\u00b0&lt;dd&gt;Slant Range: 621.58746km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2930032580417727, 51.88628825743859]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8221660786667603, 51.809617341534015], [0.9161997429668381, 51.82511569561179], [1.0103005675835994, 51.84053206460043], [1.1044682788043352, 51.855866347952634], [1.1987026012782485, 51.871118445496435], [1.2930032580417727, 51.88628825743859], [1.3873699704999205, 51.90137568436677]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1798&lt;dd&gt;Latitude: 1.38737&lt;dd&gt;Longitude: 51.901376&lt;dd&gt;Azimuth: 78.31726\u00b0&lt;dd&gt;Altitude: 60.845322\u00b0&lt;dd&gt;Slant Range: 624.81129km&quot;, &quot;name&quot;: &quot;STARLINK-1798&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3873699704999205, 51.90137568436677]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.1032345&lt;dd&gt;Longitude: 53.090031&lt;dd&gt;Azimuth: 65.732845\u00b0&lt;dd&gt;Altitude: 44.887685\u00b0&lt;dd&gt;Slant Range: 753.96053km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549], [4.203096583592367, 53.09454683420587]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.2030966&lt;dd&gt;Longitude: 53.094547&lt;dd&gt;Azimuth: 65.927681\u00b0&lt;dd&gt;Altitude: 44.483536\u00b0&lt;dd&gt;Slant Range: 758.57911km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.203096583592367, 53.09454683420587]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549], [4.203096583592367, 53.09454683420587], [4.302980239509547, 53.098971366745566]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.3029802&lt;dd&gt;Longitude: 53.098971&lt;dd&gt;Azimuth: 66.117601\u00b0&lt;dd&gt;Altitude: 44.08361\u00b0&lt;dd&gt;Slant Range: 763.23346km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.302980239509547, 53.098971366745566]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549], [4.203096583592367, 53.09454683420587], [4.302980239509547, 53.098971366745566], [4.402884989988086, 53.10330503799987]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.402885&lt;dd&gt;Longitude: 53.103305&lt;dd&gt;Azimuth: 66.302788\u00b0&lt;dd&gt;Altitude: 43.687879\u00b0&lt;dd&gt;Slant Range: 767.92294km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.402884989988086, 53.10330503799987]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549], [4.203096583592367, 53.09454683420587], [4.302980239509547, 53.098971366745566], [4.402884989988086, 53.10330503799987], [4.502810404315411, 53.107547815686345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.5028104&lt;dd&gt;Longitude: 53.107548&lt;dd&gt;Azimuth: 66.483419\u00b0&lt;dd&gt;Altitude: 43.296312\u00b0&lt;dd&gt;Slant Range: 772.64689km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.502810404315411, 53.107547815686345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549], [4.203096583592367, 53.09454683420587], [4.302980239509547, 53.098971366745566], [4.402884989988086, 53.10330503799987], [4.502810404315411, 53.107547815686345], [4.602756051165762, 53.111699668186]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.6027561&lt;dd&gt;Longitude: 53.1117&lt;dd&gt;Azimuth: 66.659658\u00b0&lt;dd&gt;Altitude: 42.908878\u00b0&lt;dd&gt;Slant Range: 777.40468km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.602756051165762, 53.111699668186]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.103234452315168, 53.09003147332549], [4.203096583592367, 53.09454683420587], [4.302980239509547, 53.098971366745566], [4.402884989988086, 53.10330503799987], [4.502810404315411, 53.107547815686345], [4.602756051165762, 53.111699668186], [4.70272149860264, 53.115760564544544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.7027215&lt;dd&gt;Longitude: 53.115761&lt;dd&gt;Azimuth: 66.831665\u00b0&lt;dd&gt;Altitude: 42.525544\u00b0&lt;dd&gt;Slant Range: 782.1957km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.70272149860264, 53.115760564544544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.203096583592367, 53.09454683420587], [4.302980239509547, 53.098971366745566], [4.402884989988086, 53.10330503799987], [4.502810404315411, 53.107547815686345], [4.602756051165762, 53.111699668186], [4.70272149860264, 53.115760564544544], [4.802706314104373, 53.11973047447328]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.8027063&lt;dd&gt;Longitude: 53.11973&lt;dd&gt;Azimuth: 66.999591\u00b0&lt;dd&gt;Altitude: 42.146276\u00b0&lt;dd&gt;Slant Range: 787.01932km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.802706314104373, 53.11973047447328]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.302980239509547, 53.098971366745566], [4.402884989988086, 53.10330503799987], [4.502810404315411, 53.107547815686345], [4.602756051165762, 53.111699668186], [4.70272149860264, 53.115760564544544], [4.802706314104373, 53.11973047447328], [4.902710064560149, 53.1236093683505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 4.9027101&lt;dd&gt;Longitude: 53.123609&lt;dd&gt;Azimuth: 67.163579\u00b0&lt;dd&gt;Altitude: 41.771037\u00b0&lt;dd&gt;Slant Range: 791.87495km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.902710064560149, 53.1236093683505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.402884989988086, 53.10330503799987], [4.502810404315411, 53.107547815686345], [4.602756051165762, 53.111699668186], [4.70272149860264, 53.115760564544544], [4.802706314104373, 53.11973047447328], [4.902710064560149, 53.1236093683505], [5.002732316301897, 53.127397217222374]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 5.0027323&lt;dd&gt;Longitude: 53.127397&lt;dd&gt;Azimuth: 67.323768\u00b0&lt;dd&gt;Altitude: 41.399792\u00b0&lt;dd&gt;Slant Range: 796.76199km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.002732316301897, 53.127397217222374]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.502810404315411, 53.107547815686345], [4.602756051165762, 53.111699668186], [4.70272149860264, 53.115760564544544], [4.802706314104373, 53.11973047447328], [4.902710064560149, 53.1236093683505], [5.002732316301897, 53.127397217222374], [5.10277263509449, 53.13109399280406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 5.1027726&lt;dd&gt;Longitude: 53.131094&lt;dd&gt;Azimuth: 67.480288\u00b0&lt;dd&gt;Altitude: 41.032504\u00b0&lt;dd&gt;Slant Range: 801.67987km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.10277263509449, 53.13109399280406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.602756051165762, 53.111699668186], [4.70272149860264, 53.115760564544544], [4.802706314104373, 53.11973047447328], [4.902710064560149, 53.1236093683505], [5.002732316301897, 53.127397217222374], [5.10277263509449, 53.13109399280406], [5.202830586173863, 53.134699667480795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1812&lt;dd&gt;Latitude: 5.2028306&lt;dd&gt;Longitude: 53.1347&lt;dd&gt;Azimuth: 67.633265\u00b0&lt;dd&gt;Altitude: 40.669134\u00b0&lt;dd&gt;Slant Range: 806.62801km&quot;, &quot;name&quot;: &quot;STARLINK-1812&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.202830586173863, 53.134699667480795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -3.1010201&lt;dd&gt;Longitude: 51.874189&lt;dd&gt;Azimuth: 323.45288\u00b0&lt;dd&gt;Altitude: 83.522592\u00b0&lt;dd&gt;Slant Range: 555.63322km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529], [-3.0067068845864724, 51.88934232459193]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -3.0067069&lt;dd&gt;Longitude: 51.889342&lt;dd&gt;Azimuth: 329.87379\u00b0&lt;dd&gt;Altitude: 83.768181\u00b0&lt;dd&gt;Slant Range: 555.39305km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0067068845864724, 51.88934232459193]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529], [-3.0067068845864724, 51.88934232459193], [-2.9123276425243465, 51.90441297351657]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.9123276&lt;dd&gt;Longitude: 51.904413&lt;dd&gt;Azimuth: 336.73112\u00b0&lt;dd&gt;Altitude: 83.930533\u00b0&lt;dd&gt;Slant Range: 555.24078km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9123276425243465, 51.90441297351657]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529], [-3.0067068845864724, 51.88934232459193], [-2.9123276425243465, 51.90441297351657], [-2.817882685244068, 51.919401119385284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.8178827&lt;dd&gt;Longitude: 51.919401&lt;dd&gt;Azimuth: 343.85956\u00b0&lt;dd&gt;Altitude: 84.002685\u00b0&lt;dd&gt;Slant Range: 555.17646km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.817882685244068, 51.919401119385284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529], [-3.0067068845864724, 51.88934232459193], [-2.9123276425243465, 51.90441297351657], [-2.817882685244068, 51.919401119385284], [-2.7233722949917993, 51.934306663630764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.7233723&lt;dd&gt;Longitude: 51.934307&lt;dd&gt;Azimuth: 351.04872\u00b0&lt;dd&gt;Altitude: 83.981307\u00b0&lt;dd&gt;Slant Range: 555.20014km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7233722949917993, 51.934306663630764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529], [-3.0067068845864724, 51.88934232459193], [-2.9123276425243465, 51.90441297351657], [-2.817882685244068, 51.919401119385284], [-2.7233722949917993, 51.934306663630764], [-2.6287967553512916, 51.94912950811714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.6287968&lt;dd&gt;Longitude: 51.94913&lt;dd&gt;Azimuth: 358.07744\u00b0&lt;dd&gt;Altitude: 83.867407\u00b0&lt;dd&gt;Slant Range: 555.3118km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6287967553512916, 51.94912950811714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1010201308952934, 51.8741892715529], [-3.0067068845864724, 51.88934232459193], [-2.9123276425243465, 51.90441297351657], [-2.817882685244068, 51.919401119385284], [-2.7233722949917993, 51.934306663630764], [-2.6287967553512916, 51.94912950811714], [-2.5341563517958012, 51.96386955506083]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.5341564&lt;dd&gt;Longitude: 51.96387&lt;dd&gt;Azimuth: 4.7524769\u00b0&lt;dd&gt;Altitude: 83.666111\u00b0&lt;dd&gt;Slant Range: 555.51138km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5341563517958012, 51.96386955506083]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0067068845864724, 51.88934232459193], [-2.9123276425243465, 51.90441297351657], [-2.817882685244068, 51.919401119385284], [-2.7233722949917993, 51.934306663630764], [-2.6287967553512916, 51.94912950811714], [-2.5341563517958012, 51.96386955506083], [-2.4394513713040786, 51.97852670708845]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.4394514&lt;dd&gt;Longitude: 51.978527&lt;dd&gt;Azimuth: 10.936082\u00b0&lt;dd&gt;Altitude: 83.385626\u00b0&lt;dd&gt;Slant Range: 555.7988km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.4394513713040786, 51.97852670708845]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9123276425243465, 51.90441297351657], [-2.817882685244068, 51.919401119385284], [-2.7233722949917993, 51.934306663630764], [-2.6287967553512916, 51.94912950811714], [-2.5341563517958012, 51.96386955506083], [-2.4394513713040786, 51.97852670708845], [-2.344682102472023, 51.99310086722592]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.3446821&lt;dd&gt;Longitude: 51.993101&lt;dd&gt;Azimuth: 16.554144\u00b0&lt;dd&gt;Altitude: 83.035833\u00b0&lt;dd&gt;Slant Range: 556.17391km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.344682102472023, 51.99310086722592]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.817882685244068, 51.919401119385284], [-2.7233722949917993, 51.934306663630764], [-2.6287967553512916, 51.94912950811714], [-2.5341563517958012, 51.96386955506083], [-2.4394513713040786, 51.97852670708845], [-2.344682102472023, 51.99310086722592], [-2.2498488354809503, 52.00759193890138]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.2498488&lt;dd&gt;Longitude: 52.007592&lt;dd&gt;Azimuth: 21.588018\u00b0&lt;dd&gt;Altitude: 82.626982\u00b0&lt;dd&gt;Slant Range: 556.63654km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2498488354809503, 52.00759193890138]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7233722949917993, 51.934306663630764], [-2.6287967553512916, 51.94912950811714], [-2.5341563517958012, 51.96386955506083], [-2.4394513713040786, 51.97852670708845], [-2.344682102472023, 51.99310086722592], [-2.2498488354809503, 52.00759193890138], [-2.1549518621242845, 52.02199982594789]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.1549519&lt;dd&gt;Longitude: 52.022&lt;dd&gt;Azimuth: 26.058482\u00b0&lt;dd&gt;Altitude: 82.168768\u00b0&lt;dd&gt;Slant Range: 557.18646km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.1549518621242845, 52.02199982594789]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6287967553512916, 51.94912950811714], [-2.5341563517958012, 51.96386955506083], [-2.4394513713040786, 51.97852670708845], [-2.344682102472023, 51.99310086722592], [-2.2498488354809503, 52.00759193890138], [-2.1549518621242845, 52.02199982594789], [-2.0599914757762123, 52.03632443260626]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -2.0599915&lt;dd&gt;Longitude: 52.036324&lt;dd&gt;Azimuth: 30.009391\u00b0&lt;dd&gt;Altitude: 81.669838\u00b0&lt;dd&gt;Slant Range: 557.82343km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0599914757762123, 52.03632443260626]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5341563517958012, 51.96386955506083], [-2.4394513713040786, 51.97852670708845], [-2.344682102472023, 51.99310086722592], [-2.2498488354809503, 52.00759193890138], [-2.1549518621242845, 52.02199982594789], [-2.0599914757762123, 52.03632443260626], [-1.9649679714081676, 52.05056566352823]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.964968&lt;dd&gt;Longitude: 52.050566&lt;dd&gt;Azimuth: 33.494926\u00b0&lt;dd&gt;Altitude: 81.13761\u00b0&lt;dd&gt;Slant Range: 558.54714km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9649679714081676, 52.05056566352823]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.4394513713040786, 51.97852670708845], [-2.344682102472023, 51.99310086722592], [-2.2498488354809503, 52.00759193890138], [-2.1549518621242845, 52.02199982594789], [-2.0599914757762123, 52.03632443260626], [-1.9649679714081676, 52.05056566352823], [-1.8698816455783265, 52.064723423779085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.8698816&lt;dd&gt;Longitude: 52.064723&lt;dd&gt;Azimuth: 36.571197\u00b0&lt;dd&gt;Altitude: 80.578301\u00b0&lt;dd&gt;Slant Range: 559.35725km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8698816455783265, 52.064723423779085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.344682102472023, 51.99310086722592], [-2.2498488354809503, 52.00759193890138], [-2.1549518621242845, 52.02199982594789], [-2.0599914757762123, 52.03632443260626], [-1.9649679714081676, 52.05056566352823], [-1.8698816455783265, 52.064723423779085], [-1.7747327964201545, 52.07879761884047]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.7747328&lt;dd&gt;Longitude: 52.078798&lt;dd&gt;Azimuth: 39.29148\u00b0&lt;dd&gt;Altitude: 79.997057\u00b0&lt;dd&gt;Slant Range: 560.25338km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7747327964201545, 52.07879761884047]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.2498488354809503, 52.00759193890138], [-2.1549518621242845, 52.02199982594789], [-2.0599914757762123, 52.03632443260626], [-1.9649679714081676, 52.05056566352823], [-1.8698816455783265, 52.064723423779085], [-1.7747327964201545, 52.07879761884047], [-1.6795217236541888, 52.09278815461337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.6795217&lt;dd&gt;Longitude: 52.092788&lt;dd&gt;Azimuth: 41.703934\u00b0&lt;dd&gt;Altitude: 79.398107\u00b0&lt;dd&gt;Slant Range: 561.23514km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6795217236541888, 52.09278815461337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.1549518621242845, 52.02199982594789], [-2.0599914757762123, 52.03632443260626], [-1.9649679714081676, 52.05056566352823], [-1.8698816455783265, 52.064723423779085], [-1.7747327964201545, 52.07879761884047], [-1.6795217236541888, 52.09278815461337], [-1.5842487285692097, 52.1066949374209]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.5842487&lt;dd&gt;Longitude: 52.106695&lt;dd&gt;Azimuth: 43.850851\u00b0&lt;dd&gt;Altitude: 78.784928\u00b0&lt;dd&gt;Slant Range: 562.30205km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5842487285692097, 52.1066949374209]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0599914757762123, 52.03632443260626], [-1.9649679714081676, 52.05056566352823], [-1.8698816455783265, 52.064723423779085], [-1.7747327964201545, 52.07879761884047], [-1.6795217236541888, 52.09278815461337], [-1.5842487285692097, 52.1066949374209], [-1.4889141140296178, 52.120517874011156]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.4889141&lt;dd&gt;Longitude: 52.120518&lt;dd&gt;Azimuth: 45.768729\u00b0&lt;dd&gt;Altitude: 78.160377\u00b0&lt;dd&gt;Slant Range: 563.45365km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4889141140296178, 52.120517874011156]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9649679714081676, 52.05056566352823], [-1.8698816455783265, 52.064723423779085], [-1.7747327964201545, 52.07879761884047], [-1.6795217236541888, 52.09278815461337], [-1.5842487285692097, 52.1066949374209], [-1.4889141140296178, 52.120517874011156], [-1.393518184462281, 52.13425687155991]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.3935182&lt;dd&gt;Longitude: 52.134257&lt;dd&gt;Azimuth: 47.488757\u00b0&lt;dd&gt;Altitude: 77.526821\u00b0&lt;dd&gt;Slant Range: 564.6894km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.393518184462281, 52.13425687155991]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8698816455783265, 52.064723423779085], [-1.7747327964201545, 52.07879761884047], [-1.6795217236541888, 52.09278815461337], [-1.5842487285692097, 52.1066949374209], [-1.4889141140296178, 52.120517874011156], [-1.393518184462281, 52.13425687155991], [-1.2980612458605283, 52.14791183767357]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.2980612&lt;dd&gt;Longitude: 52.147912&lt;dd&gt;Azimuth: 49.037447\u00b0&lt;dd&gt;Altitude: 76.886226\u00b0&lt;dd&gt;Slant Range: 566.00876km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2980612458605283, 52.14791183767357]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7747327964201545, 52.07879761884047], [-1.6795217236541888, 52.09278815461337], [-1.5842487285692097, 52.1066949374209], [-1.4889141140296178, 52.120517874011156], [-1.393518184462281, 52.13425687155991], [-1.2980612458605283, 52.14791183767357], [-1.2025436057706391, 52.161482680392076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.2025436&lt;dd&gt;Longitude: 52.161483&lt;dd&gt;Azimuth: 50.437287\u00b0&lt;dd&gt;Altitude: 76.240236\u00b0&lt;dd&gt;Slant Range: 567.41114km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2025436057706391, 52.161482680392076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6795217236541888, 52.09278815461337], [-1.5842487285692097, 52.1066949374209], [-1.4889141140296178, 52.120517874011156], [-1.393518184462281, 52.13425687155991], [-1.2980612458605283, 52.14791183767357], [-1.2025436057706391, 52.161482680392076], [-1.106965573298611, 52.17496930819161]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.1069656&lt;dd&gt;Longitude: 52.174969&lt;dd&gt;Azimuth: 51.707355\u00b0&lt;dd&gt;Altitude: 75.59024\u00b0&lt;dd&gt;Slant Range: 568.89593km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.106965573298611, 52.17496930819161]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5842487285692097, 52.1066949374209], [-1.4889141140296178, 52.120517874011156], [-1.393518184462281, 52.13425687155991], [-1.2980612458605283, 52.14791183767357], [-1.2025436057706391, 52.161482680392076], [-1.106965573298611, 52.17496930819161], [-1.0113274590913321, 52.18837162998734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -1.0113275&lt;dd&gt;Longitude: 52.188372&lt;dd&gt;Azimuth: 52.863857\u00b0&lt;dd&gt;Altitude: 74.937414\u00b0&lt;dd&gt;Slant Range: 570.46248km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0113274590913321, 52.18837162998734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4889141140296178, 52.120517874011156], [-1.393518184462281, 52.13425687155991], [-1.2980612458605283, 52.14791183767357], [-1.2025436057706391, 52.161482680392076], [-1.106965573298611, 52.17496930819161], [-1.0113274590913321, 52.18837162998734], [-0.9156295753475207, 52.20168955513624]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.91562958&lt;dd&gt;Longitude: 52.20169&lt;dd&gt;Azimuth: 53.920591\u00b0&lt;dd&gt;Altitude: 74.282767\u00b0&lt;dd&gt;Slant Range: 572.11012km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9156295753475207, 52.20168955513624]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.393518184462281, 52.13425687155991], [-1.2980612458605283, 52.14791183767357], [-1.2025436057706391, 52.161482680392076], [-1.106965573298611, 52.17496930819161], [-1.0113274590913321, 52.18837162998734], [-0.9156295753475207, 52.20168955513624], [-0.819872235804393, 52.214922993440105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.81987224&lt;dd&gt;Longitude: 52.214923&lt;dd&gt;Azimuth: 54.889342\u00b0&lt;dd&gt;Altitude: 73.627165\u00b0&lt;dd&gt;Slant Range: 573.83814km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.819872235804393, 52.214922993440105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2980612458605283, 52.14791183767357], [-1.2025436057706391, 52.161482680392076], [-1.106965573298611, 52.17496930819161], [-1.0113274590913321, 52.18837162998734], [-0.9156295753475207, 52.20168955513624], [-0.819872235804393, 52.214922993440105], [-0.7240557557310222, 52.22807185514809]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.72405576&lt;dd&gt;Longitude: 52.228072&lt;dd&gt;Azimuth: 55.780207\u00b0&lt;dd&gt;Altitude: 72.971359\u00b0&lt;dd&gt;Slant Range: 575.64582km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7240557557310222, 52.22807185514809]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2025436057706391, 52.161482680392076], [-1.106965573298611, 52.17496930819161], [-1.0113274590913321, 52.18837162998734], [-0.9156295753475207, 52.20168955513624], [-0.819872235804393, 52.214922993440105], [-0.7240557557310222, 52.22807185514809], [-0.6281804519292801, 52.24113605095931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.62818045&lt;dd&gt;Longitude: 52.241136&lt;dd&gt;Azimuth: 56.601868\u00b0&lt;dd&gt;Altitude: 72.316005\u00b0&lt;dd&gt;Slant Range: 577.53242km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6281804519292801, 52.24113605095931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.106965573298611, 52.17496930819161], [-1.0113274590913321, 52.18837162998734], [-0.9156295753475207, 52.20168955513624], [-0.819872235804393, 52.214922993440105], [-0.7240557557310222, 52.22807185514809], [-0.6281804519292801, 52.24113605095931], [-0.5322466427289766, 52.254115492026244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.53224664&lt;dd&gt;Longitude: 52.254115&lt;dd&gt;Azimuth: 57.36182\u00b0&lt;dd&gt;Altitude: 71.661677\u00b0&lt;dd&gt;Slant Range: 579.49715km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5322466427289766, 52.254115492026244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0113274590913321, 52.18837162998734], [-0.9156295753475207, 52.20168955513624], [-0.819872235804393, 52.214922993440105], [-0.7240557557310222, 52.22807185514809], [-0.6281804519292801, 52.24113605095931], [-0.5322466427289766, 52.254115492026244], [-0.43625464797116886, 52.26701008995694]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.43625465&lt;dd&gt;Longitude: 52.26701&lt;dd&gt;Azimuth: 58.066554\u00b0&lt;dd&gt;Altitude: 71.008883\u00b0&lt;dd&gt;Slant Range: 581.53923km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.43625464797116886, 52.26701008995694]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9156295753475207, 52.20168955513624], [-0.819872235804393, 52.214922993440105], [-0.7240557557310222, 52.22807185514809], [-0.6281804519292801, 52.24113605095931], [-0.5322466427289766, 52.254115492026244], [-0.43625464797116886, 52.26701008995694], [-0.3402047890240634, 52.27981975681799]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.34020479&lt;dd&gt;Longitude: 52.27982&lt;dd&gt;Azimuth: 58.721714\u00b0&lt;dd&gt;Altitude: 70.35807\u00b0&lt;dd&gt;Slant Range: 583.65783km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3402047890240634, 52.27981975681799]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.819872235804393, 52.214922993440105], [-0.7240557557310222, 52.22807185514809], [-0.6281804519292801, 52.24113605095931], [-0.5322466427289766, 52.254115492026244], [-0.43625464797116886, 52.26701008995694], [-0.3402047890240634, 52.27981975681799], [-0.24409738875655446, 52.29254440513729]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.24409739&lt;dd&gt;Longitude: 52.292544&lt;dd&gt;Azimuth: 59.332226\u00b0&lt;dd&gt;Altitude: 69.709638\u00b0&lt;dd&gt;Slant Range: 585.85213km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.24409738875655446, 52.29254440513729]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7240557557310222, 52.22807185514809], [-0.6281804519292801, 52.24113605095931], [-0.5322466427289766, 52.254115492026244], [-0.43625464797116886, 52.26701008995694], [-0.3402047890240634, 52.27981975681799], [-0.24409738875655446, 52.29254440513729], [-0.1479327715501062, 52.30518394790665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.14793277&lt;dd&gt;Longitude: 52.305184&lt;dd&gt;Azimuth: 59.902402\u00b0&lt;dd&gt;Altitude: 69.063943\u00b0&lt;dd&gt;Slant Range: 588.12128km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.1479327715501062, 52.30518394790665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6281804519292801, 52.24113605095931], [-0.5322466427289766, 52.254115492026244], [-0.43625464797116886, 52.26701008995694], [-0.3402047890240634, 52.27981975681799], [-0.24409738875655446, 52.29254440513729], [-0.1479327715501062, 52.30518394790665], [-0.05171126327465695, 52.31773829858463]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: -0.051711263&lt;dd&gt;Longitude: 52.317738&lt;dd&gt;Azimuth: 60.436034\u00b0&lt;dd&gt;Altitude: 68.421302\u00b0&lt;dd&gt;Slant Range: 590.46441km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.05171126327465695, 52.31773829858463]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5322466427289766, 52.254115492026244], [-0.43625464797116886, 52.26701008995694], [-0.3402047890240634, 52.27981975681799], [-0.24409738875655446, 52.29254440513729], [-0.1479327715501062, 52.30518394790665], [-0.05171126327465695, 52.31773829858463], [0.04456680869390047, 52.33020737109944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.044566809&lt;dd&gt;Longitude: 52.330207&lt;dd&gt;Azimuth: 60.936464\u00b0&lt;dd&gt;Altitude: 67.782003\u00b0&lt;dd&gt;Slant Range: 592.88064km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.04456680869390047, 52.33020737109944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.43625464797116886, 52.26701008995694], [-0.3402047890240634, 52.27981975681799], [-0.24409738875655446, 52.29254440513729], [-0.1479327715501062, 52.30518394790665], [-0.05171126327465695, 52.31773829858463], [0.04456680869390047, 52.33020737109944], [0.14090111549873066, 52.34259107985113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.14090112&lt;dd&gt;Longitude: 52.342591&lt;dd&gt;Azimuth: 61.406647\u00b0&lt;dd&gt;Altitude: 67.146302\u00b0&lt;dd&gt;Slant Range: 595.36908km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.14090111549873066, 52.34259107985113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3402047890240634, 52.27981975681799], [-0.24409738875655446, 52.29254440513729], [-0.1479327715501062, 52.30518394790665], [-0.05171126327465695, 52.31773829858463], [0.04456680869390047, 52.33020737109944], [0.14090111549873066, 52.34259107985113], [0.23729132679643242, 52.35488933971492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.23729133&lt;dd&gt;Longitude: 52.354889&lt;dd&gt;Azimuth: 61.849207\u00b0&lt;dd&gt;Altitude: 66.514431\u00b0&lt;dd&gt;Slant Range: 597.92882km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.23729132679643242, 52.35488933971492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.24409738875655446, 52.29254440513729], [-0.1479327715501062, 52.30518394790665], [-0.05171126327465695, 52.31773829858463], [0.04456680869390047, 52.33020737109944], [0.14090111549873066, 52.34259107985113], [0.23729132679643242, 52.35488933971492], [0.33373711077110946, 52.36710206604358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.33373711&lt;dd&gt;Longitude: 52.367102&lt;dd&gt;Azimuth: 62.266479\u00b0&lt;dd&gt;Altitude: 65.886597\u00b0&lt;dd&gt;Slant Range: 600.55895km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.33373711077110946, 52.36710206604358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.1479327715501062, 52.30518394790665], [-0.05171126327465695, 52.31773829858463], [0.04456680869390047, 52.33020737109944], [0.14090111549873066, 52.34259107985113], [0.23729132679643242, 52.35488933971492], [0.33373711077110946, 52.36710206604358], [0.4302381341292817, 52.37922917467011]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.43023813&lt;dd&gt;Longitude: 52.379229&lt;dd&gt;Azimuth: 62.660546\u00b0&lt;dd&gt;Altitude: 65.262989\u00b0&lt;dd&gt;Slant Range: 603.25854km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.4302381341292817, 52.37922917467011]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.05171126327465695, 52.31773829858463], [0.04456680869390047, 52.33020737109944], [0.14090111549873066, 52.34259107985113], [0.23729132679643242, 52.35488933971492], [0.33373711077110946, 52.36710206604358], [0.4302381341292817, 52.37922917467011], [0.5267940621192226, 52.39127058191046]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.52679406&lt;dd&gt;Longitude: 52.391271&lt;dd&gt;Azimuth: 63.033275\u00b0&lt;dd&gt;Altitude: 64.643775\u00b0&lt;dd&gt;Slant Range: 606.02667km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5267940621192226, 52.39127058191046]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.04456680869390047, 52.33020737109944], [0.14090111549873066, 52.34259107985113], [0.23729132679643242, 52.35488933971492], [0.33373711077110946, 52.36710206604358], [0.4302381341292817, 52.37922917467011], [0.5267940621192226, 52.39127058191046], [0.6234045585294078, 52.40322620456646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.62340456&lt;dd&gt;Longitude: 52.403226&lt;dd&gt;Azimuth: 63.386338\u00b0&lt;dd&gt;Altitude: 64.029108\u00b0&lt;dd&gt;Slant Range: 608.8624km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6234045585294078, 52.40322620456646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.14090111549873066, 52.34259107985113], [0.23729132679643242, 52.35488933971492], [0.33373711077110946, 52.36710206604358], [0.4302381341292817, 52.37922917467011], [0.5267940621192226, 52.39127058191046], [0.6234045585294078, 52.40322620456646], [0.7200692856838325, 52.41509595992777]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.72006929&lt;dd&gt;Longitude: 52.415096&lt;dd&gt;Azimuth: 63.721243\u00b0&lt;dd&gt;Altitude: 63.419125\u00b0&lt;dd&gt;Slant Range: 611.76477km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7200692856838325, 52.41509595992777]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.23729132679643242, 52.35488933971492], [0.33373711077110946, 52.36710206604358], [0.4302381341292817, 52.37922917467011], [0.5267940621192226, 52.39127058191046], [0.6234045585294078, 52.40322620456646], [0.7200692856838325, 52.41509595992777], [0.8167879044765911, 52.426879765775546]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.8167879&lt;dd&gt;Longitude: 52.42688&lt;dd&gt;Azimuth: 64.039348\u00b0&lt;dd&gt;Altitude: 62.813947\u00b0&lt;dd&gt;Slant Range: 614.73286km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8167879044765911, 52.426879765775546]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.33373711077110946, 52.36710206604358], [0.4302381341292817, 52.37922917467011], [0.5267940621192226, 52.39127058191046], [0.6234045585294078, 52.40322620456646], [0.7200692856838325, 52.41509595992777], [0.8167879044765911, 52.426879765775546], [0.9135600743471448, 52.43857754038412]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 0.91356007&lt;dd&gt;Longitude: 52.438578&lt;dd&gt;Azimuth: 64.341881\u00b0&lt;dd&gt;Altitude: 62.213684\u00b0&lt;dd&gt;Slant Range: 617.76569km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9135600743471448, 52.43857754038412]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.4302381341292817, 52.37922917467011], [0.5267940621192226, 52.39127058191046], [0.6234045585294078, 52.40322620456646], [0.7200692856838325, 52.41509595992777], [0.8167879044765911, 52.426879765775546], [0.9135600743471448, 52.43857754038412], [1.0103854533084888, 52.450189202524385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.0103855&lt;dd&gt;Longitude: 52.450189&lt;dd&gt;Azimuth: 64.629955\u00b0&lt;dd&gt;Altitude: 61.618434\u00b0&lt;dd&gt;Slant Range: 620.86233km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0103854533084888, 52.450189202524385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5267940621192226, 52.39127058191046], [0.6234045585294078, 52.40322620456646], [0.7200692856838325, 52.41509595992777], [0.8167879044765911, 52.426879765775546], [0.9135600743471448, 52.43857754038412], [1.0103854533084888, 52.450189202524385], [1.107263697943463, 52.46171467146586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.1072637&lt;dd&gt;Longitude: 52.461715&lt;dd&gt;Azimuth: 64.904581\u00b0&lt;dd&gt;Altitude: 61.028284\u00b0&lt;dd&gt;Slant Range: 624.02182km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.107263697943463, 52.46171467146586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6234045585294078, 52.40322620456646], [0.7200692856838325, 52.41509595992777], [0.8167879044765911, 52.426879765775546], [0.9135600743471448, 52.43857754038412], [1.0103854533084888, 52.450189202524385], [1.107263697943463, 52.46171467146586], [1.2041944634127406, 52.47315386697972]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.2041945&lt;dd&gt;Longitude: 52.473154&lt;dd&gt;Azimuth: 65.166679\u00b0&lt;dd&gt;Altitude: 60.443308\u00b0&lt;dd&gt;Slant Range: 627.2432km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2041944634127406, 52.47315386697972]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7200692856838325, 52.41509595992777], [0.8167879044765911, 52.426879765775546], [0.9135600743471448, 52.43857754038412], [1.0103854533084888, 52.450189202524385], [1.107263697943463, 52.46171467146586], [1.2041944634127406, 52.47315386697972], [1.3011774034601735, 52.484506709341154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.3011774&lt;dd&gt;Longitude: 52.484507&lt;dd&gt;Azimuth: 65.417089\u00b0&lt;dd&gt;Altitude: 59.863574\u00b0&lt;dd&gt;Slant Range: 630.52553km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3011774034601735, 52.484506709341154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8167879044765911, 52.426879765775546], [0.9135600743471448, 52.43857754038412], [1.0103854533084888, 52.450189202524385], [1.107263697943463, 52.46171467146586], [1.2041944634127406, 52.47315386697972], [1.3011774034601735, 52.484506709341154], [1.3982121704298376, 52.49577311933205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.3982122&lt;dd&gt;Longitude: 52.495773&lt;dd&gt;Azimuth: 65.656575\u00b0&lt;dd&gt;Altitude: 59.28914\u00b0&lt;dd&gt;Slant Range: 633.86784km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3982121704298376, 52.49577311933205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9135600743471448, 52.43857754038412], [1.0103854533084888, 52.450189202524385], [1.107263697943463, 52.46171467146586], [1.2041944634127406, 52.47315386697972], [1.3011774034601735, 52.484506709341154], [1.3982121704298376, 52.49577311933205], [1.4952984152535158, 52.50695301824342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.4952984&lt;dd&gt;Longitude: 52.506953&lt;dd&gt;Azimuth: 65.885841\u00b0&lt;dd&gt;Altitude: 58.720054\u00b0&lt;dd&gt;Slant Range: 637.26921km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4952984152535158, 52.50695301824342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0103854533084888, 52.450189202524385], [1.107263697943463, 52.46171467146586], [1.2041944634127406, 52.47315386697972], [1.3011774034601735, 52.484506709341154], [1.3982121704298376, 52.49577311933205], [1.4952984152535158, 52.50695301824342], [1.5924357874786608, 52.5180463278782]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.5924358&lt;dd&gt;Longitude: 52.518046&lt;dd&gt;Azimuth: 66.10553\u00b0&lt;dd&gt;Altitude: 58.156358\u00b0&lt;dd&gt;Slant Range: 640.72867km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5924357874786608, 52.5180463278782]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.107263697943463, 52.46171467146586], [1.2041944634127406, 52.47315386697972], [1.3011774034601735, 52.484506709341154], [1.3982121704298376, 52.49577311933205], [1.4952984152535158, 52.50695301824342], [1.5924357874786608, 52.5180463278782], [1.6896239352540448, 52.52905297055376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.6896239&lt;dd&gt;Longitude: 52.529053&lt;dd&gt;Azimuth: 66.316231\u00b0&lt;dd&gt;Altitude: 57.598086\u00b0&lt;dd&gt;Slant Range: 644.24529km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6896239352540448, 52.52905297055376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2041944634127406, 52.47315386697972], [1.3011774034601735, 52.484506709341154], [1.3982121704298376, 52.49577311933205], [1.4952984152535158, 52.50695301824342], [1.5924357874786608, 52.5180463278782], [1.6896239352540448, 52.52905297055376], [1.7868625053617935, 52.53997286910439]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.7868625&lt;dd&gt;Longitude: 52.539973&lt;dd&gt;Azimuth: 66.518491\u00b0&lt;dd&gt;Altitude: 57.045266\u00b0&lt;dd&gt;Slant Range: 647.81814km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7868625053617935, 52.53997286910439]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3011774034601735, 52.484506709341154], [1.3982121704298376, 52.49577311933205], [1.4952984152535158, 52.50695301824342], [1.5924357874786608, 52.5180463278782], [1.6896239352540448, 52.52905297055376], [1.7868625053617935, 52.53997286910439], [1.8841511431989901, 52.550805946883706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.8841511&lt;dd&gt;Longitude: 52.550806&lt;dd&gt;Azimuth: 66.712808\u00b0&lt;dd&gt;Altitude: 56.497918\u00b0&lt;dd&gt;Slant Range: 651.44628km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8841511431989901, 52.550805946883706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3982121704298376, 52.49577311933205], [1.4952984152535158, 52.50695301824342], [1.5924357874786608, 52.5180463278782], [1.6896239352540448, 52.52905297055376], [1.7868625053617935, 52.53997286910439], [1.8841511431989901, 52.550805946883706], [1.981489492804418, 52.5615521277675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 1.9814895&lt;dd&gt;Longitude: 52.561552&lt;dd&gt;Azimuth: 66.899647\u00b0&lt;dd&gt;Altitude: 55.956058\u00b0&lt;dd&gt;Slant Range: 655.1288km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.981489492804418, 52.5615521277675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4952984152535158, 52.50695301824342], [1.5924357874786608, 52.5180463278782], [1.6896239352540448, 52.52905297055376], [1.7868625053617935, 52.53997286910439], [1.8841511431989901, 52.550805946883706], [1.981489492804418, 52.5615521277675], [2.0788771968518165, 52.57221133615597]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.0788772&lt;dd&gt;Longitude: 52.572211&lt;dd&gt;Azimuth: 67.079436\u00b0&lt;dd&gt;Altitude: 55.419696\u00b0&lt;dd&gt;Slant Range: 658.86478km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0788771968518165, 52.57221133615597]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5924357874786608, 52.5180463278782], [1.6896239352540448, 52.52905297055376], [1.7868625053617935, 52.53997286910439], [1.8841511431989901, 52.550805946883706], [1.981489492804418, 52.5615521277675], [2.0788771968518165, 52.57221133615597], [2.176313896672859, 52.5827834969764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.1763139&lt;dd&gt;Longitude: 52.582783&lt;dd&gt;Azimuth: 67.252569\u00b0&lt;dd&gt;Altitude: 54.888835\u00b0&lt;dd&gt;Slant Range: 662.6533km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.176313896672859, 52.5827834969764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6896239352540448, 52.52905297055376], [1.7868625053617935, 52.53997286910439], [1.8841511431989901, 52.550805946883706], [1.981489492804418, 52.5615521277675], [2.0788771968518165, 52.57221133615597], [2.176313896672859, 52.5827834969764], [2.2737992322430545, 52.59326853568531]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.2737992&lt;dd&gt;Longitude: 52.593269&lt;dd&gt;Azimuth: 67.419414\u00b0&lt;dd&gt;Altitude: 54.363476\u00b0&lt;dd&gt;Slant Range: 666.49348km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2737992322430545, 52.59326853568531]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7868625053617935, 52.53997286910439], [1.8841511431989901, 52.550805946883706], [1.981489492804418, 52.5615521277675], [2.0788771968518165, 52.57221133615597], [2.176313896672859, 52.5827834969764], [2.2737992322430545, 52.59326853568531], [2.3713328422143958, 52.603666378271456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.3713328&lt;dd&gt;Longitude: 52.603666&lt;dd&gt;Azimuth: 67.580312\u00b0&lt;dd&gt;Altitude: 53.843612\u00b0&lt;dd&gt;Slant Range: 670.38441km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3713328422143958, 52.603666378271456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8841511431989901, 52.550805946883706], [1.981489492804418, 52.5615521277675], [2.0788771968518165, 52.57221133615597], [2.176313896672859, 52.5827834969764], [2.2737992322430545, 52.59326853568531], [2.3713328422143958, 52.603666378271456], [2.468914363901057, 52.61397695125792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.4689144&lt;dd&gt;Longitude: 52.613977&lt;dd&gt;Azimuth: 67.73558\u00b0&lt;dd&gt;Altitude: 53.329235\u00b0&lt;dd&gt;Slant Range: 674.32521km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.468914363901057, 52.61397695125792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.981489492804418, 52.5615521277675], [2.0788771968518165, 52.57221133615597], [2.176313896672859, 52.5827834969764], [2.2737992322430545, 52.59326853568531], [2.3713328422143958, 52.603666378271456], [2.468914363901057, 52.61397695125792], [2.566543433301964, 52.624200181704595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.5665434&lt;dd&gt;Longitude: 52.6242&lt;dd&gt;Azimuth: 67.885512\u00b0&lt;dd&gt;Altitude: 52.820331\u00b0&lt;dd&gt;Slant Range: 678.31502km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.566543433301964, 52.624200181704595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0788771968518165, 52.57221133615597], [2.176313896672859, 52.5827834969764], [2.2737992322430545, 52.59326853568531], [2.3713328422143958, 52.603666378271456], [2.468914363901057, 52.61397695125792], [2.566543433301964, 52.624200181704595], [2.6642196850987587, 52.63433599721077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.6642197&lt;dd&gt;Longitude: 52.634336&lt;dd&gt;Azimuth: 68.030383\u00b0&lt;dd&gt;Altitude: 52.316884\u00b0&lt;dd&gt;Slant Range: 682.35296km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.6642196850987587, 52.63433599721077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.176313896672859, 52.5827834969764], [2.2737992322430545, 52.59326853568531], [2.3713328422143958, 52.603666378271456], [2.468914363901057, 52.61397695125792], [2.566543433301964, 52.624200181704595], [2.6642196850987587, 52.63433599721077], [2.761942752672694, 52.6443843259175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.7619428&lt;dd&gt;Longitude: 52.644384&lt;dd&gt;Azimuth: 68.17045\u00b0&lt;dd&gt;Altitude: 51.818872\u00b0&lt;dd&gt;Slant Range: 686.43818km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.761942752672694, 52.6443843259175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2737992322430545, 52.59326853568531], [2.3713328422143958, 52.603666378271456], [2.468914363901057, 52.61397695125792], [2.566543433301964, 52.624200181704595], [2.6642196850987587, 52.63433599721077], [2.761942752672694, 52.6443843259175], [2.859712268104507, 52.65434509650966]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.8597123&lt;dd&gt;Longitude: 52.654345&lt;dd&gt;Azimuth: 68.305952\u00b0&lt;dd&gt;Altitude: 51.326272\u00b0&lt;dd&gt;Slant Range: 690.56984km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.859712268104507, 52.65434509650966]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3713328422143958, 52.603666378271456], [2.468914363901057, 52.61397695125792], [2.566543433301964, 52.624200181704595], [2.6642196850987587, 52.63433599721077], [2.761942752672694, 52.6443843259175], [2.859712268104507, 52.65434509650966], [2.9575278621865815, 52.66421823821915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 2.9575279&lt;dd&gt;Longitude: 52.664218&lt;dd&gt;Azimuth: 68.437112\u00b0&lt;dd&gt;Altitude: 50.839058\u00b0&lt;dd&gt;Slant Range: 694.7471km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9575278621865815, 52.66421823821915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.468914363901057, 52.61397695125792], [2.566543433301964, 52.624200181704595], [2.6642196850987587, 52.63433599721077], [2.761942752672694, 52.6443843259175], [2.859712268104507, 52.65434509650966], [2.9575278621865815, 52.66421823821915], [3.0553891644345237, 52.67400368082635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.0553892&lt;dd&gt;Longitude: 52.674004&lt;dd&gt;Azimuth: 68.564141\u00b0&lt;dd&gt;Altitude: 50.357198\u00b0&lt;dd&gt;Slant Range: 698.96915km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0553891644345237, 52.67400368082635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.566543433301964, 52.624200181704595], [2.6642196850987587, 52.63433599721077], [2.761942752672694, 52.6443843259175], [2.859712268104507, 52.65434509650966], [2.9575278621865815, 52.66421823821915], [3.0553891644345237, 52.67400368082635], [3.153295803086427, 52.68370135466309]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.1532958&lt;dd&gt;Longitude: 52.683701&lt;dd&gt;Azimuth: 68.687234\u00b0&lt;dd&gt;Altitude: 49.880663\u00b0&lt;dd&gt;Slant Range: 703.23517km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.153295803086427, 52.68370135466309]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.6642196850987587, 52.63433599721077], [2.761942752672694, 52.6443843259175], [2.859712268104507, 52.65434509650966], [2.9575278621865815, 52.66421823821915], [3.0553891644345237, 52.67400368082635], [3.153295803086427, 52.68370135466309], [3.2512474051166853, 52.69331119061484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.2512474&lt;dd&gt;Longitude: 52.693311&lt;dd&gt;Azimuth: 68.806577\u00b0&lt;dd&gt;Altitude: 49.409416\u00b0&lt;dd&gt;Slant Range: 707.54436km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.2512474051166853, 52.69331119061484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.761942752672694, 52.6443843259175], [2.859712268104507, 52.65434509650966], [2.9575278621865815, 52.66421823821915], [3.0553891644345237, 52.67400368082635], [3.153295803086427, 52.68370135466309], [3.2512474051166853, 52.69331119061484], [3.3492435962469878, 52.70283312012301]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.3492436&lt;dd&gt;Longitude: 52.702833&lt;dd&gt;Azimuth: 68.92234\u00b0&lt;dd&gt;Altitude: 48.943421\u00b0&lt;dd&gt;Slant Range: 711.89593km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3492435962469878, 52.70283312012301]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.859712268104507, 52.65434509650966], [2.9575278621865815, 52.66421823821915], [3.0553891644345237, 52.67400368082635], [3.153295803086427, 52.68370135466309], [3.2512474051166853, 52.69331119061484], [3.3492435962469878, 52.70283312012301], [3.447284000951431, 52.71226707518721]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.447284&lt;dd&gt;Longitude: 52.712267&lt;dd&gt;Azimuth: 69.034688\u00b0&lt;dd&gt;Altitude: 48.48264\u00b0&lt;dd&gt;Slant Range: 716.28911km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.447284000951431, 52.71226707518721]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9575278621865815, 52.66421823821915], [3.0553891644345237, 52.67400368082635], [3.153295803086427, 52.68370135466309], [3.2512474051166853, 52.69331119061484], [3.3492435962469878, 52.70283312012301], [3.447284000951431, 52.71226707518721], [3.54536824246133, 52.72161298836784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.5453682&lt;dd&gt;Longitude: 52.721613&lt;dd&gt;Azimuth: 69.143774\u00b0&lt;dd&gt;Altitude: 48.027032\u00b0&lt;dd&gt;Slant Range: 720.72312km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.54536824246133, 52.72161298836784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0553891644345237, 52.67400368082635], [3.153295803086427, 52.68370135466309], [3.2512474051166853, 52.69331119061484], [3.3492435962469878, 52.70283312012301], [3.447284000951431, 52.71226707518721], [3.54536824246133, 52.72161298836784], [3.6434959427882174, 52.73087079278794]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.6434959&lt;dd&gt;Longitude: 52.730871&lt;dd&gt;Azimuth: 69.24974\u00b0&lt;dd&gt;Altitude: 47.576555\u00b0&lt;dd&gt;Slant Range: 725.19722km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6434959427882174, 52.73087079278794]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.153295803086427, 52.68370135466309], [3.2512474051166853, 52.69331119061484], [3.3492435962469878, 52.70283312012301], [3.447284000951431, 52.71226707518721], [3.54536824246133, 52.72161298836784], [3.6434959427882174, 52.73087079278794], [3.7416667227060603, 52.740040422135934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.7416667&lt;dd&gt;Longitude: 52.74004&lt;dd&gt;Azimuth: 69.352722\u00b0&lt;dd&gt;Altitude: 47.131164\u00b0&lt;dd&gt;Slant Range: 729.71067km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.7416667227060603, 52.740040422135934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.2512474051166853, 52.69331119061484], [3.3492435962469878, 52.70283312012301], [3.447284000951431, 52.71226707518721], [3.54536824246133, 52.72161298836784], [3.6434959427882174, 52.73087079278794], [3.7416667227060603, 52.740040422135934], [3.8398802017929627, 52.749121810667496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.8398802&lt;dd&gt;Longitude: 52.749122&lt;dd&gt;Azimuth: 69.452849\u00b0&lt;dd&gt;Altitude: 46.690814\u00b0&lt;dd&gt;Slant Range: 734.26272km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8398802017929627, 52.749121810667496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.3492435962469878, 52.70283312012301], [3.447284000951431, 52.71226707518721], [3.54536824246133, 52.72161298836784], [3.6434959427882174, 52.73087079278794], [3.7416667227060603, 52.740040422135934], [3.8398802017929627, 52.749121810667496], [3.9381359984125903, 52.75811489320802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 3.938136&lt;dd&gt;Longitude: 52.758115&lt;dd&gt;Azimuth: 69.550241\u00b0&lt;dd&gt;Altitude: 46.255459\u00b0&lt;dd&gt;Slant Range: 738.85267km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9381359984125903, 52.75811489320802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.447284000951431, 52.71226707518721], [3.54536824246133, 52.72161298836784], [3.6434959427882174, 52.73087079278794], [3.7416667227060603, 52.740040422135934], [3.8398802017929627, 52.749121810667496], [3.9381359984125903, 52.75811489320802], [4.03643372974122, 52.76701960515484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.0364337&lt;dd&gt;Longitude: 52.76702&lt;dd&gt;Azimuth: 69.645013\u00b0&lt;dd&gt;Altitude: 45.825052\u00b0&lt;dd&gt;Slant Range: 743.47981km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.03643372974122, 52.76701960515484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.54536824246133, 52.72161298836784], [3.6434959427882174, 52.73087079278794], [3.7416667227060603, 52.740040422135934], [3.8398802017929627, 52.749121810667496], [3.9381359984125903, 52.75811489320802], [4.03643372974122, 52.76701960515484], [4.13477301176415, 52.77583588247941]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.134773&lt;dd&gt;Longitude: 52.775836&lt;dd&gt;Azimuth: 69.737271\u00b0&lt;dd&gt;Altitude: 45.399543\u00b0&lt;dd&gt;Slant Range: 748.14343km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.13477301176415, 52.77583588247941]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6434959427882174, 52.73087079278794], [3.7416667227060603, 52.740040422135934], [3.8398802017929627, 52.749121810667496], [3.9381359984125903, 52.75811489320802], [4.03643372974122, 52.76701960515484], [4.13477301176415, 52.77583588247941], [4.233153459296284, 52.78456366172951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.2331535&lt;dd&gt;Longitude: 52.784564&lt;dd&gt;Azimuth: 69.827119\u00b0&lt;dd&gt;Altitude: 44.978882\u00b0&lt;dd&gt;Slant Range: 752.84286km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.233153459296284, 52.78456366172951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.7416667227060603, 52.740040422135934], [3.8398802017929627, 52.749121810667496], [3.9381359984125903, 52.75811489320802], [4.03643372974122, 52.76701960515484], [4.13477301176415, 52.77583588247941], [4.233153459296284, 52.78456366172951], [4.331574685979973, 52.793202880031345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.3315747&lt;dd&gt;Longitude: 52.793203&lt;dd&gt;Azimuth: 69.914652\u00b0&lt;dd&gt;Altitude: 44.563019\u00b0&lt;dd&gt;Slant Range: 757.57743km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.331574685979973, 52.793202880031345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8398802017929627, 52.749121810667496], [3.9381359984125903, 52.75811489320802], [4.03643372974122, 52.76701960515484], [4.13477301176415, 52.77583588247941], [4.233153459296284, 52.78456366172951], [4.331574685979973, 52.793202880031345], [4.430036304304067, 52.80175347509182]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.4300363&lt;dd&gt;Longitude: 52.801753&lt;dd&gt;Azimuth: 69.999963\u00b0&lt;dd&gt;Altitude: 44.151904\u00b0&lt;dd&gt;Slant Range: 762.34648km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.430036304304067, 52.80175347509182]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9381359984125903, 52.75811489320802], [4.03643372974122, 52.76701960515484], [4.13477301176415, 52.77583588247941], [4.233153459296284, 52.78456366172951], [4.331574685979973, 52.793202880031345], [4.430036304304067, 52.80175347509182], [4.528537925604605, 52.81021538520068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.5285379&lt;dd&gt;Longitude: 52.810215&lt;dd&gt;Azimuth: 70.083137\u00b0&lt;dd&gt;Altitude: 43.745484\u00b0&lt;dd&gt;Slant Range: 767.14935km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.528537925604605, 52.81021538520068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.03643372974122, 52.76701960515484], [4.13477301176415, 52.77583588247941], [4.233153459296284, 52.78456366172951], [4.331574685979973, 52.793202880031345], [4.430036304304067, 52.80175347509182], [4.528537925604605, 52.81021538520068], [4.627079160086344, 52.81858854923256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.6270792&lt;dd&gt;Longitude: 52.818589&lt;dd&gt;Azimuth: 70.164257\u00b0&lt;dd&gt;Altitude: 43.343706\u00b0&lt;dd&gt;Slant Range: 771.98541km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.627079160086344, 52.81858854923256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.13477301176415, 52.77583588247941], [4.233153459296284, 52.78456366172951], [4.331574685979973, 52.793202880031345], [4.430036304304067, 52.80175347509182], [4.528537925604605, 52.81021538520068], [4.627079160086344, 52.81858854923256], [4.7256596168184, 52.8268729066492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.7256596&lt;dd&gt;Longitude: 52.826873&lt;dd&gt;Azimuth: 70.243402\u00b0&lt;dd&gt;Altitude: 42.946519\u00b0&lt;dd&gt;Slant Range: 776.85404km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.7256596168184, 52.8268729066492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.233153459296284, 52.78456366172951], [4.331574685979973, 52.793202880031345], [4.430036304304067, 52.80175347509182], [4.528537925604605, 52.81021538520068], [4.627079160086344, 52.81858854923256], [4.7256596168184, 52.8268729066492], [4.824278903751102, 52.83506839750155]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.8242789&lt;dd&gt;Longitude: 52.835068&lt;dd&gt;Azimuth: 70.320646\u00b0&lt;dd&gt;Altitude: 42.553868\u00b0&lt;dd&gt;Slant Range: 781.75462km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.824278903751102, 52.83506839750155]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.331574685979973, 52.793202880031345], [4.430036304304067, 52.80175347509182], [4.528537925604605, 52.81021538520068], [4.627079160086344, 52.81858854923256], [4.7256596168184, 52.8268729066492], [4.824278903751102, 52.83506839750155], [4.922936627727356, 52.843174962431725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 4.9229366&lt;dd&gt;Longitude: 52.843175&lt;dd&gt;Azimuth: 70.396059\u00b0&lt;dd&gt;Altitude: 42.165701\u00b0&lt;dd&gt;Slant Range: 786.68655km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.922936627727356, 52.843174962431725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.430036304304067, 52.80175347509182], [4.528537925604605, 52.81021538520068], [4.627079160086344, 52.81858854923256], [4.7256596168184, 52.8268729066492], [4.824278903751102, 52.83506839750155], [4.922936627727356, 52.843174962431725], [5.02163239448932, 52.85119254267514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.0216324&lt;dd&gt;Longitude: 52.851193&lt;dd&gt;Azimuth: 70.469708\u00b0&lt;dd&gt;Altitude: 41.781963\u00b0&lt;dd&gt;Slant Range: 791.64924km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.02163239448932, 52.85119254267514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.528537925604605, 52.81021538520068], [4.627079160086344, 52.81858854923256], [4.7256596168184, 52.8268729066492], [4.824278903751102, 52.83506839750155], [4.922936627727356, 52.843174962431725], [5.02163239448932, 52.85119254267514], [5.120365808685854, 52.85912108006267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.1203658&lt;dd&gt;Longitude: 52.859121&lt;dd&gt;Azimuth: 70.541658\u00b0&lt;dd&gt;Altitude: 41.402602\u00b0&lt;dd&gt;Slant Range: 796.6421km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.120365808685854, 52.85912108006267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.627079160086344, 52.81858854923256], [4.7256596168184, 52.8268729066492], [4.824278903751102, 52.83506839750155], [4.922936627727356, 52.843174962431725], [5.02163239448932, 52.85119254267514], [5.120365808685854, 52.85912108006267], [5.219136473891757, 52.86696051702244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.2191365&lt;dd&gt;Longitude: 52.866961&lt;dd&gt;Azimuth: 70.611969\u00b0&lt;dd&gt;Altitude: 41.027562\u00b0&lt;dd&gt;Slant Range: 801.66457km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.219136473891757, 52.86696051702244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.7256596168184, 52.8268729066492], [4.824278903751102, 52.83506839750155], [4.922936627727356, 52.843174962431725], [5.02163239448932, 52.85119254267514], [5.120365808685854, 52.85912108006267], [5.219136473891757, 52.86696051702244], [5.317943992605401, 52.874710796582036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.317944&lt;dd&gt;Longitude: 52.874711&lt;dd&gt;Azimuth: 70.680699\u00b0&lt;dd&gt;Altitude: 40.65679\u00b0&lt;dd&gt;Slant Range: 806.71609km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.317943992605401, 52.874710796582036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.824278903751102, 52.83506839750155], [4.922936627727356, 52.843174962431725], [5.02163239448932, 52.85119254267514], [5.120365808685854, 52.85912108006267], [5.219136473891757, 52.86696051702244], [5.317943992605401, 52.874710796582036], [5.41678796626489, 52.882371862370476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.416788&lt;dd&gt;Longitude: 52.882372&lt;dd&gt;Azimuth: 70.747904\u00b0&lt;dd&gt;Altitude: 40.290233\u00b0&lt;dd&gt;Slant Range: 811.79612km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.41678796626489, 52.882371862370476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.922936627727356, 52.843174962431725], [5.02163239448932, 52.85119254267514], [5.120365808685854, 52.85912108006267], [5.219136473891757, 52.86696051702244], [5.317943992605401, 52.874710796582036], [5.41678796626489, 52.882371862370476], [5.5156679952655105, 52.889943658620005]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.515668&lt;dd&gt;Longitude: 52.889944&lt;dd&gt;Azimuth: 70.813636\u00b0&lt;dd&gt;Altitude: 39.927836\u00b0&lt;dd&gt;Slant Range: 816.9041km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.5156679952655105, 52.889943658620005]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.02163239448932, 52.85119254267514], [5.120365808685854, 52.85912108006267], [5.219136473891757, 52.86696051702244], [5.317943992605401, 52.874710796582036], [5.41678796626489, 52.882371862370476], [5.5156679952655105, 52.889943658620005], [5.6145836789541645, 52.89742613016841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.6145837&lt;dd&gt;Longitude: 52.897426&lt;dd&gt;Azimuth: 70.877946\u00b0&lt;dd&gt;Altitude: 39.569545\u00b0&lt;dd&gt;Slant Range: 822.03952km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.6145836789541645, 52.89742613016841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.120365808685854, 52.85912108006267], [5.219136473891757, 52.86696051702244], [5.317943992605401, 52.874710796582036], [5.41678796626489, 52.882371862370476], [5.5156679952655105, 52.889943658620005], [5.6145836789541645, 52.89742613016841], [5.713534615654225, 52.90481922246053]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.7135346&lt;dd&gt;Longitude: 52.904819&lt;dd&gt;Azimuth: 70.940881\u00b0&lt;dd&gt;Altitude: 39.215308\u00b0&lt;dd&gt;Slant Range: 827.20187km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.713534615654225, 52.90481922246053]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.219136473891757, 52.86696051702244], [5.317943992605401, 52.874710796582036], [5.41678796626489, 52.882371862370476], [5.5156679952655105, 52.889943658620005], [5.6145836789541645, 52.89742613016841], [5.713534615654225, 52.90481922246053], [5.8125204026644415, 52.91212288155046]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.8125204&lt;dd&gt;Longitude: 52.912123&lt;dd&gt;Azimuth: 71.002489\u00b0&lt;dd&gt;Altitude: 38.86507\u00b0&lt;dd&gt;Slant Range: 832.39062km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.8125204026644415, 52.91212288155046]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.317943992605401, 52.874710796582036], [5.41678796626489, 52.882371862370476], [5.5156679952655105, 52.889943658620005], [5.6145836789541645, 52.89742613016841], [5.713534615654225, 52.90481922246053], [5.8125204026644415, 52.91212288155046], [5.911540636282352, 52.91933705410342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 5.9115406&lt;dd&gt;Longitude: 52.919337&lt;dd&gt;Azimuth: 71.062812\u00b0&lt;dd&gt;Altitude: 38.518779\u00b0&lt;dd&gt;Slant Range: 837.60529km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.911540636282352, 52.91933705410342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.41678796626489, 52.882371862370476], [5.5156679952655105, 52.889943658620005], [5.6145836789541645, 52.89742613016841], [5.713534615654225, 52.90481922246053], [5.8125204026644415, 52.91212288155046], [5.911540636282352, 52.91933705410342], [6.0105949117953505, 52.92646168739748]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 6.0105949&lt;dd&gt;Longitude: 52.926462&lt;dd&gt;Azimuth: 71.121893\u00b0&lt;dd&gt;Altitude: 38.176381\u00b0&lt;dd&gt;Slant Range: 842.8454km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.0105949117953505, 52.92646168739748]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.5156679952655105, 52.889943658620005], [5.6145836789541645, 52.89742613016841], [5.713534615654225, 52.90481922246053], [5.8125204026644415, 52.91212288155046], [5.911540636282352, 52.91933705410342], [6.0105949117953505, 52.92646168739748], [6.10968282351697, 52.93349672932562]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 6.1096828&lt;dd&gt;Longitude: 52.933497&lt;dd&gt;Azimuth: 71.179772\u00b0&lt;dd&gt;Altitude: 37.837824\u00b0&lt;dd&gt;Slant Range: 848.11045km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.10968282351697, 52.93349672932562]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.6145836789541645, 52.89742613016841], [5.713534615654225, 52.90481922246053], [5.8125204026644415, 52.91212288155046], [5.911540636282352, 52.91933705410342], [6.0105949117953505, 52.92646168739748], [6.10968282351697, 52.93349672932562], [6.20880396477299, 52.94044212839745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1852&lt;dd&gt;Latitude: 6.208804&lt;dd&gt;Longitude: 52.940442&lt;dd&gt;Azimuth: 71.236488\u00b0&lt;dd&gt;Altitude: 37.503057\u00b0&lt;dd&gt;Slant Range: 853.39999km&quot;, &quot;name&quot;: &quot;STARLINK-1852&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.20880396477299, 52.94044212839745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -10.205637&lt;dd&gt;Longitude: 52.834962&lt;dd&gt;Azimuth: 289.37829\u00b0&lt;dd&gt;Altitude: 41.885772\u00b0&lt;dd&gt;Slant Range: 790.39729km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758], [-10.106986106638958, 52.84308863418362]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -10.106986&lt;dd&gt;Longitude: 52.843089&lt;dd&gt;Azimuth: 289.63745\u00b0&lt;dd&gt;Altitude: 42.246427\u00b0&lt;dd&gt;Slant Range: 785.75823km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.106986106638958, 52.84308863418362]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758], [-10.106986106638958, 52.84308863418362], [-10.008297136077484, 52.8511259146549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -10.008297&lt;dd&gt;Longitude: 52.851126&lt;dd&gt;Azimuth: 289.90263\u00b0&lt;dd&gt;Altitude: 42.610383\u00b0&lt;dd&gt;Slant Range: 781.15378km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.008297136077484, 52.8511259146549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758], [-10.106986106638958, 52.84308863418362], [-10.008297136077484, 52.8511259146549], [-9.90957043290326, 52.85907416342129]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.9095704&lt;dd&gt;Longitude: 52.859074&lt;dd&gt;Azimuth: 290.17403\u00b0&lt;dd&gt;Altitude: 42.977642\u00b0&lt;dd&gt;Slant Range: 776.58456km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.90957043290326, 52.85907416342129]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758], [-10.106986106638958, 52.84308863418362], [-10.008297136077484, 52.8511259146549], [-9.90957043290326, 52.85907416342129], [-9.810806393345514, 52.866933322789386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.8108064&lt;dd&gt;Longitude: 52.866933&lt;dd&gt;Azimuth: 290.45187\u00b0&lt;dd&gt;Altitude: 43.348205\u00b0&lt;dd&gt;Slant Range: 772.0512km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.810806393345514, 52.866933322789386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758], [-10.106986106638958, 52.84308863418362], [-10.008297136077484, 52.8511259146549], [-9.90957043290326, 52.85907416342129], [-9.810806393345514, 52.866933322789386], [-9.712005414707127, 52.87470333566482]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.7120054&lt;dd&gt;Longitude: 52.874703&lt;dd&gt;Azimuth: 290.73636\u00b0&lt;dd&gt;Altitude: 43.72207\u00b0&lt;dd&gt;Slant Range: 767.55433km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.712005414707127, 52.87470333566482]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.205636949445491, 52.83496238029758], [-10.106986106638958, 52.84308863418362], [-10.008297136077484, 52.8511259146549], [-9.90957043290326, 52.85907416342129], [-9.810806393345514, 52.866933322789386], [-9.712005414707127, 52.87470333566482], [-9.613167895353639, 52.882384145554326]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.6131679&lt;dd&gt;Longitude: 52.882384&lt;dd&gt;Azimuth: 291.02774\u00b0&lt;dd&gt;Altitude: 44.099231\u00b0&lt;dd&gt;Slant Range: 763.09461km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.613167895353639, 52.882384145554326]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.106986106638958, 52.84308863418362], [-10.008297136077484, 52.8511259146549], [-9.90957043290326, 52.85907416342129], [-9.810806393345514, 52.866933322789386], [-9.712005414707127, 52.87470333566482], [-9.613167895353639, 52.882384145554326], [-9.514294234696285, 52.889975696567525]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.5142942&lt;dd&gt;Longitude: 52.889976&lt;dd&gt;Azimuth: 291.32625\u00b0&lt;dd&gt;Altitude: 44.479681\u00b0&lt;dd&gt;Slant Range: 758.6727km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.514294234696285, 52.889975696567525]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.008297136077484, 52.8511259146549], [-9.90957043290326, 52.85907416342129], [-9.810806393345514, 52.866933322789386], [-9.712005414707127, 52.87470333566482], [-9.613167895353639, 52.882384145554326], [-9.514294234696285, 52.889975696567525], [-9.41538483319929, 52.89747793341894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.4153848&lt;dd&gt;Longitude: 52.897478&lt;dd&gt;Azimuth: 291.63214\u00b0&lt;dd&gt;Altitude: 44.863406\u00b0&lt;dd&gt;Slant Range: 754.28927km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.41538483319929, 52.89747793341894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.90957043290326, 52.85907416342129], [-9.810806393345514, 52.866933322789386], [-9.712005414707127, 52.87470333566482], [-9.613167895353639, 52.882384145554326], [-9.514294234696285, 52.889975696567525], [-9.41538483319929, 52.89747793341894], [-9.316440092345726, 52.90489080143011]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.3164401&lt;dd&gt;Longitude: 52.904891&lt;dd&gt;Azimuth: 291.94568\u00b0&lt;dd&gt;Altitude: 45.250393\u00b0&lt;dd&gt;Slant Range: 749.945km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.316440092345726, 52.90489080143011]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.810806393345514, 52.866933322789386], [-9.712005414707127, 52.87470333566482], [-9.613167895353639, 52.882384145554326], [-9.514294234696285, 52.889975696567525], [-9.41538483319929, 52.89747793341894], [-9.316440092345726, 52.90489080143011], [-9.21746041465705, 52.91221424653118]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.2174604&lt;dd&gt;Longitude: 52.912214&lt;dd&gt;Azimuth: 292.26714\u00b0&lt;dd&gt;Altitude: 45.640622\u00b0&lt;dd&gt;Slant Range: 745.64058km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.21746041465705, 52.91221424653118]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.712005414707127, 52.87470333566482], [-9.613167895353639, 52.882384145554326], [-9.514294234696285, 52.889975696567525], [-9.41538483319929, 52.89747793341894], [-9.316440092345726, 52.90489080143011], [-9.21746041465705, 52.91221424653118], [-9.118446203647233, 52.91944821526324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.1184462&lt;dd&gt;Longitude: 52.919448&lt;dd&gt;Azimuth: 292.59681\u00b0&lt;dd&gt;Altitude: 46.03407\u00b0&lt;dd&gt;Slant Range: 741.3767km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.118446203647233, 52.91944821526324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.613167895353639, 52.882384145554326], [-9.514294234696285, 52.889975696567525], [-9.41538483319929, 52.89747793341894], [-9.316440092345726, 52.90489080143011], [-9.21746041465705, 52.91221424653118], [-9.118446203647233, 52.91944821526324], [-9.019397863844892, 52.92659265477974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -9.0193979&lt;dd&gt;Longitude: 52.926593&lt;dd&gt;Azimuth: 292.93499\u00b0&lt;dd&gt;Altitude: 46.43071\u00b0&lt;dd&gt;Slant Range: 737.15408km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.019397863844892, 52.92659265477974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.514294234696285, 52.889975696567525], [-9.41538483319929, 52.89747793341894], [-9.316440092345726, 52.90489080143011], [-9.21746041465705, 52.91221424653118], [-9.118446203647233, 52.91944821526324], [-9.019397863844892, 52.92659265477974], [-8.920315800760978, 52.93364751284875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.9203158&lt;dd&gt;Longitude: 52.933648&lt;dd&gt;Azimuth: 293.28199\u00b0&lt;dd&gt;Altitude: 46.83051\u00b0&lt;dd&gt;Slant Range: 732.97343km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.920315800760978, 52.93364751284875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.41538483319929, 52.89747793341894], [-9.316440092345726, 52.90489080143011], [-9.21746041465705, 52.91221424653118], [-9.118446203647233, 52.91944821526324], [-9.019397863844892, 52.92659265477974], [-8.920315800760978, 52.93364751284875], [-8.821200420891806, 52.94061273785459]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.8212004&lt;dd&gt;Longitude: 52.940613&lt;dd&gt;Azimuth: 293.63814\u00b0&lt;dd&gt;Altitude: 47.233432\u00b0&lt;dd&gt;Slant Range: 728.83548km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.821200420891806, 52.94061273785459]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.316440092345726, 52.90489080143011], [-9.21746041465705, 52.91221424653118], [-9.118446203647233, 52.91944821526324], [-9.019397863844892, 52.92659265477974], [-8.920315800760978, 52.93364751284875], [-8.821200420891806, 52.94061273785459], [-8.722052131693832, 52.947488278799696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.7220521&lt;dd&gt;Longitude: 52.947488&lt;dd&gt;Azimuth: 294.00379\u00b0&lt;dd&gt;Altitude: 47.639436\u00b0&lt;dd&gt;Slant Range: 724.74096km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.722052131693832, 52.947488278799696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.21746041465705, 52.91221424653118], [-9.118446203647233, 52.91944821526324], [-9.019397863844892, 52.92659265477974], [-8.920315800760978, 52.93364751284875], [-8.821200420891806, 52.94061273785459], [-8.722052131693832, 52.947488278799696], [-8.622871341593253, 52.95427408530638]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.6228713&lt;dd&gt;Longitude: 52.954274&lt;dd&gt;Azimuth: 294.3793\u00b0&lt;dd&gt;Altitude: 48.048473\u00b0&lt;dd&gt;Slant Range: 720.69062km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.622871341593253, 52.95427408530638]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.118446203647233, 52.91944821526324], [-9.019397863844892, 52.92659265477974], [-8.920315800760978, 52.93364751284875], [-8.821200420891806, 52.94061273785459], [-8.722052131693832, 52.947488278799696], [-8.622871341593253, 52.95427408530638], [-8.523658459948884, 52.960970107618955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.5236585&lt;dd&gt;Longitude: 52.96097&lt;dd&gt;Azimuth: 294.76504\u00b0&lt;dd&gt;Altitude: 48.46049\u00b0&lt;dd&gt;Slant Range: 716.68522km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.523658459948884, 52.960970107618955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.019397863844892, 52.92659265477974], [-8.920315800760978, 52.93364751284875], [-8.821200420891806, 52.94061273785459], [-8.722052131693832, 52.947488278799696], [-8.622871341593253, 52.95427408530638], [-8.523658459948884, 52.960970107618955], [-8.424413897069982, 52.96757629660492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.4244139&lt;dd&gt;Longitude: 52.967576&lt;dd&gt;Azimuth: 295.1614\u00b0&lt;dd&gt;Altitude: 48.875428\u00b0&lt;dd&gt;Slant Range: 712.72551km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.424413897069982, 52.96757629660492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.920315800760978, 52.93364751284875], [-8.821200420891806, 52.94061273785459], [-8.722052131693832, 52.947488278799696], [-8.622871341593253, 52.95427408530638], [-8.523658459948884, 52.960970107618955], [-8.424413897069982, 52.96757629660492], [-8.325138064181102, 52.97409260375715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.3251381&lt;dd&gt;Longitude: 52.974093&lt;dd&gt;Azimuth: 295.5688\u00b0&lt;dd&gt;Altitude: 49.29322\u00b0&lt;dd&gt;Slant Range: 708.81227km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.325138064181102, 52.97409260375715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.821200420891806, 52.94061273785459], [-8.722052131693832, 52.947488278799696], [-8.622871341593253, 52.95427408530638], [-8.523658459948884, 52.960970107618955], [-8.424413897069982, 52.96757629660492], [-8.325138064181102, 52.97409260375715], [-8.225831373427273, 52.980518981195516]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.2258314&lt;dd&gt;Longitude: 52.980519&lt;dd&gt;Azimuth: 295.98766\u00b0&lt;dd&gt;Altitude: 49.713793\u00b0&lt;dd&gt;Slant Range: 704.94627km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.225831373427273, 52.980518981195516]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.722052131693832, 52.947488278799696], [-8.622871341593253, 52.95427408530638], [-8.523658459948884, 52.960970107618955], [-8.424413897069982, 52.96757629660492], [-8.325138064181102, 52.97409260375715], [-8.225831373427273, 52.980518981195516], [-8.126494237852192, 52.986855381668605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.1264942&lt;dd&gt;Longitude: 52.986855&lt;dd&gt;Azimuth: 296.41845\u00b0&lt;dd&gt;Altitude: 50.137066\u00b0&lt;dd&gt;Slant Range: 701.1283km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.126494237852192, 52.986855381668605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.622871341593253, 52.95427408530638], [-8.523658459948884, 52.960970107618955], [-8.424413897069982, 52.96757629660492], [-8.325138064181102, 52.97409260375715], [-8.225831373427273, 52.980518981195516], [-8.126494237852192, 52.986855381668605], [-8.027127071393501, 52.99310175855519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -8.0271271&lt;dd&gt;Longitude: 52.993102&lt;dd&gt;Azimuth: 296.86162\u00b0&lt;dd&gt;Altitude: 50.562951\u00b0&lt;dd&gt;Slant Range: 697.35915km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.027127071393501, 52.99310175855519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.523658459948884, 52.960970107618955], [-8.424413897069982, 52.96757629660492], [-8.325138064181102, 52.97409260375715], [-8.225831373427273, 52.980518981195516], [-8.126494237852192, 52.986855381668605], [-8.027127071393501, 52.99310175855519], [-7.927730288871178, 52.999258065866364]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.9277303&lt;dd&gt;Longitude: 52.999258&lt;dd&gt;Azimuth: 297.31767\u00b0&lt;dd&gt;Altitude: 50.991351\u00b0&lt;dd&gt;Slant Range: 693.63963km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.927730288871178, 52.999258065866364]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.424413897069982, 52.96757629660492], [-8.325138064181102, 52.97409260375715], [-8.225831373427273, 52.980518981195516], [-8.126494237852192, 52.986855381668605], [-8.027127071393501, 52.99310175855519], [-7.927730288871178, 52.999258065866364], [-7.828304305969978, 53.00532425824668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.8283043&lt;dd&gt;Longitude: 53.005324&lt;dd&gt;Azimuth: 297.78712\u00b0&lt;dd&gt;Altitude: 51.42216\u00b0&lt;dd&gt;Slant Range: 689.97053km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.828304305969978, 53.00532425824668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.325138064181102, 52.97409260375715], [-8.225831373427273, 52.980518981195516], [-8.126494237852192, 52.986855381668605], [-8.027127071393501, 52.99310175855519], [-7.927730288871178, 52.999258065866364], [-7.828304305969978, 53.00532425824668], [-7.728849539235038, 53.01130029097618]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.7288495&lt;dd&gt;Longitude: 53.0113&lt;dd&gt;Azimuth: 298.2705\u00b0&lt;dd&gt;Altitude: 51.855263\u00b0&lt;dd&gt;Slant Range: 686.35268km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.728849539235038, 53.01130029097618]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225831373427273, 52.980518981195516], [-8.126494237852192, 52.986855381668605], [-8.027127071393501, 52.99310175855519], [-7.927730288871178, 52.999258065866364], [-7.828304305969978, 53.00532425824668], [-7.728849539235038, 53.01130029097618], [-7.629366406062887, 53.017186119971676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.6293664&lt;dd&gt;Longitude: 53.017186&lt;dd&gt;Azimuth: 298.76839\u00b0&lt;dd&gt;Altitude: 52.290535\u00b0&lt;dd&gt;Slant Range: 682.78689km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.629366406062887, 53.017186119971676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.126494237852192, 52.986855381668605], [-8.027127071393501, 52.99310175855519], [-7.927730288871178, 52.999258065866364], [-7.828304305969978, 53.00532425824668], [-7.728849539235038, 53.01130029097618], [-7.629366406062887, 53.017186119971676], [-7.529855324678886, 53.022981701788524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.5298553&lt;dd&gt;Longitude: 53.022982&lt;dd&gt;Azimuth: 299.28138\u00b0&lt;dd&gt;Altitude: 52.727841\u00b0&lt;dd&gt;Slant Range: 679.27398km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.529855324678886, 53.022981701788524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.027127071393501, 52.99310175855519], [-7.927730288871178, 52.999258065866364], [-7.828304305969978, 53.00532425824668], [-7.728849539235038, 53.01130029097618], [-7.629366406062887, 53.017186119971676], [-7.529855324678886, 53.022981701788524], [-7.430316714132664, 53.028686993622145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.4303167&lt;dd&gt;Longitude: 53.028687&lt;dd&gt;Azimuth: 299.81008\u00b0&lt;dd&gt;Altitude: 53.167033\u00b0&lt;dd&gt;Slant Range: 675.81478km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.430316714132664, 53.028686993622145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.927730288871178, 52.999258065866364], [-7.828304305969978, 53.00532425824668], [-7.728849539235038, 53.01130029097618], [-7.629366406062887, 53.017186119971676], [-7.529855324678886, 53.022981701788524], [-7.430316714132664, 53.028686993622145], [-7.330750994291739, 53.03430195330967]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.330751&lt;dd&gt;Longitude: 53.034302&lt;dd&gt;Azimuth: 300.35514\u00b0&lt;dd&gt;Altitude: 53.607954\u00b0&lt;dd&gt;Slant Range: 672.41013km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.330750994291739, 53.03430195330967]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.828304305969978, 53.00532425824668], [-7.728849539235038, 53.01130029097618], [-7.629366406062887, 53.017186119971676], [-7.529855324678886, 53.022981701788524], [-7.430316714132664, 53.028686993622145], [-7.330750994291739, 53.03430195330967], [-7.231158585811896, 53.03982653933121]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.2311586&lt;dd&gt;Longitude: 53.039827&lt;dd&gt;Azimuth: 300.91724\u00b0&lt;dd&gt;Altitude: 54.050433\u00b0&lt;dd&gt;Slant Range: 669.06086km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.231158585811896, 53.03982653933121]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.728849539235038, 53.01130029097618], [-7.629366406062887, 53.017186119971676], [-7.529855324678886, 53.022981701788524], [-7.430316714132664, 53.028686993622145], [-7.330750994291739, 53.03430195330967], [-7.231158585811896, 53.03982653933121], [-7.131539910155917, 53.045260710811576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.1315399&lt;dd&gt;Longitude: 53.045261&lt;dd&gt;Azimuth: 301.49708\u00b0&lt;dd&gt;Altitude: 54.494286\u00b0&lt;dd&gt;Slant Range: 665.76781km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.131539910155917, 53.045260710811576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.629366406062887, 53.017186119971676], [-7.529855324678886, 53.022981701788524], [-7.430316714132664, 53.028686993622145], [-7.330750994291739, 53.03430195330967], [-7.231158585811896, 53.03982653933121], [-7.131539910155917, 53.045260710811576], [-7.031895389546889, 53.05060442752159]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -7.0318954&lt;dd&gt;Longitude: 53.050604&lt;dd&gt;Azimuth: 302.09539\u00b0&lt;dd&gt;Altitude: 54.939316\u00b0&lt;dd&gt;Slant Range: 662.53183km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.031895389546889, 53.05060442752159]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.529855324678886, 53.022981701788524], [-7.430316714132664, 53.028686993622145], [-7.330750994291739, 53.03430195330967], [-7.231158585811896, 53.03982653933121], [-7.131539910155917, 53.045260710811576], [-7.031895389546889, 53.05060442752159], [-6.932225446981156, 53.05585764987983]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.9322254&lt;dd&gt;Longitude: 53.055858&lt;dd&gt;Azimuth: 302.71296\u00b0&lt;dd&gt;Altitude: 55.38531\u00b0&lt;dd&gt;Slant Range: 659.35375km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.932225446981156, 53.05585764987983]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.430316714132664, 53.028686993622145], [-7.330750994291739, 53.03430195330967], [-7.231158585811896, 53.03982653933121], [-7.131539910155917, 53.045260710811576], [-7.031895389546889, 53.05060442752159], [-6.932225446981156, 53.05585764987983], [-6.8325305062060515, 53.061020338953604]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.8325305&lt;dd&gt;Longitude: 53.06102&lt;dd&gt;Azimuth: 303.35059\u00b0&lt;dd&gt;Altitude: 55.832041\u00b0&lt;dd&gt;Slant Range: 656.23443km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.8325305062060515, 53.061020338953604]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.330750994291739, 53.03430195330967], [-7.231158585811896, 53.03982653933121], [-7.131539910155917, 53.045260710811576], [-7.031895389546889, 53.05060442752159], [-6.932225446981156, 53.05585764987983], [-6.8325305062060515, 53.061020338953604], [-6.732810991712629, 53.06609245646082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.732811&lt;dd&gt;Longitude: 53.066092&lt;dd&gt;Azimuth: 304.0091\u00b0&lt;dd&gt;Altitude: 56.279265\u00b0&lt;dd&gt;Slant Range: 653.1747km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.732810991712629, 53.06609245646082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.231158585811896, 53.03982653933121], [-7.131539910155917, 53.045260710811576], [-7.031895389546889, 53.05060442752159], [-6.932225446981156, 53.05585764987983], [-6.8325305062060515, 53.061020338953604], [-6.732810991712629, 53.06609245646082], [-6.633067328717664, 53.07107396477104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.6330673&lt;dd&gt;Longitude: 53.071074&lt;dd&gt;Azimuth: 304.68937\u00b0&lt;dd&gt;Altitude: 56.726723\u00b0&lt;dd&gt;Slant Range: 650.17542km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.633067328717664, 53.07107396477104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.131539910155917, 53.045260710811576], [-7.031895389546889, 53.05060442752159], [-6.932225446981156, 53.05585764987983], [-6.8325305062060515, 53.061020338953604], [-6.732810991712629, 53.06609245646082], [-6.633067328717664, 53.07107396477104], [-6.53329994315842, 53.075964826907104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.5332999&lt;dd&gt;Longitude: 53.075965&lt;dd&gt;Azimuth: 305.39231\u00b0&lt;dd&gt;Altitude: 57.174135\u00b0&lt;dd&gt;Slant Range: 647.23741km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.53329994315842, 53.075964826907104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.031895389546889, 53.05060442752159], [-6.932225446981156, 53.05585764987983], [-6.8325305062060515, 53.061020338953604], [-6.732810991712629, 53.06609245646082], [-6.633067328717664, 53.07107396477104], [-6.53329994315842, 53.075964826907104], [-6.433509261676054, 53.080765006546194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.4335093&lt;dd&gt;Longitude: 53.080765&lt;dd&gt;Azimuth: 306.11885\u00b0&lt;dd&gt;Altitude: 57.621204\u00b0&lt;dd&gt;Slant Range: 644.36154km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.433509261676054, 53.080765006546194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.932225446981156, 53.05585764987983], [-6.8325305062060515, 53.061020338953604], [-6.732810991712629, 53.06609245646082], [-6.633067328717664, 53.07107396477104], [-6.53329994315842, 53.075964826907104], [-6.433509261676054, 53.080765006546194], [-6.333695711606661, 53.08547446802143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.3336957&lt;dd&gt;Longitude: 53.085474&lt;dd&gt;Azimuth: 306.86998\u00b0&lt;dd&gt;Altitude: 58.067613\u00b0&lt;dd&gt;Slant Range: 641.54863km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.333695711606661, 53.08547446802143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.8325305062060515, 53.061020338953604], [-6.732810991712629, 53.06609245646082], [-6.633067328717664, 53.07107396477104], [-6.53329994315842, 53.075964826907104], [-6.433509261676054, 53.080765006546194], [-6.333695711606661, 53.08547446802143], [-6.233859720961938, 53.090093176323]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.2338597&lt;dd&gt;Longitude: 53.090093&lt;dd&gt;Azimuth: 307.64669\u00b0&lt;dd&gt;Altitude: 58.513025\u00b0&lt;dd&gt;Slant Range: 638.79953km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.233859720961938, 53.090093176323]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.732810991712629, 53.06609245646082], [-6.633067328717664, 53.07107396477104], [-6.53329994315842, 53.075964826907104], [-6.433509261676054, 53.080765006546194], [-6.333695711606661, 53.08547446802143], [-6.233859720961938, 53.090093176323], [-6.134001718428316, 53.094621097099456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.1340017&lt;dd&gt;Longitude: 53.094621&lt;dd&gt;Azimuth: 308.45003\u00b0&lt;dd&gt;Altitude: 58.957081\u00b0&lt;dd&gt;Slant Range: 636.11505km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.134001718428316, 53.094621097099456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.633067328717664, 53.07107396477104], [-6.53329994315842, 53.075964826907104], [-6.433509261676054, 53.080765006546194], [-6.333695711606661, 53.08547446802143], [-6.233859720961938, 53.090093176323], [-6.134001718428316, 53.094621097099456], [-6.034122133347651, 53.09905819665907]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -6.0341221&lt;dd&gt;Longitude: 53.099058&lt;dd&gt;Azimuth: 309.28108\u00b0&lt;dd&gt;Altitude: 59.399399\u00b0&lt;dd&gt;Slant Range: 633.49603km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.034122133347651, 53.09905819665907]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.53329994315842, 53.075964826907104], [-6.433509261676054, 53.080765006546194], [-6.333695711606661, 53.08547446802143], [-6.233859720961938, 53.090093176323], [-6.134001718428316, 53.094621097099456], [-6.034122133347651, 53.09905819665907], [-5.934221395703582, 53.10340444197086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.9342214&lt;dd&gt;Longitude: 53.103404&lt;dd&gt;Azimuth: 310.14092\u00b0&lt;dd&gt;Altitude: 59.839573\u00b0&lt;dd&gt;Slant Range: 630.94328km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.934221395703582, 53.10340444197086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.433509261676054, 53.080765006546194], [-6.333695711606661, 53.08547446802143], [-6.233859720961938, 53.090093176323], [-6.134001718428316, 53.094621097099456], [-6.034122133347651, 53.09905819665907], [-5.934221395703582, 53.10340444197086], [-5.834299936111154, 53.10765980066605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.8342999&lt;dd&gt;Longitude: 53.10766&lt;dd&gt;Azimuth: 311.03071\u00b0&lt;dd&gt;Altitude: 60.277175\u00b0&lt;dd&gt;Slant Range: 628.45761km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.834299936111154, 53.10765980066605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.333695711606661, 53.08547446802143], [-6.233859720961938, 53.090093176323], [-6.134001718428316, 53.094621097099456], [-6.034122133347651, 53.09905819665907], [-5.934221395703582, 53.10340444197086], [-5.834299936111154, 53.10765980066605], [-5.734358185809308, 53.11182424103906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.7343582&lt;dd&gt;Longitude: 53.111824&lt;dd&gt;Azimuth: 311.95158\u00b0&lt;dd&gt;Altitude: 60.711749\u00b0&lt;dd&gt;Slant Range: 626.03983km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.734358185809308, 53.11182424103906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.233859720961938, 53.090093176323], [-6.134001718428316, 53.094621097099456], [-6.034122133347651, 53.09905819665907], [-5.934221395703582, 53.10340444197086], [-5.834299936111154, 53.10765980066605], [-5.734358185809308, 53.11182424103906], [-5.634396576637626, 53.11589773204866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.6343966&lt;dd&gt;Longitude: 53.115898&lt;dd&gt;Azimuth: 312.9047\u00b0&lt;dd&gt;Altitude: 61.142813\u00b0&lt;dd&gt;Slant Range: 623.69073km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.634396576637626, 53.11589773204866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.134001718428316, 53.094621097099456], [-6.034122133347651, 53.09905819665907], [-5.934221395703582, 53.10340444197086], [-5.834299936111154, 53.10765980066605], [-5.734358185809308, 53.11182424103906], [-5.634396576637626, 53.11589773204866], [-5.534415541032594, 53.11988024331934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.5344155&lt;dd&gt;Longitude: 53.11988&lt;dd&gt;Azimuth: 313.89127\u00b0&lt;dd&gt;Altitude: 61.56986\u00b0&lt;dd&gt;Slant Range: 621.41109km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.534415541032594, 53.11988024331934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.034122133347651, 53.09905819665907], [-5.934221395703582, 53.10340444197086], [-5.834299936111154, 53.10765980066605], [-5.734358185809308, 53.11182424103906], [-5.634396576637626, 53.11589773204866], [-5.534415541032594, 53.11988024331934], [-5.4344155120177735, 53.12377174514214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.4344155&lt;dd&gt;Longitude: 53.123772&lt;dd&gt;Azimuth: 314.91246\u00b0&lt;dd&gt;Altitude: 61.992354\u00b0&lt;dd&gt;Slant Range: 619.20167km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.4344155120177735, 53.12377174514214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.934221395703582, 53.10340444197086], [-5.834299936111154, 53.10765980066605], [-5.734358185809308, 53.11182424103906], [-5.634396576637626, 53.11589773204866], [-5.534415541032594, 53.11988024331934], [-5.4344155120177735, 53.12377174514214], [-5.334396923175082, 53.127572208475854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.3343969&lt;dd&gt;Longitude: 53.127572&lt;dd&gt;Azimuth: 315.96948\u00b0&lt;dd&gt;Altitude: 62.409729\u00b0&lt;dd&gt;Slant Range: 617.06324km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.334396923175082, 53.127572208475854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.834299936111154, 53.10765980066605], [-5.734358185809308, 53.11182424103906], [-5.634396576637626, 53.11589773204866], [-5.534415541032594, 53.11988024331934], [-5.4344155120177735, 53.12377174514214], [-5.334396923175082, 53.127572208475854], [-5.2343602086528795, 53.13128160494818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.2343602&lt;dd&gt;Longitude: 53.131282&lt;dd&gt;Azimuth: 317.06348\u00b0&lt;dd&gt;Altitude: 62.821393\u00b0&lt;dd&gt;Slant Range: 614.99654km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.2343602086528795, 53.13128160494818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.734358185809308, 53.11182424103906], [-5.634396576637626, 53.11589773204866], [-5.534415541032594, 53.11988024331934], [-5.4344155120177735, 53.12377174514214], [-5.334396923175082, 53.127572208475854], [-5.2343602086528795, 53.13128160494818], [-5.134305803136556, 53.13489990685657]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.1343058&lt;dd&gt;Longitude: 53.1349&lt;dd&gt;Azimuth: 318.19563\u00b0&lt;dd&gt;Altitude: 63.226723\u00b0&lt;dd&gt;Slant Range: 613.00229km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.134305803136556, 53.13489990685657]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.634396576637626, 53.11589773204866], [-5.534415541032594, 53.11988024331934], [-5.4344155120177735, 53.12377174514214], [-5.334396923175082, 53.127572208475854], [-5.2343602086528795, 53.13128160494818], [-5.134305803136556, 53.13489990685657], [-5.0342341418483025, 53.138427087169454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -5.0342341&lt;dd&gt;Longitude: 53.138427&lt;dd&gt;Azimuth: 319.36704\u00b0&lt;dd&gt;Altitude: 63.625067\u00b0&lt;dd&gt;Slant Range: 611.08121km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.0342341418483025, 53.138427087169454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.534415541032594, 53.11988024331934], [-5.4344155120177735, 53.12377174514214], [-5.334396923175082, 53.127572208475854], [-5.2343602086528795, 53.13128160494818], [-5.134305803136556, 53.13489990685657], [-5.0342341418483025, 53.138427087169454], [-4.93414566052083, 53.14186311952712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.9341457&lt;dd&gt;Longitude: 53.141863&lt;dd&gt;Azimuth: 320.57877\u00b0&lt;dd&gt;Altitude: 64.015746\u00b0&lt;dd&gt;Slant Range: 609.234km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.93414566052083, 53.14186311952712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.4344155120177735, 53.12377174514214], [-5.334396923175082, 53.127572208475854], [-5.2343602086528795, 53.13128160494818], [-5.134305803136556, 53.13489990685657], [-5.0342341418483025, 53.138427087169454], [-4.93414566052083, 53.14186311952712], [-4.834040795406117, 53.145207978242595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.8340408&lt;dd&gt;Longitude: 53.145208&lt;dd&gt;Azimuth: 321.83182\u00b0&lt;dd&gt;Altitude: 64.398049\u00b0&lt;dd&gt;Slant Range: 607.46132km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.834040795406117, 53.145207978242595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.334396923175082, 53.127572208475854], [-5.2343602086528795, 53.13128160494818], [-5.134305803136556, 53.13489990685657], [-5.0342341418483025, 53.138427087169454], [-4.93414566052083, 53.14186311952712], [-4.834040795406117, 53.145207978242595], [-4.7339199832310115, 53.14846163830287]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.73392&lt;dd&gt;Longitude: 53.148462&lt;dd&gt;Azimuth: 323.1271\u00b0&lt;dd&gt;Altitude: 64.771241\u00b0&lt;dd&gt;Slant Range: 605.76383km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.7339199832310115, 53.14846163830287]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.2343602086528795, 53.13128160494818], [-5.134305803136556, 53.13489990685657], [-5.0342341418483025, 53.138427087169454], [-4.93414566052083, 53.14186311952712], [-4.834040795406117, 53.145207978242595], [-4.7339199832310115, 53.14846163830287], [-4.6337836612167225, 53.151624075369575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.6337837&lt;dd&gt;Longitude: 53.151624&lt;dd&gt;Azimuth: 324.46541\u00b0&lt;dd&gt;Altitude: 65.134559\u00b0&lt;dd&gt;Slant Range: 604.14217km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.6337836612167225, 53.151624075369575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.134305803136556, 53.13489990685657], [-5.0342341418483025, 53.138427087169454], [-4.93414566052083, 53.14186311952712], [-4.834040795406117, 53.145207978242595], [-4.7339199832310115, 53.14846163830287], [-4.6337836612167225, 53.151624075369575], [-4.533632267042102, 53.15469526577987]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.5336323&lt;dd&gt;Longitude: 53.154695&lt;dd&gt;Azimuth: 325.84741\u00b0&lt;dd&gt;Altitude: 65.487216\u00b0&lt;dd&gt;Slant Range: 602.59696km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.533632267042102, 53.15469526577987]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.0342341418483025, 53.138427087169454], [-4.93414566052083, 53.14186311952712], [-4.834040795406117, 53.145207978242595], [-4.7339199832310115, 53.14846163830287], [-4.6337836612167225, 53.151624075369575], [-4.533632267042102, 53.15469526577987], [-4.433466238849728, 53.15767518654749]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.4334662&lt;dd&gt;Longitude: 53.157675&lt;dd&gt;Azimuth: 327.27362\u00b0&lt;dd&gt;Altitude: 65.828404\u00b0&lt;dd&gt;Slant Range: 601.12878km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.433466238849728, 53.15767518654749]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.93414566052083, 53.14186311952712], [-4.834040795406117, 53.145207978242595], [-4.7339199832310115, 53.14846163830287], [-4.6337836612167225, 53.151624075369575], [-4.533632267042102, 53.15469526577987], [-4.433466238849728, 53.15767518654749], [-4.333286015210431, 53.1605638153635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.333286&lt;dd&gt;Longitude: 53.160564&lt;dd&gt;Azimuth: 328.74435\u00b0&lt;dd&gt;Altitude: 66.157295\u00b0&lt;dd&gt;Slant Range: 599.7382km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.333286015210431, 53.1605638153635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.834040795406117, 53.145207978242595], [-4.7339199832310115, 53.14846163830287], [-4.6337836612167225, 53.151624075369575], [-4.533632267042102, 53.15469526577987], [-4.433466238849728, 53.15767518654749], [-4.333286015210431, 53.1605638153635], [-4.233092035135642, 53.16336113059703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.233092&lt;dd&gt;Longitude: 53.163361&lt;dd&gt;Azimuth: 330.25971\u00b0&lt;dd&gt;Altitude: 66.473046\u00b0&lt;dd&gt;Slant Range: 598.42577km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.233092035135642, 53.16336113059703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.7339199832310115, 53.14846163830287], [-4.6337836612167225, 53.151624075369575], [-4.533632267042102, 53.15469526577987], [-4.433466238849728, 53.15767518654749], [-4.333286015210431, 53.1605638153635], [-4.233092035135642, 53.16336113059703], [-4.1328847380425, 53.16606711129631]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.1328847&lt;dd&gt;Longitude: 53.166067&lt;dd&gt;Azimuth: 331.81958\u00b0&lt;dd&gt;Altitude: 66.774805\u00b0&lt;dd&gt;Slant Range: 597.19199km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.1328847380425, 53.16606711129631]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.6337836612167225, 53.151624075369575], [-4.533632267042102, 53.15469526577987], [-4.433466238849728, 53.15767518654749], [-4.333286015210431, 53.1605638153635], [-4.233092035135642, 53.16336113059703], [-4.1328847380425, 53.16606711129631], [-4.032664563753905, 53.16868173718915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -4.0326646&lt;dd&gt;Longitude: 53.168682&lt;dd&gt;Azimuth: 333.42355\u00b0&lt;dd&gt;Altitude: 67.061713\u00b0&lt;dd&gt;Slant Range: 596.03737km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.032664563753905, 53.16868173718915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.533632267042102, 53.15469526577987], [-4.433466238849728, 53.15767518654749], [-4.333286015210431, 53.1605638153635], [-4.233092035135642, 53.16336113059703], [-4.1328847380425, 53.16606711129631], [-4.032664563753905, 53.16868173718915], [-3.9324319524817835, 53.171204988683954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.932432&lt;dd&gt;Longitude: 53.171205&lt;dd&gt;Azimuth: 335.07093\u00b0&lt;dd&gt;Altitude: 67.332913\u00b0&lt;dd&gt;Slant Range: 594.96236km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9324319524817835, 53.171204988683954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.433466238849728, 53.15767518654749], [-4.333286015210431, 53.1605638153635], [-4.233092035135642, 53.16336113059703], [-4.1328847380425, 53.16606711129631], [-4.032664563753905, 53.16868173718915], [-3.9324319524817835, 53.171204988683954], [-3.832187344816006, 53.17363684687023]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.8321873&lt;dd&gt;Longitude: 53.173637&lt;dd&gt;Azimuth: 336.76069\u00b0&lt;dd&gt;Altitude: 67.587554\u00b0&lt;dd&gt;Slant Range: 593.9674km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.832187344816006, 53.17363684687023]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.333286015210431, 53.1605638153635], [-4.233092035135642, 53.16336113059703], [-4.1328847380425, 53.16606711129631], [-4.032664563753905, 53.16868173718915], [-3.9324319524817835, 53.171204988683954], [-3.832187344816006, 53.17363684687023], [-3.7319311817009657, 53.17597729351948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.7319312&lt;dd&gt;Longitude: 53.175977&lt;dd&gt;Azimuth: 338.49147\u00b0&lt;dd&gt;Altitude: 67.824801\u00b0&lt;dd&gt;Slant Range: 593.05289km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7319311817009657, 53.17597729351948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.233092035135642, 53.16336113059703], [-4.1328847380425, 53.16606711129631], [-4.032664563753905, 53.16868173718915], [-3.9324319524817835, 53.171204988683954], [-3.832187344816006, 53.17363684687023], [-3.7319311817009657, 53.17597729351948], [-3.631663904438904, 53.1782263110857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.6316639&lt;dd&gt;Longitude: 53.178226&lt;dd&gt;Azimuth: 340.26153\u00b0&lt;dd&gt;Altitude: 68.04384\u00b0&lt;dd&gt;Slant Range: 592.2192km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.631663904438904, 53.1782263110857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.1328847380425, 53.16606711129631], [-4.032664563753905, 53.16868173718915], [-3.9324319524817835, 53.171204988683954], [-3.832187344816006, 53.17363684687023], [-3.7319311817009657, 53.17597729351948], [-3.631663904438904, 53.1782263110857], [-3.53138595466223, 53.18038388270618]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.531386&lt;dd&gt;Longitude: 53.180384&lt;dd&gt;Azimuth: 342.06875\u00b0&lt;dd&gt;Altitude: 68.243891\u00b0&lt;dd&gt;Slant Range: 591.46667km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.53138595466223, 53.18038388270618]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.032664563753905, 53.16868173718915], [-3.9324319524817835, 53.171204988683954], [-3.832187344816006, 53.17363684687023], [-3.7319311817009657, 53.17597729351948], [-3.631663904438904, 53.1782263110857], [-3.53138595466223, 53.18038388270618], [-3.431097774333138, 53.182449992202045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.4310978&lt;dd&gt;Longitude: 53.18245&lt;dd&gt;Azimuth: 343.91066\u00b0&lt;dd&gt;Altitude: 68.424214\u00b0&lt;dd&gt;Slant Range: 590.79563km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.431097774333138, 53.182449992202045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9324319524817835, 53.171204988683954], [-3.832187344816006, 53.17363684687023], [-3.7319311817009657, 53.17597729351948], [-3.631663904438904, 53.1782263110857], [-3.53138595466223, 53.18038388270618], [-3.431097774333138, 53.182449992202045], [-3.330799805713252, 53.18442462407883]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.3307998&lt;dd&gt;Longitude: 53.184425&lt;dd&gt;Azimuth: 345.78436\u00b0&lt;dd&gt;Altitude: 68.584118\u00b0&lt;dd&gt;Slant Range: 590.20634km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.330799805713252, 53.18442462407883]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.832187344816006, 53.17363684687023], [-3.7319311817009657, 53.17597729351948], [-3.631663904438904, 53.1782263110857], [-3.53138595466223, 53.18038388270618], [-3.431097774333138, 53.182449992202045], [-3.330799805713252, 53.18442462407883], [-3.230492491372507, 53.18630776352714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.2304925&lt;dd&gt;Longitude: 53.186308&lt;dd&gt;Azimuth: 347.68661\u00b0&lt;dd&gt;Altitude: 68.722971\u00b0&lt;dd&gt;Slant Range: 589.69905km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.230492491372507, 53.18630776352714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7319311817009657, 53.17597729351948], [-3.631663904438904, 53.1782263110857], [-3.53138595466223, 53.18038388270618], [-3.431097774333138, 53.182449992202045], [-3.330799805713252, 53.18442462407883], [-3.230492491372507, 53.18630776352714], [-3.130176274154188, 53.18809939642319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.1301763&lt;dd&gt;Longitude: 53.188099&lt;dd&gt;Azimuth: 349.61382\u00b0&lt;dd&gt;Altitude: 68.840211\u00b0&lt;dd&gt;Slant Range: 589.27397km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.130176274154188, 53.18809939642319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.631663904438904, 53.1782263110857], [-3.53138595466223, 53.18038388270618], [-3.431097774333138, 53.182449992202045], [-3.330799805713252, 53.18442462407883], [-3.230492491372507, 53.18630776352714], [-3.130176274154188, 53.18809939642319], [-3.0298515971737063, 53.18979950932923]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -3.0298516&lt;dd&gt;Longitude: 53.1898&lt;dd&gt;Azimuth: 351.56207\u00b0&lt;dd&gt;Altitude: 68.935349\u00b0&lt;dd&gt;Slant Range: 588.93129km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0298515971737063, 53.18979950932923]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.53138595466223, 53.18038388270618], [-3.431097774333138, 53.182449992202045], [-3.330799805713252, 53.18442462407883], [-3.230492491372507, 53.18630776352714], [-3.130176274154188, 53.18809939642319], [-3.0298515971737063, 53.18979950932923], [-2.929518903804991, 53.191408089494125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.9295189&lt;dd&gt;Longitude: 53.191408&lt;dd&gt;Azimuth: 353.52717\u00b0&lt;dd&gt;Altitude: 69.007983\u00b0&lt;dd&gt;Slant Range: 588.67114km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.929518903804991, 53.191408089494125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.431097774333138, 53.182449992202045], [-3.330799805713252, 53.18442462407883], [-3.230492491372507, 53.18630776352714], [-3.130176274154188, 53.18809939642319], [-3.0298515971737063, 53.18979950932923], [-2.929518903804991, 53.191408089494125], [-2.829178637665778, 53.19292512485383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.8291786&lt;dd&gt;Longitude: 53.192925&lt;dd&gt;Azimuth: 355.50469\u00b0&lt;dd&gt;Altitude: 69.057801\u00b0&lt;dd&gt;Slant Range: 588.49364km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.829178637665778, 53.19292512485383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.330799805713252, 53.18442462407883], [-3.230492491372507, 53.18630776352714], [-3.130176274154188, 53.18809939642319], [-3.0298515971737063, 53.18979950932923], [-2.929518903804991, 53.191408089494125], [-2.829178637665778, 53.19292512485383], [-2.728831242599446, 53.19435060403187]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.7288312&lt;dd&gt;Longitude: 53.194351&lt;dd&gt;Azimuth: 357.49004\u00b0&lt;dd&gt;Altitude: 69.084586\u00b0&lt;dd&gt;Slant Range: 588.39886km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.728831242599446, 53.19435060403187]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.230492491372507, 53.18630776352714], [-3.130176274154188, 53.18809939642319], [-3.0298515971737063, 53.18979950932923], [-2.929518903804991, 53.191408089494125], [-2.829178637665778, 53.19292512485383], [-2.728831242599446, 53.19435060403187], [-2.6284771626669476, 53.19568451633962]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.6284772&lt;dd&gt;Longitude: 53.195685&lt;dd&gt;Azimuth: 359.4785\u00b0&lt;dd&gt;Altitude: 69.08822\u00b0&lt;dd&gt;Slant Range: 588.38685km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6284771626669476, 53.19568451633962]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.130176274154188, 53.18809939642319], [-3.0298515971737063, 53.18979950932923], [-2.929518903804991, 53.191408089494125], [-2.829178637665778, 53.19292512485383], [-2.728831242599446, 53.19435060403187], [-2.6284771626669476, 53.19568451633962], [-2.5281168421365066, 53.196926851776844]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.5281168&lt;dd&gt;Longitude: 53.196927&lt;dd&gt;Azimuth: 1.465322\u00b0&lt;dd&gt;Altitude: 69.068689\u00b0&lt;dd&gt;Slant Range: 588.45759km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5281168421365066, 53.196926851776844]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0298515971737063, 53.18979950932923], [-2.929518903804991, 53.191408089494125], [-2.829178637665778, 53.19292512485383], [-2.728831242599446, 53.19435060403187], [-2.6284771626669476, 53.19568451633962], [-2.5281168421365066, 53.196926851776844], [-2.42775072545858, 53.19807760103207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.4277507&lt;dd&gt;Longitude: 53.198078&lt;dd&gt;Azimuth: 3.4457752\u00b0&lt;dd&gt;Altitude: 69.026077\u00b0&lt;dd&gt;Slant Range: 588.61108km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.42775072545858, 53.19807760103207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.929518903804991, 53.191408089494125], [-2.829178637665778, 53.19292512485383], [-2.728831242599446, 53.19435060403187], [-2.6284771626669476, 53.19568451633962], [-2.5281168421365066, 53.196926851776844], [-2.42775072545858, 53.19807760103207], [-2.3273792572639493, 53.1991367554828]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-1876&lt;dd&gt;Latitude: -2.3273793&lt;dd&gt;Longitude: 53.199137&lt;dd&gt;Azimuth: 5.4152196\u00b0&lt;dd&gt;Altitude: 68.960572\u00b0&lt;dd&gt;Slant Range: 588.84724km&quot;, &quot;name&quot;: &quot;STARLINK-1876&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3273792572639493, 53.1991367554828]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -11.374061&lt;dd&gt;Longitude: 50.530535&lt;dd&gt;Azimuth: 263.909\u00b0&lt;dd&gt;Altitude: 37.491585\u00b0&lt;dd&gt;Slant Range: 853.11363km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014], [-11.285389731034766, 50.509501351748774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -11.28539&lt;dd&gt;Longitude: 50.509501&lt;dd&gt;Azimuth: 263.56725\u00b0&lt;dd&gt;Altitude: 37.771728\u00b0&lt;dd&gt;Slant Range: 848.67784km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.285389731034766, 50.509501351748774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014], [-11.285389731034766, 50.509501351748774], [-11.196801258570813, 50.48839422581428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -11.196801&lt;dd&gt;Longitude: 50.488394&lt;dd&gt;Azimuth: 263.21923\u00b0&lt;dd&gt;Altitude: 38.053394\u00b0&lt;dd&gt;Slant Range: 844.27673km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.196801258570813, 50.48839422581428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014], [-11.285389731034766, 50.509501351748774], [-11.196801258570813, 50.48839422581428], [-11.108295465333365, 50.46721327819855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -11.108295&lt;dd&gt;Longitude: 50.467213&lt;dd&gt;Azimuth: 262.8648\u00b0&lt;dd&gt;Altitude: 38.336548\u00b0&lt;dd&gt;Slant Range: 839.91084km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.108295465333365, 50.46721327819855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014], [-11.285389731034766, 50.509501351748774], [-11.196801258570813, 50.48839422581428], [-11.108295465333365, 50.46721327819855], [-11.019872502957579, 50.44595862926599]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -11.019873&lt;dd&gt;Longitude: 50.445959&lt;dd&gt;Azimuth: 262.5038\u00b0&lt;dd&gt;Altitude: 38.621155\u00b0&lt;dd&gt;Slant Range: 835.58075km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.019872502957579, 50.44595862926599]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014], [-11.285389731034766, 50.509501351748774], [-11.196801258570813, 50.48839422581428], [-11.108295465333365, 50.46721327819855], [-11.019872502957579, 50.44595862926599], [-10.93153252148004, 50.42463039954466]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.931533&lt;dd&gt;Longitude: 50.42463&lt;dd&gt;Azimuth: 262.13608\u00b0&lt;dd&gt;Altitude: 38.907176\u00b0&lt;dd&gt;Slant Range: 831.287km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.93153252148004, 50.42463039954466]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.374060729473017, 50.5305345358014], [-11.285389731034766, 50.509501351748774], [-11.196801258570813, 50.48839422581428], [-11.108295465333365, 50.46721327819855], [-11.019872502957579, 50.44595862926599], [-10.93153252148004, 50.42463039954466], [-10.843275669332222, 50.40322870972077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.843276&lt;dd&gt;Longitude: 50.403229&lt;dd&gt;Azimuth: 261.76149\u00b0&lt;dd&gt;Altitude: 39.19457\u00b0&lt;dd&gt;Slant Range: 827.03018km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.843275669332222, 50.40322870972077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.285389731034766, 50.509501351748774], [-11.196801258570813, 50.48839422581428], [-11.108295465333365, 50.46721327819855], [-11.019872502957579, 50.44595862926599], [-10.93153252148004, 50.42463039954466], [-10.843275669332222, 50.40322870972077], [-10.755102093352653, 50.38175368063853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.755102&lt;dd&gt;Longitude: 50.381754&lt;dd&gt;Azimuth: 261.37986\u00b0&lt;dd&gt;Altitude: 39.483292\u00b0&lt;dd&gt;Slant Range: 822.81085km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.755102093352653, 50.38175368063853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.196801258570813, 50.48839422581428], [-11.108295465333365, 50.46721327819855], [-11.019872502957579, 50.44595862926599], [-10.93153252148004, 50.42463039954466], [-10.843275669332222, 50.40322870972077], [-10.755102093352653, 50.38175368063853], [-10.667011938774618, 50.36020543329602]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.667012&lt;dd&gt;Longitude: 50.360205&lt;dd&gt;Azimuth: 260.99104\u00b0&lt;dd&gt;Altitude: 39.773294\u00b0&lt;dd&gt;Slant Range: 818.62961km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.667011938774618, 50.36020543329602]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.108295465333365, 50.46721327819855], [-11.019872502957579, 50.44595862926599], [-10.93153252148004, 50.42463039954466], [-10.843275669332222, 50.40322870972077], [-10.755102093352653, 50.38175368063853], [-10.667011938774618, 50.36020543329602], [-10.579005349247105, 50.33858408884288]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.579005&lt;dd&gt;Longitude: 50.338584&lt;dd&gt;Azimuth: 260.59484\u00b0&lt;dd&gt;Altitude: 40.064525\u00b0&lt;dd&gt;Slant Range: 814.48705km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.579005349247105, 50.33858408884288]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.019872502957579, 50.44595862926599], [-10.93153252148004, 50.42463039954466], [-10.843275669332222, 50.40322870972077], [-10.755102093352653, 50.38175368063853], [-10.667011938774618, 50.36020543329602], [-10.579005349247105, 50.33858408884288], [-10.491082466823407, 50.31688976857792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.491082&lt;dd&gt;Longitude: 50.31689&lt;dd&gt;Azimuth: 260.19111\u00b0&lt;dd&gt;Altitude: 40.356931\u00b0&lt;dd&gt;Slant Range: 810.38375km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.491082466823407, 50.31688976857792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.93153252148004, 50.42463039954466], [-10.843275669332222, 50.40322870972077], [-10.755102093352653, 50.38175368063853], [-10.667011938774618, 50.36020543329602], [-10.579005349247105, 50.33858408884288], [-10.491082466823407, 50.31688976857792], [-10.403243431976565, 50.295122593946644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.403243&lt;dd&gt;Longitude: 50.295123&lt;dd&gt;Azimuth: 259.77967\u00b0&lt;dd&gt;Altitude: 40.650453\u00b0&lt;dd&gt;Slant Range: 806.32034km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.403243431976565, 50.295122593946644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.843275669332222, 50.40322870972077], [-10.755102093352653, 50.38175368063853], [-10.667011938774618, 50.36020543329602], [-10.579005349247105, 50.33858408884288], [-10.491082466823407, 50.31688976857792], [-10.403243431976565, 50.295122593946644], [-10.315488383587557, 50.273282686537556]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.315488&lt;dd&gt;Longitude: 50.273283&lt;dd&gt;Azimuth: 259.36035\u00b0&lt;dd&gt;Altitude: 40.94503\u00b0&lt;dd&gt;Slant Range: 802.29741km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.315488383587557, 50.273282686537556]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.755102093352653, 50.38175368063853], [-10.667011938774618, 50.36020543329602], [-10.579005349247105, 50.33858408884288], [-10.491082466823407, 50.31688976857792], [-10.403243431976565, 50.295122593946644], [-10.315488383587557, 50.273282686537556], [-10.227817458966172, 50.25137016808139]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.227817&lt;dd&gt;Longitude: 50.25137&lt;dd&gt;Azimuth: 258.93295\u00b0&lt;dd&gt;Altitude: 41.240595\u00b0&lt;dd&gt;Slant Range: 798.31558km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.227817458966172, 50.25137016808139]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.667011938774618, 50.36020543329602], [-10.579005349247105, 50.33858408884288], [-10.491082466823407, 50.31688976857792], [-10.403243431976565, 50.295122593946644], [-10.315488383587557, 50.273282686537556], [-10.227817458966172, 50.25137016808139], [-10.140230793839578, 50.229385160446796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.140231&lt;dd&gt;Longitude: 50.229385&lt;dd&gt;Azimuth: 258.4973\u00b0&lt;dd&gt;Altitude: 41.53708\u00b0&lt;dd&gt;Slant Range: 794.37549km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.140230793839578, 50.229385160446796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.579005349247105, 50.33858408884288], [-10.491082466823407, 50.31688976857792], [-10.403243431976565, 50.295122593946644], [-10.315488383587557, 50.273282686537556], [-10.227817458966172, 50.25137016808139], [-10.140230793839578, 50.229385160446796], [-10.052728522358866, 50.207327785638746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -10.052729&lt;dd&gt;Longitude: 50.207328&lt;dd&gt;Azimuth: 258.05321\u00b0&lt;dd&gt;Altitude: 41.83441\u00b0&lt;dd&gt;Slant Range: 790.47774km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.052728522358866, 50.207327785638746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.491082466823407, 50.31688976857792], [-10.403243431976565, 50.295122593946644], [-10.315488383587557, 50.273282686537556], [-10.227817458966172, 50.25137016808139], [-10.140230793839578, 50.229385160446796], [-10.052728522358866, 50.207327785638746], [-9.965310777109424, 50.18519816579533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.9653108&lt;dd&gt;Longitude: 50.185198&lt;dd&gt;Azimuth: 257.60049\u00b0&lt;dd&gt;Altitude: 42.132507\u00b0&lt;dd&gt;Slant Range: 786.62299km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.965310777109424, 50.18519816579533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.403243431976565, 50.295122593946644], [-10.315488383587557, 50.273282686537556], [-10.227817458966172, 50.25137016808139], [-10.140230793839578, 50.229385160446796], [-10.052728522358866, 50.207327785638746], [-9.965310777109424, 50.18519816579533], [-9.87797768911128, 50.16299642318632]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.8779777&lt;dd&gt;Longitude: 50.162996&lt;dd&gt;Azimuth: 257.13895\u00b0&lt;dd&gt;Altitude: 42.431289\u00b0&lt;dd&gt;Slant Range: 782.81187km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.87797768911128, 50.16299642318632]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.315488383587557, 50.273282686537556], [-10.227817458966172, 50.25137016808139], [-10.140230793839578, 50.229385160446796], [-10.052728522358866, 50.207327785638746], [-9.965310777109424, 50.18519816579533], [-9.87797768911128, 50.16299642318632], [-9.790729387813947, 50.140722680208704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.7907294&lt;dd&gt;Longitude: 50.140723&lt;dd&gt;Azimuth: 256.66838\u00b0&lt;dd&gt;Altitude: 42.730668\u00b0&lt;dd&gt;Slant Range: 779.04502km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.790729387813947, 50.140722680208704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.227817458966172, 50.25137016808139], [-10.140230793839578, 50.229385160446796], [-10.052728522358866, 50.207327785638746], [-9.965310777109424, 50.18519816579533], [-9.87797768911128, 50.16299642318632], [-9.790729387813947, 50.140722680208704], [-9.70356600111056, 50.11837705938652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.703566&lt;dd&gt;Longitude: 50.118377&lt;dd&gt;Azimuth: 256.18859\u00b0&lt;dd&gt;Altitude: 43.030554\u00b0&lt;dd&gt;Slant Range: 775.32309km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.70356600111056, 50.11837705938652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.140230793839578, 50.229385160446796], [-10.052728522358866, 50.207327785638746], [-9.965310777109424, 50.18519816579533], [-9.87797768911128, 50.16299642318632], [-9.790729387813947, 50.140722680208704], [-9.70356600111056, 50.11837705938652], [-9.61648765534094, 50.09595968336577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.6164877&lt;dd&gt;Longitude: 50.09596&lt;dd&gt;Azimuth: 255.69938\u00b0&lt;dd&gt;Altitude: 43.330848\u00b0&lt;dd&gt;Slant Range: 771.64674km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.61648765534094, 50.09595968336577]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.052728522358866, 50.207327785638746], [-9.965310777109424, 50.18519816579533], [-9.87797768911128, 50.16299642318632], [-9.790729387813947, 50.140722680208704], [-9.70356600111056, 50.11837705938652], [-9.61648765534094, 50.09595968336577], [-9.529494475285453, 50.07347067491427]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.5294945&lt;dd&gt;Longitude: 50.073471&lt;dd&gt;Azimuth: 255.20054\u00b0&lt;dd&gt;Altitude: 43.63145\u00b0&lt;dd&gt;Slant Range: 768.01662km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.529494475285453, 50.07347067491427]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.965310777109424, 50.18519816579533], [-9.87797768911128, 50.16299642318632], [-9.790729387813947, 50.140722680208704], [-9.70356600111056, 50.11837705938652], [-9.61648765534094, 50.09595968336577], [-9.529494475285453, 50.07347067491427], [-9.442586584179011, 50.050910156917574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2401&lt;dd&gt;Latitude: -9.4425866&lt;dd&gt;Longitude: 50.05091&lt;dd&gt;Azimuth: 254.69187\u00b0&lt;dd&gt;Altitude: 43.932253\u00b0&lt;dd&gt;Slant Range: 764.4334km&quot;, &quot;name&quot;: &quot;STARLINK-2401&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.442586584179011, 50.050910156917574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2429&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.057753648706996, 49.15428206039529]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2429&lt;dd&gt;Latitude: -11.057754&lt;dd&gt;Longitude: 49.154282&lt;dd&gt;Azimuth: 250.23872\u00b0&lt;dd&gt;Altitude: 36.01542\u00b0&lt;dd&gt;Slant Range: 877.07998km&quot;, &quot;name&quot;: &quot;STARLINK-2429&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.057753648706996, 49.15428206039529]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2429&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.057753648706996, 49.15428206039529], [-10.97420787266474, 49.12906338081041]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2429&lt;dd&gt;Latitude: -10.974208&lt;dd&gt;Longitude: 49.129063&lt;dd&gt;Azimuth: 249.77851\u00b0&lt;dd&gt;Altitude: 36.215169\u00b0&lt;dd&gt;Slant Range: 873.6787km&quot;, &quot;name&quot;: &quot;STARLINK-2429&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.97420787266474, 49.12906338081041]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2429&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.057753648706996, 49.15428206039529], [-10.97420787266474, 49.12906338081041], [-10.890751058169421, 49.10377811442125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2429&lt;dd&gt;Latitude: -10.890751&lt;dd&gt;Longitude: 49.103778&lt;dd&gt;Azimuth: 249.31231\u00b0&lt;dd&gt;Altitude: 36.414274\u00b0&lt;dd&gt;Slant Range: 870.3205km&quot;, &quot;name&quot;: &quot;STARLINK-2429&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.890751058169421, 49.10377811442125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.8973086&lt;dd&gt;Longitude: 50.041812&lt;dd&gt;Azimuth: 210.60695\u00b0&lt;dd&gt;Altitude: 70.183068\u00b0&lt;dd&gt;Slant Range: 583.8853km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176], [-3.8105161957963425, 50.019154977597864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.8105162&lt;dd&gt;Longitude: 50.019155&lt;dd&gt;Azimuth: 208.50603\u00b0&lt;dd&gt;Altitude: 70.260188\u00b0&lt;dd&gt;Slant Range: 583.62334km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8105161957963425, 50.019154977597864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176], [-3.8105161957963425, 50.019154977597864], [-3.7238093656929716, 49.99642693608318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.7238094&lt;dd&gt;Longitude: 49.996427&lt;dd&gt;Azimuth: 206.39024\u00b0&lt;dd&gt;Altitude: 70.312371\u00b0&lt;dd&gt;Slant Range: 583.44532km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7238093656929716, 49.99642693608318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176], [-3.8105161957963425, 50.019154977597864], [-3.7238093656929716, 49.99642693608318], [-3.63718822329087, 49.97362779750406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.6371882&lt;dd&gt;Longitude: 49.973628&lt;dd&gt;Azimuth: 204.26527\u00b0&lt;dd&gt;Altitude: 70.33936\u00b0&lt;dd&gt;Slant Range: 583.35131km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.63718822329087, 49.97362779750406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176], [-3.8105161957963425, 50.019154977597864], [-3.7238093656929716, 49.99642693608318], [-3.63718822329087, 49.97362779750406], [-3.5506528851264, 49.95075768523055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.5506529&lt;dd&gt;Longitude: 49.950758&lt;dd&gt;Azimuth: 202.13693\u00b0&lt;dd&gt;Altitude: 70.34102\u00b0&lt;dd&gt;Slant Range: 583.34135km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.5506528851264, 49.95075768523055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176], [-3.8105161957963425, 50.019154977597864], [-3.7238093656929716, 49.99642693608318], [-3.63718822329087, 49.97362779750406], [-3.5506528851264, 49.95075768523055], [-3.464203466201346, 49.927816722737596]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.4642035&lt;dd&gt;Longitude: 49.927817&lt;dd&gt;Azimuth: 200.01112\u00b0&lt;dd&gt;Altitude: 70.31734\u00b0&lt;dd&gt;Slant Range: 583.41543km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.464203466201346, 49.927816722737596]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8973085955356623, 50.041811798785176], [-3.8105161957963425, 50.019154977597864], [-3.7238093656929716, 49.99642693608318], [-3.63718822329087, 49.97362779750406], [-3.5506528851264, 49.95075768523055], [-3.464203466201346, 49.927816722737596], [-3.3778400799994506, 49.904805033602656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.3778401&lt;dd&gt;Longitude: 49.904805&lt;dd&gt;Azimuth: 197.89368\u00b0&lt;dd&gt;Altitude: 70.268439\u00b0&lt;dd&gt;Slant Range: 583.57354km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3778400799994506, 49.904805033602656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8105161957963425, 50.019154977597864], [-3.7238093656929716, 49.99642693608318], [-3.63718822329087, 49.97362779750406], [-3.5506528851264, 49.95075768523055], [-3.464203466201346, 49.927816722737596], [-3.3778400799994506, 49.904805033602656], [-3.291562838472473, 49.88172274150314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.2915628&lt;dd&gt;Longitude: 49.881723&lt;dd&gt;Azimuth: 195.79031\u00b0&lt;dd&gt;Altitude: 70.194555\u00b0&lt;dd&gt;Slant Range: 583.81561km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.291562838472473, 49.88172274150314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7238093656929716, 49.99642693608318], [-3.63718822329087, 49.97362779750406], [-3.5506528851264, 49.95075768523055], [-3.464203466201346, 49.927816722737596], [-3.3778400799994506, 49.904805033602656], [-3.291562838472473, 49.88172274150314], [-3.2053718520678975, 49.85856997021367]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.2053719&lt;dd&gt;Longitude: 49.85857&lt;dd&gt;Azimuth: 193.70649\u00b0&lt;dd&gt;Altitude: 70.096046\u00b0&lt;dd&gt;Slant Range: 584.14152km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2053718520678975, 49.85856997021367]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.63718822329087, 49.97362779750406], [-3.5506528851264, 49.95075768523055], [-3.464203466201346, 49.927816722737596], [-3.3778400799994506, 49.904805033602656], [-3.291562838472473, 49.88172274150314], [-3.2053718520678975, 49.85856997021367], [-3.119267229707126, 49.83534684360481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.1192672&lt;dd&gt;Longitude: 49.835347&lt;dd&gt;Azimuth: 191.64741\u00b0&lt;dd&gt;Altitude: 69.973381\u00b0&lt;dd&gt;Slant Range: 584.55114km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.119267229707126, 49.83534684360481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.5506528851264, 49.95075768523055], [-3.464203466201346, 49.927816722737596], [-3.3778400799994506, 49.904805033602656], [-3.291562838472473, 49.88172274150314], [-3.2053718520678975, 49.85856997021367], [-3.119267229707126, 49.83534684360481], [-3.033249078813572, 49.81205348563854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -3.0332491&lt;dd&gt;Longitude: 49.812053&lt;dd&gt;Azimuth: 189.61784\u00b0&lt;dd&gt;Altitude: 69.827134\u00b0&lt;dd&gt;Slant Range: 585.04429km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.033249078813572, 49.81205348563854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.464203466201346, 49.927816722737596], [-3.3778400799994506, 49.904805033602656], [-3.291562838472473, 49.88172274150314], [-3.2053718520678975, 49.85856997021367], [-3.119267229707126, 49.83534684360481], [-3.033249078813572, 49.81205348563854], [-2.94731750529566, 49.7886900203683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.9473175&lt;dd&gt;Longitude: 49.78869&lt;dd&gt;Azimuth: 187.62216\u00b0&lt;dd&gt;Altitude: 69.65797\u00b0&lt;dd&gt;Slant Range: 585.62077km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.94731750529566, 49.7886900203683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3778400799994506, 49.904805033602656], [-3.291562838472473, 49.88172274150314], [-3.2053718520678975, 49.85856997021367], [-3.119267229707126, 49.83534684360481], [-3.033249078813572, 49.81205348563854], [-2.94731750529566, 49.7886900203683], [-2.861472613566624, 49.76525657193468]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.8614726&lt;dd&gt;Longitude: 49.765257&lt;dd&gt;Azimuth: 185.66426\u00b0&lt;dd&gt;Altitude: 69.466636\u00b0&lt;dd&gt;Slant Range: 586.28031km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.861472613566624, 49.76525657193468]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.291562838472473, 49.88172274150314], [-3.2053718520678975, 49.85856997021367], [-3.119267229707126, 49.83534684360481], [-3.033249078813572, 49.81205348563854], [-2.94731750529566, 49.7886900203683], [-2.861472613566624, 49.76525657193468], [-2.775714506544023, 49.74175326456391]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.7757145&lt;dd&gt;Longitude: 49.741753&lt;dd&gt;Azimuth: 183.74752\u00b0&lt;dd&gt;Altitude: 69.253947\u00b0&lt;dd&gt;Slant Range: 587.02265km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.775714506544023, 49.74175326456391]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2053718520678975, 49.85856997021367], [-3.119267229707126, 49.83534684360481], [-3.033249078813572, 49.81205348563854], [-2.94731750529566, 49.7886900203683], [-2.861472613566624, 49.76525657193468], [-2.775714506544023, 49.74175326456391], [-2.6900432856446264, 49.718180222565266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.6900433&lt;dd&gt;Longitude: 49.71818&lt;dd&gt;Azimuth: 181.87483\u00b0&lt;dd&gt;Altitude: 69.020778\u00b0&lt;dd&gt;Slant Range: 587.84747km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6900432856446264, 49.718180222565266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.119267229707126, 49.83534684360481], [-3.033249078813572, 49.81205348563854], [-2.94731750529566, 49.7886900203683], [-2.861472613566624, 49.76525657193468], [-2.775714506544023, 49.74175326456391], [-2.6900432856446264, 49.718180222565266], [-2.6044590508075434, 49.69453757032922]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.6044591&lt;dd&gt;Longitude: 49.694538&lt;dd&gt;Azimuth: 180.04857\u00b0&lt;dd&gt;Altitude: 68.768047\u00b0&lt;dd&gt;Slant Range: 588.75442km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6044590508075434, 49.69453757032922]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.033249078813572, 49.81205348563854], [-2.94731750529566, 49.7886900203683], [-2.861472613566624, 49.76525657193468], [-2.775714506544023, 49.74175326456391], [-2.6900432856446264, 49.718180222565266], [-2.6044590508075434, 49.69453757032922], [-2.518961900477557, 49.67082543232351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.5189619&lt;dd&gt;Longitude: 49.670825&lt;dd&gt;Azimuth: 178.27062\u00b0&lt;dd&gt;Altitude: 68.496704\u00b0&lt;dd&gt;Slant Range: 589.74313km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.518961900477557, 49.67082543232351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.94731750529566, 49.7886900203683], [-2.861472613566624, 49.76525657193468], [-2.775714506544023, 49.74175326456391], [-2.6900432856446264, 49.718180222565266], [-2.6044590508075434, 49.69453757032922], [-2.518961900477557, 49.67082543232351], [-2.433551931628711, 49.64704393309306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.4335519&lt;dd&gt;Longitude: 49.647044&lt;dd&gt;Azimuth: 176.54239\u00b0&lt;dd&gt;Altitude: 68.207725\u00b0&lt;dd&gt;Slant Range: 590.81317km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.433551931628711, 49.64704393309306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.861472613566624, 49.76525657193468], [-2.775714506544023, 49.74175326456391], [-2.6900432856446264, 49.718180222565266], [-2.6044590508075434, 49.69453757032922], [-2.518961900477557, 49.67082543232351], [-2.433551931628711, 49.64704393309306], [-2.348229239751994, 49.62319319725561]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.3482292&lt;dd&gt;Longitude: 49.623193&lt;dd&gt;Azimuth: 174.86485\u00b0&lt;dd&gt;Altitude: 67.902094\u00b0&lt;dd&gt;Slant Range: 591.96411km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.348229239751994, 49.62319319725561]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.775714506544023, 49.74175326456391], [-2.6900432856446264, 49.718180222565266], [-2.6044590508075434, 49.69453757032922], [-2.518961900477557, 49.67082543232351], [-2.433551931628711, 49.64704393309306], [-2.348229239751994, 49.62319319725561], [-2.26299391887389, 49.59927334950075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.2629939&lt;dd&gt;Longitude: 49.599273&lt;dd&gt;Azimuth: 173.23858\u00b0&lt;dd&gt;Altitude: 67.580802\u00b0&lt;dd&gt;Slant Range: 593.19548km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.26299391887389, 49.59927334950075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6900432856446264, 49.718180222565266], [-2.6044590508075434, 49.69453757032922], [-2.518961900477557, 49.67082543232351], [-2.433551931628711, 49.64704393309306], [-2.348229239751994, 49.62319319725561], [-2.26299391887389, 49.59927334950075], [-2.177846061547981, 49.575284514586684]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.1778461&lt;dd&gt;Longitude: 49.575285&lt;dd&gt;Azimuth: 171.66376\u00b0&lt;dd&gt;Altitude: 67.24483\u00b0&lt;dd&gt;Slant Range: 594.50677km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.177846061547981, 49.575284514586684]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6044590508075434, 49.69453757032922], [-2.518961900477557, 49.67082543232351], [-2.433551931628711, 49.64704393309306], [-2.348229239751994, 49.62319319725561], [-2.26299391887389, 49.59927334950075], [-2.177846061547981, 49.575284514586684], [-2.0927857588730108, 49.55122681733861]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.0927858&lt;dd&gt;Longitude: 49.551227&lt;dd&gt;Azimuth: 170.14029\u00b0&lt;dd&gt;Altitude: 66.895151\u00b0&lt;dd&gt;Slant Range: 595.89746km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0927857588730108, 49.55122681733861]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.518961900477557, 49.67082543232351], [-2.433551931628711, 49.64704393309306], [-2.348229239751994, 49.62319319725561], [-2.26299391887389, 49.59927334950075], [-2.177846061547981, 49.575284514586684], [-2.0927857588730108, 49.55122681733861], [-2.007813100480115, 49.52710038264578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -2.0078131&lt;dd&gt;Longitude: 49.5271&lt;dd&gt;Azimuth: 168.66775\u00b0&lt;dd&gt;Altitude: 66.532718\u00b0&lt;dd&gt;Slant Range: 597.36699km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.007813100480115, 49.52710038264578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.433551931628711, 49.64704393309306], [-2.348229239751994, 49.62319319725561], [-2.26299391887389, 49.59927334950075], [-2.177846061547981, 49.575284514586684], [-2.0927857588730108, 49.55122681733861], [-2.007813100480115, 49.52710038264578], [-1.9229281745572964, 49.502905335460234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.9229282&lt;dd&gt;Longitude: 49.502905&lt;dd&gt;Azimuth: 167.24549\u00b0&lt;dd&gt;Altitude: 66.158461\u00b0&lt;dd&gt;Slant Range: 598.91478km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9229281745572964, 49.502905335460234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.348229239751994, 49.62319319725561], [-2.26299391887389, 49.59927334950075], [-2.177846061547981, 49.575284514586684], [-2.0927857588730108, 49.55122681733861], [-2.007813100480115, 49.52710038264578], [-1.9229281745572964, 49.502905335460234], [-1.838131067838892, 49.47864180079276]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.8381311&lt;dd&gt;Longitude: 49.478642&lt;dd&gt;Azimuth: 165.87267\u00b0&lt;dd&gt;Altitude: 65.773281\u00b0&lt;dd&gt;Slant Range: 600.54022km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.838131067838892, 49.47864180079276]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.26299391887389, 49.59927334950075], [-2.177846061547981, 49.575284514586684], [-2.0927857588730108, 49.55122681733861], [-2.007813100480115, 49.52710038264578], [-1.9229281745572964, 49.502905335460234], [-1.838131067838892, 49.47864180079276], [-1.75342186561659, 49.45430990371273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.7534219&lt;dd&gt;Longitude: 49.45431&lt;dd&gt;Azimuth: 164.54825\u00b0&lt;dd&gt;Altitude: 65.378054\u00b0&lt;dd&gt;Slant Range: 602.24269km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.75342186561659, 49.45430990371273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.177846061547981, 49.575284514586684], [-2.0927857588730108, 49.55122681733861], [-2.007813100480115, 49.52710038264578], [-1.9229281745572964, 49.502905335460234], [-1.838131067838892, 49.47864180079276], [-1.75342186561659, 49.45430990371273], [-1.6688006517405494, 49.429909769344306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.6688007&lt;dd&gt;Longitude: 49.42991&lt;dd&gt;Azimuth: 163.27108\u00b0&lt;dd&gt;Altitude: 64.973618\u00b0&lt;dd&gt;Slant Range: 604.02152km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6688006517405494, 49.429909769344306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0927857588730108, 49.55122681733861], [-2.007813100480115, 49.52710038264578], [-1.9229281745572964, 49.502905335460234], [-1.838131067838892, 49.47864180079276], [-1.75342186561659, 49.45430990371273], [-1.6688006517405494, 49.429909769344306], [-1.5842675086319693, 49.40544152286472]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.5842675&lt;dd&gt;Longitude: 49.405442&lt;dd&gt;Azimuth: 162.03988\u00b0&lt;dd&gt;Altitude: 64.56078\u00b0&lt;dd&gt;Slant Range: 605.87604km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5842675086319693, 49.40544152286472]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.007813100480115, 49.52710038264578], [-1.9229281745572964, 49.502905335460234], [-1.838131067838892, 49.47864180079276], [-1.75342186561659, 49.45430990371273], [-1.6688006517405494, 49.429909769344306], [-1.5842675086319693, 49.40544152286472], [-1.4998225172717923, 49.38090528950212]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.4998225&lt;dd&gt;Longitude: 49.380905&lt;dd&gt;Azimuth: 160.85332\u00b0&lt;dd&gt;Altitude: 64.140313\u00b0&lt;dd&gt;Slant Range: 607.80557km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4998225172717923, 49.38090528950212]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9229281745572964, 49.502905335460234], [-1.838131067838892, 49.47864180079276], [-1.75342186561659, 49.45430990371273], [-1.6688006517405494, 49.429909769344306], [-1.5842675086319693, 49.40544152286472], [-1.4998225172717923, 49.38090528950212], [-1.415465757228489, 49.35630119453323]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.4154658&lt;dd&gt;Longitude: 49.356301&lt;dd&gt;Azimuth: 159.70997\u00b0&lt;dd&gt;Altitude: 63.712952\u00b0&lt;dd&gt;Slant Range: 609.80938km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.415465757228489, 49.35630119453323]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.838131067838892, 49.47864180079276], [-1.75342186561659, 49.45430990371273], [-1.6688006517405494, 49.429909769344306], [-1.5842675086319693, 49.40544152286472], [-1.4998225172717923, 49.38090528950212], [-1.415465757228489, 49.35630119453323], [-1.3311973066389755, 49.33162936328086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.3311973&lt;dd&gt;Longitude: 49.331629&lt;dd&gt;Azimuth: 158.6084\u00b0&lt;dd&gt;Altitude: 63.279398\u00b0&lt;dd&gt;Slant Range: 611.88674km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3311973066389755, 49.33162936328086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.75342186561659, 49.45430990371273], [-1.6688006517405494, 49.429909769344306], [-1.5842675086319693, 49.40544152286472], [-1.4998225172717923, 49.38090528950212], [-1.415465757228489, 49.35630119453323], [-1.3311973066389755, 49.33162936328086], [-1.2470172422351766, 49.30688992111286]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.2470172&lt;dd&gt;Longitude: 49.30689&lt;dd&gt;Azimuth: 157.54713\u00b0&lt;dd&gt;Altitude: 62.840315\u00b0&lt;dd&gt;Slant Range: 614.03691km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2470172422351766, 49.30688992111286]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6688006517405494, 49.429909769344306], [-1.5842675086319693, 49.40544152286472], [-1.4998225172717923, 49.38090528950212], [-1.415465757228489, 49.35630119453323], [-1.3311973066389755, 49.33162936328086], [-1.2470172422351766, 49.30688992111286], [-1.1629256393231362, 49.282082993437704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.1629256&lt;dd&gt;Longitude: 49.282083&lt;dd&gt;Azimuth: 156.5247\u00b0&lt;dd&gt;Altitude: 62.396336\u00b0&lt;dd&gt;Slant Range: 616.25911km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1629256393231362, 49.282082993437704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5842675086319693, 49.40544152286472], [-1.4998225172717923, 49.38090528950212], [-1.415465757228489, 49.35630119453323], [-1.3311973066389755, 49.33162936328086], [-1.2470172422351766, 49.30688992111286], [-1.1629256393231362, 49.282082993437704], [-1.0789225718197342, 49.25720870570492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -1.0789226&lt;dd&gt;Longitude: 49.257209&lt;dd&gt;Azimuth: 155.53963\u00b0&lt;dd&gt;Altitude: 61.948055\u00b0&lt;dd&gt;Slant Range: 618.55258km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0789225718197342, 49.25720870570492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4998225172717923, 49.38090528950212], [-1.415465757228489, 49.35630119453323], [-1.3311973066389755, 49.33162936328086], [-1.2470172422351766, 49.30688992111286], [-1.1629256393231362, 49.282082993437704], [-1.0789225718197342, 49.25720870570492], [-0.9950081122284624, 49.23226718340101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.99500811&lt;dd&gt;Longitude: 49.232267&lt;dd&gt;Azimuth: 154.59048\u00b0&lt;dd&gt;Altitude: 61.496038\u00b0&lt;dd&gt;Slant Range: 620.91652km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9950081122284624, 49.23226718340101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.415465757228489, 49.35630119453323], [-1.3311973066389755, 49.33162936328086], [-1.2470172422351766, 49.30688992111286], [-1.1629256393231362, 49.282082993437704], [-1.0789225718197342, 49.25720870570492], [-0.9950081122284624, 49.23226718340101], [-0.9111823316631903, 49.20725855204801]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.91118233&lt;dd&gt;Longitude: 49.207259&lt;dd&gt;Azimuth: 153.67582\u00b0&lt;dd&gt;Altitude: 61.040815\u00b0&lt;dd&gt;Slant Range: 623.35012km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9111823316631903, 49.20725855204801]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3311973066389755, 49.33162936328086], [-1.2470172422351766, 49.30688992111286], [-1.1629256393231362, 49.282082993437704], [-1.0789225718197342, 49.25720870570492], [-0.9950081122284624, 49.23226718340101], [-0.9111823316631903, 49.20725855204801], [-0.8274452998409386, 49.18218293720125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.8274453&lt;dd&gt;Longitude: 49.182183&lt;dd&gt;Azimuth: 152.79426\u00b0&lt;dd&gt;Altitude: 60.582887\u00b0&lt;dd&gt;Slant Range: 625.85258km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8274452998409386, 49.18218293720125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2470172422351766, 49.30688992111286], [-1.1629256393231362, 49.282082993437704], [-1.0789225718197342, 49.25720870570492], [-0.9950081122284624, 49.23226718340101], [-0.9111823316631903, 49.20725855204801], [-0.8274452998409386, 49.18218293720125], [-0.7437970850994104, 49.1570404644474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.74379709&lt;dd&gt;Longitude: 49.15704&lt;dd&gt;Azimuth: 151.94443\u00b0&lt;dd&gt;Altitude: 60.122726\u00b0&lt;dd&gt;Slant Range: 628.42306km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7437970850994104, 49.1570404644474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1629256393231362, 49.282082993437704], [-1.0789225718197342, 49.25720870570492], [-0.9950081122284624, 49.23226718340101], [-0.9111823316631903, 49.20725855204801], [-0.8274452998409386, 49.18218293720125], [-0.7437970850994104, 49.1570404644474], [-0.660237754386076, 49.131831259401906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.66023775&lt;dd&gt;Longitude: 49.131831&lt;dd&gt;Azimuth: 151.12501\u00b0&lt;dd&gt;Altitude: 59.660774\u00b0&lt;dd&gt;Slant Range: 631.06073km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.660237754386076, 49.131831259401906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0789225718197342, 49.25720870570492], [-0.9950081122284624, 49.23226718340101], [-0.9111823316631903, 49.20725855204801], [-0.8274452998409386, 49.18218293720125], [-0.7437970850994104, 49.1570404644474], [-0.660237754386076, 49.131831259401906], [-0.5767673732761359, 49.10655544770752]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.57676737&lt;dd&gt;Longitude: 49.106555&lt;dd&gt;Azimuth: 150.33473\u00b0&lt;dd&gt;Altitude: 59.197446\u00b0&lt;dd&gt;Slant Range: 633.76474km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5767673732761359, 49.10655544770752]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9950081122284624, 49.23226718340101], [-0.9111823316631903, 49.20725855204801], [-0.8274452998409386, 49.18218293720125], [-0.7437970850994104, 49.1570404644474], [-0.660237754386076, 49.131831259401906], [-0.5767673732761359, 49.10655544770752], [-0.4933860059796458, 49.08121315503155]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.49338601&lt;dd&gt;Longitude: 49.081213&lt;dd&gt;Azimuth: 149.57234\u00b0&lt;dd&gt;Altitude: 58.733133\u00b0&lt;dd&gt;Slant Range: 636.53426km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4933860059796458, 49.08121315503155]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9111823316631903, 49.20725855204801], [-0.8274452998409386, 49.18218293720125], [-0.7437970850994104, 49.1570404644474], [-0.660237754386076, 49.131831259401906], [-0.5767673732761359, 49.10655544770752], [-0.4933860059796458, 49.08121315503155], [-0.41009371532739475, 49.05580450706398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.41009372&lt;dd&gt;Longitude: 49.055805&lt;dd&gt;Azimuth: 148.83667\u00b0&lt;dd&gt;Altitude: 58.268199\u00b0&lt;dd&gt;Slant Range: 639.36843km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.41009371532739475, 49.05580450706398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8274452998409386, 49.18218293720125], [-0.7437970850994104, 49.1570404644474], [-0.660237754386076, 49.131831259401906], [-0.5767673732761359, 49.10655544770752], [-0.4933860059796458, 49.08121315503155], [-0.41009371532739475, 49.05580450706398], [-0.32689056279986095, 49.03032962951563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.32689056&lt;dd&gt;Longitude: 49.03033&lt;dd&gt;Azimuth: 148.12657\u00b0&lt;dd&gt;Altitude: 57.802985\u00b0&lt;dd&gt;Slant Range: 642.26638km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.32689056279986095, 49.03032962951563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7437970850994104, 49.1570404644474], [-0.660237754386076, 49.131831259401906], [-0.5767673732761359, 49.10655544770752], [-0.4933860059796458, 49.08121315503155], [-0.41009371532739475, 49.05580450706398], [-0.32689056279986095, 49.03032962951563], [-0.24377660851520205, 49.00478864811567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.24377661&lt;dd&gt;Longitude: 49.004789&lt;dd&gt;Azimuth: 147.44094\u00b0&lt;dd&gt;Altitude: 57.337812\u00b0&lt;dd&gt;Slant Range: 645.22726km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.24377660851520205, 49.00478864811567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.660237754386076, 49.131831259401906], [-0.5767673732761359, 49.10655544770752], [-0.4933860059796458, 49.08121315503155], [-0.41009371532739475, 49.05580450706398], [-0.32689056279986095, 49.03032962951563], [-0.24377660851520205, 49.00478864811567], [-0.16075191124093396, 48.97918168860998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.16075191&lt;dd&gt;Longitude: 48.979182&lt;dd&gt;Azimuth: 146.77874\u00b0&lt;dd&gt;Altitude: 56.872978\u00b0&lt;dd&gt;Slant Range: 648.2502km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.16075191124093396, 48.97918168860998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5767673732761359, 49.10655544770752], [-0.4933860059796458, 49.08121315503155], [-0.41009371532739475, 49.05580450706398], [-0.32689056279986095, 49.03032962951563], [-0.24377660851520205, 49.00478864811567], [-0.16075191124093396, 48.97918168860998], [-0.07781652840113182, 48.953508876758825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: -0.077816528&lt;dd&gt;Longitude: 48.953509&lt;dd&gt;Azimuth: 146.13895\u00b0&lt;dd&gt;Altitude: 56.40876\u00b0&lt;dd&gt;Slant Range: 651.33433km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.07781652840113182, 48.953508876758825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4933860059796458, 49.08121315503155], [-0.41009371532739475, 49.05580450706398], [-0.32689056279986095, 49.03032962951563], [-0.24377660851520205, 49.00478864811567], [-0.16075191124093396, 48.97918168860998], [-0.07781652840113182, 48.953508876758825], [0.005029483920542251, 48.92777033833468]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.0050294839&lt;dd&gt;Longitude: 48.92777&lt;dd&gt;Azimuth: 145.52062\u00b0&lt;dd&gt;Altitude: 55.945417\u00b0&lt;dd&gt;Slant Range: 654.47878km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.005029483920542251, 48.92777033833468]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.41009371532739475, 49.05580450706398], [-0.32689056279986095, 49.03032962951563], [-0.24377660851520205, 49.00478864811567], [-0.16075191124093396, 48.97918168860998], [-0.07781652840113182, 48.953508876758825], [0.005029483920542251, 48.92777033833468], [0.08778607098234029, 48.90196619912089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.087786071&lt;dd&gt;Longitude: 48.901966&lt;dd&gt;Azimuth: 144.92283\u00b0&lt;dd&gt;Altitude: 55.483192\u00b0&lt;dd&gt;Slant Range: 657.68269km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.08778607098234029, 48.90196619912089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.32689056279986095, 49.03032962951563], [-0.24377660851520205, 49.00478864811567], [-0.16075191124093396, 48.97918168860998], [-0.07781652840113182, 48.953508876758825], [0.005029483920542251, 48.92777033833468], [0.08778607098234029, 48.90196619912089], [0.17045317936509075, 48.87609658490882]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.17045318&lt;dd&gt;Longitude: 48.876097&lt;dd&gt;Azimuth: 144.34469\u00b0&lt;dd&gt;Altitude: 55.022308\u00b0&lt;dd&gt;Slant Range: 660.94519km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.17045317936509075, 48.87609658490882]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.24377660851520205, 49.00478864811567], [-0.16075191124093396, 48.97918168860998], [-0.07781652840113182, 48.953508876758825], [0.005029483920542251, 48.92777033833468], [0.08778607098234029, 48.90196619912089], [0.17045317936509075, 48.87609658490882], [0.25303075698232536, 48.85016162149631]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.25303076&lt;dd&gt;Longitude: 48.850162&lt;dd&gt;Azimuth: 143.78538\u00b0&lt;dd&gt;Altitude: 54.562974\u00b0&lt;dd&gt;Slant Range: 664.26541km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.25303075698232536, 48.85016162149631]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.16075191124093396, 48.97918168860998], [-0.07781652840113182, 48.953508876758825], [0.005029483920542251, 48.92777033833468], [0.08778607098234029, 48.90196619912089], [0.17045317936509075, 48.87609658490882], [0.25303075698232536, 48.85016162149631], [0.3355187530578118, 48.824161434685514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.33551875&lt;dd&gt;Longitude: 48.824161&lt;dd&gt;Azimuth: 143.2441\u00b0&lt;dd&gt;Altitude: 54.105383\u00b0&lt;dd&gt;Slant Range: 667.64248km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3355187530578118, 48.824161434685514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.07781652840113182, 48.953508876758825], [0.005029483920542251, 48.92777033833468], [0.08778607098234029, 48.90196619912089], [0.17045317936509075, 48.87609658490882], [0.25303075698232536, 48.85016162149631], [0.3355187530578118, 48.824161434685514], [0.41791711814260135, 48.798096150281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.41791712&lt;dd&gt;Longitude: 48.798096&lt;dd&gt;Azimuth: 142.72008\u00b0&lt;dd&gt;Altitude: 53.649714\u00b0&lt;dd&gt;Slant Range: 671.07555km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.41791711814260135, 48.798096150281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.005029483920542251, 48.92777033833468], [0.08778607098234029, 48.90196619912089], [0.17045317936509075, 48.87609658490882], [0.25303075698232536, 48.85016162149631], [0.3355187530578118, 48.824161434685514], [0.41791711814260135, 48.798096150281], [0.5002258040865055, 48.77196589408788]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.5002258&lt;dd&gt;Longitude: 48.771966&lt;dd&gt;Azimuth: 142.21261\u00b0&lt;dd&gt;Altitude: 53.196132\u00b0&lt;dd&gt;Slant Range: 674.56376km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5002258040865055, 48.77196589408788]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.08778607098234029, 48.90196619912089], [0.17045317936509075, 48.87609658490882], [0.25303075698232536, 48.85016162149631], [0.3355187530578118, 48.824161434685514], [0.41791711814260135, 48.798096150281], [0.5002258040865055, 48.77196589408788], [0.5824447640513277, 48.74577079190951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.58244476&lt;dd&gt;Longitude: 48.745771&lt;dd&gt;Azimuth: 141.72098\u00b0&lt;dd&gt;Altitude: 52.74479\u00b0&lt;dd&gt;Slant Range: 678.10624km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5824447640513277, 48.74577079190951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.17045317936509075, 48.87609658490882], [0.25303075698232536, 48.85016162149631], [0.3355187530578118, 48.824161434685514], [0.41791711814260135, 48.798096150281], [0.5002258040865055, 48.77196589408788], [0.5824447640513277, 48.74577079190951], [0.664573952490736, 48.7195109695458]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.66457395&lt;dd&gt;Longitude: 48.719511&lt;dd&gt;Azimuth: 141.24455\u00b0&lt;dd&gt;Altitude: 52.295828\u00b0&lt;dd&gt;Slant Range: 681.70215km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.664573952490736, 48.7195109695458]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.25303075698232536, 48.85016162149631], [0.3355187530578118, 48.824161434685514], [0.41791711814260135, 48.798096150281], [0.5002258040865055, 48.77196589408788], [0.5824447640513277, 48.74577079190951], [0.664573952490736, 48.7195109695458], [0.7466133251595763, 48.69318655279165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.74661333&lt;dd&gt;Longitude: 48.693187&lt;dd&gt;Azimuth: 140.78269\u00b0&lt;dd&gt;Altitude: 51.849377\u00b0&lt;dd&gt;Slant Range: 685.35066km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7466133251595763, 48.69318655279165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3355187530578118, 48.824161434685514], [0.41791711814260135, 48.798096150281], [0.5002258040865055, 48.77196589408788], [0.5824447640513277, 48.74577079190951], [0.664573952490736, 48.7195109695458], [0.7466133251595763, 48.69318655279165], [0.8285628390927786, 48.666797667434125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.82856284&lt;dd&gt;Longitude: 48.666798&lt;dd&gt;Azimuth: 140.33479\u00b0&lt;dd&gt;Altitude: 51.405555\u00b0&lt;dd&gt;Slant Range: 689.0509km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8285628390927786, 48.666797667434125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.41791711814260135, 48.798096150281], [0.5002258040865055, 48.77196589408788], [0.5824447640513277, 48.74577079190951], [0.664573952490736, 48.7195109695458], [0.7466133251595763, 48.69318655279165], [0.8285628390927786, 48.666797667434125], [0.9104224526171124, 48.64034443925135]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.91042245&lt;dd&gt;Longitude: 48.640344&lt;dd&gt;Azimuth: 139.9003\u00b0&lt;dd&gt;Altitude: 50.964469\u00b0&lt;dd&gt;Slant Range: 692.80206km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9104224526171124, 48.64034443925135]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5002258040865055, 48.77196589408788], [0.5824447640513277, 48.74577079190951], [0.664573952490736, 48.7195109695458], [0.7466133251595763, 48.69318655279165], [0.8285628390927786, 48.666797667434125], [0.9104224526171124, 48.64034443925135], [0.9921921253290247, 48.613826994009955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 0.99219213&lt;dd&gt;Longitude: 48.613827&lt;dd&gt;Azimuth: 139.47868\u00b0&lt;dd&gt;Altitude: 50.526221\u00b0&lt;dd&gt;Slant Range: 696.60331km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9921921253290247, 48.613826994009955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5824447640513277, 48.74577079190951], [0.664573952490736, 48.7195109695458], [0.7466133251595763, 48.69318655279165], [0.8285628390927786, 48.666797667434125], [0.9104224526171124, 48.64034443925135], [0.9921921253290247, 48.613826994009955], [1.073871818102248, 48.587245457463766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.0738718&lt;dd&gt;Longitude: 48.587245&lt;dd&gt;Azimuth: 139.0694\u00b0&lt;dd&gt;Altitude: 50.090899\u00b0&lt;dd&gt;Slant Range: 700.45383km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.073871818102248, 48.587245457463766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.664573952490736, 48.7195109695458], [0.7466133251595763, 48.69318655279165], [0.8285628390927786, 48.666797667434125], [0.9104224526171124, 48.64034443925135], [0.9921921253290247, 48.613826994009955], [1.073871818102248, 48.587245457463766], [1.1554614930732963, 48.56059995535154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.1554615&lt;dd&gt;Longitude: 48.5606&lt;dd&gt;Azimuth: 138.67198\u00b0&lt;dd&gt;Altitude: 49.658586\u00b0&lt;dd&gt;Slant Range: 704.3528km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1554614930732963, 48.56059995535154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7466133251595763, 48.69318655279165], [0.8285628390927786, 48.666797667434125], [0.9104224526171124, 48.64034443925135], [0.9921921253290247, 48.613826994009955], [1.073871818102248, 48.587245457463766], [1.1554614930732963, 48.56059995535154], [1.236961113642382, 48.53389061339558]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.2369611&lt;dd&gt;Longitude: 48.533891&lt;dd&gt;Azimuth: 138.28594\u00b0&lt;dd&gt;Altitude: 49.229355\u00b0&lt;dd&gt;Slant Range: 708.29942km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.236961113642382, 48.53389061339558]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8285628390927786, 48.666797667434125], [0.9104224526171124, 48.64034443925135], [0.9921921253290247, 48.613826994009955], [1.073871818102248, 48.587245457463766], [1.1554614930732963, 48.56059995535154], [1.236961113642382, 48.53389061339558], [1.318370644466698, 48.507117557299104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.3183706&lt;dd&gt;Longitude: 48.507118&lt;dd&gt;Azimuth: 137.91086\u00b0&lt;dd&gt;Altitude: 48.803273\u00b0&lt;dd&gt;Slant Range: 712.2929km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.318370644466698, 48.507117557299104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9104224526171124, 48.64034443925135], [0.9921921253290247, 48.613826994009955], [1.073871818102248, 48.587245457463766], [1.1554614930732963, 48.56059995535154], [1.236961113642382, 48.53389061339558], [1.318370644466698, 48.507117557299104], [1.3996900514481794, 48.480280912745066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.3996901&lt;dd&gt;Longitude: 48.480281&lt;dd&gt;Azimuth: 137.54629\u00b0&lt;dd&gt;Altitude: 48.380401\u00b0&lt;dd&gt;Slant Range: 716.33244km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3996900514481794, 48.480280912745066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9921921253290247, 48.613826994009955], [1.073871818102248, 48.587245457463766], [1.1554614930732963, 48.56059995535154], [1.236961113642382, 48.53389061339558], [1.318370644466698, 48.507117557299104], [1.3996900514481794, 48.480280912745066], [1.4809193017434004, 48.45338080539391]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.4809193&lt;dd&gt;Longitude: 48.453381&lt;dd&gt;Azimuth: 137.19183\u00b0&lt;dd&gt;Altitude: 47.960789\u00b0&lt;dd&gt;Slant Range: 720.41727km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4809193017434004, 48.45338080539391]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.073871818102248, 48.587245457463766], [1.1554614930732963, 48.56059995535154], [1.236961113642382, 48.53389061339558], [1.318370644466698, 48.507117557299104], [1.3996900514481794, 48.480280912745066], [1.4809193017434004, 48.45338080539391], [1.5620583637395051, 48.426417360882176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.5620584&lt;dd&gt;Longitude: 48.426417&lt;dd&gt;Azimuth: 136.84711\u00b0&lt;dd&gt;Altitude: 47.544486\u00b0&lt;dd&gt;Slant Range: 724.54662km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5620583637395051, 48.426417360882176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1554614930732963, 48.56059995535154], [1.236961113642382, 48.53389061339558], [1.318370644466698, 48.507117557299104], [1.3996900514481794, 48.480280912745066], [1.4809193017434004, 48.45338080539391], [1.5620583637395051, 48.426417360882176], [1.6431072070598045, 48.39939070482024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.6431072&lt;dd&gt;Longitude: 48.399391&lt;dd&gt;Azimuth: 136.51175\u00b0&lt;dd&gt;Altitude: 47.131533\u00b0&lt;dd&gt;Slant Range: 728.71972km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6431072070598045, 48.39939070482024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.236961113642382, 48.53389061339558], [1.318370644466698, 48.507117557299104], [1.3996900514481794, 48.480280912745066], [1.4809193017434004, 48.45338080539391], [1.5620583637395051, 48.426417360882176], [1.6431072070598045, 48.39939070482024], [1.7240658025582807, 48.37230096279076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.7240658&lt;dd&gt;Longitude: 48.372301&lt;dd&gt;Azimuth: 136.1854\u00b0&lt;dd&gt;Altitude: 46.721964\u00b0&lt;dd&gt;Slant Range: 732.93583km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7240658025582807, 48.37230096279076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.318370644466698, 48.507117557299104], [1.3996900514481794, 48.480280912745066], [1.4809193017434004, 48.45338080539391], [1.5620583637395051, 48.426417360882176], [1.6431072070598045, 48.39939070482024], [1.7240658025582807, 48.37230096279076], [1.804934122312488, 48.34514826034662]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.8049341&lt;dd&gt;Longitude: 48.345148&lt;dd&gt;Azimuth: 135.86772\u00b0&lt;dd&gt;Altitude: 46.315811\u00b0&lt;dd&gt;Slant Range: 737.1942km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.804934122312488, 48.34514826034662]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3996900514481794, 48.480280912745066], [1.4809193017434004, 48.45338080539391], [1.5620583637395051, 48.426417360882176], [1.6431072070598045, 48.39939070482024], [1.7240658025582807, 48.37230096279076], [1.804934122312488, 48.34514826034662], [1.8857121396098888, 48.31793272301029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.8857121&lt;dd&gt;Longitude: 48.317933&lt;dd&gt;Azimuth: 135.5584\u00b0&lt;dd&gt;Altitude: 45.913098\u00b0&lt;dd&gt;Slant Range: 741.4941km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8857121396098888, 48.31793272301029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4809193017434004, 48.45338080539391], [1.5620583637395051, 48.426417360882176], [1.6431072070598045, 48.39939070482024], [1.7240658025582807, 48.37230096279076], [1.804934122312488, 48.34514826034662], [1.8857121396098888, 48.31793272301029], [1.9663998289656404, 48.29065447626955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 1.9663998&lt;dd&gt;Longitude: 48.290654&lt;dd&gt;Azimuth: 135.25713\u00b0&lt;dd&gt;Altitude: 45.513848\u00b0&lt;dd&gt;Slant Range: 745.8348km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9663998289656404, 48.29065447626955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5620583637395051, 48.426417360882176], [1.6431072070598045, 48.39939070482024], [1.7240658025582807, 48.37230096279076], [1.804934122312488, 48.34514826034662], [1.8857121396098888, 48.31793272301029], [1.9663998289656404, 48.29065447626955], [2.046997166078574, 48.26331364557893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.0469972&lt;dd&gt;Longitude: 48.263314&lt;dd&gt;Azimuth: 134.96362\u00b0&lt;dd&gt;Altitude: 45.118076\u00b0&lt;dd&gt;Slant Range: 750.2156km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.046997166078574, 48.26331364557893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6431072070598045, 48.39939070482024], [1.7240658025582807, 48.37230096279076], [1.804934122312488, 48.34514826034662], [1.8857121396098888, 48.31793272301029], [1.9663998289656404, 48.29065447626955], [2.046997166078574, 48.26331364557893], [2.1275041278693134, 48.23591035635549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.1275041&lt;dd&gt;Longitude: 48.23591&lt;dd&gt;Azimuth: 134.67759\u00b0&lt;dd&gt;Altitude: 44.725797\u00b0&lt;dd&gt;Slant Range: 754.63578km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1275041278693134, 48.23591035635549]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7240658025582807, 48.37230096279076], [1.804934122312488, 48.34514826034662], [1.8857121396098888, 48.31793272301029], [1.9663998289656404, 48.29065447626955], [2.046997166078574, 48.26331364557893], [2.1275041278693134, 48.23591035635549], [2.2079206924409354, 48.20844473397817]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.2079207&lt;dd&gt;Longitude: 48.208445&lt;dd&gt;Azimuth: 134.39878\u00b0&lt;dd&gt;Altitude: 44.337019\u00b0&lt;dd&gt;Slant Range: 759.09467km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2079206924409354, 48.20844473397817]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.804934122312488, 48.34514826034662], [1.8857121396098888, 48.31793272301029], [1.9663998289656404, 48.29065447626955], [2.046997166078574, 48.26331364557893], [2.1275041278693134, 48.23591035635549], [2.2079206924409354, 48.20844473397817], [2.2882468390936013, 48.180916903785715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.2882468&lt;dd&gt;Longitude: 48.180917&lt;dd&gt;Azimuth: 134.12693\u00b0&lt;dd&gt;Altitude: 43.951748\u00b0&lt;dd&gt;Slant Range: 763.59157km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2882468390936013, 48.180916903785715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8857121396098888, 48.31793272301029], [1.9663998289656404, 48.29065447626955], [2.046997166078574, 48.26331364557893], [2.1275041278693134, 48.23591035635549], [2.2079206924409354, 48.20844473397817], [2.2882468390936013, 48.180916903785715], [2.368482548304557, 48.1533269910755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.3684825&lt;dd&gt;Longitude: 48.153327&lt;dd&gt;Azimuth: 133.86179\u00b0&lt;dd&gt;Altitude: 43.569987\u00b0&lt;dd&gt;Slant Range: 768.12581km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.368482548304557, 48.1533269910755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9663998289656404, 48.29065447626955], [2.046997166078574, 48.26331364557893], [2.1275041278693134, 48.23591035635549], [2.2079206924409354, 48.20844473397817], [2.2882468390936013, 48.180916903785715], [2.368482548304557, 48.1533269910755], [2.4486278017368113, 48.125675121100834]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.4486278&lt;dd&gt;Longitude: 48.125675&lt;dd&gt;Azimuth: 133.60315\u00b0&lt;dd&gt;Altitude: 43.191735\u00b0&lt;dd&gt;Slant Range: 772.69673km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.4486278017368113, 48.125675121100834]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.046997166078574, 48.26331364557893], [2.1275041278693134, 48.23591035635549], [2.2079206924409354, 48.20844473397817], [2.2882468390936013, 48.180916903785715], [2.368482548304557, 48.1533269910755], [2.4486278017368113, 48.125675121100834], [2.5286825822188543, 48.0979614190708]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.5286826&lt;dd&gt;Longitude: 48.097961&lt;dd&gt;Azimuth: 133.35076\u00b0&lt;dd&gt;Altitude: 42.81699\u00b0&lt;dd&gt;Slant Range: 777.30367km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.5286825822188543, 48.0979614190708]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1275041278693134, 48.23591035635549], [2.2079206924409354, 48.20844473397817], [2.2882468390936013, 48.180916903785715], [2.368482548304557, 48.1533269910755], [2.4486278017368113, 48.125675121100834], [2.5286825822188543, 48.0979614190708], [2.608646873752649, 48.07018601014703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.6086469&lt;dd&gt;Longitude: 48.070186&lt;dd&gt;Azimuth: 133.10443\u00b0&lt;dd&gt;Altitude: 42.445745\u00b0&lt;dd&gt;Slant Range: 781.946km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.608646873752649, 48.07018601014703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2079206924409354, 48.20844473397817], [2.2882468390936013, 48.180916903785715], [2.368482548304557, 48.1533269910755], [2.4486278017368113, 48.125675121100834], [2.5286825822188543, 48.0979614190708], [2.608646873752649, 48.07018601014703], [2.688520661495514, 48.042349019442796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.6885207&lt;dd&gt;Longitude: 48.042349&lt;dd&gt;Azimuth: 132.86394\u00b0&lt;dd&gt;Altitude: 42.077993\u00b0&lt;dd&gt;Slant Range: 786.62309km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.688520661495514, 48.042349019442796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2882468390936013, 48.180916903785715], [2.368482548304557, 48.1533269910755], [2.4486278017368113, 48.125675121100834], [2.5286825822188543, 48.0979614190708], [2.608646873752649, 48.07018601014703], [2.688520661495514, 48.042349019442796], [2.768303931769333, 48.01445057202134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.7683039&lt;dd&gt;Longitude: 48.014451&lt;dd&gt;Azimuth: 132.6291\u00b0&lt;dd&gt;Altitude: 41.713722\u00b0&lt;dd&gt;Slant Range: 791.33431km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.768303931769333, 48.01445057202134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.368482548304557, 48.1533269910755], [2.4486278017368113, 48.125675121100834], [2.5286825822188543, 48.0979614190708], [2.608646873752649, 48.07018601014703], [2.688520661495514, 48.042349019442796], [2.768303931769333, 48.01445057202134], [2.8479966720390575, 47.98649079289398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.8479967&lt;dd&gt;Longitude: 47.986491&lt;dd&gt;Azimuth: 132.39973\u00b0&lt;dd&gt;Altitude: 41.352922\u00b0&lt;dd&gt;Slant Range: 796.07905km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.8479966720390575, 47.98649079289398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.4486278017368113, 48.125675121100834], [2.5286825822188543, 48.0979614190708], [2.608646873752649, 48.07018601014703], [2.688520661495514, 48.042349019442796], [2.768303931769333, 48.01445057202134], [2.8479966720390575, 47.98649079289398], [2.9275988709147898, 47.9584698070191]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 2.9275989&lt;dd&gt;Longitude: 47.95847&lt;dd&gt;Azimuth: 132.17564\u00b0&lt;dd&gt;Altitude: 40.995576\u00b0&lt;dd&gt;Slant Range: 800.85672km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9275988709147898, 47.9584698070191]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.5286825822188543, 48.0979614190708], [2.608646873752649, 48.07018601014703], [2.688520661495514, 48.042349019442796], [2.768303931769333, 48.01445057202134], [2.8479966720390575, 47.98649079289398], [2.9275988709147898, 47.9584698070191], [3.0071105181492657, 47.93038773929952]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 3.0071105&lt;dd&gt;Longitude: 47.930388&lt;dd&gt;Azimuth: 131.95667\u00b0&lt;dd&gt;Altitude: 40.641669\u00b0&lt;dd&gt;Slant Range: 805.66671km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0071105181492657, 47.93038773929952]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.608646873752649, 48.07018601014703], [2.688520661495514, 48.042349019442796], [2.768303931769333, 48.01445057202134], [2.8479966720390575, 47.98649079289398], [2.9275988709147898, 47.9584698070191], [3.0071105181492657, 47.93038773929952], [3.08653160462806, 47.90224471458169]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 3.0865316&lt;dd&gt;Longitude: 47.902245&lt;dd&gt;Azimuth: 131.74264\u00b0&lt;dd&gt;Altitude: 40.291183\u00b0&lt;dd&gt;Slant Range: 810.50845km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.08653160462806, 47.90224471458169]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.688520661495514, 48.042349019442796], [2.768303931769333, 48.01445057202134], [2.8479966720390575, 47.98649079289398], [2.9275988709147898, 47.9584698070191], [3.0071105181492657, 47.93038773929952], [3.08653160462806, 47.90224471458169], [3.165862122358412, 47.87404085765438]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 3.1658621&lt;dd&gt;Longitude: 47.874041&lt;dd&gt;Azimuth: 131.53341\u00b0&lt;dd&gt;Altitude: 39.944098\u00b0&lt;dd&gt;Slant Range: 815.38137km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.165862122358412, 47.87404085765438]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.768303931769333, 48.01445057202134], [2.8479966720390575, 47.98649079289398], [2.9275988709147898, 47.9584698070191], [3.0071105181492657, 47.93038773929952], [3.08653160462806, 47.90224471458169], [3.165862122358412, 47.87404085765438], [3.245102064480426, 47.84577629324585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 3.2451021&lt;dd&gt;Longitude: 47.845776&lt;dd&gt;Azimuth: 131.32881\u00b0&lt;dd&gt;Altitude: 39.600394\u00b0&lt;dd&gt;Slant Range: 820.28491km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.245102064480426, 47.84577629324585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.8479966720390575, 47.98649079289398], [2.9275988709147898, 47.9584698070191], [3.0071105181492657, 47.93038773929952], [3.08653160462806, 47.90224471458169], [3.165862122358412, 47.87404085765438], [3.245102064480426, 47.84577629324585], [3.3242514252418522, 47.817451146023295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 3.3242514&lt;dd&gt;Longitude: 47.817451&lt;dd&gt;Azimuth: 131.12871\u00b0&lt;dd&gt;Altitude: 39.260049\u00b0&lt;dd&gt;Slant Range: 825.21851km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3242514252418522, 47.817451146023295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9275988709147898, 47.9584698070191], [3.0071105181492657, 47.93038773929952], [3.08653160462806, 47.90224471458169], [3.165862122358412, 47.87404085765438], [3.245102064480426, 47.84577629324585], [3.3242514252418522, 47.817451146023295], [3.4033102000014472, 47.78906554059106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2327&lt;dd&gt;Latitude: 3.4033102&lt;dd&gt;Longitude: 47.789066&lt;dd&gt;Azimuth: 130.93296\u00b0&lt;dd&gt;Altitude: 38.923039\u00b0&lt;dd&gt;Slant Range: 830.18164km&quot;, &quot;name&quot;: &quot;STARLINK-2327&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4033102000014472, 47.78906554059106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 0.62083441&lt;dd&gt;Longitude: 52.664039&lt;dd&gt;Azimuth: 57.4848\u00b0&lt;dd&gt;Altitude: 62.82856\u00b0&lt;dd&gt;Slant Range: 614.92403km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396], [0.7186448142925183, 52.65416852288664]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 0.71864481&lt;dd&gt;Longitude: 52.654169&lt;dd&gt;Azimuth: 58.409361\u00b0&lt;dd&gt;Altitude: 62.350646\u00b0&lt;dd&gt;Slant Range: 617.32664km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7186448142925183, 52.65416852288664]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396], [0.7186448142925183, 52.65416852288664], [0.8164091142784483, 52.64421032736322]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 0.81640911&lt;dd&gt;Longitude: 52.64421&lt;dd&gt;Azimuth: 59.297957\u00b0&lt;dd&gt;Altitude: 61.870359\u00b0&lt;dd&gt;Slant Range: 619.79853km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8164091142784483, 52.64421032736322]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396], [0.7186448142925183, 52.65416852288664], [0.8164091142784483, 52.64421032736322], [0.9141269455575576, 52.63416458605735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 0.91412695&lt;dd&gt;Longitude: 52.634165&lt;dd&gt;Azimuth: 60.152256\u00b0&lt;dd&gt;Altitude: 61.388191\u00b0&lt;dd&gt;Slant Range: 622.33888km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9141269455575576, 52.63416458605735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396], [0.7186448142925183, 52.65416852288664], [0.8164091142784483, 52.64421032736322], [0.9141269455575576, 52.63416458605735], [1.0117979403072972, 52.62403137034893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.0117979&lt;dd&gt;Longitude: 52.624031&lt;dd&gt;Azimuth: 60.973862\u00b0&lt;dd&gt;Altitude: 60.904597\u00b0&lt;dd&gt;Slant Range: 624.94684km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0117979403072972, 52.62403137034893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396], [0.7186448142925183, 52.65416852288664], [0.8164091142784483, 52.64421032736322], [0.9141269455575576, 52.63416458605735], [1.0117979403072972, 52.62403137034893], [1.109421732006958, 52.6138107521617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.1094217&lt;dd&gt;Longitude: 52.613811&lt;dd&gt;Azimuth: 61.764309\u00b0&lt;dd&gt;Altitude: 60.420005\u00b0&lt;dd&gt;Slant Range: 627.62157km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.109421732006958, 52.6138107521617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6208344147070566, 52.66403910179396], [0.7186448142925183, 52.65416852288664], [0.8164091142784483, 52.64421032736322], [0.9141269455575576, 52.63416458605735], [1.0117979403072972, 52.62403137034893], [1.109421732006958, 52.6138107521617], [1.2069979554342596, 52.60350280396099]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.206998&lt;dd&gt;Longitude: 52.603503&lt;dd&gt;Azimuth: 62.525064\u00b0&lt;dd&gt;Altitude: 59.934812\u00b0&lt;dd&gt;Slant Range: 630.36221km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2069979554342596, 52.60350280396099]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7186448142925183, 52.65416852288664], [0.8164091142784483, 52.64421032736322], [0.9141269455575576, 52.63416458605735], [1.0117979403072972, 52.62403137034893], [1.109421732006958, 52.6138107521617], [1.2069979554342596, 52.60350280396099], [1.3045262466915855, 52.59310759875104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.3045262&lt;dd&gt;Longitude: 52.593108&lt;dd&gt;Azimuth: 63.257529\u00b0&lt;dd&gt;Altitude: 59.449389\u00b0&lt;dd&gt;Slant Range: 633.16791km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3045262466915855, 52.59310759875104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8164091142784483, 52.64421032736322], [0.9141269455575576, 52.63416458605735], [1.0117979403072972, 52.62403137034893], [1.109421732006958, 52.6138107521617], [1.2069979554342596, 52.60350280396099], [1.3045262466915855, 52.59310759875104], [1.4020062431876614, 52.582625210072685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.4020062&lt;dd&gt;Longitude: 52.582625&lt;dd&gt;Azimuth: 63.963036\u00b0&lt;dd&gt;Altitude: 58.964082\u00b0&lt;dd&gt;Slant Range: 636.03781km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4020062431876614, 52.582625210072685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9141269455575576, 52.63416458605735], [1.0117979403072972, 52.62403137034893], [1.109421732006958, 52.6138107521617], [1.2069979554342596, 52.60350280396099], [1.3045262466915855, 52.59310759875104], [1.4020062431876614, 52.582625210072685], [1.4994375836736107, 52.572055712001216]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.4994376&lt;dd&gt;Longitude: 52.572056&lt;dd&gt;Azimuth: 64.642856\u00b0&lt;dd&gt;Altitude: 58.47921\u00b0&lt;dd&gt;Slant Range: 638.97103km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4994375836736107, 52.572055712001216]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0117979403072972, 52.62403137034893], [1.109421732006958, 52.6138107521617], [1.2069979554342596, 52.60350280396099], [1.3045262466915855, 52.59310759875104], [1.4020062431876614, 52.582625210072685], [1.4994375836736107, 52.572055712001216], [1.5968199082252963, 52.56139917914314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.5968199&lt;dd&gt;Longitude: 52.561399&lt;dd&gt;Azimuth: 65.298196\u00b0&lt;dd&gt;Altitude: 57.995073\u00b0&lt;dd&gt;Slant Range: 641.96671km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5968199082252963, 52.56139917914314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.109421732006958, 52.6138107521617], [1.2069979554342596, 52.60350280396099], [1.3045262466915855, 52.59310759875104], [1.4020062431876614, 52.582625210072685], [1.4994375836736107, 52.572055712001216], [1.5968199082252963, 52.56139917914314], [1.694152858272632, 52.55065568663458]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.6941529&lt;dd&gt;Longitude: 52.550656&lt;dd&gt;Azimuth: 65.930202\u00b0&lt;dd&gt;Altitude: 57.511948\u00b0&lt;dd&gt;Slant Range: 645.02396km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.694152858272632, 52.55065568663458]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2069979554342596, 52.60350280396099], [1.3045262466915855, 52.59310759875104], [1.4020062431876614, 52.582625210072685], [1.4994375836736107, 52.572055712001216], [1.5968199082252963, 52.56139917914314], [1.694152858272632, 52.55065568663458], [1.7914360765907789, 52.53982531013826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.7914361&lt;dd&gt;Longitude: 52.539825&lt;dd&gt;Azimuth: 66.539962\u00b0&lt;dd&gt;Altitude: 57.030092\u00b0&lt;dd&gt;Slant Range: 648.14193km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7914360765907789, 52.53982531013826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3045262466915855, 52.59310759875104], [1.4020062431876614, 52.582625210072685], [1.4994375836736107, 52.572055712001216], [1.5968199082252963, 52.56139917914314], [1.694152858272632, 52.55065568663458], [1.7914360765907789, 52.53982531013826], [1.8886692073125628, 52.52890812584113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.8886692&lt;dd&gt;Longitude: 52.528908&lt;dd&gt;Azimuth: 67.12851\u00b0&lt;dd&gt;Altitude: 56.549742\u00b0&lt;dd&gt;Slant Range: 651.31972km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8886692073125628, 52.52890812584113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4020062431876614, 52.582625210072685], [1.4994375836736107, 52.572055712001216], [1.5968199082252963, 52.56139917914314], [1.694152858272632, 52.55065568663458], [1.7914360765907789, 52.53982531013826], [1.8886692073125628, 52.52890812584113], [1.9858518959456994, 52.51790421045179]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 1.9858519&lt;dd&gt;Longitude: 52.517904&lt;dd&gt;Azimuth: 67.696823\u00b0&lt;dd&gt;Altitude: 56.071118\u00b0&lt;dd&gt;Slant Range: 654.55647km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9858518959456994, 52.51790421045179]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4994375836736107, 52.572055712001216], [1.5968199082252963, 52.56139917914314], [1.694152858272632, 52.55065568663458], [1.7914360765907789, 52.53982531013826], [1.8886692073125628, 52.52890812584113], [1.9858518959456994, 52.51790421045179], [2.082983789359538, 52.50681364119839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.0829838&lt;dd&gt;Longitude: 52.506814&lt;dd&gt;Azimuth: 68.245832\u00b0&lt;dd&gt;Altitude: 55.594425\u00b0&lt;dd&gt;Slant Range: 657.8513km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.082983789359538, 52.50681364119839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5968199082252963, 52.56139917914314], [1.694152858272632, 52.55065568663458], [1.7914360765907789, 52.53982531013826], [1.8886692073125628, 52.52890812584113], [1.9858518959456994, 52.51790421045179], [2.082983789359538, 52.50681364119839], [2.180064535815315, 52.49563649582512]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.1800645&lt;dd&gt;Longitude: 52.495636&lt;dd&gt;Azimuth: 68.776415\u00b0&lt;dd&gt;Altitude: 55.119851\u00b0&lt;dd&gt;Slant Range: 661.20334km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.180064535815315, 52.49563649582512]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.694152858272632, 52.55065568663458], [1.7914360765907789, 52.53982531013826], [1.8886692073125628, 52.52890812584113], [1.9858518959456994, 52.51790421045179], [2.082983789359538, 52.50681364119839], [2.180064535815315, 52.49563649582512], [2.2770937849516257, 52.48437285259094]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.2770938&lt;dd&gt;Longitude: 52.484373&lt;dd&gt;Azimuth: 69.289406\u00b0&lt;dd&gt;Altitude: 54.647567\u00b0&lt;dd&gt;Slant Range: 664.61173km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2770937849516257, 52.48437285259094]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7914360765907789, 52.53982531013826], [1.8886692073125628, 52.52890812584113], [1.9858518959456994, 52.51790421045179], [2.082983789359538, 52.50681364119839], [2.180064535815315, 52.49563649582512], [2.2770937849516257, 52.48437285259094], [2.3740711878100194, 52.47302279026595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.3740712&lt;dd&gt;Longitude: 52.473023&lt;dd&gt;Azimuth: 69.785596\u00b0&lt;dd&gt;Altitude: 54.177735\u00b0&lt;dd&gt;Slant Range: 668.07559km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3740711878100194, 52.47302279026595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8886692073125628, 52.52890812584113], [1.9858518959456994, 52.51790421045179], [2.082983789359538, 52.50681364119839], [2.180064535815315, 52.49563649582512], [2.2770937849516257, 52.48437285259094], [2.3740711878100194, 52.47302279026595], [2.470996396827089, 52.46158638812938]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.4709964&lt;dd&gt;Longitude: 52.461586&lt;dd&gt;Azimuth: 70.265734\u00b0&lt;dd&gt;Altitude: 53.710499\u00b0&lt;dd&gt;Slant Range: 671.59406km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.470996396827089, 52.46158638812938]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9858518959456994, 52.51790421045179], [2.082983789359538, 52.50681364119839], [2.180064535815315, 52.49563649582512], [2.2770937849516257, 52.48437285259094], [2.3740711878100194, 52.47302279026595], [2.470996396827089, 52.46158638812938], [2.56786906585289, 52.45006372596694]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.5678691&lt;dd&gt;Longitude: 52.450064&lt;dd&gt;Azimuth: 70.730529\u00b0&lt;dd&gt;Altitude: 53.245994\u00b0&lt;dd&gt;Slant Range: 675.16629km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.56786906585289, 52.45006372596694]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.082983789359538, 52.50681364119839], [2.180064535815315, 52.49563649582512], [2.2770937849516257, 52.48437285259094], [2.3740711878100194, 52.47302279026595], [2.470996396827089, 52.46158638812938], [2.56786906585289, 52.45006372596694], [2.664688850146796, 52.438454884067916]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.6646889&lt;dd&gt;Longitude: 52.438455&lt;dd&gt;Azimuth: 71.180654\u00b0&lt;dd&gt;Altitude: 52.784344\u00b0&lt;dd&gt;Slant Range: 678.79142km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.664688850146796, 52.438454884067916]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.180064535815315, 52.49563649582512], [2.2770937849516257, 52.48437285259094], [2.3740711878100194, 52.47302279026595], [2.470996396827089, 52.46158638812938], [2.56786906585289, 52.45006372596694], [2.664688850146796, 52.438454884067916], [2.761455406398335, 52.42675994322297]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.7614554&lt;dd&gt;Longitude: 52.42676&lt;dd&gt;Azimuth: 71.616748\u00b0&lt;dd&gt;Altitude: 52.325658\u00b0&lt;dd&gt;Slant Range: 682.46861km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.761455406398335, 52.42675994322297]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2770937849516257, 52.48437285259094], [2.3740711878100194, 52.47302279026595], [2.470996396827089, 52.46158638812938], [2.56786906585289, 52.45006372596694], [2.664688850146796, 52.438454884067916], [2.761455406398335, 52.42675994322297], [2.8581683927153336, 52.41497898472154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.8581684&lt;dd&gt;Longitude: 52.414979&lt;dd&gt;Azimuth: 72.039413\u00b0&lt;dd&gt;Altitude: 51.87004\u00b0&lt;dd&gt;Slant Range: 686.19701km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.8581683927153336, 52.41497898472154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3740711878100194, 52.47302279026595], [2.470996396827089, 52.46158638812938], [2.56786906585289, 52.45006372596694], [2.664688850146796, 52.438454884067916], [2.761455406398335, 52.42675994322297], [2.8581683927153336, 52.41497898472154], [2.9548274686456204, 52.40311209034855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 2.9548275&lt;dd&gt;Longitude: 52.403112&lt;dd&gt;Azimuth: 72.449224\u00b0&lt;dd&gt;Altitude: 51.417582\u00b0&lt;dd&gt;Slant Range: 689.9758km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9548274686456204, 52.40311209034855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.470996396827089, 52.46158638812938], [2.56786906585289, 52.45006372596694], [2.664688850146796, 52.438454884067916], [2.761455406398335, 52.42675994322297], [2.8581683927153336, 52.41497898472154], [2.9548274686456204, 52.40311209034855], [3.0514322951768498, 52.391159342382714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.0514323&lt;dd&gt;Longitude: 52.391159&lt;dd&gt;Azimuth: 72.846725\u00b0&lt;dd&gt;Altitude: 50.968366\u00b0&lt;dd&gt;Slant Range: 693.80413km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0514322951768498, 52.391159342382714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.56786906585289, 52.45006372596694], [2.664688850146796, 52.438454884067916], [2.761455406398335, 52.42675994322297], [2.8581683927153336, 52.41497898472154], [2.9548274686456204, 52.40311209034855], [3.0514322951768498, 52.391159342382714], [3.1479825347453536, 52.37912082359324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.1479825&lt;dd&gt;Longitude: 52.379121&lt;dd&gt;Azimuth: 73.232432\u00b0&lt;dd&gt;Altitude: 50.522467\u00b0&lt;dd&gt;Slant Range: 697.68121km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.1479825347453536, 52.37912082359324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.664688850146796, 52.438454884067916], [2.761455406398335, 52.42675994322297], [2.8581683927153336, 52.41497898472154], [2.9548274686456204, 52.40311209034855], [3.0514322951768498, 52.391159342382714], [3.1479825347453536, 52.37912082359324], [3.2444778512355077, 52.36699661723735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.2444779&lt;dd&gt;Longitude: 52.366997&lt;dd&gt;Azimuth: 73.606834\u00b0&lt;dd&gt;Altitude: 50.079954\u00b0&lt;dd&gt;Slant Range: 701.6062km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.2444778512355077, 52.36699661723735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.761455406398335, 52.42675994322297], [2.8581683927153336, 52.41497898472154], [2.9548274686456204, 52.40311209034855], [3.0514322951768498, 52.391159342382714], [3.1479825347453536, 52.37912082359324], [3.2444778512355077, 52.36699661723735], [3.340917910001002, 52.35478680705771]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.3409179&lt;dd&gt;Longitude: 52.354787&lt;dd&gt;Azimuth: 73.970396\u00b0&lt;dd&gt;Altitude: 49.640884\u00b0&lt;dd&gt;Slant Range: 705.57831km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.340917910001002, 52.35478680705771]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.8581683927153336, 52.41497898472154], [2.9548274686456204, 52.40311209034855], [3.0514322951768498, 52.391159342382714], [3.1479825347453536, 52.37912082359324], [3.2444778512355077, 52.36699661723735], [3.340917910001002, 52.35478680705771], [3.4373023778486833, 52.34249147727963]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.4373024&lt;dd&gt;Longitude: 52.342491&lt;dd&gt;Azimuth: 74.323561\u00b0&lt;dd&gt;Altitude: 49.205312\u00b0&lt;dd&gt;Slant Range: 709.59675km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4373023778486833, 52.34249147727963]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9548274686456204, 52.40311209034855], [3.0514322951768498, 52.391159342382714], [3.1479825347453536, 52.37912082359324], [3.2444778512355077, 52.36699661723735], [3.340917910001002, 52.35478680705771], [3.4373023778486833, 52.34249147727963], [3.5336309230672325, 52.330110712608366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.5336309&lt;dd&gt;Longitude: 52.330111&lt;dd&gt;Azimuth: 74.666747\u00b0&lt;dd&gt;Altitude: 48.773282\u00b0&lt;dd&gt;Slant Range: 713.66072km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5336309230672325, 52.330110712608366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0514322951768498, 52.391159342382714], [3.1479825347453536, 52.37912082359324], [3.2444778512355077, 52.36699661723735], [3.340917910001002, 52.35478680705771], [3.4373023778486833, 52.34249147727963], [3.5336309230672325, 52.330110712608366], [3.62990321541182, 52.317644598226856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.6299032&lt;dd&gt;Longitude: 52.317645&lt;dd&gt;Azimuth: 75.000353\u00b0&lt;dd&gt;Altitude: 48.344837\u00b0&lt;dd&gt;Slant Range: 717.76944km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.62990321541182, 52.317644598226856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.1479825347453536, 52.37912082359324], [3.2444778512355077, 52.36699661723735], [3.340917910001002, 52.35478680705771], [3.4373023778486833, 52.34249147727963], [3.5336309230672325, 52.330110712608366], [3.62990321541182, 52.317644598226856], [3.7261189261360395, 52.30509321979197]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.7261189&lt;dd&gt;Longitude: 52.305093&lt;dd&gt;Azimuth: 75.324759\u00b0&lt;dd&gt;Altitude: 47.920009\u00b0&lt;dd&gt;Slant Range: 721.92216km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.7261189261360395, 52.30509321979197]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.2444778512355077, 52.36699661723735], [3.340917910001002, 52.35478680705771], [3.4373023778486833, 52.34249147727963], [3.5336309230672325, 52.330110712608366], [3.62990321541182, 52.317644598226856], [3.7261189261360395, 52.30509321979197], [3.8222777279637397, 52.29245666343326]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.8222777&lt;dd&gt;Longitude: 52.292457&lt;dd&gt;Azimuth: 75.640325\u00b0&lt;dd&gt;Altitude: 47.498828\u00b0&lt;dd&gt;Slant Range: 726.11811km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8222777279637397, 52.29245666343326]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.340917910001002, 52.35478680705771], [3.4373023778486833, 52.34249147727963], [3.5336309230672325, 52.330110712608366], [3.62990321541182, 52.317644598226856], [3.7261189261360395, 52.30509321979197], [3.8222777279637397, 52.29245666343326], [3.9183792951262264, 52.27973501574894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 3.9183793&lt;dd&gt;Longitude: 52.279735&lt;dd&gt;Azimuth: 75.947393\u00b0&lt;dd&gt;Altitude: 47.081318\u00b0&lt;dd&gt;Slant Range: 730.35653km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9183792951262264, 52.27973501574894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4373023778486833, 52.34249147727963], [3.5336309230672325, 52.330110712608366], [3.62990321541182, 52.317644598226856], [3.7261189261360395, 52.30509321979197], [3.8222777279637397, 52.29245666343326], [3.9183792951262264, 52.27973501574894], [4.0144233033475025, 52.26692836380383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.0144233&lt;dd&gt;Longitude: 52.266928&lt;dd&gt;Azimuth: 76.246291\u00b0&lt;dd&gt;Altitude: 46.6675\u00b0&lt;dd&gt;Slant Range: 734.6367km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.0144233033475025, 52.26692836380383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5336309230672325, 52.330110712608366], [3.62990321541182, 52.317644598226856], [3.7261189261360395, 52.30509321979197], [3.8222777279637397, 52.29245666343326], [3.9183792951262264, 52.27973501574894], [4.0144233033475025, 52.26692836380383], [4.110409429860527, 52.254036795126545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.1104094&lt;dd&gt;Longitude: 52.254037&lt;dd&gt;Azimuth: 76.537329\u00b0&lt;dd&gt;Altitude: 46.257386\u00b0&lt;dd&gt;Slant Range: 738.95788km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.110409429860527, 52.254036795126545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.62990321541182, 52.317644598226856], [3.7261189261360395, 52.30509321979197], [3.8222777279637397, 52.29245666343326], [3.9183792951262264, 52.27973501574894], [4.0144233033475025, 52.26692836380383], [4.110409429860527, 52.254036795126545], [4.20633735340302, 52.241060397706605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.2063374&lt;dd&gt;Longitude: 52.24106&lt;dd&gt;Azimuth: 76.820803\u00b0&lt;dd&gt;Altitude: 45.85099\u00b0&lt;dd&gt;Slant Range: 743.31934km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.20633735340302, 52.241060397706605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.7261189261360395, 52.30509321979197], [3.8222777279637397, 52.29245666343326], [3.9183792951262264, 52.27973501574894], [4.0144233033475025, 52.26692836380383], [4.110409429860527, 52.254036795126545], [4.20633735340302, 52.241060397706605], [4.302206754235498, 52.22799925999172]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.3022068&lt;dd&gt;Longitude: 52.227999&lt;dd&gt;Azimuth: 77.096996\u00b0&lt;dd&gt;Altitude: 45.448318\u00b0&lt;dd&gt;Slant Range: 747.72039km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.302206754235498, 52.22799925999172]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8222777279637397, 52.29245666343326], [3.9183792951262264, 52.27973501574894], [4.0144233033475025, 52.26692836380383], [4.110409429860527, 52.254036795126545], [4.20633735340302, 52.241060397706605], [4.302206754235498, 52.22799925999172], [4.398017314135347, 52.21485347088528]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.3980173&lt;dd&gt;Longitude: 52.214853&lt;dd&gt;Azimuth: 77.366175\u00b0&lt;dd&gt;Altitude: 45.049373\u00b0&lt;dd&gt;Slant Range: 752.16032km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.398017314135347, 52.21485347088528]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9183792951262264, 52.27973501574894], [4.0144233033475025, 52.26692836380383], [4.110409429860527, 52.254036795126545], [4.20633735340302, 52.241060397706605], [4.302206754235498, 52.22799925999172], [4.398017314135347, 52.21485347088528], [4.493768716398761, 52.201623119743196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.4937687&lt;dd&gt;Longitude: 52.201623&lt;dd&gt;Azimuth: 77.628599\u00b0&lt;dd&gt;Altitude: 44.654157\u00b0&lt;dd&gt;Slant Range: 756.63844km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.493768716398761, 52.201623119743196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.0144233033475025, 52.26692836380383], [4.110409429860527, 52.254036795126545], [4.20633735340302, 52.241060397706605], [4.302206754235498, 52.22799925999172], [4.398017314135347, 52.21485347088528], [4.493768716398761, 52.201623119743196], [4.589460645865032, 52.188308296371346]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.5894606&lt;dd&gt;Longitude: 52.188308&lt;dd&gt;Azimuth: 77.88451\u00b0&lt;dd&gt;Altitude: 44.262666\u00b0&lt;dd&gt;Slant Range: 761.15408km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.589460645865032, 52.188308296371346]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.110409429860527, 52.254036795126545], [4.20633735340302, 52.241060397706605], [4.302206754235498, 52.22799925999172], [4.398017314135347, 52.21485347088528], [4.493768716398761, 52.201623119743196], [4.589460645865032, 52.188308296371346], [4.685092788898214, 52.17490909102275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.6850928&lt;dd&gt;Longitude: 52.174909&lt;dd&gt;Azimuth: 78.134144\u00b0&lt;dd&gt;Altitude: 43.874894\u00b0&lt;dd&gt;Slant Range: 765.70656km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.685092788898214, 52.17490909102275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.20633735340302, 52.241060397706605], [4.302206754235498, 52.22799925999172], [4.398017314135347, 52.21485347088528], [4.493768716398761, 52.201623119743196], [4.589460645865032, 52.188308296371346], [4.685092788898214, 52.17490909102275], [4.780664833407295, 52.161425594394856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.7806648&lt;dd&gt;Longitude: 52.161426&lt;dd&gt;Azimuth: 78.377722\u00b0&lt;dd&gt;Altitude: 43.490834\u00b0&lt;dd&gt;Slant Range: 770.29523km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.780664833407295, 52.161425594394856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.302206754235498, 52.22799925999172], [4.398017314135347, 52.21485347088528], [4.493768716398761, 52.201623119743196], [4.589460645865032, 52.188308296371346], [4.685092788898214, 52.17490909102275], [4.780664833407295, 52.161425594394856], [4.8761764688463245, 52.14785789762659]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.8761765&lt;dd&gt;Longitude: 52.147858&lt;dd&gt;Azimuth: 78.615458\u00b0&lt;dd&gt;Altitude: 43.110474\u00b0&lt;dd&gt;Slant Range: 774.91943km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.8761764688463245, 52.14785789762659]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.398017314135347, 52.21485347088528], [4.493768716398761, 52.201623119743196], [4.589460645865032, 52.188308296371346], [4.685092788898214, 52.17490909102275], [4.780664833407295, 52.161425594394856], [4.8761764688463245, 52.14785789762659], [4.97162738621518, 52.13420609229578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 4.9716274&lt;dd&gt;Longitude: 52.134206&lt;dd&gt;Azimuth: 78.847555\u00b0&lt;dd&gt;Altitude: 42.733802\u00b0&lt;dd&gt;Slant Range: 779.57854km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.97162738621518, 52.13420609229578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.493768716398761, 52.201623119743196], [4.589460645865032, 52.188308296371346], [4.685092788898214, 52.17490909102275], [4.780664833407295, 52.161425594394856], [4.8761764688463245, 52.14785789762659], [4.97162738621518, 52.13420609229578], [5.0670172780675005, 52.12047027041598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.0670173&lt;dd&gt;Longitude: 52.12047&lt;dd&gt;Azimuth: 79.074208\u00b0&lt;dd&gt;Altitude: 42.360803\u00b0&lt;dd&gt;Slant Range: 784.27192km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.0670172780675005, 52.12047027041598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.589460645865032, 52.188308296371346], [4.685092788898214, 52.17490909102275], [4.780664833407295, 52.161425594394856], [4.8761764688463245, 52.14785789762659], [4.97162738621518, 52.13420609229578], [5.0670172780675005, 52.12047027041598], [5.162345838520439, 52.106650524434265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.1623458&lt;dd&gt;Longitude: 52.106651&lt;dd&gt;Azimuth: 79.295603\u00b0&lt;dd&gt;Altitude: 41.991458\u00b0&lt;dd&gt;Slant Range: 788.99895km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.162345838520439, 52.106650524434265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.685092788898214, 52.17490909102275], [4.780664833407295, 52.161425594394856], [4.8761764688463245, 52.14785789762659], [4.97162738621518, 52.13420609229578], [5.0670172780675005, 52.12047027041598], [5.162345838520439, 52.106650524434265], [5.257612763246029, 52.09274694722776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.2576128&lt;dd&gt;Longitude: 52.092747&lt;dd&gt;Azimuth: 79.511917\u00b0&lt;dd&gt;Altitude: 41.62575\u00b0&lt;dd&gt;Slant Range: 793.75904km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.257612763246029, 52.09274694722776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.780664833407295, 52.161425594394856], [4.8761764688463245, 52.14785789762659], [4.97162738621518, 52.13420609229578], [5.0670172780675005, 52.12047027041598], [5.162345838520439, 52.106650524434265], [5.257612763246029, 52.09274694722776], [5.352817749490807, 52.07875963210107]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.3528177&lt;dd&gt;Longitude: 52.07876&lt;dd&gt;Azimuth: 79.723321\u00b0&lt;dd&gt;Altitude: 41.263657\u00b0&lt;dd&gt;Slant Range: 798.55159km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.352817749490807, 52.07875963210107]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.8761764688463245, 52.14785789762659], [4.97162738621518, 52.13420609229578], [5.0670172780675005, 52.12047027041598], [5.162345838520439, 52.106650524434265], [5.257612763246029, 52.09274694722776], [5.352817749490807, 52.07875963210107], [5.447960496060622, 52.06468867278369]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.4479605&lt;dd&gt;Longitude: 52.064689&lt;dd&gt;Azimuth: 79.929977\u00b0&lt;dd&gt;Altitude: 40.905158\u00b0&lt;dd&gt;Slant Range: 803.376km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.447960496060622, 52.06468867278369]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.97162738621518, 52.13420609229578], [5.0670172780675005, 52.12047027041598], [5.162345838520439, 52.106650524434265], [5.257612763246029, 52.09274694722776], [5.352817749490807, 52.07875963210107], [5.447960496060622, 52.06468867278369], [5.5430407033496145, 52.0505341634268]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.5430407&lt;dd&gt;Longitude: 52.050534&lt;dd&gt;Azimuth: 80.132043\u00b0&lt;dd&gt;Altitude: 40.550228\u00b0&lt;dd&gt;Slant Range: 808.2317km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.5430407033496145, 52.0505341634268]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.0670172780675005, 52.12047027041598], [5.162345838520439, 52.106650524434265], [5.257612763246029, 52.09274694722776], [5.352817749490807, 52.07875963210107], [5.447960496060622, 52.06468867278369], [5.5430407033496145, 52.0505341634268], [5.638058073320168, 52.03629619860051]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.6380581&lt;dd&gt;Longitude: 52.036296&lt;dd&gt;Azimuth: 80.329667\u00b0&lt;dd&gt;Altitude: 40.198843\u00b0&lt;dd&gt;Slant Range: 813.11813km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.638058073320168, 52.03629619860051]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.162345838520439, 52.106650524434265], [5.257612763246029, 52.09274694722776], [5.352817749490807, 52.07875963210107], [5.447960496060622, 52.06468867278369], [5.5430407033496145, 52.0505341634268], [5.638058073320168, 52.03629619860051], [5.733012309523492, 52.021974873291285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.7330123&lt;dd&gt;Longitude: 52.021975&lt;dd&gt;Azimuth: 80.522993\u00b0&lt;dd&gt;Altitude: 39.850977\u00b0&lt;dd&gt;Slant Range: 818.03474km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.733012309523492, 52.021974873291285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.257612763246029, 52.09274694722776], [5.352817749490807, 52.07875963210107], [5.447960496060622, 52.06468867278369], [5.5430407033496145, 52.0505341634268], [5.638058073320168, 52.03629619860051], [5.733012309523492, 52.021974873291285], [5.827903117091049, 52.00757028289867]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.8279031&lt;dd&gt;Longitude: 52.00757&lt;dd&gt;Azimuth: 80.712158\u00b0&lt;dd&gt;Altitude: 39.506602\u00b0&lt;dd&gt;Slant Range: 822.98096km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.827903117091049, 52.00757028289867]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.352817749490807, 52.07875963210107], [5.447960496060622, 52.06468867278369], [5.5430407033496145, 52.0505341634268], [5.638058073320168, 52.03629619860051], [5.733012309523492, 52.021974873291285], [5.827903117091049, 52.00757028289867], [5.922730202751525, 51.99308252323293]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 5.9227302&lt;dd&gt;Longitude: 51.993083&lt;dd&gt;Azimuth: 80.897294\u00b0&lt;dd&gt;Altitude: 39.16569\u00b0&lt;dd&gt;Slant Range: 827.95628km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.922730202751525, 51.99308252323293]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.447960496060622, 52.06468867278369], [5.5430407033496145, 52.0505341634268], [5.638058073320168, 52.03629619860051], [5.733012309523492, 52.021974873291285], [5.827903117091049, 52.00757028289867], [5.922730202751525, 51.99308252323293], [6.017493274818949, 51.978511690511674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 6.0174933&lt;dd&gt;Longitude: 51.978512&lt;dd&gt;Azimuth: 81.078528\u00b0&lt;dd&gt;Altitude: 38.828212\u00b0&lt;dd&gt;Slant Range: 832.96016km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.017493274818949, 51.978511690511674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.5430407033496145, 52.0505341634268], [5.638058073320168, 52.03629619860051], [5.733012309523492, 52.021974873291285], [5.827903117091049, 52.00757028289867], [5.922730202751525, 51.99308252323293], [6.017493274818949, 51.978511690511674], [6.112192043213527, 51.96385788135731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 6.112192&lt;dd&gt;Longitude: 51.963858&lt;dd&gt;Azimuth: 81.25598\u00b0&lt;dd&gt;Altitude: 38.494138\u00b0&lt;dd&gt;Slant Range: 837.99208km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.112192043213527, 51.96385788135731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.638058073320168, 52.03629619860051], [5.733012309523492, 52.021974873291285], [5.827903117091049, 52.00757028289867], [5.922730202751525, 51.99308252323293], [6.017493274818949, 51.978511690511674], [6.112192043213527, 51.96385788135731], [6.2068262194472705, 51.94912119279416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2368&lt;dd&gt;Latitude: 6.2068262&lt;dd&gt;Longitude: 51.949121&lt;dd&gt;Azimuth: 81.429768\u00b0&lt;dd&gt;Altitude: 38.163438\u00b0&lt;dd&gt;Slant Range: 843.05154km&quot;, &quot;name&quot;: &quot;STARLINK-2368&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.2068262194472705, 51.94912119279416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.8371579&lt;dd&gt;Longitude: 53.19604&lt;dd&gt;Azimuth: 305.47313\u00b0&lt;dd&gt;Altitude: 55.19114\u00b0&lt;dd&gt;Slant Range: 660.89327km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968], [-6.736797441365772, 53.19723470825843]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.7367974&lt;dd&gt;Longitude: 53.197235&lt;dd&gt;Azimuth: 306.09076\u00b0&lt;dd&gt;Altitude: 55.64101\u00b0&lt;dd&gt;Slant Range: 657.72197km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.736797441365772, 53.19723470825843]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968], [-6.736797441365772, 53.19723470825843], [-6.636431385741289, 53.19833786689795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.6364314&lt;dd&gt;Longitude: 53.198338&lt;dd&gt;Azimuth: 306.72871\u00b0&lt;dd&gt;Altitude: 56.091665\u00b0&lt;dd&gt;Slant Range: 654.60964km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.636431385741289, 53.19833786689795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968], [-6.736797441365772, 53.19723470825843], [-6.636431385741289, 53.19833786689795], [-6.53606019164452, 53.199349431486525]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.5360602&lt;dd&gt;Longitude: 53.199349&lt;dd&gt;Azimuth: 307.38785\u00b0&lt;dd&gt;Altitude: 56.54286\u00b0&lt;dd&gt;Slant Range: 651.55711km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.53606019164452, 53.199349431486525]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968], [-6.736797441365772, 53.19723470825843], [-6.636431385741289, 53.19833786689795], [-6.53606019164452, 53.199349431486525], [-6.435684303905017, 53.200269394401865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.4356843&lt;dd&gt;Longitude: 53.200269&lt;dd&gt;Azimuth: 308.06906\u00b0&lt;dd&gt;Altitude: 56.994333\u00b0&lt;dd&gt;Slant Range: 648.56525km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.435684303905017, 53.200269394401865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968], [-6.736797441365772, 53.19723470825843], [-6.636431385741289, 53.19833786689795], [-6.53606019164452, 53.199349431486525], [-6.435684303905017, 53.200269394401865], [-6.335304167489835, 53.20109774871143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.3353042&lt;dd&gt;Longitude: 53.201098&lt;dd&gt;Azimuth: 308.7733\u00b0&lt;dd&gt;Altitude: 57.445802\u00b0&lt;dd&gt;Slant Range: 645.63489km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.335304167489835, 53.20109774871143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.837157913850647, 53.19603996387968], [-6.736797441365772, 53.19723470825843], [-6.636431385741289, 53.19833786689795], [-6.53606019164452, 53.199349431486525], [-6.435684303905017, 53.200269394401865], [-6.335304167489835, 53.20109774871143], [-6.234920227500377, 53.20183448817273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.2349202&lt;dd&gt;Longitude: 53.201834&lt;dd&gt;Azimuth: 309.50153\u00b0&lt;dd&gt;Altitude: 57.896966\u00b0&lt;dd&gt;Slant Range: 642.76689km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.234920227500377, 53.20183448817273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.736797441365772, 53.19723470825843], [-6.636431385741289, 53.19833786689795], [-6.53606019164452, 53.199349431486525], [-6.435684303905017, 53.200269394401865], [-6.335304167489835, 53.20109774871143], [-6.234920227500377, 53.20183448817273], [-6.134532929144428, 53.202479607233414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.1345329&lt;dd&gt;Longitude: 53.20248&lt;dd&gt;Azimuth: 310.25477\u00b0&lt;dd&gt;Altitude: 58.347505\u00b0&lt;dd&gt;Slant Range: 639.96208km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.134532929144428, 53.202479607233414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.636431385741289, 53.19833786689795], [-6.53606019164452, 53.199349431486525], [-6.435684303905017, 53.200269394401865], [-6.335304167489835, 53.20109774871143], [-6.234920227500377, 53.20183448817273], [-6.134532929144428, 53.202479607233414], [-6.034142717745264, 53.20303310103153]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -6.0341427&lt;dd&gt;Longitude: 53.203033&lt;dd&gt;Azimuth: 311.03405\u00b0&lt;dd&gt;Altitude: 58.797077\u00b0&lt;dd&gt;Slant Range: 637.2213km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.034142717745264, 53.20303310103153]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.53606019164452, 53.199349431486525], [-6.435684303905017, 53.200269394401865], [-6.335304167489835, 53.20109774871143], [-6.234920227500377, 53.20183448817273], [-6.134532929144428, 53.202479607233414], [-6.034142717745264, 53.20303310103153], [-5.9337500386994435, 53.203494965395905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.93375&lt;dd&gt;Longitude: 53.203495&lt;dd&gt;Azimuth: 311.84048\u00b0&lt;dd&gt;Altitude: 59.245318\u00b0&lt;dd&gt;Slant Range: 634.54539km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.9337500386994435, 53.203494965395905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.435684303905017, 53.200269394401865], [-6.335304167489835, 53.20109774871143], [-6.234920227500377, 53.20183448817273], [-6.134532929144428, 53.202479607233414], [-6.034142717745264, 53.20303310103153], [-5.9337500386994435, 53.203494965395905], [-5.833355337492782, 53.203865196845946]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.8333553&lt;dd&gt;Longitude: 53.203865&lt;dd&gt;Azimuth: 312.67515\u00b0&lt;dd&gt;Altitude: 59.69184\u00b0&lt;dd&gt;Slant Range: 631.93516km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.833355337492782, 53.203865196845946]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.335304167489835, 53.20109774871143], [-6.234920227500377, 53.20183448817273], [-6.134532929144428, 53.202479607233414], [-6.034142717745264, 53.20303310103153], [-5.9337500386994435, 53.203494965395905], [-5.833355337492782, 53.203865196845946], [-5.732959059660993, 53.204143792592056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.7329591&lt;dd&gt;Longitude: 53.204144&lt;dd&gt;Azimuth: 313.53923\u00b0&lt;dd&gt;Altitude: 60.136232\u00b0&lt;dd&gt;Slant Range: 629.39145km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.732959059660993, 53.204143792592056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.234920227500377, 53.20183448817273], [-6.134532929144428, 53.202479607233414], [-6.034142717745264, 53.20303310103153], [-5.9337500386994435, 53.203494965395905], [-5.833355337492782, 53.203865196845946], [-5.732959059660993, 53.204143792592056], [-5.632561650794316, 53.204330750535604]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.6325617&lt;dd&gt;Longitude: 53.204331&lt;dd&gt;Azimuth: 314.4339\u00b0&lt;dd&gt;Altitude: 60.578057\u00b0&lt;dd&gt;Slant Range: 626.91506km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.632561650794316, 53.204330750535604]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.134532929144428, 53.202479607233414], [-6.034142717745264, 53.20303310103153], [-5.9337500386994435, 53.203494965395905], [-5.833355337492782, 53.203865196845946], [-5.732959059660993, 53.204143792592056], [-5.632561650794316, 53.204330750535604], [-5.532163556517952, 53.20442606926907]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.5321636&lt;dd&gt;Longitude: 53.204426&lt;dd&gt;Azimuth: 315.36035\u00b0&lt;dd&gt;Altitude: 61.016853\u00b0&lt;dd&gt;Slant Range: 624.5068km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.532163556517952, 53.20442606926907]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.034142717745264, 53.20303310103153], [-5.9337500386994435, 53.203494965395905], [-5.833355337492782, 53.203865196845946], [-5.732959059660993, 53.204143792592056], [-5.632561650794316, 53.204330750535604], [-5.532163556517952, 53.20442606926907], [-5.431765222470488, 53.20442974807603]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.4317652&lt;dd&gt;Longitude: 53.20443&lt;dd&gt;Azimuth: 316.31983\u00b0&lt;dd&gt;Altitude: 61.452128\u00b0&lt;dd&gt;Slant Range: 622.16746km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.431765222470488, 53.20442974807603]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.9337500386994435, 53.203494965395905], [-5.833355337492782, 53.203865196845946], [-5.732959059660993, 53.204143792592056], [-5.632561650794316, 53.204330750535604], [-5.532163556517952, 53.20442606926907], [-5.431765222470488, 53.20442974807603], [-5.331367094306459, 53.20434178693124]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.3313671&lt;dd&gt;Longitude: 53.204342&lt;dd&gt;Azimuth: 317.31357\u00b0&lt;dd&gt;Altitude: 61.883365\u00b0&lt;dd&gt;Slant Range: 619.89783km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.331367094306459, 53.20434178693124]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.833355337492782, 53.203865196845946], [-5.732959059660993, 53.204143792592056], [-5.632561650794316, 53.204330750535604], [-5.532163556517952, 53.20442606926907], [-5.431765222470488, 53.20442974807603], [-5.331367094306459, 53.20434178693124], [-5.230969617668065, 53.20416218650057]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.2309696&lt;dd&gt;Longitude: 53.204162&lt;dd&gt;Azimuth: 318.34282\u00b0&lt;dd&gt;Altitude: 62.310016\u00b0&lt;dd&gt;Slant Range: 617.69867km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.230969617668065, 53.20416218650057]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.732959059660993, 53.204143792592056], [-5.632561650794316, 53.204330750535604], [-5.532163556517952, 53.20442606926907], [-5.431765222470488, 53.20442974807603], [-5.331367094306459, 53.20434178693124], [-5.230969617668065, 53.20416218650057], [-5.130573238181906, 53.20389094814108]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.1305732&lt;dd&gt;Longitude: 53.203891&lt;dd&gt;Azimuth: 319.40885\u00b0&lt;dd&gt;Altitude: 62.731505\u00b0&lt;dd&gt;Slant Range: 615.57074km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.130573238181906, 53.20389094814108]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.632561650794316, 53.204330750535604], [-5.532163556517952, 53.20442606926907], [-5.431765222470488, 53.20442974807603], [-5.331367094306459, 53.20434178693124], [-5.230969617668065, 53.20416218650057], [-5.130573238181906, 53.20389094814108], [-5.030178401438146, 53.203528073900905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -5.0301784&lt;dd&gt;Longitude: 53.203528&lt;dd&gt;Azimuth: 320.51289\u00b0&lt;dd&gt;Altitude: 63.147224\u00b0&lt;dd&gt;Slant Range: 613.51479km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.030178401438146, 53.203528073900905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.532163556517952, 53.20442606926907], [-5.431765222470488, 53.20442974807603], [-5.331367094306459, 53.20434178693124], [-5.230969617668065, 53.20416218650057], [-5.130573238181906, 53.20389094814108], [-5.030178401438146, 53.203528073900905], [-4.9297855529835655, 53.20307356651913]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.9297856&lt;dd&gt;Longitude: 53.203074&lt;dd&gt;Azimuth: 321.65617\u00b0&lt;dd&gt;Altitude: 63.556536\u00b0&lt;dd&gt;Slant Range: 611.53154km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.9297855529835655, 53.20307356651913]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.431765222470488, 53.20442974807603], [-5.331367094306459, 53.20434178693124], [-5.230969617668065, 53.20416218650057], [-5.130573238181906, 53.20389094814108], [-5.030178401438146, 53.203528073900905], [-4.9297855529835655, 53.20307356651913], [-4.82939513829981, 53.20252742942583]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.8293951&lt;dd&gt;Longitude: 53.202527&lt;dd&gt;Azimuth: 322.83987\u00b0&lt;dd&gt;Altitude: 63.958774\u00b0&lt;dd&gt;Slant Range: 609.62171km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.82939513829981, 53.20252742942583]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.331367094306459, 53.20434178693124], [-5.230969617668065, 53.20416218650057], [-5.130573238181906, 53.20389094814108], [-5.030178401438146, 53.203528073900905], [-4.9297855529835655, 53.20307356651913], [-4.82939513829981, 53.20252742942583], [-4.729007602800838, 53.20188966674176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.7290076&lt;dd&gt;Longitude: 53.20189&lt;dd&gt;Azimuth: 324.06513\u00b0&lt;dd&gt;Altitude: 64.353238\u00b0&lt;dd&gt;Slant Range: 607.78599km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.729007602800838, 53.20188966674176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.230969617668065, 53.20416218650057], [-5.130573238181906, 53.20389094814108], [-5.030178401438146, 53.203528073900905], [-4.9297855529835655, 53.20307356651913], [-4.82939513829981, 53.20252742942583], [-4.729007602800838, 53.20188966674176], [-4.62862339180489, 53.2011602832784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.6286234&lt;dd&gt;Longitude: 53.20116&lt;dd&gt;Azimuth: 325.33302\u00b0&lt;dd&gt;Altitude: 64.7392\u00b0&lt;dd&gt;Slant Range: 606.02506km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.62862339180489, 53.2011602832784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.130573238181906, 53.20389094814108], [-5.030178401438146, 53.203528073900905], [-4.9297855529835655, 53.20307356651913], [-4.82939513829981, 53.20252742942583], [-4.729007602800838, 53.20188966674176], [-4.62862339180489, 53.2011602832784], [-4.528242950536087, 53.200339284537584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.528243&lt;dd&gt;Longitude: 53.200339&lt;dd&gt;Azimuth: 326.6445\u00b0&lt;dd&gt;Altitude: 65.115904\u00b0&lt;dd&gt;Slant Range: 604.33957km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.528242950536087, 53.200339284537584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.030178401438146, 53.203528073900905], [-4.9297855529835655, 53.20307356651913], [-4.82939513829981, 53.20252742942583], [-4.729007602800838, 53.20188966674176], [-4.62862339180489, 53.2011602832784], [-4.528242950536087, 53.200339284537584], [-4.427866724103642, 53.19942667671149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.4278667&lt;dd&gt;Longitude: 53.199427&lt;dd&gt;Azimuth: 328.00045\u00b0&lt;dd&gt;Altitude: 65.482563\u00b0&lt;dd&gt;Slant Range: 602.73015km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.427866724103642, 53.19942667671149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.9297855529835655, 53.20307356651913], [-4.82939513829981, 53.20252742942583], [-4.729007602800838, 53.20188966674176], [-4.62862339180489, 53.2011602832784], [-4.528242950536087, 53.200339284537584], [-4.427866724103642, 53.19942667671149], [-4.327495157485118, 53.19842246668214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.3274952&lt;dd&gt;Longitude: 53.198422&lt;dd&gt;Azimuth: 329.40159\u00b0&lt;dd&gt;Altitude: 65.838367\u00b0&lt;dd&gt;Slant Range: 601.19743km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.327495157485118, 53.19842246668214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.82939513829981, 53.20252742942583], [-4.729007602800838, 53.20188966674176], [-4.62862339180489, 53.2011602832784], [-4.528242950536087, 53.200339284537584], [-4.427866724103642, 53.19942667671149], [-4.327495157485118, 53.19842246668214], [-4.227128695518516, 53.19732666202148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.2271287&lt;dd&gt;Longitude: 53.197327&lt;dd&gt;Azimuth: 330.84846\u00b0&lt;dd&gt;Altitude: 66.182482\u00b0&lt;dd&gt;Slant Range: 599.74198km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.227128695518516, 53.19732666202148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.729007602800838, 53.20188966674176], [-4.62862339180489, 53.2011602832784], [-4.528242950536087, 53.200339284537584], [-4.427866724103642, 53.19942667671149], [-4.327495157485118, 53.19842246668214], [-4.227128695518516, 53.19732666202148], [-4.126767782890799, 53.196139270990855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.1267678&lt;dd&gt;Longitude: 53.196139&lt;dd&gt;Azimuth: 332.34144\u00b0&lt;dd&gt;Altitude: 66.514054\u00b0&lt;dd&gt;Slant Range: 598.36438km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.126767782890799, 53.196139270990855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.62862339180489, 53.2011602832784], [-4.528242950536087, 53.200339284537584], [-4.427866724103642, 53.19942667671149], [-4.327495157485118, 53.19842246668214], [-4.227128695518516, 53.19732666202148], [-4.126767782890799, 53.196139270990855], [-4.026412864110362, 53.19486030254077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -4.0264129&lt;dd&gt;Longitude: 53.19486&lt;dd&gt;Azimuth: 333.88067\u00b0&lt;dd&gt;Altitude: 66.832213\u00b0&lt;dd&gt;Slant Range: 597.06517km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.026412864110362, 53.19486030254077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.528242950536087, 53.200339284537584], [-4.427866724103642, 53.19942667671149], [-4.327495157485118, 53.19842246668214], [-4.227128695518516, 53.19732666202148], [-4.126767782890799, 53.196139270990855], [-4.026412864110362, 53.19486030254077], [-3.926064383516722, 53.19348976631056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.9260644&lt;dd&gt;Longitude: 53.19349&lt;dd&gt;Azimuth: 335.46601\u00b0&lt;dd&gt;Altitude: 67.136075\u00b0&lt;dd&gt;Slant Range: 595.84485km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.926064383516722, 53.19348976631056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.427866724103642, 53.19942667671149], [-4.327495157485118, 53.19842246668214], [-4.227128695518516, 53.19732666202148], [-4.126767782890799, 53.196139270990855], [-4.026412864110362, 53.19486030254077], [-3.926064383516722, 53.19348976631056], [-3.8257227852437827, 53.19202767262808]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.8257228&lt;dd&gt;Longitude: 53.192028&lt;dd&gt;Azimuth: 337.09708\u00b0&lt;dd&gt;Altitude: 67.424755\u00b0&lt;dd&gt;Slant Range: 594.70392km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8257227852437827, 53.19202767262808]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.327495157485118, 53.19842246668214], [-4.227128695518516, 53.19732666202148], [-4.126767782890799, 53.196139270990855], [-4.026412864110362, 53.19486030254077], [-3.926064383516722, 53.19348976631056], [-3.8257227852437827, 53.19202767262808], [-3.7253885132248676, 53.190474032509194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.7253885&lt;dd&gt;Longitude: 53.190474&lt;dd&gt;Azimuth: 338.77313\u00b0&lt;dd&gt;Altitude: 67.697364\u00b0&lt;dd&gt;Slant Range: 593.64284km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7253885132248676, 53.190474032509194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.227128695518516, 53.19732666202148], [-4.126767782890799, 53.196139270990855], [-4.026412864110362, 53.19486030254077], [-3.926064383516722, 53.19348976631056], [-3.8257227852437827, 53.19202767262808], [-3.7253885132248676, 53.190474032509194], [-3.625062011160764, 53.1888288576575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.625062&lt;dd&gt;Longitude: 53.188829&lt;dd&gt;Azimuth: 340.4931\u00b0&lt;dd&gt;Altitude: 67.953024\u00b0&lt;dd&gt;Slant Range: 592.66203km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.625062011160764, 53.1888288576575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.126767782890799, 53.196139270990855], [-4.026412864110362, 53.19486030254077], [-3.926064383516722, 53.19348976631056], [-3.8257227852437827, 53.19202767262808], [-3.7253885132248676, 53.190474032509194], [-3.625062011160764, 53.1888288576575], [-3.524743722528603, 53.18709216046387]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.5247437&lt;dd&gt;Longitude: 53.187092&lt;dd&gt;Azimuth: 342.25554\u00b0&lt;dd&gt;Altitude: 68.190868\u00b0&lt;dd&gt;Slant Range: 591.7619km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.524743722528603, 53.18709216046387]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.026412864110362, 53.19486030254077], [-3.926064383516722, 53.19348976631056], [-3.8257227852437827, 53.19202767262808], [-3.7253885132248676, 53.190474032509194], [-3.625062011160764, 53.1888288576575], [-3.524743722528603, 53.18709216046387], [-3.4244340905488566, 53.185263954005904]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.4244341&lt;dd&gt;Longitude: 53.185264&lt;dd&gt;Azimuth: 344.05862\u00b0&lt;dd&gt;Altitude: 68.410059\u00b0&lt;dd&gt;Slant Range: 590.94281km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4244340905488566, 53.185263954005904]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.926064383516722, 53.19348976631056], [-3.8257227852437827, 53.19202767262808], [-3.7253885132248676, 53.190474032509194], [-3.625062011160764, 53.1888288576575], [-3.524743722528603, 53.18709216046387], [-3.4244340905488566, 53.185263954005904], [-3.3241335581843985, 53.18334425204755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.3241336&lt;dd&gt;Longitude: 53.183344&lt;dd&gt;Azimuth: 345.90009\u00b0&lt;dd&gt;Altitude: 68.609789\u00b0&lt;dd&gt;Slant Range: 590.20511km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3241335581843985, 53.18334425204755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8257227852437827, 53.19202767262808], [-3.7253885132248676, 53.190474032509194], [-3.625062011160764, 53.1888288576575], [-3.524743722528603, 53.18709216046387], [-3.4244340905488566, 53.185263954005904], [-3.3241335581843985, 53.18334425204755], [-3.2238425681175005, 53.18133306903847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.2238426&lt;dd&gt;Longitude: 53.181333&lt;dd&gt;Azimuth: 347.7773\u00b0&lt;dd&gt;Altitude: 68.789295\u00b0&lt;dd&gt;Slant Range: 589.54909km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2238425681175005, 53.18133306903847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7253885132248676, 53.190474032509194], [-3.625062011160764, 53.1888288576575], [-3.524743722528603, 53.18709216046387], [-3.4244340905488566, 53.185263954005904], [-3.3241335581843985, 53.18334425204755], [-3.2238425681175005, 53.18133306903847], [-3.12356156274823, 53.17923042011366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.1235616&lt;dd&gt;Longitude: 53.17923&lt;dd&gt;Azimuth: 349.68719\u00b0&lt;dd&gt;Altitude: 68.947868\u00b0&lt;dd&gt;Slant Range: 588.97505km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.12356156274823, 53.17923042011366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.625062011160764, 53.1888288576575], [-3.524743722528603, 53.18709216046387], [-3.4244340905488566, 53.185263954005904], [-3.3241335581843985, 53.18334425204755], [-3.2238425681175005, 53.18133306903847], [-3.12356156274823, 53.17923042011366], [-3.0232909841670215, 53.17703632109284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -3.023291&lt;dd&gt;Longitude: 53.177036&lt;dd&gt;Azimuth: 351.6263\u00b0&lt;dd&gt;Altitude: 69.08486\u00b0&lt;dd&gt;Slant Range: 588.4832km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0232909841670215, 53.17703632109284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.524743722528603, 53.18709216046387], [-3.4244340905488566, 53.185263954005904], [-3.3241335581843985, 53.18334425204755], [-3.2238425681175005, 53.18133306903847], [-3.12356156274823, 53.17923042011366], [-3.0232909841670215, 53.17703632109284], [-2.9230312741504263, 53.17475078847967]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.9230313&lt;dd&gt;Longitude: 53.174751&lt;dd&gt;Azimuth: 353.5908\u00b0&lt;dd&gt;Altitude: 69.199697\u00b0&lt;dd&gt;Slant Range: 588.07377km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9230312741504263, 53.17475078847967]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4244340905488566, 53.185263954005904], [-3.3241335581843985, 53.18334425204755], [-3.2238425681175005, 53.18133306903847], [-3.12356156274823, 53.17923042011366], [-3.0232909841670215, 53.17703632109284], [-2.9230312741504263, 53.17475078847967], [-2.822782874157323, 53.17237383946153]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.8227829&lt;dd&gt;Longitude: 53.172374&lt;dd&gt;Azimuth: 355.57652\u00b0&lt;dd&gt;Altitude: 69.291886\u00b0&lt;dd&gt;Slant Range: 587.74692km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.822782874157323, 53.17237383946153]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3241335581843985, 53.18334425204755], [-3.2238425681175005, 53.18133306903847], [-3.12356156274823, 53.17923042011366], [-3.0232909841670215, 53.17703632109284], [-2.9230312741504263, 53.17475078847967], [-2.822782874157323, 53.17237383946153], [-2.7225462252865755, 53.16990549190842]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.7225462&lt;dd&gt;Longitude: 53.169905&lt;dd&gt;Azimuth: 357.579\u00b0&lt;dd&gt;Altitude: 69.361023\u00b0&lt;dd&gt;Slant Range: 587.5028km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7225462252865755, 53.16990549190842]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2238425681175005, 53.18133306903847], [-3.12356156274823, 53.17923042011366], [-3.0232909841670215, 53.17703632109284], [-2.9230312741504263, 53.17475078847967], [-2.822782874157323, 53.17237383946153], [-2.7225462252865755, 53.16990549190842], [-2.622321768297086, 53.1673457643728]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.6223218&lt;dd&gt;Longitude: 53.167346&lt;dd&gt;Azimuth: 359.59354\u00b0&lt;dd&gt;Altitude: 69.406801\u00b0&lt;dd&gt;Slant Range: 587.3415km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.622321768297086, 53.1673457643728]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.12356156274823, 53.17923042011366], [-3.0232909841670215, 53.17703632109284], [-2.9230312741504263, 53.17475078847967], [-2.822782874157323, 53.17237383946153], [-2.7225462252865755, 53.16990549190842], [-2.622321768297086, 53.1673457643728], [-2.522109943571737, 53.16469467608841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.5221099&lt;dd&gt;Longitude: 53.164695&lt;dd&gt;Azimuth: 1.6152679\u00b0&lt;dd&gt;Altitude: 69.429014\u00b0&lt;dd&gt;Slant Range: 587.26309km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.522109943571737, 53.16469467608841]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0232909841670215, 53.17703632109284], [-2.9230312741504263, 53.17475078847967], [-2.822782874157323, 53.17237383946153], [-2.7225462252865755, 53.16990549190842], [-2.622321768297086, 53.1673457643728], [-2.522109943571737, 53.16469467608841], [-2.4219111911130944, 53.161952246969896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.4219112&lt;dd&gt;Longitude: 53.161952&lt;dd&gt;Azimuth: 3.6391954\u00b0&lt;dd&gt;Altitude: 69.427562\u00b0&lt;dd&gt;Slant Range: 587.26761km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.4219111911130944, 53.161952246969896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9230312741504263, 53.17475078847967], [-2.822782874157323, 53.17237383946153], [-2.7225462252865755, 53.16990549190842], [-2.622321768297086, 53.1673457643728], [-2.522109943571737, 53.16469467608841], [-2.4219111911130944, 53.161952246969896], [-2.3217259505309387, 53.159118497612]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.321726&lt;dd&gt;Longitude: 53.159118&lt;dd&gt;Azimuth: 5.6603129\u00b0&lt;dd&gt;Altitude: 69.402451\u00b0&lt;dd&gt;Slant Range: 587.35506km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3217259505309387, 53.159118497612]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.822782874157323, 53.17237383946153], [-2.7225462252865755, 53.16990549190842], [-2.622321768297086, 53.1673457643728], [-2.522109943571737, 53.16469467608841], [-2.4219111911130944, 53.161952246969896], [-2.3217259505309387, 53.159118497612], [-2.221554661029108, 53.15619344928866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.2215547&lt;dd&gt;Longitude: 53.156193&lt;dd&gt;Azimuth: 7.6736488\u00b0&lt;dd&gt;Altitude: 69.353794\u00b0&lt;dd&gt;Slant Range: 587.52539km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.221554661029108, 53.15619344928866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7225462252865755, 53.16990549190842], [-2.622321768297086, 53.1673457643728], [-2.522109943571737, 53.16469467608841], [-2.4219111911130944, 53.161952246969896], [-2.3217259505309387, 53.159118497612], [-2.221554661029108, 53.15619344928866], [-2.1213977613828816, 53.15317712395241]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.1213978&lt;dd&gt;Longitude: 53.153177&lt;dd&gt;Azimuth: 9.6743458\u00b0&lt;dd&gt;Altitude: 69.28181\u00b0&lt;dd&gt;Slant Range: 587.77855km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.1213977613828816, 53.15317712395241]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.622321768297086, 53.1673457643728], [-2.522109943571737, 53.16469467608841], [-2.4219111911130944, 53.161952246969896], [-2.3217259505309387, 53.159118497612], [-2.221554661029108, 53.15619344928866], [-2.1213977613828816, 53.15317712395241], [-2.021255689944549, 53.15006954423355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -2.0212557&lt;dd&gt;Longitude: 53.15007&lt;dd&gt;Azimuth: 11.65773\u00b0&lt;dd&gt;Altitude: 69.186817\u00b0&lt;dd&gt;Slant Range: 588.11441km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.021255689944549, 53.15006954423355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.522109943571737, 53.16469467608841], [-2.4219111911130944, 53.161952246969896], [-2.3217259505309387, 53.159118497612], [-2.221554661029108, 53.15619344928866], [-2.1213977613828816, 53.15317712395241], [-2.021255689944549, 53.15006954423355], [-1.9211288846095715, 53.146870733439066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.9211289&lt;dd&gt;Longitude: 53.146871&lt;dd&gt;Azimuth: 13.619371\u00b0&lt;dd&gt;Altitude: 69.069231\u00b0&lt;dd&gt;Slant Range: 588.53284km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9211288846095715, 53.146870733439066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.4219111911130944, 53.161952246969896], [-2.3217259505309387, 53.159118497612], [-2.221554661029108, 53.15619344928866], [-2.1213977613828816, 53.15317712395241], [-2.021255689944549, 53.15006954423355], [-1.9211288846095715, 53.146870733439066], [-1.8210177828254606, 53.14358071555216]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.8210178&lt;dd&gt;Longitude: 53.143581&lt;dd&gt;Azimuth: 15.555141\u00b0&lt;dd&gt;Altitude: 68.929555\u00b0&lt;dd&gt;Slant Range: 589.03366km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8210177828254606, 53.14358071555216]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3217259505309387, 53.159118497612], [-2.221554661029108, 53.15619344928866], [-2.1213977613828816, 53.15317712395241], [-2.021255689944549, 53.15006954423355], [-1.9211288846095715, 53.146870733439066], [-1.8210177828254606, 53.14358071555216], [-1.7209228215533823, 53.140199515231025]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.7209228&lt;dd&gt;Longitude: 53.1402&lt;dd&gt;Azimuth: 17.461251\u00b0&lt;dd&gt;Altitude: 68.768372\u00b0&lt;dd&gt;Slant Range: 589.61666km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7209228215533823, 53.140199515231025]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.221554661029108, 53.15619344928866], [-2.1213977613828816, 53.15317712395241], [-2.021255689944549, 53.15006954423355], [-1.9211288846095715, 53.146870733439066], [-1.8210177828254606, 53.14358071555216], [-1.7209228215533823, 53.140199515231025], [-1.62084443728055, 53.136727157808096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.6208444&lt;dd&gt;Longitude: 53.136727&lt;dd&gt;Azimuth: 19.334291\u00b0&lt;dd&gt;Altitude: 68.586337\u00b0&lt;dd&gt;Slant Range: 590.28159km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.62084443728055, 53.136727157808096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.1213977613828816, 53.15317712395241], [-2.021255689944549, 53.15006954423355], [-1.9211288846095715, 53.146870733439066], [-1.8210177828254606, 53.14358071555216], [-1.7209228215533823, 53.140199515231025], [-1.62084443728055, 53.136727157808096], [-1.5207830659886208, 53.1331636692892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.5207831&lt;dd&gt;Longitude: 53.133164&lt;dd&gt;Azimuth: 21.171246\u00b0&lt;dd&gt;Altitude: 68.384167\u00b0&lt;dd&gt;Slant Range: 591.02819km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5207830659886208, 53.1331636692892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.021255689944549, 53.15006954423355], [-1.9211288846095715, 53.146870733439066], [-1.8210177828254606, 53.14358071555216], [-1.7209228215533823, 53.140199515231025], [-1.62084443728055, 53.136727157808096], [-1.5207830659886208, 53.1331636692892], [-1.4207391431543328, 53.129509076352356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.4207391&lt;dd&gt;Longitude: 53.129509&lt;dd&gt;Azimuth: 22.969514\u00b0&lt;dd&gt;Altitude: 68.162632\u00b0&lt;dd&gt;Slant Range: 591.85613km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4207391431543328, 53.129509076352356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9211288846095715, 53.146870733439066], [-1.8210177828254606, 53.14358071555216], [-1.7209228215533823, 53.140199515231025], [-1.62084443728055, 53.136727157808096], [-1.5207830659886208, 53.1331636692892], [-1.4207391431543328, 53.129509076352356], [-1.320713103721872, 53.12576340634696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.3207131&lt;dd&gt;Longitude: 53.125763&lt;dd&gt;Azimuth: 24.726902\u00b0&lt;dd&gt;Altitude: 67.922541\u00b0&lt;dd&gt;Slant Range: 592.76509km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.320713103721872, 53.12576340634696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8210177828254606, 53.14358071555216], [-1.7209228215533823, 53.140199515231025], [-1.62084443728055, 53.136727157808096], [-1.5207830659886208, 53.1331636692892], [-1.4207391431543328, 53.129509076352356], [-1.320713103721872, 53.12576340634696], [-1.2207053821100475, 53.12192668729292]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.2207054&lt;dd&gt;Longitude: 53.121927&lt;dd&gt;Azimuth: 26.441623\u00b0&lt;dd&gt;Altitude: 67.664739\u00b0&lt;dd&gt;Slant Range: 593.75467km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2207053821100475, 53.12192668729292]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7209228215533823, 53.140199515231025], [-1.62084443728055, 53.136727157808096], [-1.5207830659886208, 53.1331636692892], [-1.4207391431543328, 53.129509076352356], [-1.320713103721872, 53.12576340634696], [-1.2207053821100475, 53.12192668729292], [-1.1207164121767201, 53.11799894787924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.1207164&lt;dd&gt;Longitude: 53.117999&lt;dd&gt;Azimuth: 28.112278\u00b0&lt;dd&gt;Altitude: 67.390091\u00b0&lt;dd&gt;Slant Range: 594.82449km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1207164121767201, 53.11799894787924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.62084443728055, 53.136727157808096], [-1.5207830659886208, 53.1331636692892], [-1.4207391431543328, 53.129509076352356], [-1.320713103721872, 53.12576340634696], [-1.2207053821100475, 53.12192668729292], [-1.1207164121767201, 53.11799894787924], [-1.0207466272266912, 53.11398021746334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -1.0207466&lt;dd&gt;Longitude: 53.11398&lt;dd&gt;Azimuth: 29.737837\u00b0&lt;dd&gt;Altitude: 67.099479\u00b0&lt;dd&gt;Slant Range: 595.97411km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0207466272266912, 53.11398021746334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5207830659886208, 53.1331636692892], [-1.4207391431543328, 53.129509076352356], [-1.320713103721872, 53.12576340634696], [-1.2207053821100475, 53.12192668729292], [-1.1207164121767201, 53.11799894787924], [-1.0207466272266912, 53.11398021746334], [-0.9207964599848315, 53.10987052606974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.92079646&lt;dd&gt;Longitude: 53.109871&lt;dd&gt;Azimuth: 31.317615\u00b0&lt;dd&gt;Altitude: 66.793791\u00b0&lt;dd&gt;Slant Range: 597.20306km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9207964599848315, 53.10987052606974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4207391431543328, 53.129509076352356], [-1.320713103721872, 53.12576340634696], [-1.2207053821100475, 53.12192668729292], [-1.1207164121767201, 53.11799894787924], [-1.0207466272266912, 53.11398021746334], [-0.9207964599848315, 53.10987052606974], [-0.8208663425925714, 53.10566990438908]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.82086634&lt;dd&gt;Longitude: 53.10567&lt;dd&gt;Azimuth: 32.85124\u00b0&lt;dd&gt;Altitude: 66.473912\u00b0&lt;dd&gt;Slant Range: 598.51086km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8208663425925714, 53.10566990438908]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.320713103721872, 53.12576340634696], [-1.2207053821100475, 53.12192668729292], [-1.1207164121767201, 53.11799894787924], [-1.0207466272266912, 53.11398021746334], [-0.9207964599848315, 53.10987052606974], [-0.8208663425925714, 53.10566990438908], [-0.7209567065879009, 53.10137838377698]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.72095671&lt;dd&gt;Longitude: 53.101378&lt;dd&gt;Azimuth: 34.338625\u00b0&lt;dd&gt;Altitude: 66.140726\u00b0&lt;dd&gt;Slant Range: 599.89698km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7209567065879009, 53.10137838377698]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2207053821100475, 53.12192668729292], [-1.1207164121767201, 53.11799894787924], [-1.0207466272266912, 53.11398021746334], [-0.9207964599848315, 53.10987052606974], [-0.8208663425925714, 53.10566990438908], [-0.7209567065879009, 53.10137838377698], [-0.6210679828995938, 53.096995996252936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.62106798&lt;dd&gt;Longitude: 53.096996&lt;dd&gt;Azimuth: 35.779938\u00b0&lt;dd&gt;Altitude: 65.795099\u00b0&lt;dd&gt;Slant Range: 601.3609km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6210679828995938, 53.096995996252936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1207164121767201, 53.11799894787924], [-1.0207466272266912, 53.11398021746334], [-0.9207964599848315, 53.10987052606974], [-0.8208663425925714, 53.10566990438908], [-0.7209567065879009, 53.10137838377698], [-0.6210679828995938, 53.096995996252936], [-0.5212006018309232, 53.09252277449893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.5212006&lt;dd&gt;Longitude: 53.092523&lt;dd&gt;Azimuth: 37.175565\u00b0&lt;dd&gt;Altitude: 65.437883\u00b0&lt;dd&gt;Slant Range: 602.90203km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5212006018309232, 53.09252277449893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0207466272266912, 53.11398021746334], [-0.9207964599848315, 53.10987052606974], [-0.8208663425925714, 53.10566990438908], [-0.7209567065879009, 53.10137838377698], [-0.6210679828995938, 53.096995996252936], [-0.5212006018309232, 53.09252277449893], [-0.4213549930447767, 53.08795875185861]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.42135499&lt;dd&gt;Longitude: 53.087959&lt;dd&gt;Azimuth: 38.526086\u00b0&lt;dd&gt;Altitude: 65.069912\u00b0&lt;dd&gt;Slant Range: 604.51978km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4213549930447767, 53.08795875185861]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9207964599848315, 53.10987052606974], [-0.8208663425925714, 53.10566990438908], [-0.7209567065879009, 53.10137838377698], [-0.6210679828995938, 53.096995996252936], [-0.5212006018309232, 53.09252277449893], [-0.4213549930447767, 53.08795875185861], [-0.32153158555950884, 53.08330396233568]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.32153159&lt;dd&gt;Longitude: 53.083304&lt;dd&gt;Azimuth: 39.832242\u00b0&lt;dd&gt;Altitude: 64.691991\u00b0&lt;dd&gt;Slant Range: 606.21355km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.32153158555950884, 53.08330396233568]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8208663425925714, 53.10566990438908], [-0.7209567065879009, 53.10137838377698], [-0.6210679828995938, 53.096995996252936], [-0.5212006018309232, 53.09252277449893], [-0.4213549930447767, 53.08795875185861], [-0.32153158555950884, 53.08330396233568], [-0.22173080773105375, 53.07855844059296]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.22173081&lt;dd&gt;Longitude: 53.078558&lt;dd&gt;Azimuth: 41.094911\u00b0&lt;dd&gt;Altitude: 64.304903\u00b0&lt;dd&gt;Slant Range: 607.98268km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.22173080773105375, 53.07855844059296]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7209567065879009, 53.10137838377698], [-0.6210679828995938, 53.096995996252936], [-0.5212006018309232, 53.09252277449893], [-0.4213549930447767, 53.08795875185861], [-0.32153158555950884, 53.08330396233568], [-0.22173080773105375, 53.07855844059296], [-0.12195308723837073, 53.073722221950995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.12195309&lt;dd&gt;Longitude: 53.073722&lt;dd&gt;Azimuth: 42.31508\u00b0&lt;dd&gt;Altitude: 63.909403\u00b0&lt;dd&gt;Slant Range: 609.82654km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.12195308723837073, 53.073722221950995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6210679828995938, 53.096995996252936], [-0.5212006018309232, 53.09252277449893], [-0.4213549930447767, 53.08795875185861], [-0.32153158555950884, 53.08330396233568], [-0.22173080773105375, 53.07855844059296], [-0.12195308723837073, 53.073722221950995], [-0.022198851074615205, 53.06879534238668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: -0.022198851&lt;dd&gt;Longitude: 53.068795&lt;dd&gt;Azimuth: 43.493823\u00b0&lt;dd&gt;Altitude: 63.506214\u00b0&lt;dd&gt;Slant Range: 611.74443km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.022198851074615205, 53.06879534238668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5212006018309232, 53.09252277449893], [-0.4213549930447767, 53.08795875185861], [-0.32153158555950884, 53.08330396233568], [-0.22173080773105375, 53.07855844059296], [-0.12195308723837073, 53.073722221950995], [-0.022198851074615205, 53.06879534238668], [0.07753147446049463, 53.063777838532225]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.077531474&lt;dd&gt;Longitude: 53.063778&lt;dd&gt;Azimuth: 44.632284\u00b0&lt;dd&gt;Altitude: 63.096031\u00b0&lt;dd&gt;Slant Range: 613.73566km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.07753147446049463, 53.063777838532225]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4213549930447767, 53.08795875185861], [-0.32153158555950884, 53.08330396233568], [-0.22173080773105375, 53.07855844059296], [-0.12195308723837073, 53.073722221950995], [-0.022198851074615205, 53.06879534238668], [0.07753147446049463, 53.063777838532225], [0.17723746378904842, 53.058669747673505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.17723746&lt;dd&gt;Longitude: 53.05867&lt;dd&gt;Azimuth: 45.731654\u00b0&lt;dd&gt;Altitude: 62.67952\u00b0&lt;dd&gt;Slant Range: 615.79952km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.17723746378904842, 53.058669747673505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.32153158555950884, 53.08330396233568], [-0.22173080773105375, 53.07855844059296], [-0.12195308723837073, 53.073722221950995], [-0.022198851074615205, 53.06879534238668], [0.07753147446049463, 53.063777838532225], [0.17723746378904842, 53.058669747673505], [0.2769186920391172, 53.05347110774889]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.27691869&lt;dd&gt;Longitude: 53.053471&lt;dd&gt;Azimuth: 46.793159\u00b0&lt;dd&gt;Altitude: 62.257313\u00b0&lt;dd&gt;Slant Range: 617.93527km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.2769186920391172, 53.05347110774889]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.22173080773105375, 53.07855844059296], [-0.12195308723837073, 53.073722221950995], [-0.022198851074615205, 53.06879534238668], [0.07753147446049463, 53.063777838532225], [0.17723746378904842, 53.058669747673505], [0.2769186920391172, 53.05347110774889], [0.37657473508808503, 53.04818195734793]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.37657474&lt;dd&gt;Longitude: 53.048182&lt;dd&gt;Azimuth: 47.818045\u00b0&lt;dd&gt;Altitude: 61.830014\u00b0&lt;dd&gt;Slant Range: 620.14218km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.37657473508808503, 53.04818195734793]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.12195308723837073, 53.073722221950995], [-0.022198851074615205, 53.06879534238668], [0.07753147446049463, 53.063777838532225], [0.17723746378904842, 53.058669747673505], [0.2769186920391172, 53.05347110774889], [0.37657473508808503, 53.04818195734793], [0.4762051695515049, 53.042802335709744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.47620517&lt;dd&gt;Longitude: 53.042802&lt;dd&gt;Azimuth: 48.807565\u00b0&lt;dd&gt;Altitude: 61.398197\u00b0&lt;dd&gt;Slant Range: 622.41949km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.4762051695515049, 53.042802335709744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.022198851074615205, 53.06879534238668], [0.07753147446049463, 53.063777838532225], [0.17723746378904842, 53.058669747673505], [0.2769186920391172, 53.05347110774889], [0.37657473508808503, 53.04818195734793], [0.4762051695515049, 53.042802335709744], [0.5758095728088732, 53.037332282721756]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.57580957&lt;dd&gt;Longitude: 53.037332&lt;dd&gt;Azimuth: 49.762973\u00b0&lt;dd&gt;Altitude: 60.962404\u00b0&lt;dd&gt;Slant Range: 624.76641km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5758095728088732, 53.037332282721756]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.07753147446049463, 53.063777838532225], [0.17723746378904842, 53.058669747673505], [0.2769186920391172, 53.05347110774889], [0.37657473508808503, 53.04818195734793], [0.4762051695515049, 53.042802335709744], [0.5758095728088732, 53.037332282721756], [0.6753875230037324, 53.03177183891826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.67538752&lt;dd&gt;Longitude: 53.031772&lt;dd&gt;Azimuth: 50.685511\u00b0&lt;dd&gt;Altitude: 60.523151\u00b0&lt;dd&gt;Slant Range: 627.18217km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6753875230037324, 53.03177183891826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.17723746378904842, 53.058669747673505], [0.2769186920391172, 53.05347110774889], [0.37657473508808503, 53.04818195734793], [0.4762051695515049, 53.042802335709744], [0.5758095728088732, 53.037332282721756], [0.6753875230037324, 53.03177183891826], [0.7749385990683001, 53.02612104547878]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.7749386&lt;dd&gt;Longitude: 53.026121&lt;dd&gt;Azimuth: 51.576404\u00b0&lt;dd&gt;Altitude: 60.080926\u00b0&lt;dd&gt;Slant Range: 629.66598km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7749385990683001, 53.02612104547878]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.2769186920391172, 53.05347110774889], [0.37657473508808503, 53.04818195734793], [0.4762051695515049, 53.042802335709744], [0.5758095728088732, 53.037332282721756], [0.6753875230037324, 53.03177183891826], [0.7749385990683001, 53.02612104547878], [0.8744623807234193, 53.020379944226846]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.87446238&lt;dd&gt;Longitude: 53.02038&lt;dd&gt;Azimuth: 52.436858\u00b0&lt;dd&gt;Altitude: 59.636187\u00b0&lt;dd&gt;Slant Range: 632.21702km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8744623807234193, 53.020379944226846]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.37657473508808503, 53.04818195734793], [0.4762051695515049, 53.042802335709744], [0.5758095728088732, 53.037332282721756], [0.6753875230037324, 53.03177183891826], [0.7749385990683001, 53.02612104547878], [0.8744623807234193, 53.020379944226846], [0.973958448498608, 53.014548577628354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 0.97395845&lt;dd&gt;Longitude: 53.014549&lt;dd&gt;Azimuth: 53.268047\u00b0&lt;dd&gt;Altitude: 59.189368\u00b0&lt;dd&gt;Slant Range: 634.83448km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.973958448498608, 53.014548577628354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.4762051695515049, 53.042802335709744], [0.5758095728088732, 53.037332282721756], [0.6753875230037324, 53.03177183891826], [0.7749385990683001, 53.02612104547878], [0.8744623807234193, 53.020379944226846], [0.973958448498608, 53.014548577628354], [1.0734263837355704, 53.00862698878994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.0734264&lt;dd&gt;Longitude: 53.008627&lt;dd&gt;Azimuth: 54.07112\u00b0&lt;dd&gt;Altitude: 58.740878\u00b0&lt;dd&gt;Slant Range: 637.51755km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0734263837355704, 53.00862698878994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5758095728088732, 53.037332282721756], [0.6753875230037324, 53.03177183891826], [0.7749385990683001, 53.02612104547878], [0.8744623807234193, 53.020379944226846], [0.973958448498608, 53.014548577628354], [1.0734263837355704, 53.00862698878994], [1.1728657686138457, 53.00261522145761]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.1728658&lt;dd&gt;Longitude: 53.002615&lt;dd&gt;Azimuth: 54.847191\u00b0&lt;dd&gt;Altitude: 58.291102\u00b0&lt;dd&gt;Slant Range: 640.26539km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1728657686138457, 53.00261522145761]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6753875230037324, 53.03177183891826], [0.7749385990683001, 53.02612104547878], [0.8744623807234193, 53.020379944226846], [0.973958448498608, 53.014548577628354], [1.0734263837355704, 53.00862698878994], [1.1728657686138457, 53.00261522145761], [1.2722761861451581, 52.99651332001501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.2722762&lt;dd&gt;Longitude: 52.996513&lt;dd&gt;Azimuth: 55.597338\u00b0&lt;dd&gt;Altitude: 57.840401\u00b0&lt;dd&gt;Slant Range: 643.07718km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2722761861451581, 52.99651332001501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7749385990683001, 53.02612104547878], [0.8744623807234193, 53.020379944226846], [0.973958448498608, 53.014548577628354], [1.0734263837355704, 53.00862698878994], [1.1728657686138457, 53.00261522145761], [1.2722761861451581, 52.99651332001501], [1.3716572201936719, 52.99032132948198]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.3716572&lt;dd&gt;Longitude: 52.990321&lt;dd&gt;Azimuth: 56.322605\u00b0&lt;dd&gt;Altitude: 57.389114\u00b0&lt;dd&gt;Slant Range: 645.95207km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3716572201936719, 52.99032132948198]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8744623807234193, 53.020379944226846], [0.973958448498608, 53.014548577628354], [1.0734263837355704, 53.00862698878994], [1.1728657686138457, 53.00261522145761], [1.2722761861451581, 52.99651332001501], [1.3716572201936719, 52.99032132948198], [1.4710084554895526, 52.98403929551282]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.4710085&lt;dd&gt;Longitude: 52.984039&lt;dd&gt;Azimuth: 57.023998\u00b0&lt;dd&gt;Altitude: 56.93756\u00b0&lt;dd&gt;Slant Range: 648.88922km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4710084554895526, 52.98403929551282]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.973958448498608, 53.014548577628354], [1.0734263837355704, 53.00862698878994], [1.1728657686138457, 53.00261522145761], [1.2722761861451581, 52.99651332001501], [1.3716572201936719, 52.99032132948198], [1.4710084554895526, 52.98403929551282], [1.570329477637364, 52.97766726439466]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.5703295&lt;dd&gt;Longitude: 52.977667&lt;dd&gt;Azimuth: 57.702486\u00b0&lt;dd&gt;Altitude: 56.486036\u00b0&lt;dd&gt;Slant Range: 651.88779km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.570329477637364, 52.97766726439466]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0734263837355704, 53.00862698878994], [1.1728657686138457, 53.00261522145761], [1.2722761861451581, 52.99651332001501], [1.3716572201936719, 52.99032132948198], [1.4710084554895526, 52.98403929551282], [1.570329477637364, 52.97766726439466], [1.669619873121971, 52.97120528304595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.6696199&lt;dd&gt;Longitude: 52.971205&lt;dd&gt;Azimuth: 58.359002\u00b0&lt;dd&gt;Altitude: 56.034822\u00b0&lt;dd&gt;Slant Range: 654.94693km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.669619873121971, 52.97120528304595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1728657686138457, 53.00261522145761], [1.2722761861451581, 52.99651332001501], [1.3716572201936719, 52.99032132948198], [1.4710084554895526, 52.98403929551282], [1.570329477637364, 52.97766726439466], [1.669619873121971, 52.97120528304595], [1.7688792293330167, 52.96465339901465]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.7688792&lt;dd&gt;Longitude: 52.964653&lt;dd&gt;Azimuth: 58.99444\u00b0&lt;dd&gt;Altitude: 55.584179\u00b0&lt;dd&gt;Slant Range: 658.0658km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7688792293330167, 52.96465339901465]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2722761861451581, 52.99651332001501], [1.3716572201936719, 52.99032132948198], [1.4710084554895526, 52.98403929551282], [1.570329477637364, 52.97766726439466], [1.669619873121971, 52.97120528304595], [1.7688792293330167, 52.96465339901465], [1.8681071345612348, 52.9580116604765]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.8681071&lt;dd&gt;Longitude: 52.958012&lt;dd&gt;Azimuth: 59.609659\u00b0&lt;dd&gt;Altitude: 55.13435\u00b0&lt;dd&gt;Slant Range: 661.24354km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8681071345612348, 52.9580116604765]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3716572201936719, 52.99032132948198], [1.4710084554895526, 52.98403929551282], [1.570329477637364, 52.97766726439466], [1.669619873121971, 52.97120528304595], [1.7688792293330167, 52.96465339901465], [1.8681071345612348, 52.9580116604765], [1.967303178017047, 52.95128011623341]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 1.9673032&lt;dd&gt;Longitude: 52.95128&lt;dd&gt;Azimuth: 60.205483\u00b0&lt;dd&gt;Altitude: 54.685563\u00b0&lt;dd&gt;Slant Range: 664.4793km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.967303178017047, 52.95128011623341]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4710084554895526, 52.98403929551282], [1.570329477637364, 52.97766726439466], [1.669619873121971, 52.97120528304595], [1.7688792293330167, 52.96465339901465], [1.8681071345612348, 52.9580116604765], [1.967303178017047, 52.95128011623341], [2.0664669498471033, 52.94445881571167]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.0664669&lt;dd&gt;Longitude: 52.944459&lt;dd&gt;Azimuth: 60.7827\u00b0&lt;dd&gt;Altitude: 54.238029\u00b0&lt;dd&gt;Slant Range: 667.77224km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0664669498471033, 52.94445881571167]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.570329477637364, 52.97766726439466], [1.669619873121971, 52.97120528304595], [1.7688792293330167, 52.96465339901465], [1.8681071345612348, 52.9580116604765], [1.967303178017047, 52.95128011623341], [2.0664669498471033, 52.94445881571167], [2.1655980411306186, 52.93754780896022]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.165598&lt;dd&gt;Longitude: 52.937548&lt;dd&gt;Azimuth: 61.342063\u00b0&lt;dd&gt;Altitude: 53.791946\u00b0&lt;dd&gt;Slant Range: 671.12152km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1655980411306186, 52.93754780896022]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.669619873121971, 52.97120528304595], [1.7688792293330167, 52.96465339901465], [1.8681071345612348, 52.9580116604765], [1.967303178017047, 52.95128011623341], [2.0664669498471033, 52.94445881571167], [2.1655980411306186, 52.93754780896022], [2.2646960439051713, 52.93054714664877]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.264696&lt;dd&gt;Longitude: 52.930547&lt;dd&gt;Azimuth: 61.884295\u00b0&lt;dd&gt;Altitude: 53.347496\u00b0&lt;dd&gt;Slant Range: 674.52629km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2646960439051713, 52.93054714664877]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7688792293330167, 52.96465339901465], [1.8681071345612348, 52.9580116604765], [1.967303178017047, 52.95128011623341], [2.0664669498471033, 52.94445881571167], [2.1655980411306186, 52.93754780896022], [2.2646960439051713, 52.93054714664877], [2.3637605511650768, 52.92345688006621]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.3637606&lt;dd&gt;Longitude: 52.923457&lt;dd&gt;Azimuth: 62.410085\u00b0&lt;dd&gt;Altitude: 52.904851\u00b0&lt;dd&gt;Slant Range: 677.98571km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3637605511650768, 52.92345688006621]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8681071345612348, 52.9580116604765], [1.967303178017047, 52.95128011623341], [2.0664669498471033, 52.94445881571167], [2.1655980411306186, 52.93754780896022], [2.2646960439051713, 52.93054714664877], [2.3637605511650768, 52.92345688006621], [2.462791156885941, 52.91627706111849]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.4627912&lt;dd&gt;Longitude: 52.916277&lt;dd&gt;Azimuth: 62.920093\u00b0&lt;dd&gt;Altitude: 52.464166\u00b0&lt;dd&gt;Slant Range: 681.49894km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.462791156885941, 52.91627706111849]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.967303178017047, 52.95128011623341], [2.0664669498471033, 52.94445881571167], [2.1655980411306186, 52.93754780896022], [2.2646960439051713, 52.93054714664877], [2.3637605511650768, 52.92345688006621], [2.462791156885941, 52.91627706111849], [2.561787456014329, 52.9090077423272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.5617875&lt;dd&gt;Longitude: 52.909008&lt;dd&gt;Azimuth: 63.414948\u00b0&lt;dd&gt;Altitude: 52.025587\u00b0&lt;dd&gt;Slant Range: 685.06516km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.561787456014329, 52.9090077423272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0664669498471033, 52.94445881571167], [2.1655980411306186, 52.93754780896022], [2.2646960439051713, 52.93054714664877], [2.3637605511650768, 52.92345688006621], [2.462791156885941, 52.91627706111849], [2.561787456014329, 52.9090077423272], [2.6607490445066184, 52.90164897682726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.660749&lt;dd&gt;Longitude: 52.901649&lt;dd&gt;Azimuth: 63.895252\u00b0&lt;dd&gt;Altitude: 51.58925\u00b0&lt;dd&gt;Slant Range: 688.68354km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.6607490445066184, 52.90164897682726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1655980411306186, 52.93754780896022], [2.2646960439051713, 52.93054714664877], [2.3637605511650768, 52.92345688006621], [2.462791156885941, 52.91627706111849], [2.561787456014329, 52.9090077423272], [2.6607490445066184, 52.90164897682726], [2.7596755193129723, 52.894200818365384]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.7596755&lt;dd&gt;Longitude: 52.894201&lt;dd&gt;Azimuth: 64.36158\u00b0&lt;dd&gt;Altitude: 51.155279\u00b0&lt;dd&gt;Slant Range: 692.35325km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7596755193129723, 52.894200818365384]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2646960439051713, 52.93054714664877], [2.3637605511650768, 52.92345688006621], [2.462791156885941, 52.91627706111849], [2.561787456014329, 52.9090077423272], [2.6607490445066184, 52.90164897682726], [2.7596755193129723, 52.894200818365384], [2.8585664784070044, 52.88666332129801]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.8585665&lt;dd&gt;Longitude: 52.886663&lt;dd&gt;Azimuth: 64.814479\u00b0&lt;dd&gt;Altitude: 50.723786\u00b0&lt;dd&gt;Slant Range: 696.07348km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.8585664784070044, 52.88666332129801]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3637605511650768, 52.92345688006621], [2.462791156885941, 52.91627706111849], [2.561787456014329, 52.9090077423272], [2.6607490445066184, 52.90164897682726], [2.7596755193129723, 52.894200818365384], [2.8585664784070044, 52.88666332129801], [2.9574215207779675, 52.87903654058942]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 2.9574215&lt;dd&gt;Longitude: 52.879037&lt;dd&gt;Azimuth: 65.254475\u00b0&lt;dd&gt;Altitude: 50.294877\u00b0&lt;dd&gt;Slant Range: 699.84342km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9574215207779675, 52.87903654058942]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.462791156885941, 52.91627706111849], [2.561787456014329, 52.9090077423272], [2.6607490445066184, 52.90164897682726], [2.7596755193129723, 52.894200818365384], [2.8585664784070044, 52.88666332129801], [2.9574215207779675, 52.87903654058942], [3.0562402464655136, 52.87132053180981]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.0562402&lt;dd&gt;Longitude: 52.871321&lt;dd&gt;Azimuth: 65.682066\u00b0&lt;dd&gt;Altitude: 49.868647\u00b0&lt;dd&gt;Slant Range: 703.66226km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0562402464655136, 52.87132053180981]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.561787456014329, 52.9090077423272], [2.6607490445066184, 52.90164897682726], [2.7596755193129723, 52.894200818365384], [2.8585664784070044, 52.88666332129801], [2.9574215207779675, 52.87903654058942], [3.0562402464655136, 52.87132053180981], [3.155022256541523, 52.863515351133564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.1550223&lt;dd&gt;Longitude: 52.863515&lt;dd&gt;Azimuth: 66.097731\u00b0&lt;dd&gt;Altitude: 49.445184\u00b0&lt;dd&gt;Slant Range: 707.52922km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.155022256541523, 52.863515351133564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.6607490445066184, 52.90164897682726], [2.7596755193129723, 52.894200818365384], [2.8585664784070044, 52.88666332129801], [2.9574215207779675, 52.87903654058942], [3.0562402464655136, 52.87132053180981], [3.155022256541523, 52.863515351133564], [3.2537671531454238, 52.85562105533669]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.2537672&lt;dd&gt;Longitude: 52.855621&lt;dd&gt;Azimuth: 66.501925\u00b0&lt;dd&gt;Altitude: 49.024567\u00b0&lt;dd&gt;Slant Range: 711.44349km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.2537671531454238, 52.85562105533669]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7596755193129723, 52.894200818365384], [2.8585664784070044, 52.88666332129801], [2.9574215207779675, 52.87903654058942], [3.0562402464655136, 52.87132053180981], [3.155022256541523, 52.863515351133564], [3.2537671531454238, 52.85562105533669], [3.352474539478262, 52.84763770179563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.3524745&lt;dd&gt;Longitude: 52.847638&lt;dd&gt;Azimuth: 66.895084\u00b0&lt;dd&gt;Altitude: 48.606868\u00b0&lt;dd&gt;Slant Range: 715.40431km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.352474539478262, 52.84763770179563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.8585664784070044, 52.88666332129801], [2.9574215207779675, 52.87903654058942], [3.0562402464655136, 52.87132053180981], [3.155022256541523, 52.863515351133564], [3.2537671531454238, 52.85562105533669], [3.352474539478262, 52.84763770179563], [3.4511440198184267, 52.8395653484846]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.451144&lt;dd&gt;Longitude: 52.839565&lt;dd&gt;Azimuth: 67.277623\u00b0&lt;dd&gt;Altitude: 48.192152\u00b0&lt;dd&gt;Slant Range: 719.4109km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4511440198184267, 52.8395653484846]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9574215207779675, 52.87903654058942], [3.0562402464655136, 52.87132053180981], [3.155022256541523, 52.863515351133564], [3.2537671531454238, 52.85562105533669], [3.352474539478262, 52.84763770179563], [3.4511440198184267, 52.8395653484846], [3.549775199528621, 52.83140405397381]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.5497752&lt;dd&gt;Longitude: 52.831404&lt;dd&gt;Azimuth: 67.649939\u00b0&lt;dd&gt;Altitude: 47.780478\u00b0&lt;dd&gt;Slant Range: 723.46249km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.549775199528621, 52.83140405397381]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0562402464655136, 52.87132053180981], [3.155022256541523, 52.863515351133564], [3.2537671531454238, 52.85562105533669], [3.352474539478262, 52.84763770179563], [3.4511440198184267, 52.8395653484846], [3.549775199528621, 52.83140405397381], [3.6483676850760163, 52.82315387742757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.6483677&lt;dd&gt;Longitude: 52.823154&lt;dd&gt;Azimuth: 68.012412\u00b0&lt;dd&gt;Altitude: 47.371896\u00b0&lt;dd&gt;Slant Range: 727.55832km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6483676850760163, 52.82315387742757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.155022256541523, 52.863515351133564], [3.2537671531454238, 52.85562105533669], [3.352474539478262, 52.84763770179563], [3.4511440198184267, 52.8395653484846], [3.549775199528621, 52.83140405397381], [3.6483676850760163, 52.82315387742757], [3.746921084025404, 52.81481487860196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.7469211&lt;dd&gt;Longitude: 52.814815&lt;dd&gt;Azimuth: 68.365404\u00b0&lt;dd&gt;Altitude: 46.966455\u00b0&lt;dd&gt;Slant Range: 731.69766km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.746921084025404, 52.81481487860196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.2537671531454238, 52.85562105533669], [3.352474539478262, 52.84763770179563], [3.4511440198184267, 52.8395653484846], [3.549775199528621, 52.83140405397381], [3.6483676850760163, 52.82315387742757], [3.746921084025404, 52.81481487860196], [3.8454350050649495, 52.80638711784287]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.845435&lt;dd&gt;Longitude: 52.806387&lt;dd&gt;Azimuth: 68.709262\u00b0&lt;dd&gt;Altitude: 46.564194\u00b0&lt;dd&gt;Slant Range: 735.87975km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8454350050649495, 52.80638711784287]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.352474539478262, 52.84763770179563], [3.4511440198184267, 52.8395653484846], [3.549775199528621, 52.83140405397381], [3.6483676850760163, 52.82315387742757], [3.746921084025404, 52.81481487860196], [3.8454350050649495, 52.80638711784287], [3.9439090580004126, 52.79787065608414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 3.9439091&lt;dd&gt;Longitude: 52.797871&lt;dd&gt;Azimuth: 69.044315\u00b0&lt;dd&gt;Altitude: 46.165149\u00b0&lt;dd&gt;Slant Range: 740.10388km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9439090580004126, 52.79787065608414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4511440198184267, 52.8395653484846], [3.549775199528621, 52.83140405397381], [3.6483676850760163, 52.82315387742757], [3.746921084025404, 52.81481487860196], [3.8454350050649495, 52.80638711784287], [3.9439090580004126, 52.79787065608414], [4.04234285378291, 52.789265554844825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.0423429&lt;dd&gt;Longitude: 52.789266&lt;dd&gt;Azimuth: 69.370881\u00b0&lt;dd&gt;Altitude: 45.769351\u00b0&lt;dd&gt;Slant Range: 744.36931km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.04234285378291, 52.789265554844825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.549775199528621, 52.83140405397381], [3.6483676850760163, 52.82315387742757], [3.746921084025404, 52.81481487860196], [3.8454350050649495, 52.80638711784287], [3.9439090580004126, 52.79787065608414], [4.04234285378291, 52.789265554844825], [4.140736004498863, 52.78057187622792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.140736&lt;dd&gt;Longitude: 52.780572&lt;dd&gt;Azimuth: 69.689262\u00b0&lt;dd&gt;Altitude: 45.376825\u00b0&lt;dd&gt;Slant Range: 748.67535km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.140736004498863, 52.78057187622792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6483676850760163, 52.82315387742757], [3.746921084025404, 52.81481487860196], [3.8454350050649495, 52.80638711784287], [3.9439090580004126, 52.79787065608414], [4.04234285378291, 52.789265554844825], [4.140736004498863, 52.78057187622792], [4.239088123394018, 52.77178968291745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.2390881&lt;dd&gt;Longitude: 52.77179&lt;dd&gt;Azimuth: 69.999748\u00b0&lt;dd&gt;Altitude: 44.987594\u00b0&lt;dd&gt;Slant Range: 753.02129km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.239088123394018, 52.77178968291745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.746921084025404, 52.81481487860196], [3.8454350050649495, 52.80638711784287], [3.9439090580004126, 52.79787065608414], [4.04234285378291, 52.789265554844825], [4.140736004498863, 52.78057187622792], [4.239088123394018, 52.77178968291745], [4.337398824880801, 52.762919038176754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.3373988&lt;dd&gt;Longitude: 52.762919&lt;dd&gt;Azimuth: 70.302615\u00b0&lt;dd&gt;Altitude: 44.601676\u00b0&lt;dd&gt;Slant Range: 757.40643km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.337398824880801, 52.762919038176754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8454350050649495, 52.80638711784287], [3.9439090580004126, 52.79787065608414], [4.04234285378291, 52.789265554844825], [4.140736004498863, 52.78057187622792], [4.239088123394018, 52.77178968291745], [4.337398824880801, 52.762919038176754], [4.435667724538596, 52.753960005846146]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.4356677&lt;dd&gt;Longitude: 52.75396&lt;dd&gt;Azimuth: 70.598128\u00b0&lt;dd&gt;Altitude: 44.219084\u00b0&lt;dd&gt;Slant Range: 761.83011km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.435667724538596, 52.753960005846146]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9439090580004126, 52.79787065608414], [4.04234285378291, 52.789265554844825], [4.140736004498863, 52.78057187622792], [4.239088123394018, 52.77178968291745], [4.337398824880801, 52.762919038176754], [4.435667724538596, 52.753960005846146], [4.5338944391300515, 52.74491265034077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.5338944&lt;dd&gt;Longitude: 52.744913&lt;dd&gt;Azimuth: 70.886541\u00b0&lt;dd&gt;Altitude: 43.839829\u00b0&lt;dd&gt;Slant Range: 766.29163km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.5338944391300515, 52.74491265034077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.04234285378291, 52.789265554844825], [4.140736004498863, 52.78057187622792], [4.239088123394018, 52.77178968291745], [4.337398824880801, 52.762919038176754], [4.435667724538596, 52.753960005846146], [4.5338944391300515, 52.74491265034077], [4.632078586611547, 52.735777036648315]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.6320786&lt;dd&gt;Longitude: 52.735777&lt;dd&gt;Azimuth: 71.168096\u00b0&lt;dd&gt;Altitude: 43.463918\u00b0&lt;dd&gt;Slant Range: 770.79035km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.632078586611547, 52.735777036648315]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.140736004498863, 52.78057187622792], [4.239088123394018, 52.77178968291745], [4.337398824880801, 52.762919038176754], [4.435667724538596, 52.753960005846146], [4.5338944391300515, 52.74491265034077], [4.632078586611547, 52.735777036648315], [4.730219786139315, 52.72655323032706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.7302198&lt;dd&gt;Longitude: 52.726553&lt;dd&gt;Azimuth: 71.443026\u00b0&lt;dd&gt;Altitude: 43.091355\u00b0&lt;dd&gt;Slant Range: 775.3256km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.730219786139315, 52.72655323032706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.239088123394018, 52.77178968291745], [4.337398824880801, 52.762919038176754], [4.435667724538596, 52.753960005846146], [4.5338944391300515, 52.74491265034077], [4.632078586611547, 52.735777036648315], [4.730219786139315, 52.72655323032706], [4.82831765807398, 52.71724129750308]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.8283177&lt;dd&gt;Longitude: 52.717241&lt;dd&gt;Azimuth: 71.711553\u00b0&lt;dd&gt;Altitude: 42.722142\u00b0&lt;dd&gt;Slant Range: 779.89676km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.82831765807398, 52.71724129750308]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.337398824880801, 52.762919038176754], [4.435667724538596, 52.753960005846146], [4.5338944391300515, 52.74491265034077], [4.632078586611547, 52.735777036648315], [4.730219786139315, 52.72655323032706], [4.82831765807398, 52.71724129750308], [4.926371824000958, 52.70784130486867]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 4.9263718&lt;dd&gt;Longitude: 52.707841&lt;dd&gt;Azimuth: 71.973892\u00b0&lt;dd&gt;Altitude: 42.356277\u00b0&lt;dd&gt;Slant Range: 784.50317km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.926371824000958, 52.70784130486867]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.435667724538596, 52.753960005846146], [4.5338944391300515, 52.74491265034077], [4.632078586611547, 52.735777036648315], [4.730219786139315, 52.72655323032706], [4.82831765807398, 52.71724129750308], [4.926371824000958, 52.70784130486867], [5.024381906728928, 52.69835331967952]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2371&lt;dd&gt;Latitude: 5.0243819&lt;dd&gt;Longitude: 52.698353&lt;dd&gt;Azimuth: 72.230245\u00b0&lt;dd&gt;Altitude: 41.993756\u00b0&lt;dd&gt;Slant Range: 789.14423km&quot;, &quot;name&quot;: &quot;STARLINK-2371&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.024381906728928, 52.69835331967952]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.6550333&lt;dd&gt;Longitude: 48.590324&lt;dd&gt;Azimuth: 230.56744\u00b0&lt;dd&gt;Altitude: 45.446414\u00b0&lt;dd&gt;Slant Range: 746.29744km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855], [-7.573336717573743, 48.61690112819711]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.5733367&lt;dd&gt;Longitude: 48.616901&lt;dd&gt;Azimuth: 230.32913\u00b0&lt;dd&gt;Altitude: 45.857132\u00b0&lt;dd&gt;Slant Range: 741.82246km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.573336717573743, 48.61690112819711]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855], [-7.573336717573743, 48.61690112819711], [-7.491550169543094, 48.643414497424544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.4915502&lt;dd&gt;Longitude: 48.643414&lt;dd&gt;Azimuth: 230.08424\u00b0&lt;dd&gt;Altitude: 46.271906\u00b0&lt;dd&gt;Slant Range: 737.38663km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.491550169543094, 48.643414497424544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855], [-7.573336717573743, 48.61690112819711], [-7.491550169543094, 48.643414497424544], [-7.409673703552691, 48.669863614170076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.4096737&lt;dd&gt;Longitude: 48.669864&lt;dd&gt;Azimuth: 229.83252\u00b0&lt;dd&gt;Altitude: 46.690739\u00b0&lt;dd&gt;Slant Range: 732.99068km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.409673703552691, 48.669863614170076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855], [-7.573336717573743, 48.61690112819711], [-7.491550169543094, 48.643414497424544], [-7.409673703552691, 48.669863614170076], [-7.327707360267987, 48.69624835270938]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.3277074&lt;dd&gt;Longitude: 48.696248&lt;dd&gt;Azimuth: 229.57369\u00b0&lt;dd&gt;Altitude: 47.113636\u00b0&lt;dd&gt;Slant Range: 728.63533km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.327707360267987, 48.69624835270938]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855], [-7.573336717573743, 48.61690112819711], [-7.491550169543094, 48.643414497424544], [-7.409673703552691, 48.669863614170076], [-7.327707360267987, 48.69624835270938], [-7.245651181628589, 48.72256858730731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.2456512&lt;dd&gt;Longitude: 48.722569&lt;dd&gt;Azimuth: 229.30745\u00b0&lt;dd&gt;Altitude: 47.540596\u00b0&lt;dd&gt;Slant Range: 724.32132km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.245651181628589, 48.72256858730731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6550333082563675, 48.590323632199855], [-7.573336717573743, 48.61690112819711], [-7.491550169543094, 48.643414497424544], [-7.409673703552691, 48.669863614170076], [-7.327707360267987, 48.69624835270938], [-7.245651181628589, 48.72256858730731], [-7.1635052108634, 48.74882419222029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.1635052&lt;dd&gt;Longitude: 48.748824&lt;dd&gt;Azimuth: 229.03349\u00b0&lt;dd&gt;Altitude: 47.971614\u00b0&lt;dd&gt;Slant Range: 720.04939km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.1635052108634, 48.74882419222029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.573336717573743, 48.61690112819711], [-7.491550169543094, 48.643414497424544], [-7.409673703552691, 48.669863614170076], [-7.327707360267987, 48.69624835270938], [-7.245651181628589, 48.72256858730731], [-7.1635052108634, 48.74882419222029], [-7.08126949248169, 48.77501504169747]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -7.0812695&lt;dd&gt;Longitude: 48.775015&lt;dd&gt;Azimuth: 228.75151\u00b0&lt;dd&gt;Altitude: 48.406681\u00b0&lt;dd&gt;Slant Range: 715.8203km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.08126949248169, 48.77501504169747]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.491550169543094, 48.643414497424544], [-7.409673703552691, 48.669863614170076], [-7.327707360267987, 48.69624835270938], [-7.245651181628589, 48.72256858730731], [-7.1635052108634, 48.74882419222029], [-7.08126949248169, 48.77501504169747], [-6.998944072299982, 48.80114100998354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.9989441&lt;dd&gt;Longitude: 48.801141&lt;dd&gt;Azimuth: 228.46115\u00b0&lt;dd&gt;Altitude: 48.845785\u00b0&lt;dd&gt;Slant Range: 711.63482km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.998944072299982, 48.80114100998354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.409673703552691, 48.669863614170076], [-7.327707360267987, 48.69624835270938], [-7.245651181628589, 48.72256858730731], [-7.1635052108634, 48.74882419222029], [-7.08126949248169, 48.77501504169747], [-6.998944072299982, 48.80114100998354], [-6.916528997419468, 48.827201971320285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.916529&lt;dd&gt;Longitude: 48.827202&lt;dd&gt;Azimuth: 228.16206\u00b0&lt;dd&gt;Altitude: 49.288907\u00b0&lt;dd&gt;Slant Range: 707.49374km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.916528997419468, 48.827201971320285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.327707360267987, 48.69624835270938], [-7.245651181628589, 48.72256858730731], [-7.1635052108634, 48.74882419222029], [-7.08126949248169, 48.77501504169747], [-6.998944072299982, 48.80114100998354], [-6.916528997419468, 48.827201971320285], [-6.834024316262313, 48.85319779994829]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.8340243&lt;dd&gt;Longitude: 48.853198&lt;dd&gt;Azimuth: 227.85386\u00b0&lt;dd&gt;Altitude: 49.736025\u00b0&lt;dd&gt;Slant Range: 703.39783km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.834024316262313, 48.85319779994829]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.245651181628589, 48.72256858730731], [-7.1635052108634, 48.74882419222029], [-7.08126949248169, 48.77501504169747], [-6.998944072299982, 48.80114100998354], [-6.916528997419468, 48.827201971320285], [-6.834024316262313, 48.85319779994829], [-6.751430078546946, 48.87912837010919]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.7514301&lt;dd&gt;Longitude: 48.879128&lt;dd&gt;Azimuth: 227.53614\u00b0&lt;dd&gt;Altitude: 50.187112\u00b0&lt;dd&gt;Slant Range: 699.3479km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.751430078546946, 48.87912837010919]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.1635052108634, 48.74882419222029], [-7.08126949248169, 48.77501504169747], [-6.998944072299982, 48.80114100998354], [-6.916528997419468, 48.827201971320285], [-6.834024316262313, 48.85319779994829], [-6.751430078546946, 48.87912837010919], [-6.6687463353158, 48.904993556047664]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.6687463&lt;dd&gt;Longitude: 48.904994&lt;dd&gt;Azimuth: 227.20849\u00b0&lt;dd&gt;Altitude: 50.642132\u00b0&lt;dd&gt;Slant Range: 695.34475km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.6687463353158, 48.904993556047664]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.08126949248169, 48.77501504169747], [-6.998944072299982, 48.80114100998354], [-6.916528997419468, 48.827201971320285], [-6.834024316262313, 48.85319779994829], [-6.751430078546946, 48.87912837010919], [-6.6687463353158, 48.904993556047664], [-6.5859731389329665, 48.93079323201328]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.5859731&lt;dd&gt;Longitude: 48.930793&lt;dd&gt;Azimuth: 226.87046\u00b0&lt;dd&gt;Altitude: 51.101047\u00b0&lt;dd&gt;Slant Range: 691.3892km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.5859731389329665, 48.93079323201328]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.998944072299982, 48.80114100998354], [-6.916528997419468, 48.827201971320285], [-6.834024316262313, 48.85319779994829], [-6.751430078546946, 48.87912837010919], [-6.6687463353158, 48.904993556047664], [-6.5859731389329665, 48.93079323201328], [-6.5031105430805365, 48.95652727226267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.5031105&lt;dd&gt;Longitude: 48.956527&lt;dd&gt;Azimuth: 226.52158\u00b0&lt;dd&gt;Altitude: 51.56381\u00b0&lt;dd&gt;Slant Range: 687.48208km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.5031105430805365, 48.95652727226267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.916528997419468, 48.827201971320285], [-6.834024316262313, 48.85319779994829], [-6.751430078546946, 48.87912837010919], [-6.6687463353158, 48.904993556047664], [-6.5859731389329665, 48.93079323201328], [-6.5031105430805365, 48.95652727226267], [-6.420158602781849, 48.98219555106102]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.4201586&lt;dd&gt;Longitude: 48.982196&lt;dd&gt;Azimuth: 226.16134\u00b0&lt;dd&gt;Altitude: 52.030367\u00b0&lt;dd&gt;Slant Range: 683.62422km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.420158602781849, 48.98219555106102]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.834024316262313, 48.85319779994829], [-6.751430078546946, 48.87912837010919], [-6.6687463353158, 48.904993556047664], [-6.5859731389329665, 48.93079323201328], [-6.5031105430805365, 48.95652727226267], [-6.420158602781849, 48.98219555106102], [-6.337117374389669, 49.00779794268476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.3371174&lt;dd&gt;Longitude: 49.007798&lt;dd&gt;Azimuth: 225.78923\u00b0&lt;dd&gt;Altitude: 52.500656\u00b0&lt;dd&gt;Slant Range: 679.81646km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.337117374389669, 49.00779794268476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.751430078546946, 48.87912837010919], [-6.6687463353158, 48.904993556047664], [-6.5859731389329665, 48.93079323201328], [-6.5031105430805365, 48.95652727226267], [-6.420158602781849, 48.98219555106102], [-6.337117374389669, 49.00779794268476], [-6.253986915603404, 49.03333432142345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.2539869&lt;dd&gt;Longitude: 49.033334&lt;dd&gt;Azimuth: 225.40467\u00b0&lt;dd&gt;Altitude: 52.974609\u00b0&lt;dd&gt;Slant Range: 676.05967km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.253986915603404, 49.03333432142345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.6687463353158, 48.904993556047664], [-6.5859731389329665, 48.93079323201328], [-6.5031105430805365, 48.95652727226267], [-6.420158602781849, 48.98219555106102], [-6.337117374389669, 49.00779794268476], [-6.253986915603404, 49.03333432142345], [-6.170767285464912, 49.05880456158143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.1707673&lt;dd&gt;Longitude: 49.058805&lt;dd&gt;Azimuth: 225.00709\u00b0&lt;dd&gt;Altitude: 53.452147\u00b0&lt;dd&gt;Slant Range: 672.35468km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.170767285464912, 49.05880456158143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.5859731389329665, 48.93079323201328], [-6.5031105430805365, 48.95652727226267], [-6.420158602781849, 48.98219555106102], [-6.337117374389669, 49.00779794268476], [-6.253986915603404, 49.03333432142345], [-6.170767285464912, 49.05880456158143], [-6.08745854437247, 49.08420853748029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.0874585&lt;dd&gt;Longitude: 49.084209&lt;dd&gt;Azimuth: 224.59585\u00b0&lt;dd&gt;Altitude: 53.933184\u00b0&lt;dd&gt;Slant Range: 668.70237km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.08745854437247, 49.08420853748029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.5031105430805365, 48.95652727226267], [-6.420158602781849, 48.98219555106102], [-6.337117374389669, 49.00779794268476], [-6.253986915603404, 49.03333432142345], [-6.170767285464912, 49.05880456158143], [-6.08745854437247, 49.08420853748029], [-6.0040607540768, 49.10954612346075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -6.0040608&lt;dd&gt;Longitude: 49.109546&lt;dd&gt;Azimuth: 224.17028\u00b0&lt;dd&gt;Altitude: 54.417623\u00b0&lt;dd&gt;Slant Range: 665.10361km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.0040607540768, 49.10954612346075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.420158602781849, 48.98219555106102], [-6.337117374389669, 49.00779794268476], [-6.253986915603404, 49.03333432142345], [-6.170767285464912, 49.05880456158143], [-6.08745854437247, 49.08420853748029], [-6.0040607540768, 49.10954612346075], [-5.9205739776983, 49.1348171938843]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.920574&lt;dd&gt;Longitude: 49.134817&lt;dd&gt;Azimuth: 223.72968\u00b0&lt;dd&gt;Altitude: 54.905355\u00b0&lt;dd&gt;Slant Range: 661.55928km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.9205739776983, 49.1348171938843]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.337117374389669, 49.00779794268476], [-6.253986915603404, 49.03333432142345], [-6.170767285464912, 49.05880456158143], [-6.08745854437247, 49.08420853748029], [-6.0040607540768, 49.10954612346075], [-5.9205739776983, 49.1348171938843], [-5.836998279712666, 49.16002162313674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.8369983&lt;dd&gt;Longitude: 49.160022&lt;dd&gt;Azimuth: 223.2733\u00b0&lt;dd&gt;Altitude: 55.396263\u00b0&lt;dd&gt;Slant Range: 658.07026km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.836998279712666, 49.16002162313674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.253986915603404, 49.03333432142345], [-6.170767285464912, 49.05880456158143], [-6.08745854437247, 49.08420853748029], [-6.0040607540768, 49.10954612346075], [-5.9205739776983, 49.1348171938843], [-5.836998279712666, 49.16002162313674], [-5.7533337259792106, 49.18515928562817]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.7533337&lt;dd&gt;Longitude: 49.185159&lt;dd&gt;Azimuth: 222.80034\u00b0&lt;dd&gt;Altitude: 55.890215\u00b0&lt;dd&gt;Slant Range: 654.63744km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.7533337259792106, 49.18515928562817]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.170767285464912, 49.05880456158143], [-6.08745854437247, 49.08420853748029], [-6.0040607540768, 49.10954612346075], [-5.9205739776983, 49.1348171938843], [-5.836998279712666, 49.16002162313674], [-5.7533337259792106, 49.18515928562817], [-5.669580383730739, 49.210230055796956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.6695804&lt;dd&gt;Longitude: 49.21023&lt;dd&gt;Azimuth: 222.30996\u00b0&lt;dd&gt;Altitude: 56.387067\u00b0&lt;dd&gt;Slant Range: 651.26171km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.669580383730739, 49.210230055796956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.08745854437247, 49.08420853748029], [-6.0040607540768, 49.10954612346075], [-5.9205739776983, 49.1348171938843], [-5.836998279712666, 49.16002162313674], [-5.7533337259792106, 49.18515928562817], [-5.669580383730739, 49.210230055796956], [-5.585738321581228, 49.23523380811061]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.5857383&lt;dd&gt;Longitude: 49.235234&lt;dd&gt;Azimuth: 221.80126\u00b0&lt;dd&gt;Altitude: 56.886661\u00b0&lt;dd&gt;Slant Range: 647.94397km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.585738321581228, 49.23523380811061]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.0040607540768, 49.10954612346075], [-5.9205739776983, 49.1348171938843], [-5.836998279712666, 49.16002162313674], [-5.7533337259792106, 49.18515928562817], [-5.669580383730739, 49.210230055796956], [-5.585738321581228, 49.23523380811061], [-5.501807609530465, 49.2601704170689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.5018076&lt;dd&gt;Longitude: 49.26017&lt;dd&gt;Azimuth: 221.27329\u00b0&lt;dd&gt;Altitude: 57.388826\u00b0&lt;dd&gt;Slant Range: 644.68512km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.501807609530465, 49.2601704170689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.9205739776983, 49.1348171938843], [-5.836998279712666, 49.16002162313674], [-5.7533337259792106, 49.18515928562817], [-5.669580383730739, 49.210230055796956], [-5.585738321581228, 49.23523380811061], [-5.501807609530465, 49.2601704170689], [-5.4177883189773715, 49.28503975720496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.4177883&lt;dd&gt;Longitude: 49.28504&lt;dd&gt;Azimuth: 220.72503\u00b0&lt;dd&gt;Altitude: 57.893374\u00b0&lt;dd&gt;Slant Range: 641.48605km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.4177883189773715, 49.28503975720496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.836998279712666, 49.16002162313674], [-5.7533337259792106, 49.18515928562817], [-5.669580383730739, 49.210230055796956], [-5.585738321581228, 49.23523380811061], [-5.501807609530465, 49.2601704170689], [-5.4177883189773715, 49.28503975720496], [-5.333680522706474, 49.309841703088374]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.3336805&lt;dd&gt;Longitude: 49.309842&lt;dd&gt;Azimuth: 220.1554\u00b0&lt;dd&gt;Altitude: 58.400098\u00b0&lt;dd&gt;Slant Range: 638.34767km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.333680522706474, 49.309841703088374]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.7533337259792106, 49.18515928562817], [-5.669580383730739, 49.210230055796956], [-5.585738321581228, 49.23523380811061], [-5.501807609530465, 49.2601704170689], [-5.4177883189773715, 49.28503975720496], [-5.333680522706474, 49.309841703088374], [-5.249484294917034, 49.334576129326834]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.2494843&lt;dd&gt;Longitude: 49.334576&lt;dd&gt;Azimuth: 219.56327\u00b0&lt;dd&gt;Altitude: 58.908776\u00b0&lt;dd&gt;Slant Range: 635.27088km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.249484294917034, 49.334576129326834]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.669580383730739, 49.210230055796956], [-5.585738321581228, 49.23523380811061], [-5.501807609530465, 49.2601704170689], [-5.4177883189773715, 49.28503975720496], [-5.333680522706474, 49.309841703088374], [-5.249484294917034, 49.334576129326834], [-5.165199711205112, 49.35924291056847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.1651997&lt;dd&gt;Longitude: 49.359243&lt;dd&gt;Azimuth: 218.9474\u00b0&lt;dd&gt;Altitude: 59.419165\u00b0&lt;dd&gt;Slant Range: 632.25659km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.165199711205112, 49.35924291056847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.585738321581228, 49.23523380811061], [-5.501807609530465, 49.2601704170689], [-5.4177883189773715, 49.28503975720496], [-5.333680522706474, 49.309841703088374], [-5.249484294917034, 49.334576129326834], [-5.165199711205112, 49.35924291056847], [-5.080826848587457, 49.38384192150365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -5.0808268&lt;dd&gt;Longitude: 49.383842&lt;dd&gt;Azimuth: 218.30651\u00b0&lt;dd&gt;Altitude: 59.931001\u00b0&lt;dd&gt;Slant Range: 629.3057km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.080826848587457, 49.38384192150365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.501807609530465, 49.2601704170689], [-5.4177883189773715, 49.28503975720496], [-5.333680522706474, 49.309841703088374], [-5.249484294917034, 49.334576129326834], [-5.165199711205112, 49.35924291056847], [-5.080826848587457, 49.38384192150365], [-4.996365785485583, 49.40837303686777]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.9963658&lt;dd&gt;Longitude: 49.408373&lt;dd&gt;Azimuth: 217.63921\u00b0&lt;dd&gt;Altitude: 60.443999\u00b0&lt;dd&gt;Slant Range: 626.4191km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.996365785485583, 49.40837303686777]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.4177883189773715, 49.28503975720496], [-5.333680522706474, 49.309841703088374], [-5.249484294917034, 49.334576129326834], [-5.165199711205112, 49.35924291056847], [-5.080826848587457, 49.38384192150365], [-4.996365785485583, 49.40837303686777], [-4.911816601755023, 49.432836131443324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.9118166&lt;dd&gt;Longitude: 49.432836&lt;dd&gt;Azimuth: 216.94405\u00b0&lt;dd&gt;Altitude: 60.95785\u00b0&lt;dd&gt;Slant Range: 623.59769km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.911816601755023, 49.432836131443324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.333680522706474, 49.309841703088374], [-5.249484294917034, 49.334576129326834], [-5.165199711205112, 49.35924291056847], [-5.080826848587457, 49.38384192150365], [-4.996365785485583, 49.40837303686777], [-4.911816601755023, 49.432836131443324], [-4.827179378667676, 49.45723108006184]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.8271794&lt;dd&gt;Longitude: 49.457231&lt;dd&gt;Azimuth: 216.21947\u00b0&lt;dd&gt;Altitude: 61.472217\u00b0&lt;dd&gt;Slant Range: 620.84236km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.827179378667676, 49.45723108006184]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.249484294917034, 49.334576129326834], [-5.165199711205112, 49.35924291056847], [-5.080826848587457, 49.38384192150365], [-4.996365785485583, 49.40837303686777], [-4.911816601755023, 49.432836131443324], [-4.827179378667676, 49.45723108006184], [-4.7424541989324425, 49.48155775760625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.7424542&lt;dd&gt;Longitude: 49.481558&lt;dd&gt;Azimuth: 215.46381\u00b0&lt;dd&gt;Altitude: 61.986737\u00b0&lt;dd&gt;Slant Range: 618.154km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.7424541989324425, 49.48155775760625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.165199711205112, 49.35924291056847], [-5.080826848587457, 49.38384192150365], [-4.996365785485583, 49.40837303686777], [-4.911816601755023, 49.432836131443324], [-4.827179378667676, 49.45723108006184], [-4.7424541989324425, 49.48155775760625], [-4.657641146687641, 49.505816039013375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.6576411&lt;dd&gt;Longitude: 49.505816&lt;dd&gt;Azimuth: 214.67533\u00b0&lt;dd&gt;Altitude: 62.50102\u00b0&lt;dd&gt;Slant Range: 615.5335km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.657641146687641, 49.505816039013375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.080826848587457, 49.38384192150365], [-4.996365785485583, 49.40837303686777], [-4.911816601755023, 49.432836131443324], [-4.827179378667676, 49.45723108006184], [-4.7424541989324425, 49.48155775760625], [-4.657641146687641, 49.505816039013375], [-4.572740307520061, 49.530005799275386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.5727403&lt;dd&gt;Longitude: 49.530006&lt;dd&gt;Azimuth: 213.85216\u00b0&lt;dd&gt;Altitude: 63.014639\u00b0&lt;dd&gt;Slant Range: 612.98171km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.572740307520061, 49.530005799275386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.996365785485583, 49.40837303686777], [-4.911816601755023, 49.432836131443324], [-4.827179378667676, 49.45723108006184], [-4.7424541989324425, 49.48155775760625], [-4.657641146687641, 49.505816039013375], [-4.572740307520061, 49.530005799275386], [-4.487751768451489, 49.5541269134432]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.4877518&lt;dd&gt;Longitude: 49.554127&lt;dd&gt;Azimuth: 212.99236\u00b0&lt;dd&gt;Altitude: 63.527139\u00b0&lt;dd&gt;Slant Range: 610.49951km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.487751768451489, 49.5541269134432]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.911816601755023, 49.432836131443324], [-4.827179378667676, 49.45723108006184], [-4.7424541989324425, 49.48155775760625], [-4.657641146687641, 49.505816039013375], [-4.572740307520061, 49.530005799275386], [-4.487751768451489, 49.5541269134432], [-4.402675617956532, 49.57817925662785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.4026756&lt;dd&gt;Longitude: 49.578179&lt;dd&gt;Azimuth: 212.09383\u00b0&lt;dd&gt;Altitude: 64.038023\u00b0&lt;dd&gt;Slant Range: 608.08775km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.402675617956532, 49.57817925662785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.827179378667676, 49.45723108006184], [-4.7424541989324425, 49.48155775760625], [-4.657641146687641, 49.505816039013375], [-4.572740307520061, 49.530005799275386], [-4.487751768451489, 49.5541269134432], [-4.402675617956532, 49.57817925662785], [-4.3175119459705895, 49.6021627040033]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.3175119&lt;dd&gt;Longitude: 49.602163&lt;dd&gt;Azimuth: 211.1544\u00b0&lt;dd&gt;Altitude: 64.54676\u00b0&lt;dd&gt;Slant Range: 605.74728km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.3175119459705895, 49.6021627040033]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.7424541989324425, 49.48155775760625], [-4.657641146687641, 49.505816039013375], [-4.572740307520061, 49.530005799275386], [-4.487751768451489, 49.5541269134432], [-4.402675617956532, 49.57817925662785], [-4.3175119459705895, 49.6021627040033], [-4.232260843875553, 49.62607713080829]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.2322608&lt;dd&gt;Longitude: 49.626077&lt;dd&gt;Azimuth: 210.17175\u00b0&lt;dd&gt;Altitude: 65.052775\u00b0&lt;dd&gt;Slant Range: 603.47893km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.232260843875553, 49.62607713080829]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.657641146687641, 49.505816039013375], [-4.572740307520061, 49.530005799275386], [-4.487751768451489, 49.5541269134432], [-4.402675617956532, 49.57817925662785], [-4.3175119459705895, 49.6021627040033], [-4.232260843875553, 49.62607713080829], [-4.146922404525476, 49.64992241234908]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.1469224&lt;dd&gt;Longitude: 49.649922&lt;dd&gt;Azimuth: 209.14346\u00b0&lt;dd&gt;Altitude: 65.555449\u00b0&lt;dd&gt;Slant Range: 601.28351km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.146922404525476, 49.64992241234908]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.572740307520061, 49.530005799275386], [-4.487751768451489, 49.5541269134432], [-4.402675617956532, 49.57817925662785], [-4.3175119459705895, 49.6021627040033], [-4.232260843875553, 49.62607713080829], [-4.146922404525476, 49.64992241234908], [-4.061496722237216, 49.673698424001344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -4.0614967&lt;dd&gt;Longitude: 49.673698&lt;dd&gt;Azimuth: 208.06702\u00b0&lt;dd&gt;Altitude: 66.054115\u00b0&lt;dd&gt;Slant Range: 599.16183km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.061496722237216, 49.673698424001344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.487751768451489, 49.5541269134432], [-4.402675617956532, 49.57817925662785], [-4.3175119459705895, 49.6021627040033], [-4.232260843875553, 49.62607713080829], [-4.146922404525476, 49.64992241234908], [-4.061496722237216, 49.673698424001344], [-3.97598389279801, 49.69740504121314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.9759839&lt;dd&gt;Longitude: 49.697405&lt;dd&gt;Azimuth: 206.93978\u00b0&lt;dd&gt;Altitude: 66.548057\u00b0&lt;dd&gt;Slant Range: 597.11468km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.97598389279801, 49.69740504121314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.402675617956532, 49.57817925662785], [-4.3175119459705895, 49.6021627040033], [-4.232260843875553, 49.62607713080829], [-4.146922404525476, 49.64992241234908], [-4.061496722237216, 49.673698424001344], [-3.97598389279801, 49.69740504121314], [-3.8903840134764214, 49.72104213950603]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.890384&lt;dd&gt;Longitude: 49.721042&lt;dd&gt;Azimuth: 205.75902\u00b0&lt;dd&gt;Altitude: 67.036504\u00b0&lt;dd&gt;Slant Range: 595.14283km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8903840134764214, 49.72104213950603]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.3175119459705895, 49.6021627040033], [-4.232260843875553, 49.62607713080829], [-4.146922404525476, 49.64992241234908], [-4.061496722237216, 49.673698424001344], [-3.97598389279801, 49.69740504121314], [-3.8903840134764214, 49.72104213950603], [-3.8046971830205565, 49.74460959447888]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.8046972&lt;dd&gt;Longitude: 49.74461&lt;dd&gt;Azimuth: 204.52192\u00b0&lt;dd&gt;Altitude: 67.518631\u00b0&lt;dd&gt;Slant Range: 593.24703km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8046971830205565, 49.74460959447888]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.232260843875553, 49.62607713080829], [-4.146922404525476, 49.64992241234908], [-4.061496722237216, 49.673698424001344], [-3.97598389279801, 49.69740504121314], [-3.8903840134764214, 49.72104213950603], [-3.8046971830205565, 49.74460959447888], [-3.7189235016562576, 49.76810728180921]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.7189235&lt;dd&gt;Longitude: 49.768107&lt;dd&gt;Azimuth: 203.22562\u00b0&lt;dd&gt;Altitude: 67.993551\u00b0&lt;dd&gt;Slant Range: 591.42802km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7189235016562576, 49.76810728180921]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.146922404525476, 49.64992241234908], [-4.061496722237216, 49.673698424001344], [-3.97598389279801, 49.69740504121314], [-3.8903840134764214, 49.72104213950603], [-3.8046971830205565, 49.74460959447888], [-3.7189235016562576, 49.76810728180921], [-3.633063071107104, 49.79153507725609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.6330631&lt;dd&gt;Longitude: 49.791535&lt;dd&gt;Azimuth: 201.8672\u00b0&lt;dd&gt;Altitude: 68.460318\u00b0&lt;dd&gt;Slant Range: 589.6865km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.633063071107104, 49.79153507725609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.061496722237216, 49.673698424001344], [-3.97598389279801, 49.69740504121314], [-3.8903840134764214, 49.72104213950603], [-3.8046971830205565, 49.74460959447888], [-3.7189235016562576, 49.76810728180921], [-3.633063071107104, 49.79153507725609], [-3.547115994582756, 49.81489285666202]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.547116&lt;dd&gt;Longitude: 49.814893&lt;dd&gt;Azimuth: 200.44376\u00b0&lt;dd&gt;Altitude: 68.91792\u00b0&lt;dd&gt;Slant Range: 588.02318km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.547115994582756, 49.81489285666202]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.97598389279801, 49.69740504121314], [-3.8903840134764214, 49.72104213950603], [-3.8046971830205565, 49.74460959447888], [-3.7189235016562576, 49.76810728180921], [-3.633063071107104, 49.79153507725609], [-3.547115994582756, 49.81489285666202], [-3.4610823768002543, 49.83818049595589]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.4610824&lt;dd&gt;Longitude: 49.83818&lt;dd&gt;Azimuth: 198.95241\u00b0&lt;dd&gt;Altitude: 69.36528\u00b0&lt;dd&gt;Slant Range: 586.4387km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4610823768002543, 49.83818049595589]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8903840134764214, 49.72104213950603], [-3.8046971830205565, 49.74460959447888], [-3.7189235016562576, 49.76810728180921], [-3.633063071107104, 49.79153507725609], [-3.547115994582756, 49.81489285666202], [-3.4610823768002543, 49.83818049595589], [-3.374962323965469, 49.86139787115492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.3749623&lt;dd&gt;Longitude: 49.861398&lt;dd&gt;Azimuth: 197.39036\u00b0&lt;dd&gt;Altitude: 69.801253\u00b0&lt;dd&gt;Slant Range: 584.93373km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.374962323965469, 49.86139787115492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8046971830205565, 49.74460959447888], [-3.7189235016562576, 49.76810728180921], [-3.633063071107104, 49.79153507725609], [-3.547115994582756, 49.81489285666202], [-3.4610823768002543, 49.83818049595589], [-3.374962323965469, 49.86139787115492], [-3.2887559438003784, 49.884544858367285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.2887559&lt;dd&gt;Longitude: 49.884545&lt;dd&gt;Azimuth: 195.755\u00b0&lt;dd&gt;Altitude: 70.22463\u00b0&lt;dd&gt;Slant Range: 583.50887km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2887559438003784, 49.884544858367285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7189235016562576, 49.76810728180921], [-3.633063071107104, 49.79153507725609], [-3.547115994582756, 49.81489285666202], [-3.4610823768002543, 49.83818049595589], [-3.374962323965469, 49.86139787115492], [-3.2887559438003784, 49.884544858367285], [-3.202463345531311, 49.907621333794275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.2024633&lt;dd&gt;Longitude: 49.907621&lt;dd&gt;Azimuth: 194.0439\u00b0&lt;dd&gt;Altitude: 70.634134\u00b0&lt;dd&gt;Slant Range: 582.16471km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.202463345531311, 49.907621333794275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.633063071107104, 49.79153507725609], [-3.547115994582756, 49.81489285666202], [-3.4610823768002543, 49.83818049595589], [-3.374962323965469, 49.86139787115492], [-3.2887559438003784, 49.884544858367285], [-3.202463345531311, 49.907621333794275], [-3.1160846399038835, 49.930627173733086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.1160846&lt;dd&gt;Longitude: 49.930627&lt;dd&gt;Azimuth: 192.25499\u00b0&lt;dd&gt;Altitude: 71.028425\u00b0&lt;dd&gt;Slant Range: 580.90182km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1160846399038835, 49.930627173733086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.547115994582756, 49.81489285666202], [-3.4610823768002543, 49.83818049595589], [-3.374962323965469, 49.86139787115492], [-3.2887559438003784, 49.884544858367285], [-3.202463345531311, 49.907621333794275], [-3.1160846399038835, 49.930627173733086], [-3.0296199391731777, 49.95356225457904]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -3.0296199&lt;dd&gt;Longitude: 49.953562&lt;dd&gt;Azimuth: 190.38659\u00b0&lt;dd&gt;Altitude: 71.406109\u00b0&lt;dd&gt;Slant Range: 579.72073km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0296199391731777, 49.95356225457904]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4610823768002543, 49.83818049595589], [-3.374962323965469, 49.86139787115492], [-3.2887559438003784, 49.884544858367285], [-3.202463345531311, 49.907621333794275], [-3.1160846399038835, 49.930627173733086], [-3.0296199391731777, 49.95356225457904], [-2.9430693571260056, 49.97642645282819]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.9430694&lt;dd&gt;Longitude: 49.976426&lt;dd&gt;Azimuth: 188.43754\u00b0&lt;dd&gt;Altitude: 71.765738\u00b0&lt;dd&gt;Slant Range: 578.62193km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9430693571260056, 49.97642645282819]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.374962323965469, 49.86139787115492], [-3.2887559438003784, 49.884544858367285], [-3.202463345531311, 49.907621333794275], [-3.1160846399038835, 49.930627173733086], [-3.0296199391731777, 49.95356225457904], [-2.9430693571260056, 49.97642645282819], [-2.8564330090649803, 49.99921964507954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.856433&lt;dd&gt;Longitude: 49.99922&lt;dd&gt;Azimuth: 186.40735\u00b0&lt;dd&gt;Altitude: 72.105827\u00b0&lt;dd&gt;Slant Range: 577.60591km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8564330090649803, 49.99921964507954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2887559438003784, 49.884544858367285], [-3.202463345531311, 49.907621333794275], [-3.1160846399038835, 49.930627173733086], [-3.0296199391731777, 49.95356225457904], [-2.9430693571260056, 49.97642645282819], [-2.8564330090649803, 49.99921964507954], [-2.7697110118314425, 50.0219417080376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.769711&lt;dd&gt;Longitude: 50.021942&lt;dd&gt;Azimuth: 184.29628\u00b0&lt;dd&gt;Altitude: 72.424861\u00b0&lt;dd&gt;Slant Range: 576.67309km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7697110118314425, 50.0219417080376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.202463345531311, 49.907621333794275], [-3.1160846399038835, 49.930627173733086], [-3.0296199391731777, 49.95356225457904], [-2.9430693571260056, 49.97642645282819], [-2.8564330090649803, 49.99921964507954], [-2.7697110118314425, 50.0219417080376], [-2.6829034837957138, 50.044592518514506]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.6829035&lt;dd&gt;Longitude: 50.044593&lt;dd&gt;Azimuth: 182.10552\u00b0&lt;dd&gt;Altitude: 72.721316\u00b0&lt;dd&gt;Slant Range: 575.82389km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6829034837957138, 50.044592518514506]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1160846399038835, 49.930627173733086], [-3.0296199391731777, 49.95356225457904], [-2.9430693571260056, 49.97642645282819], [-2.8564330090649803, 49.99921964507954], [-2.7697110118314425, 50.0219417080376], [-2.6829034837957138, 50.044592518514506], [-2.596010544866385, 50.06717195343389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.5960105&lt;dd&gt;Longitude: 50.067172&lt;dd&gt;Azimuth: 179.83725\u00b0&lt;dd&gt;Altitude: 72.993676\u00b0&lt;dd&gt;Slant Range: 575.05867km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.596010544866385, 50.06717195343389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0296199391731777, 49.95356225457904], [-2.9430693571260056, 49.97642645282819], [-2.8564330090649803, 49.99921964507954], [-2.7697110118314425, 50.0219417080376], [-2.6829034837957138, 50.044592518514506], [-2.596010544866385, 50.06717195343389], [-2.5090323164936743, 50.08967988983126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.5090323&lt;dd&gt;Longitude: 50.08968&lt;dd&gt;Azimuth: 177.4948\u00b0&lt;dd&gt;Altitude: 73.240457\u00b0&lt;dd&gt;Slant Range: 574.37778km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5090323164936743, 50.08967988983126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9430693571260056, 49.97642645282819], [-2.8564330090649803, 49.99921964507954], [-2.7697110118314425, 50.0219417080376], [-2.6829034837957138, 50.044592518514506], [-2.596010544866385, 50.06717195343389], [-2.5090323164936743, 50.08967988983126], [-2.4219689216708784, 50.11211620485803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.4219689&lt;dd&gt;Longitude: 50.112116&lt;dd&gt;Azimuth: 175.08271\u00b0&lt;dd&gt;Altitude: 73.460233\u00b0&lt;dd&gt;Slant Range: 573.78151km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.4219689216708784, 50.11211620485803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8564330090649803, 49.99921964507954], [-2.7697110118314425, 50.0219417080376], [-2.6829034837957138, 50.044592518514506], [-2.596010544866385, 50.06717195343389], [-2.5090323164936743, 50.08967988983126], [-2.4219689216708784, 50.11211620485803], [-2.3348204849446765, 50.134480775783715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.3348205&lt;dd&gt;Longitude: 50.134481&lt;dd&gt;Azimuth: 172.60676\u00b0&lt;dd&gt;Altitude: 73.651664\u00b0&lt;dd&gt;Slant Range: 573.27012km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3348204849446765, 50.134480775783715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7697110118314425, 50.0219417080376], [-2.6829034837957138, 50.044592518514506], [-2.596010544866385, 50.06717195343389], [-2.5090323164936743, 50.08967988983126], [-2.4219689216708784, 50.11211620485803], [-2.3348204849446765, 50.134480775783715], [-2.247587132405207, 50.1567734799982]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.2475871&lt;dd&gt;Longitude: 50.156773&lt;dd&gt;Azimuth: 170.07402\u00b0&lt;dd&gt;Altitude: 73.813526\u00b0&lt;dd&gt;Slant Range: 572.84385km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.247587132405207, 50.1567734799982]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6829034837957138, 50.044592518514506], [-2.596010544866385, 50.06717195343389], [-2.5090323164936743, 50.08967988983126], [-2.4219689216708784, 50.11211620485803], [-2.3348204849446765, 50.134480775783715], [-2.247587132405207, 50.1567734799982], [-2.160268991706806, 50.17899419501417]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.160269&lt;dd&gt;Longitude: 50.178994&lt;dd&gt;Azimuth: 167.49275\u00b0&lt;dd&gt;Altitude: 73.944739\u00b0&lt;dd&gt;Slant Range: 572.50288km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.160268991706806, 50.17899419501417]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.596010544866385, 50.06717195343389], [-2.5090323164936743, 50.08967988983126], [-2.4219689216708784, 50.11211620485803], [-2.3348204849446765, 50.134480775783715], [-2.247587132405207, 50.1567734799982], [-2.160268991706806, 50.17899419501417], [-2.0728661920599905, 50.20114279847049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -2.0728662&lt;dd&gt;Longitude: 50.201143&lt;dd&gt;Azimuth: 164.87232\u00b0&lt;dd&gt;Altitude: 74.044397\u00b0&lt;dd&gt;Slant Range: 572.24737km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0728661920599905, 50.20114279847049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5090323164936743, 50.08967988983126], [-2.4219689216708784, 50.11211620485803], [-2.3348204849446765, 50.134480775783715], [-2.247587132405207, 50.1567734799982], [-2.160268991706806, 50.17899419501417], [-2.0728661920599905, 50.20114279847049], [-1.9853788642390422, 50.22321916813306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.9853789&lt;dd&gt;Longitude: 50.223219&lt;dd&gt;Azimuth: 162.22303\u00b0&lt;dd&gt;Altitude: 74.111795\u00b0&lt;dd&gt;Slant Range: 572.07744km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9853788642390422, 50.22321916813306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.4219689216708784, 50.11211620485803], [-2.3348204849446765, 50.134480775783715], [-2.247587132405207, 50.1567734799982], [-2.160268991706806, 50.17899419501417], [-2.0728661920599905, 50.20114279847049], [-1.9853788642390422, 50.22321916813306], [-1.8978071405795645, 50.24522318189976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.8978071&lt;dd&gt;Longitude: 50.245223&lt;dd&gt;Azimuth: 159.55591\u00b0&lt;dd&gt;Altitude: 74.146443\u00b0&lt;dd&gt;Slant Range: 571.99315km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8978071405795645, 50.24522318189976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3348204849446765, 50.134480775783715], [-2.247587132405207, 50.1567734799982], [-2.160268991706806, 50.17899419501417], [-2.0728661920599905, 50.20114279847049], [-1.9853788642390422, 50.22321916813306], [-1.8978071405795645, 50.24522318189976], [-1.8101511549962421, 50.267154717800565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.8101512&lt;dd&gt;Longitude: 50.267155&lt;dd&gt;Azimuth: 156.88244\u00b0&lt;dd&gt;Altitude: 74.14809\u00b0&lt;dd&gt;Slant Range: 571.99455km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8101511549962421, 50.267154717800565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.247587132405207, 50.1567734799982], [-2.160268991706806, 50.17899419501417], [-2.0728661920599905, 50.20114279847049], [-1.9853788642390422, 50.22321916813306], [-1.8978071405795645, 50.24522318189976], [-1.8101511549962421, 50.267154717800565], [-1.722411042963097, 50.28901365400173]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.722411&lt;dd&gt;Longitude: 50.289014&lt;dd&gt;Azimuth: 154.21427\u00b0&lt;dd&gt;Altitude: 74.116725\u00b0&lt;dd&gt;Slant Range: 572.08163km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.722411042963097, 50.28901365400173]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.160268991706806, 50.17899419501417], [-2.0728661920599905, 50.20114279847049], [-1.9853788642390422, 50.22321916813306], [-1.8978071405795645, 50.24522318189976], [-1.8101511549962421, 50.267154717800565], [-1.722411042963097, 50.28901365400173], [-1.6345869415487284, 50.31079986880792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.6345869&lt;dd&gt;Longitude: 50.3108&lt;dd&gt;Azimuth: 151.56291\u00b0&lt;dd&gt;Altitude: 74.052581\u00b0&lt;dd&gt;Slant Range: 572.25436km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6345869415487284, 50.31079986880792]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0728661920599905, 50.20114279847049], [-1.9853788642390422, 50.22321916813306], [-1.8978071405795645, 50.24522318189976], [-1.8101511549962421, 50.267154717800565], [-1.722411042963097, 50.28901365400173], [-1.6345869415487284, 50.31079986880792], [-1.5466789893835409, 50.33251324066457]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.546679&lt;dd&gt;Longitude: 50.332513&lt;dd&gt;Azimuth: 148.93943\u00b0&lt;dd&gt;Altitude: 73.956126\u00b0&lt;dd&gt;Slant Range: 572.51266km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5466789893835409, 50.33251324066457]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9853788642390422, 50.22321916813306], [-1.8978071405795645, 50.24522318189976], [-1.8101511549962421, 50.267154717800565], [-1.722411042963097, 50.28901365400173], [-1.6345869415487284, 50.31079986880792], [-1.5466789893835409, 50.33251324066457], [-1.4586873266917273, 50.35415364816085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.4586873&lt;dd&gt;Longitude: 50.354154&lt;dd&gt;Azimuth: 146.35421\u00b0&lt;dd&gt;Altitude: 73.82805\u00b0&lt;dd&gt;Slant Range: 572.8564km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4586873266917273, 50.35415364816085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8978071405795645, 50.24522318189976], [-1.8101511549962421, 50.267154717800565], [-1.722411042963097, 50.28901365400173], [-1.6345869415487284, 50.31079986880792], [-1.5466789893835409, 50.33251324066457], [-1.4586873266917273, 50.35415364816085], [-1.3706120952766134, 50.375720970032134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.3706121&lt;dd&gt;Longitude: 50.375721&lt;dd&gt;Azimuth: 143.81673\u00b0&lt;dd&gt;Altitude: 73.669243\u00b0&lt;dd&gt;Slant Range: 573.28545km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3706120952766134, 50.375720970032134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8101511549962421, 50.267154717800565], [-1.722411042963097, 50.28901365400173], [-1.6345869415487284, 50.31079986880792], [-1.5466789893835409, 50.33251324066457], [-1.4586873266917273, 50.35415364816085], [-1.3706120952766134, 50.375720970032134], [-1.2824534385386976, 50.39721508516187]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.2824534&lt;dd&gt;Longitude: 50.397215&lt;dd&gt;Azimuth: 141.33534\u00b0&lt;dd&gt;Altitude: 73.48077\u00b0&lt;dd&gt;Slant Range: 573.7996km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2824534385386976, 50.39721508516187]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.722411042963097, 50.28901365400173], [-1.6345869415487284, 50.31079986880792], [-1.5466789893835409, 50.33251324066457], [-1.4586873266917273, 50.35415364816085], [-1.3706120952766134, 50.375720970032134], [-1.2824534385386976, 50.39721508516187], [-1.1942115014599266, 50.4186358725862]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.1942115&lt;dd&gt;Longitude: 50.418636&lt;dd&gt;Azimuth: 138.91721\u00b0&lt;dd&gt;Altitude: 73.263847\u00b0&lt;dd&gt;Slant Range: 574.39863km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1942115014599266, 50.4186358725862]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6345869415487284, 50.31079986880792], [-1.5466789893835409, 50.33251324066457], [-1.4586873266917273, 50.35415364816085], [-1.3706120952766134, 50.375720970032134], [-1.2824534385386976, 50.39721508516187], [-1.1942115014599266, 50.4186358725862], [-1.1058864306274347, 50.439983211494045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.1058864&lt;dd&gt;Longitude: 50.439983&lt;dd&gt;Azimuth: 136.56826\u00b0&lt;dd&gt;Altitude: 73.019804\u00b0&lt;dd&gt;Slant Range: 575.08227km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1058864306274347, 50.439983211494045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5466789893835409, 50.33251324066457], [-1.4586873266917273, 50.35415364816085], [-1.3706120952766134, 50.375720970032134], [-1.2824534385386976, 50.39721508516187], [-1.1942115014599266, 50.4186358725862], [-1.1058864306274347, 50.439983211494045], [-1.0174783742185065, 50.46125698123172]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -1.0174784&lt;dd&gt;Longitude: 50.461257&lt;dd&gt;Azimuth: 134.29313\u00b0&lt;dd&gt;Altitude: 72.750063\u00b0&lt;dd&gt;Slant Range: 575.85021km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0174783742185065, 50.46125698123172]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4586873266917273, 50.35415364816085], [-1.3706120952766134, 50.375720970032134], [-1.2824534385386976, 50.39721508516187], [-1.1942115014599266, 50.4186358725862], [-1.1058864306274347, 50.439983211494045], [-1.0174783742185065, 50.46125698123172], [-0.9289874820186677, 50.48245706130454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.92898748&lt;dd&gt;Longitude: 50.482457&lt;dd&gt;Azimuth: 132.09525\u00b0&lt;dd&gt;Altitude: 72.456103\u00b0&lt;dd&gt;Slant Range: 576.70213km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9289874820186677, 50.48245706130454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3706120952766134, 50.375720970032134], [-1.2824534385386976, 50.39721508516187], [-1.1942115014599266, 50.4186358725862], [-1.1058864306274347, 50.439983211494045], [-1.0174783742185065, 50.46125698123172], [-0.9289874820186677, 50.48245706130454], [-0.8404139054068505, 50.50358333138015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.84041391&lt;dd&gt;Longitude: 50.503583&lt;dd&gt;Azimuth: 129.97692\u00b0&lt;dd&gt;Altitude: 72.13944\u00b0&lt;dd&gt;Slant Range: 577.63764km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8404139054068505, 50.50358333138015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2824534385386976, 50.39721508516187], [-1.1942115014599266, 50.4186358725862], [-1.1058864306274347, 50.439983211494045], [-1.0174783742185065, 50.46125698123172], [-0.9289874820186677, 50.48245706130454], [-0.8404139054068505, 50.50358333138015], [-0.7517577973792109, 50.52463567129003]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.7517578&lt;dd&gt;Longitude: 50.524636&lt;dd&gt;Azimuth: 127.9394\u00b0&lt;dd&gt;Altitude: 71.801598\u00b0&lt;dd&gt;Slant Range: 578.65635km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7517577973792109, 50.52463567129003]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1942115014599266, 50.4186358725862], [-1.1058864306274347, 50.439983211494045], [-1.0174783742185065, 50.46125698123172], [-0.9289874820186677, 50.48245706130454], [-0.8404139054068505, 50.50358333138015], [-0.7517577973792109, 50.52463567129003], [-0.6630193125356417, 50.545613961034036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.66301931&lt;dd&gt;Longitude: 50.545614&lt;dd&gt;Azimuth: 125.98303\u00b0&lt;dd&gt;Altitude: 71.444094\u00b0&lt;dd&gt;Slant Range: 579.7578km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6630193125356417, 50.545613961034036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1058864306274347, 50.439983211494045], [-1.0174783742185065, 50.46125698123172], [-0.9289874820186677, 50.48245706130454], [-0.8404139054068505, 50.50358333138015], [-0.7517577973792109, 50.52463567129003], [-0.6630193125356417, 50.545613961034036], [-0.5741986070885267, 50.566518080781165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.57419861&lt;dd&gt;Longitude: 50.566518&lt;dd&gt;Azimuth: 124.10737\u00b0&lt;dd&gt;Altitude: 71.068418\u00b0&lt;dd&gt;Slant Range: 580.94153km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5741986070885267, 50.566518080781165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0174783742185065, 50.46125698123172], [-0.9289874820186677, 50.48245706130454], [-0.8404139054068505, 50.50358333138015], [-0.7517577973792109, 50.52463567129003], [-0.6630193125356417, 50.545613961034036], [-0.5741986070885267, 50.566518080781165], [-0.4852958388640368, 50.58734791087339]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.48529584&lt;dd&gt;Longitude: 50.587348&lt;dd&gt;Azimuth: 122.31134\u00b0&lt;dd&gt;Altitude: 70.676019\u00b0&lt;dd&gt;Slant Range: 582.20704km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4852958388640368, 50.58734791087339]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9289874820186677, 50.48245706130454], [-0.8404139054068505, 50.50358333138015], [-0.7517577973792109, 50.52463567129003], [-0.6630193125356417, 50.545613961034036], [-0.5741986070885267, 50.566518080781165], [-0.4852958388640368, 50.58734791087339], [-0.3963111673095616, 50.60810333182807]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.39631117&lt;dd&gt;Longitude: 50.608103&lt;dd&gt;Azimuth: 120.5933\u00b0&lt;dd&gt;Altitude: 70.268301\u00b0&lt;dd&gt;Slant Range: 583.55379km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3963111673095616, 50.60810333182807]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8404139054068505, 50.50358333138015], [-0.7517577973792109, 50.52463567129003], [-0.6630193125356417, 50.545613961034036], [-0.5741986070885267, 50.566518080781165], [-0.4852958388640368, 50.58734791087339], [-0.3963111673095616, 50.60810333182807], [-0.3072447534839117, 50.62878422434053]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.30724475&lt;dd&gt;Longitude: 50.628784&lt;dd&gt;Azimuth: 118.9512\u00b0&lt;dd&gt;Altitude: 69.846605\u00b0&lt;dd&gt;Slant Range: 584.98122km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3072447534839117, 50.62878422434053]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7517577973792109, 50.52463567129003], [-0.6630193125356417, 50.545613961034036], [-0.5741986070885267, 50.566518080781165], [-0.4852958388640368, 50.58734791087339], [-0.3963111673095616, 50.60810333182807], [-0.3072447534839117, 50.62878422434053], [-0.21809676007579246, 50.64939046928681]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.21809676&lt;dd&gt;Longitude: 50.64939&lt;dd&gt;Azimuth: 117.38264\u00b0&lt;dd&gt;Altitude: 69.412216\u00b0&lt;dd&gt;Slant Range: 586.48874km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.21809676007579246, 50.64939046928681]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6630193125356417, 50.545613961034036], [-0.5741986070885267, 50.566518080781165], [-0.4852958388640368, 50.58734791087339], [-0.3963111673095616, 50.60810333182807], [-0.3072447534839117, 50.62878422434053], [-0.21809676007579246, 50.64939046928681], [-0.12886735139675512, 50.66992194772675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.12886735&lt;dd&gt;Longitude: 50.669922&lt;dd&gt;Azimuth: 115.88503\u00b0&lt;dd&gt;Altitude: 68.966348\u00b0&lt;dd&gt;Slant Range: 588.07572km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.12886735139675512, 50.66992194772675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5741986070885267, 50.566518080781165], [-0.4852958388640368, 50.58734791087339], [-0.3963111673095616, 50.60810333182807], [-0.3072447534839117, 50.62878422434053], [-0.21809676007579246, 50.64939046928681], [-0.12886735139675512, 50.66992194772675], [-0.03955669338081571, 50.69037854090563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: -0.039556693&lt;dd&gt;Longitude: 50.690379&lt;dd&gt;Azimuth: 114.45558\u00b0&lt;dd&gt;Altitude: 68.510152\u00b0&lt;dd&gt;Slant Range: 589.74154km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.03955669338081571, 50.69037854090563]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4852958388640368, 50.58734791087339], [-0.3963111673095616, 50.60810333182807], [-0.3072447534839117, 50.62878422434053], [-0.21809676007579246, 50.64939046928681], [-0.12886735139675512, 50.66992194772675], [-0.03955669338081571, 50.69037854090563], [0.049835046404731395, 50.71076013025877]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.049835046&lt;dd&gt;Longitude: 50.71076&lt;dd&gt;Azimuth: 113.09142\u00b0&lt;dd&gt;Altitude: 68.044711\u00b0&lt;dd&gt;Slant Range: 591.48551km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.049835046404731395, 50.71076013025877]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3963111673095616, 50.60810333182807], [-0.3072447534839117, 50.62878422434053], [-0.21809676007579246, 50.64939046928681], [-0.12886735139675512, 50.66992194772675], [-0.03955669338081571, 50.69037854090563], [0.049835046404731395, 50.71076013025877], [0.13930769876356258, 50.73106659741205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.1393077&lt;dd&gt;Longitude: 50.731067&lt;dd&gt;Azimuth: 111.78964\u00b0&lt;dd&gt;Altitude: 67.571041\u00b0&lt;dd&gt;Slant Range: 593.30695km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.13930769876356258, 50.73106659741205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3072447534839117, 50.62878422434053], [-0.21809676007579246, 50.64939046928681], [-0.12886735139675512, 50.66992194772675], [-0.03955669338081571, 50.69037854090563], [0.049835046404731395, 50.71076013025877], [0.13930769876356258, 50.73106659741205], [0.2288610928630479, 50.75129782418642]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.22886109&lt;dd&gt;Longitude: 50.751298&lt;dd&gt;Azimuth: 110.54733\u00b0&lt;dd&gt;Altitude: 67.090096\u00b0&lt;dd&gt;Slant Range: 595.20514km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.2288610928630479, 50.75129782418642]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.21809676007579246, 50.64939046928681], [-0.12886735139675512, 50.66992194772675], [-0.03955669338081571, 50.69037854090563], [0.049835046404731395, 50.71076013025877], [0.13930769876356258, 50.73106659741205], [0.2288610928630479, 50.75129782418642], [0.3184950562412738, 50.7714536925998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.31849506&lt;dd&gt;Longitude: 50.771454&lt;dd&gt;Azimuth: 109.36162\u00b0&lt;dd&gt;Altitude: 66.602766\u00b0&lt;dd&gt;Slant Range: 597.17936km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3184950562412738, 50.7714536925998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.12886735139675512, 50.66992194772675], [-0.03955669338081571, 50.69037854090563], [0.049835046404731395, 50.71076013025877], [0.13930769876356258, 50.73106659741205], [0.2288610928630479, 50.75129782418642], [0.3184950562412738, 50.7714536925998], [0.40820941478806133, 50.791534084869916]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.40820941&lt;dd&gt;Longitude: 50.791534&lt;dd&gt;Azimuth: 108.22968\u00b0&lt;dd&gt;Altitude: 66.109882\u00b0&lt;dd&gt;Slant Range: 599.22883km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.40820941478806133, 50.791534084869916]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.03955669338081571, 50.69037854090563], [0.049835046404731395, 50.71076013025877], [0.13930769876356258, 50.73106659741205], [0.2288610928630479, 50.75129782418642], [0.3184950562412738, 50.7714536925998], [0.40820941478806133, 50.791534084869916], [0.49800399276682333, 50.81153888341726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.49800399&lt;dd&gt;Longitude: 50.811539&lt;dd&gt;Azimuth: 107.14878\u00b0&lt;dd&gt;Altitude: 65.612219\u00b0&lt;dd&gt;Slant Range: 601.35281km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.49800399276682333, 50.81153888341726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.049835046404731395, 50.71076013025877], [0.13930769876356258, 50.73106659741205], [0.2288610928630479, 50.75129782418642], [0.3184950562412738, 50.7714536925998], [0.40820941478806133, 50.791534084869916], [0.49800399276682333, 50.81153888341726], [0.5878786127900866, 50.831467970867934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.58787861&lt;dd&gt;Longitude: 50.831468&lt;dd&gt;Azimuth: 106.11628\u00b0&lt;dd&gt;Altitude: 65.110497\u00b0&lt;dd&gt;Slant Range: 603.55049km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5878786127900866, 50.831467970867934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.13930769876356258, 50.73106659741205], [0.2288610928630479, 50.75129782418642], [0.3184950562412738, 50.7714536925998], [0.40820941478806133, 50.791534084869916], [0.49800399276682333, 50.81153888341726], [0.5878786127900866, 50.831467970867934], [0.6778330958318324, 50.851321230055575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.6778331&lt;dd&gt;Longitude: 50.851321&lt;dd&gt;Azimuth: 105.12964\u00b0&lt;dd&gt;Altitude: 64.605387\u00b0&lt;dd&gt;Slant Range: 605.82107km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6778330958318324, 50.851321230055575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.2288610928630479, 50.75129782418642], [0.3184950562412738, 50.7714536925998], [0.40820941478806133, 50.791534084869916], [0.49800399276682333, 50.81153888341726], [0.5878786127900866, 50.831467970867934], [0.6778330958318324, 50.851321230055575], [0.7678672612156648, 50.87109854402578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.76786726&lt;dd&gt;Longitude: 50.871099&lt;dd&gt;Azimuth: 104.18642\u00b0&lt;dd&gt;Altitude: 64.09751\u00b0&lt;dd&gt;Slant Range: 608.16373km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7678672612156648, 50.87109854402578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3184950562412738, 50.7714536925998], [0.40820941478806133, 50.791534084869916], [0.49800399276682333, 50.81153888341726], [0.5878786127900866, 50.831467970867934], [0.6778330958318324, 50.851321230055575], [0.7678672612156648, 50.87109854402578], [0.8579809266267192, 50.89079979603704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.85798093&lt;dd&gt;Longitude: 50.8908&lt;dd&gt;Azimuth: 103.28432\u00b0&lt;dd&gt;Altitude: 63.587446\u00b0&lt;dd&gt;Slant Range: 610.57763km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8579809266267192, 50.89079979603704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.40820941478806133, 50.791534084869916], [0.49800399276682333, 50.81153888341726], [0.5878786127900866, 50.831467970867934], [0.6778330958318324, 50.851321230055575], [0.7678672612156648, 50.87109854402578], [0.8579809266267192, 50.89079979603704], [0.9481739080940538, 50.91042486956491]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 0.94817391&lt;dd&gt;Longitude: 50.910425&lt;dd&gt;Azimuth: 102.42114\u00b0&lt;dd&gt;Altitude: 63.07573\u00b0&lt;dd&gt;Slant Range: 613.06195km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9481739080940538, 50.91042486956491]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.49800399276682333, 50.81153888341726], [0.5878786127900866, 50.831467970867934], [0.6778330958318324, 50.851321230055575], [0.7678672612156648, 50.87109854402578], [0.8579809266267192, 50.89079979603704], [0.9481739080940538, 50.91042486956491], [1.0384460200010064, 50.92997364830416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.038446&lt;dd&gt;Longitude: 50.929974&lt;dd&gt;Azimuth: 101.59479\u00b0&lt;dd&gt;Altitude: 62.562859\u00b0&lt;dd&gt;Slant Range: 615.61581km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0384460200010064, 50.92997364830416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5878786127900866, 50.831467970867934], [0.6778330958318324, 50.851321230055575], [0.7678672612156648, 50.87109854402578], [0.8579809266267192, 50.89079979603704], [0.9481739080940538, 50.91042486956491], [1.0384460200010064, 50.92997364830416], [1.1287970750797487, 50.94944601617176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.1287971&lt;dd&gt;Longitude: 50.949446&lt;dd&gt;Azimuth: 100.80329\u00b0&lt;dd&gt;Altitude: 62.049294\u00b0&lt;dd&gt;Slant Range: 618.23836km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1287970750797487, 50.94944601617176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6778330958318324, 50.851321230055575], [0.7678672612156648, 50.87109854402578], [0.8579809266267192, 50.89079979603704], [0.9481739080940538, 50.91042486956491], [1.0384460200010064, 50.92997364830416], [1.1287970750797487, 50.94944601617176], [1.21922688440546, 50.968841857309336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.2192269&lt;dd&gt;Longitude: 50.968842&lt;dd&gt;Azimuth: 100.04478\u00b0&lt;dd&gt;Altitude: 61.53546\u00b0&lt;dd&gt;Slant Range: 620.92871km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.21922688440546, 50.968841857309336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7678672612156648, 50.87109854402578], [0.8579809266267192, 50.89079979603704], [0.9481739080940538, 50.91042486956491], [1.0384460200010064, 50.92997364830416], [1.1287970750797487, 50.94944601617176], [1.21922688440546, 50.968841857309336], [1.3097352574004995, 50.98816105608693]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.3097353&lt;dd&gt;Longitude: 50.988161&lt;dd&gt;Azimuth: 99.3175\u00b0&lt;dd&gt;Altitude: 61.021753\u00b0&lt;dd&gt;Slant Range: 623.686km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3097352574004995, 50.98816105608693]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8579809266267192, 50.89079979603704], [0.9481739080940538, 50.91042486956491], [1.0384460200010064, 50.92997364830416], [1.1287970750797487, 50.94944601617176], [1.21922688440546, 50.968841857309336], [1.3097352574004995, 50.98816105608693], [1.400322001835374, 51.007403497104406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.400322&lt;dd&gt;Longitude: 51.007403&lt;dd&gt;Azimuth: 98.619788\u00b0&lt;dd&gt;Altitude: 60.508537\u00b0&lt;dd&gt;Slant Range: 626.50933km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.400322001835374, 51.007403497104406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9481739080940538, 50.91042486956491], [1.0384460200010064, 50.92997364830416], [1.1287970750797487, 50.94944601617176], [1.21922688440546, 50.968841857309336], [1.3097352574004995, 50.98816105608693], [1.400322001835374, 51.007403497104406], [1.4909869238195257, 51.026569065195936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.4909869&lt;dd&gt;Longitude: 51.026569&lt;dd&gt;Azimuth: 97.950082\u00b0&lt;dd&gt;Altitude: 59.996149\u00b0&lt;dd&gt;Slant Range: 629.39781km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4909869238195257, 51.026569065195936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0384460200010064, 50.92997364830416], [1.1287970750797487, 50.94944601617176], [1.21922688440546, 50.968841857309336], [1.3097352574004995, 50.98816105608693], [1.400322001835374, 51.007403497104406], [1.4909869238195257, 51.026569065195936], [1.5817298278056595, 51.04565764543106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.5817298&lt;dd&gt;Longitude: 51.045658&lt;dd&gt;Azimuth: 97.306909\u00b0&lt;dd&gt;Altitude: 59.484901\u00b0&lt;dd&gt;Slant Range: 632.35054km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5817298278056595, 51.04565764543106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1287970750797487, 50.94944601617176], [1.21922688440546, 50.968841857309336], [1.3097352574004995, 50.98816105608693], [1.400322001835374, 51.007403497104406], [1.4909869238195257, 51.026569065195936], [1.5817298278056595, 51.04565764543106], [1.6725505165845, 51.064669123118875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.6725505&lt;dd&gt;Longitude: 51.064669&lt;dd&gt;Azimuth: 96.688885\u00b0&lt;dd&gt;Altitude: 58.97508\u00b0&lt;dd&gt;Slant Range: 635.36664km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6725505165845, 51.064669123118875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.21922688440546, 50.968841857309336], [1.3097352574004995, 50.98816105608693], [1.400322001835374, 51.007403497104406], [1.4909869238195257, 51.026569065195936], [1.5817298278056595, 51.04565764543106], [1.6725505165845, 51.064669123118875], [1.7634487912915098, 51.08360338381036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.7634488&lt;dd&gt;Longitude: 51.083603&lt;dd&gt;Azimuth: 96.094707\u00b0&lt;dd&gt;Altitude: 58.466951\u00b0&lt;dd&gt;Slant Range: 638.44518km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7634487912915098, 51.08360338381036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3097352574004995, 50.98816105608693], [1.400322001835374, 51.007403497104406], [1.4909869238195257, 51.026569065195936], [1.5817298278056595, 51.04565764543106], [1.6725505165845, 51.064669123118875], [1.7634487912915098, 51.08360338381036], [1.8544244513955148, 51.10246031330125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.8544245&lt;dd&gt;Longitude: 51.10246&lt;dd&gt;Azimuth: 95.523149\u00b0&lt;dd&gt;Altitude: 57.960757\u00b0&lt;dd&gt;Slant Range: 641.58528km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8544244513955148, 51.10246031330125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.400322001835374, 51.007403497104406], [1.4909869238195257, 51.026569065195936], [1.5817298278056595, 51.04565764543106], [1.6725505165845, 51.064669123118875], [1.7634487912915098, 51.08360338381036], [1.8544244513955148, 51.10246031330125], [1.9454772947051937, 51.12123979763481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 1.9454773&lt;dd&gt;Longitude: 51.12124&lt;dd&gt;Azimuth: 94.973058\u00b0&lt;dd&gt;Altitude: 57.456724\u00b0&lt;dd&gt;Slant Range: 644.78602km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9454772947051937, 51.12123979763481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4909869238195257, 51.026569065195936], [1.5817298278056595, 51.04565764543106], [1.6725505165845, 51.064669123118875], [1.7634487912915098, 51.08360338381036], [1.8544244513955148, 51.10246031330125], [1.9454772947051937, 51.12123979763481], [2.0366071173707563, 51.13994172310497]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.0366071&lt;dd&gt;Longitude: 51.139942&lt;dd&gt;Azimuth: 94.443352\u00b0&lt;dd&gt;Altitude: 56.955057\u00b0&lt;dd&gt;Slant Range: 648.04652km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0366071173707563, 51.13994172310497]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5817298278056595, 51.04565764543106], [1.6725505165845, 51.064669123118875], [1.7634487912915098, 51.08360338381036], [1.8544244513955148, 51.10246031330125], [1.9454772947051937, 51.12123979763481], [2.0366071173707563, 51.13994172310497], [2.1278137138703315, 51.15856597625855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.1278137&lt;dd&gt;Longitude: 51.158566&lt;dd&gt;Azimuth: 93.93301\u00b0&lt;dd&gt;Altitude: 56.455946\u00b0&lt;dd&gt;Slant Range: 651.36585km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1278137138703315, 51.15856597625855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6725505165845, 51.064669123118875], [1.7634487912915098, 51.08360338381036], [1.8544244513955148, 51.10246031330125], [1.9454772947051937, 51.12123979763481], [2.0366071173707563, 51.13994172310497], [2.1278137138703315, 51.15856597625855], [2.2190968770204247, 51.17711244389894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.2190969&lt;dd&gt;Longitude: 51.177112&lt;dd&gt;Azimuth: 93.441072\u00b0&lt;dd&gt;Altitude: 55.959563\u00b0&lt;dd&gt;Slant Range: 654.74314km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2190968770204247, 51.17711244389894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7634487912915098, 51.08360338381036], [1.8544244513955148, 51.10246031330125], [1.9454772947051937, 51.12123979763481], [2.0366071173707563, 51.13994172310497], [2.1278137138703315, 51.15856597625855], [2.2190968770204247, 51.17711244389894], [2.3104563979740598, 51.19558101308851]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.3104564&lt;dd&gt;Longitude: 51.195581&lt;dd&gt;Azimuth: 92.966637\u00b0&lt;dd&gt;Altitude: 55.466067\u00b0&lt;dd&gt;Slant Range: 658.17747km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3104563979740598, 51.19558101308851]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8544244513955148, 51.10246031330125], [1.9454772947051937, 51.12123979763481], [2.0366071173707563, 51.13994172310497], [2.1278137138703315, 51.15856597625855], [2.2190968770204247, 51.17711244389894], [2.3104563979740598, 51.19558101308851], [2.4018920662197627, 51.21397157115141]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.4018921&lt;dd&gt;Longitude: 51.213972&lt;dd&gt;Azimuth: 92.508854\u00b0&lt;dd&gt;Altitude: 54.975603\u00b0&lt;dd&gt;Slant Range: 661.66796km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.4018920662197627, 51.21397157115141]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9454772947051937, 51.12123979763481], [2.0366071173707563, 51.13994172310497], [2.1278137138703315, 51.15856597625855], [2.2190968770204247, 51.17711244389894], [2.3104563979740598, 51.19558101308851], [2.4018920662197627, 51.21397157115141], [2.4934036695709243, 51.232284005676675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.4934037&lt;dd&gt;Longitude: 51.232284&lt;dd&gt;Azimuth: 92.066924\u00b0&lt;dd&gt;Altitude: 54.488303\u00b0&lt;dd&gt;Slant Range: 665.21373km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.4934036695709243, 51.232284005676675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0366071173707563, 51.13994172310497], [2.1278137138703315, 51.15856597625855], [2.2190968770204247, 51.17711244389894], [2.3104563979740598, 51.19558101308851], [2.4018920662197627, 51.21397157115141], [2.4934036695709243, 51.232284005676675], [2.5849909941858007, 51.25051820452106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.584991&lt;dd&gt;Longitude: 51.250518&lt;dd&gt;Azimuth: 91.640092\u00b0&lt;dd&gt;Altitude: 54.004285\u00b0&lt;dd&gt;Slant Range: 668.81388km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.5849909941858007, 51.25051820452106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1278137138703315, 51.15856597625855], [2.2190968770204247, 51.17711244389894], [2.3104563979740598, 51.19558101308851], [2.4018920662197627, 51.21397157115141], [2.4934036695709243, 51.232284005676675], [2.5849909941858007, 51.25051820452106], [2.6766538245473344, 51.26867405581145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2272&lt;dd&gt;Latitude: 2.6766538&lt;dd&gt;Longitude: 51.268674&lt;dd&gt;Azimuth: 91.227649\u00b0&lt;dd&gt;Altitude: 53.523658\u00b0&lt;dd&gt;Slant Range: 672.46754km&quot;, &quot;name&quot;: &quot;STARLINK-2272&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.6766538245473344, 51.26867405581145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -10.21302&lt;dd&gt;Longitude: 52.71378&lt;dd&gt;Azimuth: 287.97133\u00b0&lt;dd&gt;Altitude: 42.022574\u00b0&lt;dd&gt;Slant Range: 788.48138km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675], [-10.114975274714212, 52.70435263578368]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -10.114975&lt;dd&gt;Longitude: 52.704353&lt;dd&gt;Azimuth: 288.00917\u00b0&lt;dd&gt;Altitude: 42.410742\u00b0&lt;dd&gt;Slant Range: 783.51861km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.114975274714212, 52.70435263578368]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675], [-10.114975274714212, 52.70435263578368], [-10.01697499347537, 52.69483734050423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -10.016975&lt;dd&gt;Longitude: 52.694837&lt;dd&gt;Azimuth: 288.04789\u00b0&lt;dd&gt;Altitude: 42.803449\u00b0&lt;dd&gt;Slant Range: 778.58674km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.01697499347537, 52.69483734050423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675], [-10.114975274714212, 52.70435263578368], [-10.01697499347537, 52.69483734050423], [-9.91901931217061, 52.68523413658476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.9190193&lt;dd&gt;Longitude: 52.685234&lt;dd&gt;Azimuth: 288.08751\u00b0&lt;dd&gt;Altitude: 43.200752\u00b0&lt;dd&gt;Slant Range: 773.68639km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.91901931217061, 52.68523413658476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675], [-10.114975274714212, 52.70435263578368], [-10.01697499347537, 52.69483734050423], [-9.91901931217061, 52.68523413658476], [-9.821108605128902, 52.6755430926399]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.8211086&lt;dd&gt;Longitude: 52.675543&lt;dd&gt;Azimuth: 288.12808\u00b0&lt;dd&gt;Altitude: 43.602708\u00b0&lt;dd&gt;Slant Range: 768.81816km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.821108605128902, 52.6755430926399]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675], [-10.114975274714212, 52.70435263578368], [-10.01697499347537, 52.69483734050423], [-9.91901931217061, 52.68523413658476], [-9.821108605128902, 52.6755430926399], [-9.723243245433563, 52.66576427784047]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.7232432&lt;dd&gt;Longitude: 52.665764&lt;dd&gt;Azimuth: 288.16964\u00b0&lt;dd&gt;Altitude: 44.009375\u00b0&lt;dd&gt;Slant Range: 763.98267km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.723243245433563, 52.66576427784047]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.213019780300167, 52.71377995436675], [-10.114975274714212, 52.70435263578368], [-10.01697499347537, 52.69483734050423], [-9.91901931217061, 52.68523413658476], [-9.821108605128902, 52.6755430926399], [-9.723243245433563, 52.66576427784047], [-9.625423604900158, 52.655897761910765]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.6254236&lt;dd&gt;Longitude: 52.655898&lt;dd&gt;Azimuth: 288.21221\u00b0&lt;dd&gt;Altitude: 44.420808\u00b0&lt;dd&gt;Slant Range: 759.18055km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.625423604900158, 52.655897761910765]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.114975274714212, 52.70435263578368], [-10.01697499347537, 52.69483734050423], [-9.91901931217061, 52.68523413658476], [-9.821108605128902, 52.6755430926399], [-9.723243245433563, 52.66576427784047], [-9.625423604900158, 52.655897761910765], [-9.527650054068781, 52.645943615126264]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.5276501&lt;dd&gt;Longitude: 52.645944&lt;dd&gt;Azimuth: 288.25585\u00b0&lt;dd&gt;Altitude: 44.837063\u00b0&lt;dd&gt;Slant Range: 754.41244km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.527650054068781, 52.645943615126264]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.01697499347537, 52.69483734050423], [-9.91901931217061, 52.68523413658476], [-9.821108605128902, 52.6755430926399], [-9.723243245433563, 52.66576427784047], [-9.625423604900158, 52.655897761910765], [-9.527650054068781, 52.645943615126264], [-9.429922962199871, 52.6359019083116]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.429923&lt;dd&gt;Longitude: 52.635902&lt;dd&gt;Azimuth: 288.3006\u00b0&lt;dd&gt;Altitude: 45.258198\u00b0&lt;dd&gt;Slant Range: 749.679km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.429922962199871, 52.6359019083116]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.91901931217061, 52.68523413658476], [-9.821108605128902, 52.6755430926399], [-9.723243245433563, 52.66576427784047], [-9.625423604900158, 52.655897761910765], [-9.527650054068781, 52.645943615126264], [-9.429922962199871, 52.6359019083116], [-9.332242697268997, 52.62577271283784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.3322427&lt;dd&gt;Longitude: 52.625773&lt;dd&gt;Azimuth: 288.34651\u00b0&lt;dd&gt;Altitude: 45.684267\u00b0&lt;dd&gt;Slant Range: 744.98089km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.332242697268997, 52.62577271283784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.821108605128902, 52.6755430926399], [-9.723243245433563, 52.66576427784047], [-9.625423604900158, 52.655897761910765], [-9.527650054068781, 52.645943615126264], [-9.429922962199871, 52.6359019083116], [-9.332242697268997, 52.62577271283784], [-9.23460962594529, 52.61555610062013]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.2346096&lt;dd&gt;Longitude: 52.615556&lt;dd&gt;Azimuth: 288.39361\u00b0&lt;dd&gt;Altitude: 46.115325\u00b0&lt;dd&gt;Slant Range: 740.3188km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.23460962594529, 52.61555610062013]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.723243245433563, 52.66576427784047], [-9.625423604900158, 52.655897761910765], [-9.527650054068781, 52.645943615126264], [-9.429922962199871, 52.6359019083116], [-9.332242697268997, 52.62577271283784], [-9.23460962594529, 52.61555610062013], [-9.137024113601251, 52.60525214411551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.1370241&lt;dd&gt;Longitude: 52.605252&lt;dd&gt;Azimuth: 288.44197\u00b0&lt;dd&gt;Altitude: 46.551427\u00b0&lt;dd&gt;Slant Range: 735.69341km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.137024113601251, 52.60525214411551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.625423604900158, 52.655897761910765], [-9.527650054068781, 52.645943615126264], [-9.429922962199871, 52.6359019083116], [-9.332242697268997, 52.62577271283784], [-9.23460962594529, 52.61555610062013], [-9.137024113601251, 52.60525214411551], [-9.039486524293906, 52.594860916320094]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -9.0394865&lt;dd&gt;Longitude: 52.594861&lt;dd&gt;Azimuth: 288.49165\u00b0&lt;dd&gt;Altitude: 46.992626\u00b0&lt;dd&gt;Slant Range: 731.10542km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.039486524293906, 52.594860916320094]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.527650054068781, 52.645943615126264], [-9.429922962199871, 52.6359019083116], [-9.332242697268997, 52.62577271283784], [-9.23460962594529, 52.61555610062013], [-9.137024113601251, 52.60525214411551], [-9.039486524293906, 52.594860916320094], [-8.941997220755443, 52.5843824907672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.9419972&lt;dd&gt;Longitude: 52.584382&lt;dd&gt;Azimuth: 288.54269\u00b0&lt;dd&gt;Altitude: 47.438976\u00b0&lt;dd&gt;Slant Range: 726.55555km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.941997220755443, 52.5843824907672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.429922962199871, 52.6359019083116], [-9.332242697268997, 52.62577271283784], [-9.23460962594529, 52.61555610062013], [-9.137024113601251, 52.60525214411551], [-9.039486524293906, 52.594860916320094], [-8.941997220755443, 52.5843824907672], [-8.844556564394807, 52.57381694152437]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.8445566&lt;dd&gt;Longitude: 52.573817&lt;dd&gt;Azimuth: 288.59516\u00b0&lt;dd&gt;Altitude: 47.890528\u00b0&lt;dd&gt;Slant Range: 722.04453km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.844556564394807, 52.57381694152437]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.332242697268997, 52.62577271283784], [-9.23460962594529, 52.61555610062013], [-9.137024113601251, 52.60525214411551], [-9.039486524293906, 52.594860916320094], [-8.941997220755443, 52.5843824907672], [-8.844556564394807, 52.57381694152437], [-8.747164915279592, 52.563164343191104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.7471649&lt;dd&gt;Longitude: 52.563164&lt;dd&gt;Azimuth: 288.64912\u00b0&lt;dd&gt;Altitude: 48.347333\u00b0&lt;dd&gt;Slant Range: 717.57308km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.747164915279592, 52.563164343191104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.23460962594529, 52.61555610062013], [-9.137024113601251, 52.60525214411551], [-9.039486524293906, 52.594860916320094], [-8.941997220755443, 52.5843824907672], [-8.844556564394807, 52.57381694152437], [-8.747164915279592, 52.563164343191104], [-8.649822632137589, 52.55242477089642]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.6498226&lt;dd&gt;Longitude: 52.552425&lt;dd&gt;Azimuth: 288.70465\u00b0&lt;dd&gt;Altitude: 48.809441\u00b0&lt;dd&gt;Slant Range: 713.14197km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.649822632137589, 52.55242477089642]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.137024113601251, 52.60525214411551], [-9.039486524293906, 52.594860916320094], [-8.941997220755443, 52.5843824907672], [-8.844556564394807, 52.57381694152437], [-8.747164915279592, 52.563164343191104], [-8.649822632137589, 52.55242477089642], [-8.552530072339534, 52.5415983002964]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.5525301&lt;dd&gt;Longitude: 52.541598&lt;dd&gt;Azimuth: 288.76182\u00b0&lt;dd&gt;Altitude: 49.2769\u00b0&lt;dd&gt;Slant Range: 708.75195km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.552530072339534, 52.5415983002964]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.039486524293906, 52.594860916320094], [-8.941997220755443, 52.5843824907672], [-8.844556564394807, 52.57381694152437], [-8.747164915279592, 52.563164343191104], [-8.649822632137589, 52.55242477089642], [-8.552530072339534, 52.5415983002964], [-8.45528759190667, 52.53068500757151]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.4552876&lt;dd&gt;Longitude: 52.530685&lt;dd&gt;Azimuth: 288.82071\u00b0&lt;dd&gt;Altitude: 49.749759\u00b0&lt;dd&gt;Slant Range: 704.40379km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.45528759190667, 52.53068500757151]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.941997220755443, 52.5843824907672], [-8.844556564394807, 52.57381694152437], [-8.747164915279592, 52.563164343191104], [-8.649822632137589, 52.55242477089642], [-8.552530072339534, 52.5415983002964], [-8.45528759190667, 52.53068500757151], [-8.358095545481095, 52.51968496942425]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.3580955&lt;dd&gt;Longitude: 52.519685&lt;dd&gt;Azimuth: 288.88139\u00b0&lt;dd&gt;Altitude: 50.228061\u00b0&lt;dd&gt;Slant Range: 700.09829km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.358095545481095, 52.51968496942425]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.844556564394807, 52.57381694152437], [-8.747164915279592, 52.563164343191104], [-8.649822632137589, 52.55242477089642], [-8.552530072339534, 52.5415983002964], [-8.45528759190667, 52.53068500757151], [-8.358095545481095, 52.51968496942425], [-8.260954286343507, 52.508598263076806]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.2609543&lt;dd&gt;Longitude: 52.508598&lt;dd&gt;Azimuth: 288.94397\u00b0&lt;dd&gt;Altitude: 50.711852\u00b0&lt;dd&gt;Slant Range: 695.83623km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.260954286343507, 52.508598263076806]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.747164915279592, 52.563164343191104], [-8.649822632137589, 52.55242477089642], [-8.552530072339534, 52.5415983002964], [-8.45528759190667, 52.53068500757151], [-8.358095545481095, 52.51968496942425], [-8.260954286343507, 52.508598263076806], [-8.16386416638414, 52.497424966268]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.1638642&lt;dd&gt;Longitude: 52.497425&lt;dd&gt;Azimuth: 289.00852\u00b0&lt;dd&gt;Altitude: 51.201174\u00b0&lt;dd&gt;Slant Range: 691.61843km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.16386416638414, 52.497424966268]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.649822632137589, 52.55242477089642], [-8.552530072339534, 52.5415983002964], [-8.45528759190667, 52.53068500757151], [-8.358095545481095, 52.51968496942425], [-8.260954286343507, 52.508598263076806], [-8.16386416638414, 52.497424966268], [-8.066825536116278, 52.4861651572511]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -8.0668255&lt;dd&gt;Longitude: 52.486165&lt;dd&gt;Azimuth: 289.07517\u00b0&lt;dd&gt;Altitude: 51.696066\u00b0&lt;dd&gt;Slant Range: 687.44571km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.066825536116278, 52.4861651572511]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.552530072339534, 52.5415983002964], [-8.45528759190667, 52.53068500757151], [-8.358095545481095, 52.51968496942425], [-8.260954286343507, 52.508598263076806], [-8.16386416638414, 52.497424966268], [-8.066825536116278, 52.4861651572511], [-7.969838744646126, 52.47481891479131]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.9698387&lt;dd&gt;Longitude: 52.474819&lt;dd&gt;Azimuth: 289.14401\u00b0&lt;dd&gt;Altitude: 52.196568\u00b0&lt;dd&gt;Slant Range: 683.31888km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.969838744646126, 52.47481891479131]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.45528759190667, 52.53068500757151], [-8.358095545481095, 52.51968496942425], [-8.260954286343507, 52.508598263076806], [-8.16386416638414, 52.497424966268], [-8.066825536116278, 52.4861651572511], [-7.969838744646126, 52.47481891479131], [-7.8729041396881305, 52.46338631816298]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.8729041&lt;dd&gt;Longitude: 52.463386&lt;dd&gt;Azimuth: 289.21516\u00b0&lt;dd&gt;Altitude: 52.702714\u00b0&lt;dd&gt;Slant Range: 679.23881km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.8729041396881305, 52.46338631816298]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.358095545481095, 52.51968496942425], [-8.260954286343507, 52.508598263076806], [-8.16386416638414, 52.497424966268], [-8.066825536116278, 52.4861651572511], [-7.969838744646126, 52.47481891479131], [-7.8729041396881305, 52.46338631816298], [-7.776022067543349, 52.45186744714717]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.7760221&lt;dd&gt;Longitude: 52.451867&lt;dd&gt;Azimuth: 289.28874\u00b0&lt;dd&gt;Altitude: 53.214539\u00b0&lt;dd&gt;Slant Range: 675.20634km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.776022067543349, 52.45186744714717]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.260954286343507, 52.508598263076806], [-8.16386416638414, 52.497424966268], [-8.066825536116278, 52.4861651572511], [-7.969838744646126, 52.47481891479131], [-7.8729041396881305, 52.46338631816298], [-7.776022067543349, 52.45186744714717], [-7.679192873097187, 52.44026238202892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.6791929&lt;dd&gt;Longitude: 52.440262&lt;dd&gt;Azimuth: 289.36489\u00b0&lt;dd&gt;Altitude: 53.732073\u00b0&lt;dd&gt;Slant Range: 671.22232km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.679192873097187, 52.44026238202892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.16386416638414, 52.497424966268], [-8.066825536116278, 52.4861651572511], [-7.969838744646126, 52.47481891479131], [-7.8729041396881305, 52.46338631816298], [-7.776022067543349, 52.45186744714717], [-7.679192873097187, 52.44026238202892], [-7.582416899817873, 52.428571203595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.5824169&lt;dd&gt;Longitude: 52.428571&lt;dd&gt;Azimuth: 289.44376\u00b0&lt;dd&gt;Altitude: 54.255344\u00b0&lt;dd&gt;Slant Range: 667.28765km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.582416899817873, 52.428571203595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.066825536116278, 52.4861651572511], [-7.969838744646126, 52.47481891479131], [-7.8729041396881305, 52.46338631816298], [-7.776022067543349, 52.45186744714717], [-7.679192873097187, 52.44026238202892], [-7.582416899817873, 52.428571203595], [-7.485694489744648, 52.41679399313076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.4856945&lt;dd&gt;Longitude: 52.416794&lt;dd&gt;Azimuth: 289.52549\u00b0&lt;dd&gt;Altitude: 54.784378\u00b0&lt;dd&gt;Slant Range: 663.40319km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.485694489744648, 52.41679399313076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.969838744646126, 52.47481891479131], [-7.8729041396881305, 52.46338631816298], [-7.776022067543349, 52.45186744714717], [-7.679192873097187, 52.44026238202892], [-7.582416899817873, 52.428571203595], [-7.485694489744648, 52.41679399313076], [-7.3890259834748955, 52.404930832417946]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.389026&lt;dd&gt;Longitude: 52.404931&lt;dd&gt;Azimuth: 289.61025\u00b0&lt;dd&gt;Altitude: 55.319197\u00b0&lt;dd&gt;Slant Range: 659.56983km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.3890259834748955, 52.404930832417946]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.8729041396881305, 52.46338631816298], [-7.776022067543349, 52.45186744714717], [-7.679192873097187, 52.44026238202892], [-7.582416899817873, 52.428571203595], [-7.485694489744648, 52.41679399313076], [-7.3890259834748955, 52.404930832417946], [-7.292411720174163, 52.39298180373175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.2924117&lt;dd&gt;Longitude: 52.392982&lt;dd&gt;Azimuth: 289.69822\u00b0&lt;dd&gt;Altitude: 55.859818\u00b0&lt;dd&gt;Slant Range: 655.78849km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.292411720174163, 52.39298180373175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.776022067543349, 52.45186744714717], [-7.679192873097187, 52.44026238202892], [-7.582416899817873, 52.428571203595], [-7.485694489744648, 52.41679399313076], [-7.3890259834748955, 52.404930832417946], [-7.292411720174163, 52.39298180373175], [-7.195852037553924, 52.38094698983847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.195852&lt;dd&gt;Longitude: 52.380947&lt;dd&gt;Azimuth: 289.7896\u00b0&lt;dd&gt;Altitude: 56.406257\u00b0&lt;dd&gt;Slant Range: 652.06006km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.195852037553924, 52.38094698983847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.679192873097187, 52.44026238202892], [-7.582416899817873, 52.428571203595], [-7.485694489744648, 52.41679399313076], [-7.3890259834748955, 52.404930832417946], [-7.292411720174163, 52.39298180373175], [-7.195852037553924, 52.38094698983847], [-7.0993472718781945, 52.36882647399267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.0993473&lt;dd&gt;Longitude: 52.368826&lt;dd&gt;Azimuth: 289.88459\u00b0&lt;dd&gt;Altitude: 56.958526\u00b0&lt;dd&gt;Slant Range: 648.38547km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.0993472718781945, 52.36882647399267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.582416899817873, 52.428571203595], [-7.485694489744648, 52.41679399313076], [-7.3890259834748955, 52.404930832417946], [-7.292411720174163, 52.39298180373175], [-7.195852037553924, 52.38094698983847], [-7.0993472718781945, 52.36882647399267], [-7.002897757944885, 52.356620339934416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -7.0028978&lt;dd&gt;Longitude: 52.35662&lt;dd&gt;Azimuth: 289.98342\u00b0&lt;dd&gt;Altitude: 57.51663\u00b0&lt;dd&gt;Slant Range: 644.76564km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.002897757944885, 52.356620339934416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.485694489744648, 52.41679399313076], [-7.3890259834748955, 52.404930832417946], [-7.292411720174163, 52.39298180373175], [-7.195852037553924, 52.38094698983847], [-7.0993472718781945, 52.36882647399267], [-7.002897757944885, 52.356620339934416], [-6.906503829092407, 52.34432867188687]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.9065038&lt;dd&gt;Longitude: 52.344329&lt;dd&gt;Azimuth: 290.08634\u00b0&lt;dd&gt;Altitude: 58.080573\u00b0&lt;dd&gt;Slant Range: 641.2015km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.906503829092407, 52.34432867188687]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.3890259834748955, 52.404930832417946], [-7.292411720174163, 52.39298180373175], [-7.195852037553924, 52.38094698983847], [-7.0993472718781945, 52.36882647399267], [-7.002897757944885, 52.356620339934416], [-6.906503829092407, 52.34432867188687], [-6.810165817183985, 52.331951554553335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.8101658&lt;dd&gt;Longitude: 52.331952&lt;dd&gt;Azimuth: 290.19362\u00b0&lt;dd&gt;Altitude: 58.650354\u00b0&lt;dd&gt;Slant Range: 637.69399km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.810165817183985, 52.331951554553335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.292411720174163, 52.39298180373175], [-7.195852037553924, 52.38094698983847], [-7.0993472718781945, 52.36882647399267], [-7.002897757944885, 52.356620339934416], [-6.906503829092407, 52.34432867188687], [-6.810165817183985, 52.331951554553335], [-6.713884052604114, 52.3194890731149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.7138841&lt;dd&gt;Longitude: 52.319489&lt;dd&gt;Azimuth: 290.30554\u00b0&lt;dd&gt;Altitude: 59.225966\u00b0&lt;dd&gt;Slant Range: 634.24405km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.713884052604114, 52.3194890731149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.195852037553924, 52.38094698983847], [-7.0993472718781945, 52.36882647399267], [-7.002897757944885, 52.356620339934416], [-6.906503829092407, 52.34432867188687], [-6.810165817183985, 52.331951554553335], [-6.713884052604114, 52.3194890731149], [-6.617658864258405, 52.306941313227334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.6176589&lt;dd&gt;Longitude: 52.306941&lt;dd&gt;Azimuth: 290.42242\u00b0&lt;dd&gt;Altitude: 59.807397\u00b0&lt;dd&gt;Slant Range: 630.85264km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.617658864258405, 52.306941313227334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.0993472718781945, 52.36882647399267], [-7.002897757944885, 52.356620339934416], [-6.906503829092407, 52.34432867188687], [-6.810165817183985, 52.331951554553335], [-6.713884052604114, 52.3194890731149], [-6.617658864258405, 52.306941313227334], [-6.521490579563081, 52.29430836101864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.5214906&lt;dd&gt;Longitude: 52.294308&lt;dd&gt;Azimuth: 290.54462\u00b0&lt;dd&gt;Altitude: 60.394632\u00b0&lt;dd&gt;Slant Range: 627.5207km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.521490579563081, 52.29430836101864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.002897757944885, 52.356620339934416], [-6.906503829092407, 52.34432867188687], [-6.810165817183985, 52.331951554553335], [-6.713884052604114, 52.3194890731149], [-6.617658864258405, 52.306941313227334], [-6.521490579563081, 52.29430836101864], [-6.425379524437366, 52.28159030308625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.4253795&lt;dd&gt;Longitude: 52.28159&lt;dd&gt;Azimuth: 290.67252\u00b0&lt;dd&gt;Altitude: 60.987647\u00b0&lt;dd&gt;Slant Range: 624.24919km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.425379524437366, 52.28159030308625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.906503829092407, 52.34432867188687], [-6.810165817183985, 52.331951554553335], [-6.713884052604114, 52.3194890731149], [-6.617658864258405, 52.306941313227334], [-6.521490579563081, 52.29430836101864], [-6.425379524437366, 52.28159030308625], [-6.3293260233003314, 52.26878722649436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.329326&lt;dd&gt;Longitude: 52.268787&lt;dd&gt;Azimuth: 290.80652\u00b0&lt;dd&gt;Altitude: 61.586414\u00b0&lt;dd&gt;Slant Range: 621.03907km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.3293260233003314, 52.26878722649436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.810165817183985, 52.331951554553335], [-6.713884052604114, 52.3194890731149], [-6.617658864258405, 52.306941313227334], [-6.521490579563081, 52.29430836101864], [-6.425379524437366, 52.28159030308625], [-6.3293260233003314, 52.26878722649436], [-6.233330399073591, 52.25589921877105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.2333304&lt;dd&gt;Longitude: 52.255899&lt;dd&gt;Azimuth: 290.9471\u00b0&lt;dd&gt;Altitude: 62.1909\u00b0&lt;dd&gt;Slant Range: 617.89129km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.233330399073591, 52.25589921877105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.713884052604114, 52.3194890731149], [-6.617658864258405, 52.306941313227334], [-6.521490579563081, 52.29430836101864], [-6.425379524437366, 52.28159030308625], [-6.3293260233003314, 52.26878722649436], [-6.233330399073591, 52.25589921877105], [-6.137392973157362, 52.24292636790567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.137393&lt;dd&gt;Longitude: 52.242926&lt;dd&gt;Azimuth: 291.09476\u00b0&lt;dd&gt;Altitude: 62.801064\u00b0&lt;dd&gt;Slant Range: 614.80683km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.137392973157362, 52.24292636790567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.617658864258405, 52.306941313227334], [-6.521490579563081, 52.29430836101864], [-6.425379524437366, 52.28159030308625], [-6.3293260233003314, 52.26878722649436], [-6.233330399073591, 52.25589921877105], [-6.137392973157362, 52.24292636790567], [-6.0415140654442006, 52.22986876234622]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-2301&lt;dd&gt;Latitude: -6.0415141&lt;dd&gt;Longitude: 52.229869&lt;dd&gt;Azimuth: 291.25005\u00b0&lt;dd&gt;Altitude: 63.416858\u00b0&lt;dd&gt;Slant Range: 611.78665km&quot;, &quot;name&quot;: &quot;STARLINK-2301&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.0415140654442006, 52.22986876234622]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -10.398576&lt;dd&gt;Longitude: 53.155041&lt;dd&gt;Azimuth: 292.60415\u00b0&lt;dd&gt;Altitude: 40.283249\u00b0&lt;dd&gt;Slant Range: 801.24538km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411], [-10.298614416574916, 53.16120466158265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -10.298614&lt;dd&gt;Longitude: 53.161205&lt;dd&gt;Azimuth: 292.86682\u00b0&lt;dd&gt;Altitude: 40.62816\u00b0&lt;dd&gt;Slant Range: 796.52084km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.298614416574916, 53.16120466158265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411], [-10.298614416574916, 53.16120466158265], [-10.198623281645956, 53.16727693914811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -10.198623&lt;dd&gt;Longitude: 53.167277&lt;dd&gt;Azimuth: 293.13532\u00b0&lt;dd&gt;Altitude: 40.976188\u00b0&lt;dd&gt;Slant Range: 791.82956km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.198623281645956, 53.16727693914811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411], [-10.298614416574916, 53.16120466158265], [-10.198623281645956, 53.16727693914811], [-10.098603038454515, 53.173258218628554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -10.098603&lt;dd&gt;Longitude: 53.173258&lt;dd&gt;Azimuth: 293.40983\u00b0&lt;dd&gt;Altitude: 41.327337\u00b0&lt;dd&gt;Slant Range: 787.17214km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.098603038454515, 53.173258218628554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411], [-10.298614416574916, 53.16120466158265], [-10.198623281645956, 53.16727693914811], [-10.098603038454515, 53.173258218628554], [-9.998554113152453, 53.179148455393715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.9985541&lt;dd&gt;Longitude: 53.179148&lt;dd&gt;Azimuth: 293.69054\u00b0&lt;dd&gt;Altitude: 41.681608\u00b0&lt;dd&gt;Slant Range: 782.54918km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.998554113152453, 53.179148455393715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411], [-10.298614416574916, 53.16120466158265], [-10.198623281645956, 53.16727693914811], [-10.098603038454515, 53.173258218628554], [-9.998554113152453, 53.179148455393715], [-9.898476932757811, 53.184947605466554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.8984769&lt;dd&gt;Longitude: 53.184948&lt;dd&gt;Azimuth: 293.97765\u00b0&lt;dd&gt;Altitude: 42.038999\u00b0&lt;dd&gt;Slant Range: 777.9613km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.898476932757811, 53.184947605466554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.398576017944874, 53.15504143121411], [-10.298614416574916, 53.16120466158265], [-10.198623281645956, 53.16727693914811], [-10.098603038454515, 53.173258218628554], [-9.998554113152453, 53.179148455393715], [-9.898476932757811, 53.184947605466554], [-9.798371925128091, 53.190655625524805]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.7983719&lt;dd&gt;Longitude: 53.190656&lt;dd&gt;Azimuth: 294.27137\u00b0&lt;dd&gt;Altitude: 42.399506\u00b0&lt;dd&gt;Slant Range: 773.40914km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.798371925128091, 53.190655625524805]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.298614416574916, 53.16120466158265], [-10.198623281645956, 53.16727693914811], [-10.098603038454515, 53.173258218628554], [-9.998554113152453, 53.179148455393715], [-9.898476932757811, 53.184947605466554], [-9.798371925128091, 53.190655625524805], [-9.698239518952168, 53.19627247290277]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.6982395&lt;dd&gt;Longitude: 53.196272&lt;dd&gt;Azimuth: 294.57194\u00b0&lt;dd&gt;Altitude: 42.763121\u00b0&lt;dd&gt;Slant Range: 768.89333km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.698239518952168, 53.19627247290277]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.198623281645956, 53.16727693914811], [-10.098603038454515, 53.173258218628554], [-9.998554113152453, 53.179148455393715], [-9.898476932757811, 53.184947605466554], [-9.798371925128091, 53.190655625524805], [-9.698239518952168, 53.19627247290277], [-9.598080143743113, 53.20179810559266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.5980801&lt;dd&gt;Longitude: 53.201798&lt;dd&gt;Azimuth: 294.87956\u00b0&lt;dd&gt;Altitude: 43.129836\u00b0&lt;dd&gt;Slant Range: 764.41453km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.598080143743113, 53.20179810559266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.098603038454515, 53.173258218628554], [-9.998554113152453, 53.179148455393715], [-9.898476932757811, 53.184947605466554], [-9.798371925128091, 53.190655625524805], [-9.698239518952168, 53.19627247290277], [-9.598080143743113, 53.20179810559266], [-9.497894229819389, 53.207232482246305]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.4978942&lt;dd&gt;Longitude: 53.207232&lt;dd&gt;Azimuth: 295.19449\u00b0&lt;dd&gt;Altitude: 43.499636\u00b0&lt;dd&gt;Slant Range: 759.97339km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.497894229819389, 53.207232482246305]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.998554113152453, 53.179148455393715], [-9.898476932757811, 53.184947605466554], [-9.798371925128091, 53.190655625524805], [-9.698239518952168, 53.19627247290277], [-9.598080143743113, 53.20179810559266], [-9.497894229819389, 53.207232482246305], [-9.397682208292002, 53.21257556217647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.3976822&lt;dd&gt;Longitude: 53.212576&lt;dd&gt;Azimuth: 295.51696\u00b0&lt;dd&gt;Altitude: 43.872505\u00b0&lt;dd&gt;Slant Range: 755.57058km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.397682208292002, 53.21257556217647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.898476932757811, 53.184947605466554], [-9.798371925128091, 53.190655625524805], [-9.698239518952168, 53.19627247290277], [-9.598080143743113, 53.20179810559266], [-9.497894229819389, 53.207232482246305], [-9.397682208292002, 53.21257556217647], [-9.297444511061553, 53.21782730535863]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.2974445&lt;dd&gt;Longitude: 53.217827&lt;dd&gt;Azimuth: 295.84724\u00b0&lt;dd&gt;Altitude: 44.248423\u00b0&lt;dd&gt;Slant Range: 751.20678km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.297444511061553, 53.21782730535863]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.798371925128091, 53.190655625524805], [-9.698239518952168, 53.19627247290277], [-9.598080143743113, 53.20179810559266], [-9.497894229819389, 53.207232482246305], [-9.397682208292002, 53.21257556217647], [-9.297444511061553, 53.21782730535863], [-9.197181570792685, 53.22298767243207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.1971816&lt;dd&gt;Longitude: 53.222988&lt;dd&gt;Azimuth: 296.18559\u00b0&lt;dd&gt;Altitude: 44.627364\u00b0&lt;dd&gt;Slant Range: 746.88268km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.197181570792685, 53.22298767243207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.698239518952168, 53.19627247290277], [-9.598080143743113, 53.20179810559266], [-9.497894229819389, 53.207232482246305], [-9.397682208292002, 53.21257556217647], [-9.297444511061553, 53.21782730535863], [-9.197181570792685, 53.22298767243207], [-9.096893820919252, 53.22805662470174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -9.0968938&lt;dd&gt;Longitude: 53.228057&lt;dd&gt;Azimuth: 296.5323\u00b0&lt;dd&gt;Altitude: 45.009301\u00b0&lt;dd&gt;Slant Range: 742.59897km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.096893820919252, 53.22805662470174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.598080143743113, 53.20179810559266], [-9.497894229819389, 53.207232482246305], [-9.397682208292002, 53.21257556217647], [-9.297444511061553, 53.21782730535863], [-9.197181570792685, 53.22298767243207], [-9.096893820919252, 53.22805662470174], [-8.996581695608343, 53.233034124139394]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.9965817&lt;dd&gt;Longitude: 53.233034&lt;dd&gt;Azimuth: 296.88765\u00b0&lt;dd&gt;Altitude: 45.394201\u00b0&lt;dd&gt;Slant Range: 738.35637km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.996581695608343, 53.233034124139394]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.497894229819389, 53.207232482246305], [-9.397682208292002, 53.21257556217647], [-9.297444511061553, 53.21782730535863], [-9.197181570792685, 53.22298767243207], [-9.096893820919252, 53.22805662470174], [-8.996581695608343, 53.233034124139394], [-8.896245629771549, 53.237920133384996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.8962456&lt;dd&gt;Longitude: 53.23792&lt;dd&gt;Azimuth: 297.25196\u00b0&lt;dd&gt;Altitude: 45.782025\u00b0&lt;dd&gt;Slant Range: 734.15559km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.896245629771549, 53.237920133384996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.397682208292002, 53.21257556217647], [-9.297444511061553, 53.21782730535863], [-9.197181570792685, 53.22298767243207], [-9.096893820919252, 53.22805662470174], [-8.996581695608343, 53.233034124139394], [-8.896245629771549, 53.237920133384996], [-8.795886059037384, 53.242714615748234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.7958861&lt;dd&gt;Longitude: 53.242715&lt;dd&gt;Azimuth: 297.62553\u00b0&lt;dd&gt;Altitude: 46.172732\u00b0&lt;dd&gt;Slant Range: 729.99736km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.795886059037384, 53.242714615748234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.297444511061553, 53.21782730535863], [-9.197181570792685, 53.22298767243207], [-9.096893820919252, 53.22805662470174], [-8.996581695608343, 53.233034124139394], [-8.896245629771549, 53.237920133384996], [-8.795886059037384, 53.242714615748234], [-8.695503419744236, 53.24741753520995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.6955034&lt;dd&gt;Longitude: 53.247418&lt;dd&gt;Azimuth: 298.0087\u00b0&lt;dd&gt;Altitude: 46.566274\u00b0&lt;dd&gt;Slant Range: 725.88242km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.695503419744236, 53.24741753520995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.197181570792685, 53.22298767243207], [-9.096893820919252, 53.22805662470174], [-8.996581695608343, 53.233034124139394], [-8.896245629771549, 53.237920133384996], [-8.795886059037384, 53.242714615748234], [-8.695503419744236, 53.24741753520995], [-8.595098148924949, 53.252028856422996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.5950981&lt;dd&gt;Longitude: 53.252029&lt;dd&gt;Azimuth: 298.40181\u00b0&lt;dd&gt;Altitude: 46.962596\u00b0&lt;dd&gt;Slant Range: 721.8115km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.595098148924949, 53.252028856422996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.096893820919252, 53.22805662470174], [-8.996581695608343, 53.233034124139394], [-8.896245629771549, 53.237920133384996], [-8.795886059037384, 53.242714615748234], [-8.695503419744236, 53.24741753520995], [-8.595098148924949, 53.252028856422996], [-8.494670684300358, 53.25654854471422]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.4946707&lt;dd&gt;Longitude: 53.256549&lt;dd&gt;Azimuth: 298.80522\u00b0&lt;dd&gt;Altitude: 47.361639\u00b0&lt;dd&gt;Slant Range: 717.78537km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.494670684300358, 53.25654854471422]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.996581695608343, 53.233034124139394], [-8.896245629771549, 53.237920133384996], [-8.795886059037384, 53.242714615748234], [-8.695503419744236, 53.24741753520995], [-8.595098148924949, 53.252028856422996], [-8.494670684300358, 53.25654854471422], [-8.394221464255425, 53.26097656608523]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.3942215&lt;dd&gt;Longitude: 53.260977&lt;dd&gt;Azimuth: 299.2193\u00b0&lt;dd&gt;Altitude: 47.763338\u00b0&lt;dd&gt;Slant Range: 713.80478km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.394221464255425, 53.26097656608523]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.896245629771549, 53.237920133384996], [-8.795886059037384, 53.242714615748234], [-8.695503419744236, 53.24741753520995], [-8.595098148924949, 53.252028856422996], [-8.494670684300358, 53.25654854471422], [-8.394221464255425, 53.26097656608523], [-8.29375092783982, 53.26531288721389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.2937509&lt;dd&gt;Longitude: 53.265313&lt;dd&gt;Azimuth: 299.64445\u00b0&lt;dd&gt;Altitude: 48.16762\u00b0&lt;dd&gt;Slant Range: 709.87051km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.29375092783982, 53.26531288721389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.795886059037384, 53.242714615748234], [-8.695503419744236, 53.24741753520995], [-8.595098148924949, 53.252028856422996], [-8.494670684300358, 53.25654854471422], [-8.394221464255425, 53.26097656608523], [-8.29375092783982, 53.26531288721389], [-8.193259514745128, 53.26955747545535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.1932595&lt;dd&gt;Longitude: 53.269557&lt;dd&gt;Azimuth: 300.08107\u00b0&lt;dd&gt;Altitude: 48.574404\u00b0&lt;dd&gt;Slant Range: 705.98333km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.193259514745128, 53.26955747545535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.695503419744236, 53.24741753520995], [-8.595098148924949, 53.252028856422996], [-8.494670684300358, 53.25654854471422], [-8.394221464255425, 53.26097656608523], [-8.29375092783982, 53.26531288721389], [-8.193259514745128, 53.26955747545535], [-8.092747665296447, 53.27371029884366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -8.0927477&lt;dd&gt;Longitude: 53.27371&lt;dd&gt;Azimuth: 300.52959\u00b0&lt;dd&gt;Altitude: 48.983605\u00b0&lt;dd&gt;Slant Range: 702.14403km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.092747665296447, 53.27371029884366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.595098148924949, 53.252028856422996], [-8.494670684300358, 53.25654854471422], [-8.394221464255425, 53.26097656608523], [-8.29375092783982, 53.26531288721389], [-8.193259514745128, 53.26955747545535], [-8.092747665296447, 53.27371029884366], [-7.9922158204386005, 53.27777132609243]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.9922158&lt;dd&gt;Longitude: 53.277771&lt;dd&gt;Azimuth: 300.99044\u00b0&lt;dd&gt;Altitude: 49.395128\u00b0&lt;dd&gt;Slant Range: 698.35341km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.9922158204386005, 53.27777132609243]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.494670684300358, 53.25654854471422], [-8.394221464255425, 53.26097656608523], [-8.29375092783982, 53.26531288721389], [-8.193259514745128, 53.26955747545535], [-8.092747665296447, 53.27371029884366], [-7.9922158204386005, 53.27777132609243], [-7.891664421719727, 53.281740526596415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.8916644&lt;dd&gt;Longitude: 53.281741&lt;dd&gt;Azimuth: 301.46409\u00b0&lt;dd&gt;Altitude: 49.808868\u00b0&lt;dd&gt;Slant Range: 694.61226km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.891664421719727, 53.281740526596415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.394221464255425, 53.26097656608523], [-8.29375092783982, 53.26531288721389], [-8.193259514745128, 53.26955747545535], [-8.092747665296447, 53.27371029884366], [-7.9922158204386005, 53.27777132609243], [-7.891664421719727, 53.281740526596415], [-7.791093911289113, 53.28561787043246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.7910939&lt;dd&gt;Longitude: 53.285618&lt;dd&gt;Azimuth: 301.95101\u00b0&lt;dd&gt;Altitude: 50.224713\u00b0&lt;dd&gt;Slant Range: 690.9214km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.791093911289113, 53.28561787043246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.29375092783982, 53.26531288721389], [-8.193259514745128, 53.26955747545535], [-8.092747665296447, 53.27371029884366], [-7.9922158204386005, 53.27777132609243], [-7.891664421719727, 53.281740526596415], [-7.791093911289113, 53.28561787043246], [-7.690504731866281, 53.28940332836065]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.6905047&lt;dd&gt;Longitude: 53.289403&lt;dd&gt;Azimuth: 302.45171\u00b0&lt;dd&gt;Altitude: 50.642543\u00b0&lt;dd&gt;Slant Range: 687.28163km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.690504731866281, 53.28940332836065]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.193259514745128, 53.26955747545535], [-8.092747665296447, 53.27371029884366], [-7.9922158204386005, 53.27777132609243], [-7.891664421719727, 53.281740526596415], [-7.791093911289113, 53.28561787043246], [-7.690504731866281, 53.28940332836065], [-7.58989732674618, 53.29309687182533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.5898973&lt;dd&gt;Longitude: 53.293097&lt;dd&gt;Azimuth: 302.96671\u00b0&lt;dd&gt;Altitude: 51.062226\u00b0&lt;dd&gt;Slant Range: 683.69379km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.58989732674618, 53.29309687182533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.092747665296447, 53.27371029884366], [-7.9922158204386005, 53.27777132609243], [-7.891664421719727, 53.281740526596415], [-7.791093911289113, 53.28561787043246], [-7.690504731866281, 53.28940332836065], [-7.58989732674618, 53.29309687182533], [-7.489272139775876, 53.296698472956386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.4892721&lt;dd&gt;Longitude: 53.296698&lt;dd&gt;Azimuth: 303.49655\u00b0&lt;dd&gt;Altitude: 51.48362\u00b0&lt;dd&gt;Slant Range: 680.15868km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.489272139775876, 53.296698472956386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.9922158204386005, 53.27777132609243], [-7.891664421719727, 53.281740526596415], [-7.791093911289113, 53.28561787043246], [-7.690504731866281, 53.28940332836065], [-7.58989732674618, 53.29309687182533], [-7.489272139775876, 53.296698472956386], [-7.388629615344455, 53.30020810456991]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.3886296&lt;dd&gt;Longitude: 53.300208&lt;dd&gt;Azimuth: 304.04178\u00b0&lt;dd&gt;Altitude: 51.906573\u00b0&lt;dd&gt;Slant Range: 676.67715km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.388629615344455, 53.30020810456991]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.891664421719727, 53.281740526596415], [-7.791093911289113, 53.28561787043246], [-7.690504731866281, 53.28940332836065], [-7.58989732674618, 53.29309687182533], [-7.489272139775876, 53.296698472956386], [-7.388629615344455, 53.30020810456991], [-7.287970198363606, 53.30362574016967]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.2879702&lt;dd&gt;Longitude: 53.303626&lt;dd&gt;Azimuth: 304.603\u00b0&lt;dd&gt;Altitude: 52.330921\u00b0&lt;dd&gt;Slant Range: 673.25003km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.287970198363606, 53.30362574016967]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.791093911289113, 53.28561787043246], [-7.690504731866281, 53.28940332836065], [-7.58989732674618, 53.29309687182533], [-7.489272139775876, 53.296698472956386], [-7.388629615344455, 53.30020810456991], [-7.287970198363606, 53.30362574016967], [-7.187294334269908, 53.30695135394772]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.1872943&lt;dd&gt;Longitude: 53.306951&lt;dd&gt;Azimuth: 305.18082\u00b0&lt;dd&gt;Altitude: 52.756488\u00b0&lt;dd&gt;Slant Range: 669.87816km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.187294334269908, 53.30695135394772]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.690504731866281, 53.28940332836065], [-7.58989732674618, 53.29309687182533], [-7.489272139775876, 53.296698472956386], [-7.388629615344455, 53.30020810456991], [-7.287970198363606, 53.30362574016967], [-7.187294334269908, 53.30695135394772], [-7.086602468985195, 53.31018492078557]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -7.0866025&lt;dd&gt;Longitude: 53.310185&lt;dd&gt;Azimuth: 305.77587\u00b0&lt;dd&gt;Altitude: 53.183085\u00b0&lt;dd&gt;Slant Range: 666.56237km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.086602468985195, 53.31018492078557]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.58989732674618, 53.29309687182533], [-7.489272139775876, 53.296698472956386], [-7.388629615344455, 53.30020810456991], [-7.287970198363606, 53.30362574016967], [-7.187294334269908, 53.30695135394772], [-7.086602468985195, 53.31018492078557], [-6.98589504894179, 53.31332641625502]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.985895&lt;dd&gt;Longitude: 53.313326&lt;dd&gt;Azimuth: 306.38879\u00b0&lt;dd&gt;Altitude: 53.61051\u00b0&lt;dd&gt;Slant Range: 663.30352km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.98589504894179, 53.31332641625502]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.489272139775876, 53.296698472956386], [-7.388629615344455, 53.30020810456991], [-7.287970198363606, 53.30362574016967], [-7.187294334269908, 53.30695135394772], [-7.086602468985195, 53.31018492078557], [-6.98589504894179, 53.31332641625502], [-6.88517252102582, 53.31637581661918]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.8851725&lt;dd&gt;Longitude: 53.316376&lt;dd&gt;Azimuth: 307.02029\u00b0&lt;dd&gt;Altitude: 54.038548\u00b0&lt;dd&gt;Slant Range: 660.10246km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.88517252102582, 53.31637581661918]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.388629615344455, 53.30020810456991], [-7.287970198363606, 53.30362574016967], [-7.187294334269908, 53.30695135394772], [-7.086602468985195, 53.31018492078557], [-6.98589504894179, 53.31332641625502], [-6.88517252102582, 53.31637581661918], [-6.784435332596903, 53.319333098833226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.7844353&lt;dd&gt;Longitude: 53.319333&lt;dd&gt;Azimuth: 307.67105\u00b0&lt;dd&gt;Altitude: 54.466967\u00b0&lt;dd&gt;Slant Range: 656.96002km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.784435332596903, 53.319333098833226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.287970198363606, 53.30362574016967], [-7.187294334269908, 53.30695135394772], [-7.086602468985195, 53.31018492078557], [-6.98589504894179, 53.31332641625502], [-6.88517252102582, 53.31637581661918], [-6.784435332596903, 53.319333098833226], [-6.683683931456455, 53.32219824054542]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.6836839&lt;dd&gt;Longitude: 53.322198&lt;dd&gt;Azimuth: 308.34181\u00b0&lt;dd&gt;Altitude: 54.895523\u00b0&lt;dd&gt;Slant Range: 653.87706km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.683683931456455, 53.32219824054542]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.187294334269908, 53.30695135394772], [-7.086602468985195, 53.31018492078557], [-6.98589504894179, 53.31332641625502], [-6.88517252102582, 53.31637581661918], [-6.784435332596903, 53.319333098833226], [-6.683683931456455, 53.32219824054542], [-6.582918765846025, 53.32497122009773]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.5829188&lt;dd&gt;Longitude: 53.324971&lt;dd&gt;Azimuth: 309.03331\u00b0&lt;dd&gt;Altitude: 55.323952\u00b0&lt;dd&gt;Slant Range: 650.85443km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.582918765846025, 53.32497122009773]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.086602468985195, 53.31018492078557], [-6.98589504894179, 53.31332641625502], [-6.88517252102582, 53.31637581661918], [-6.784435332596903, 53.319333098833226], [-6.683683931456455, 53.32219824054542], [-6.582918765846025, 53.32497122009773], [-6.482140284420637, 53.327652016526955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.4821403&lt;dd&gt;Longitude: 53.327652&lt;dd&gt;Azimuth: 309.74635\u00b0&lt;dd&gt;Altitude: 55.751978\u00b0&lt;dd&gt;Slant Range: 647.89297km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.482140284420637, 53.327652016526955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.98589504894179, 53.31332641625502], [-6.88517252102582, 53.31637581661918], [-6.784435332596903, 53.319333098833226], [-6.683683931456455, 53.32219824054542], [-6.582918765846025, 53.32497122009773], [-6.482140284420637, 53.327652016526955], [-6.381348936250566, 53.33024060956519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.3813489&lt;dd&gt;Longitude: 53.330241&lt;dd&gt;Azimuth: 310.48171\u00b0&lt;dd&gt;Altitude: 56.179302\u00b0&lt;dd&gt;Slant Range: 644.99353km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.381348936250566, 53.33024060956519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.88517252102582, 53.31637581661918], [-6.784435332596903, 53.319333098833226], [-6.683683931456455, 53.32219824054542], [-6.582918765846025, 53.32497122009773], [-6.482140284420637, 53.327652016526955], [-6.381348936250566, 53.33024060956519], [-6.280545170793581, 53.332736979640785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.2805452&lt;dd&gt;Longitude: 53.332737&lt;dd&gt;Azimuth: 311.24022\u00b0&lt;dd&gt;Altitude: 56.605612\u00b0&lt;dd&gt;Slant Range: 642.15696km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.280545170793581, 53.332736979640785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.784435332596903, 53.319333098833226], [-6.683683931456455, 53.32219824054542], [-6.582918765846025, 53.32497122009773], [-6.482140284420637, 53.327652016526955], [-6.381348936250566, 53.33024060956519], [-6.280545170793581, 53.332736979640785], [-6.179729437893115, 53.335141107879004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.1797294&lt;dd&gt;Longitude: 53.335141&lt;dd&gt;Azimuth: 312.02272\u00b0&lt;dd&gt;Altitude: 57.030575\u00b0&lt;dd&gt;Slant Range: 639.38409km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.179729437893115, 53.335141107879004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.683683931456455, 53.32219824054542], [-6.582918765846025, 53.32497122009773], [-6.482140284420637, 53.327652016526955], [-6.381348936250566, 53.33024060956519], [-6.280545170793581, 53.332736979640785], [-6.179729437893115, 53.335141107879004], [-6.07890218775154, 53.33745297610281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -6.0789022&lt;dd&gt;Longitude: 53.337453&lt;dd&gt;Azimuth: 312.83007\u00b0&lt;dd&gt;Altitude: 57.453837\u00b0&lt;dd&gt;Slant Range: 636.67576km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.07890218775154, 53.33745297610281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.582918765846025, 53.32497122009773], [-6.482140284420637, 53.327652016526955], [-6.381348936250566, 53.33024060956519], [-6.280545170793581, 53.332736979640785], [-6.179729437893115, 53.335141107879004], [-6.07890218775154, 53.33745297610281], [-5.978063870933206, 53.33967256683334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.9780639&lt;dd&gt;Longitude: 53.339673&lt;dd&gt;Azimuth: 313.66315\u00b0&lt;dd&gt;Altitude: 57.875027\u00b0&lt;dd&gt;Slant Range: 634.0328km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.978063870933206, 53.33967256683334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.482140284420637, 53.327652016526955], [-6.381348936250566, 53.33024060956519], [-6.280545170793581, 53.332736979640785], [-6.179729437893115, 53.335141107879004], [-6.07890218775154, 53.33745297610281], [-5.978063870933206, 53.33967256683334], [-5.877214938336038, 53.34179986329093]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.8772149&lt;dd&gt;Longitude: 53.3418&lt;dd&gt;Azimuth: 314.52285\u00b0&lt;dd&gt;Altitude: 58.293749\u00b0&lt;dd&gt;Slant Range: 631.45603km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.877214938336038, 53.34179986329093]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.381348936250566, 53.33024060956519], [-6.280545170793581, 53.332736979640785], [-6.179729437893115, 53.335141107879004], [-6.07890218775154, 53.33745297610281], [-5.978063870933206, 53.33967256683334], [-5.877214938336038, 53.34179986329093], [-5.776355841186574, 53.34383484939533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.7763558&lt;dd&gt;Longitude: 53.343835&lt;dd&gt;Azimuth: 315.41007\u00b0&lt;dd&gt;Altitude: 58.709589\u00b0&lt;dd&gt;Slant Range: 628.94627km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.776355841186574, 53.34383484939533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.280545170793581, 53.332736979640785], [-6.179729437893115, 53.335141107879004], [-6.07890218775154, 53.33745297610281], [-5.978063870933206, 53.33967256683334], [-5.877214938336038, 53.34179986329093], [-5.776355841186574, 53.34383484939533], [-5.6754870310172985, 53.34577750976668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.675487&lt;dd&gt;Longitude: 53.345778&lt;dd&gt;Azimuth: 316.32573\u00b0&lt;dd&gt;Altitude: 59.122109\u00b0&lt;dd&gt;Slant Range: 626.50433km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.6754870310172985, 53.34577750976668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.179729437893115, 53.335141107879004], [-6.07890218775154, 53.33745297610281], [-5.978063870933206, 53.33967256683334], [-5.877214938336038, 53.34179986329093], [-5.776355841186574, 53.34383484939533], [-5.6754870310172985, 53.34577750976668], [-5.57460895966959, 53.34762782972578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.574609&lt;dd&gt;Longitude: 53.347628&lt;dd&gt;Azimuth: 317.27073\u00b0&lt;dd&gt;Altitude: 59.53085\u00b0&lt;dd&gt;Slant Range: 624.131km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.57460895966959, 53.34762782972578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.07890218775154, 53.33745297610281], [-5.978063870933206, 53.33967256683334], [-5.877214938336038, 53.34179986329093], [-5.776355841186574, 53.34383484939533], [-5.6754870310172985, 53.34577750976668], [-5.57460895966959, 53.34762782972578], [-5.47372207925637, 53.349385795294864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.4737221&lt;dd&gt;Longitude: 53.349386&lt;dd&gt;Azimuth: 318.24598\u00b0&lt;dd&gt;Altitude: 59.935328\u00b0&lt;dd&gt;Slant Range: 621.82708km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.47372207925637, 53.349385795294864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.978063870933206, 53.33967256683334], [-5.877214938336038, 53.34179986329093], [-5.776355841186574, 53.34383484939533], [-5.6754870310172985, 53.34577750976668], [-5.57460895966959, 53.34762782972578], [-5.47372207925637, 53.349385795294864], [-5.372826842170372, 53.35105139319803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.3728268&lt;dd&gt;Longitude: 53.351051&lt;dd&gt;Azimuth: 319.25238\u00b0&lt;dd&gt;Altitude: 60.335037\u00b0&lt;dd&gt;Slant Range: 619.59333km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.372826842170372, 53.35105139319803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.877214938336038, 53.34179986329093], [-5.776355841186574, 53.34383484939533], [-5.6754870310172985, 53.34577750976668], [-5.57460895966959, 53.34762782972578], [-5.47372207925637, 53.349385795294864], [-5.372826842170372, 53.35105139319803], [-5.271923701059999, 53.352624610861746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.2719237&lt;dd&gt;Longitude: 53.352625&lt;dd&gt;Azimuth: 320.2908\u00b0&lt;dd&gt;Altitude: 60.729446\u00b0&lt;dd&gt;Slant Range: 617.43054km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.271923701059999, 53.352624610861746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.776355841186574, 53.34383484939533], [-5.6754870310172985, 53.34577750976668], [-5.57460895966959, 53.34762782972578], [-5.47372207925637, 53.349385795294864], [-5.372826842170372, 53.35105139319803], [-5.271923701059999, 53.352624610861746], [-5.171013108811502, 53.354105436415324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.1710131&lt;dd&gt;Longitude: 53.354105&lt;dd&gt;Azimuth: 321.36211\u00b0&lt;dd&gt;Altitude: 61.118004\u00b0&lt;dd&gt;Slant Range: 615.33944km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.171013108811502, 53.354105436415324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.6754870310172985, 53.34577750976668], [-5.57460895966959, 53.34762782972578], [-5.47372207925637, 53.349385795294864], [-5.372826842170372, 53.35105139319803], [-5.271923701059999, 53.352624610861746], [-5.171013108811502, 53.354105436415324], [-5.070095518544999, 53.355493858691474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -5.0700955&lt;dd&gt;Longitude: 53.355494&lt;dd&gt;Azimuth: 322.46711\u00b0&lt;dd&gt;Altitude: 61.500132\u00b0&lt;dd&gt;Slant Range: 613.32076km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.070095518544999, 53.355493858691474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.57460895966959, 53.34762782972578], [-5.47372207925637, 53.349385795294864], [-5.372826842170372, 53.35105139319803], [-5.271923701059999, 53.352624610861746], [-5.171013108811502, 53.354105436415324], [-5.070095518544999, 53.355493858691474], [-4.969171383594589, 53.35678986722644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.9691714&lt;dd&gt;Longitude: 53.35679&lt;dd&gt;Azimuth: 323.60658\u00b0&lt;dd&gt;Altitude: 61.875232\u00b0&lt;dd&gt;Slant Range: 611.37524km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.969171383594589, 53.35678986722644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.47372207925637, 53.349385795294864], [-5.372826842170372, 53.35105139319803], [-5.271923701059999, 53.352624610861746], [-5.171013108811502, 53.354105436415324], [-5.070095518544999, 53.355493858691474], [-4.969171383594589, 53.35678986722644], [-4.868241157493734, 53.357993452260814]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.8682412&lt;dd&gt;Longitude: 53.357993&lt;dd&gt;Azimuth: 324.78123\u00b0&lt;dd&gt;Altitude: 62.242682\u00b0&lt;dd&gt;Slant Range: 609.50358km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.868241157493734, 53.357993452260814]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.372826842170372, 53.35105139319803], [-5.271923701059999, 53.352624610861746], [-5.171013108811502, 53.354105436415324], [-5.070095518544999, 53.355493858691474], [-4.969171383594589, 53.35678986722644], [-4.868241157493734, 53.357993452260814], [-4.767305293964485, 53.359104604739535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.7673053&lt;dd&gt;Longitude: 53.359105&lt;dd&gt;Azimuth: 325.99168\u00b0&lt;dd&gt;Altitude: 62.601838\u00b0&lt;dd&gt;Slant Range: 607.70645km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.767305293964485, 53.359104604739535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.271923701059999, 53.352624610861746], [-5.171013108811502, 53.354105436415324], [-5.070095518544999, 53.355493858691474], [-4.969171383594589, 53.35678986722644], [-4.868241157493734, 53.357993452260814], [-4.767305293964485, 53.359104604739535], [-4.666364246908561, 53.360123316312354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.6663642&lt;dd&gt;Longitude: 53.360123&lt;dd&gt;Azimuth: 327.2385\u00b0&lt;dd&gt;Altitude: 62.952037\u00b0&lt;dd&gt;Slant Range: 605.98452km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.666364246908561, 53.360123316312354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.171013108811502, 53.354105436415324], [-5.070095518544999, 53.355493858691474], [-4.969171383594589, 53.35678986722644], [-4.868241157493734, 53.357993452260814], [-4.767305293964485, 53.359104604739535], [-4.666364246908561, 53.360123316312354], [-4.565418470374339, 53.36104957933429]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.5654185&lt;dd&gt;Longitude: 53.36105&lt;dd&gt;Azimuth: 328.52212\u00b0&lt;dd&gt;Altitude: 63.292599\u00b0&lt;dd&gt;Slant Range: 604.33844km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.565418470374339, 53.36104957933429]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.070095518544999, 53.355493858691474], [-4.969171383594589, 53.35678986722644], [-4.868241157493734, 53.357993452260814], [-4.767305293964485, 53.359104604739535], [-4.666364246908561, 53.360123316312354], [-4.565418470374339, 53.36104957933429], [-4.464468418566478, 53.36188338686572]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.4644684&lt;dd&gt;Longitude: 53.361883&lt;dd&gt;Azimuth: 329.84287\u00b0&lt;dd&gt;Altitude: 63.622823\u00b0&lt;dd&gt;Slant Range: 602.76883km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.464468418566478, 53.36188338686572]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.969171383594589, 53.35678986722644], [-4.868241157493734, 53.357993452260814], [-4.767305293964485, 53.359104604739535], [-4.666364246908561, 53.360123316312354], [-4.565418470374339, 53.36104957933429], [-4.464468418566478, 53.36188338686572], [-4.363514545816119, 53.362624732672764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.3635145&lt;dd&gt;Longitude: 53.362625&lt;dd&gt;Azimuth: 331.20095\u00b0&lt;dd&gt;Altitude: 63.942\u00b0&lt;dd&gt;Slant Range: 601.27629km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.363514545816119, 53.362624732672764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.868241157493734, 53.357993452260814], [-4.767305293964485, 53.359104604739535], [-4.666364246908561, 53.360123316312354], [-4.565418470374339, 53.36104957933429], [-4.464468418566478, 53.36188338686572], [-4.363514545816119, 53.362624732672764], [-4.262557306577634, 53.36327361122742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.2625573&lt;dd&gt;Longitude: 53.363274&lt;dd&gt;Azimuth: 332.59638\u00b0&lt;dd&gt;Altitude: 64.249404\u00b0&lt;dd&gt;Slant Range: 599.8614km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.262557306577634, 53.36327361122742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.767305293964485, 53.359104604739535], [-4.666364246908561, 53.360123316312354], [-4.565418470374339, 53.36104957933429], [-4.464468418566478, 53.36188338686572], [-4.363514545816119, 53.362624732672764], [-4.262557306577634, 53.36327361122742], [-4.161597155400553, 53.36383001770791]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.1615972&lt;dd&gt;Longitude: 53.36383&lt;dd&gt;Azimuth: 334.02902\u00b0&lt;dd&gt;Altitude: 64.544306\u00b0&lt;dd&gt;Slant Range: 598.52471km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.161597155400553, 53.36383001770791]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.666364246908561, 53.360123316312354], [-4.565418470374339, 53.36104957933429], [-4.464468418566478, 53.36188338686572], [-4.363514545816119, 53.362624732672764], [-4.262557306577634, 53.36327361122742], [-4.161597155400553, 53.36383001770791], [-4.060634546932702, 53.364293947998725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -4.0606345&lt;dd&gt;Longitude: 53.364294&lt;dd&gt;Azimuth: 335.49854\u00b0&lt;dd&gt;Altitude: 64.82597\u00b0&lt;dd&gt;Slant Range: 597.26675km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.060634546932702, 53.364293947998725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.565418470374339, 53.36104957933429], [-4.464468418566478, 53.36188338686572], [-4.363514545816119, 53.362624732672764], [-4.262557306577634, 53.36327361122742], [-4.161597155400553, 53.36383001770791], [-4.060634546932702, 53.364293947998725], [-3.959669935892715, 53.36466539869088]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.9596699&lt;dd&gt;Longitude: 53.364665&lt;dd&gt;Azimuth: 337.00439\u00b0&lt;dd&gt;Altitude: 65.093663\u00b0&lt;dd&gt;Slant Range: 596.08801km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.959669935892715, 53.36466539869088]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.464468418566478, 53.36188338686572], [-4.363514545816119, 53.362624732672764], [-4.262557306577634, 53.36327361122742], [-4.161597155400553, 53.36383001770791], [-4.060634546932702, 53.364293947998725], [-3.959669935892715, 53.36466539869088], [-3.8587037770599397, 53.36494436708201]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.8587038&lt;dd&gt;Longitude: 53.364944&lt;dd&gt;Azimuth: 338.54581\u00b0&lt;dd&gt;Altitude: 65.346655\u00b0&lt;dd&gt;Slant Range: 594.98898km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8587037770599397, 53.36494436708201]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.363514545816119, 53.362624732672764], [-4.262557306577634, 53.36327361122742], [-4.161597155400553, 53.36383001770791], [-4.060634546932702, 53.364293947998725], [-3.959669935892715, 53.36466539869088], [-3.8587037770599397, 53.36494436708201], [-3.75773652526746, 53.36513085117647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.7577365&lt;dd&gt;Longitude: 53.365131&lt;dd&gt;Azimuth: 340.12177\u00b0&lt;dd&gt;Altitude: 65.584229\u00b0&lt;dd&gt;Slant Range: 593.97008km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.75773652526746, 53.36513085117647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.262557306577634, 53.36327361122742], [-4.161597155400553, 53.36383001770791], [-4.060634546932702, 53.364293947998725], [-3.959669935892715, 53.36466539869088], [-3.8587037770599397, 53.36494436708201], [-3.75773652526746, 53.36513085117647], [-3.656768635378386, 53.365224849685355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.6567686&lt;dd&gt;Longitude: 53.365225&lt;dd&gt;Azimuth: 341.73101\u00b0&lt;dd&gt;Altitude: 65.805684\u00b0&lt;dd&gt;Slant Range: 593.03174km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.656768635378386, 53.365224849685355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.161597155400553, 53.36383001770791], [-4.060634546932702, 53.364293947998725], [-3.959669935892715, 53.36466539869088], [-3.8587037770599397, 53.36494436708201], [-3.75773652526746, 53.36513085117647], [-3.656768635378386, 53.365224849685355], [-3.555800562274528, 53.365226362026725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.5558006&lt;dd&gt;Longitude: 53.365226&lt;dd&gt;Azimuth: 343.37201\u00b0&lt;dd&gt;Altitude: 66.010342\u00b0&lt;dd&gt;Slant Range: 592.17434km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.555800562274528, 53.365226362026725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.060634546932702, 53.364293947998725], [-3.959669935892715, 53.36466539869088], [-3.8587037770599397, 53.36494436708201], [-3.75773652526746, 53.36513085117647], [-3.656768635378386, 53.365224849685355], [-3.555800562274528, 53.365226362026725], [-3.4548327608449996, 53.3651353883254]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.4548328&lt;dd&gt;Longitude: 53.365135&lt;dd&gt;Azimuth: 345.04296\u00b0&lt;dd&gt;Altitude: 66.197552\u00b0&lt;dd&gt;Slant Range: 591.39824km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4548327608449996, 53.3651353883254]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.959669935892715, 53.36466539869088], [-3.8587037770599397, 53.36494436708201], [-3.75773652526746, 53.36513085117647], [-3.656768635378386, 53.365224849685355], [-3.555800562274528, 53.365226362026725], [-3.4548327608449996, 53.3651353883254], [-3.3538656859701366, 53.36495192941314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.3538657&lt;dd&gt;Longitude: 53.364952&lt;dd&gt;Azimuth: 346.7418\u00b0&lt;dd&gt;Altitude: 66.366704\u00b0&lt;dd&gt;Slant Range: 590.70374km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3538656859701366, 53.36495192941314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8587037770599397, 53.36494436708201], [-3.75773652526746, 53.36513085117647], [-3.656768635378386, 53.365224849685355], [-3.555800562274528, 53.365226362026725], [-3.4548327608449996, 53.3651353883254], [-3.3538656859701366, 53.36495192941314], [-3.2528997925112155, 53.3646759868285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.2528998&lt;dd&gt;Longitude: 53.364676&lt;dd&gt;Azimuth: 348.4662\u00b0&lt;dd&gt;Altitude: 66.517225\u00b0&lt;dd&gt;Slant Range: 590.09115km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2528997925112155, 53.3646759868285]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.75773652526746, 53.36513085117647], [-3.656768635378386, 53.365224849685355], [-3.555800562274528, 53.365226362026725], [-3.4548327608449996, 53.3651353883254], [-3.3538656859701366, 53.36495192941314], [-3.2528997925112155, 53.3646759868285], [-3.151935535287658, 53.36430756281687]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.1519355&lt;dd&gt;Longitude: 53.364308&lt;dd&gt;Azimuth: 350.21357\u00b0&lt;dd&gt;Altitude: 66.648595\u00b0&lt;dd&gt;Slant Range: 589.56072km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.151935535287658, 53.36430756281687]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.656768635378386, 53.365224849685355], [-3.555800562274528, 53.365226362026725], [-3.4548327608449996, 53.3651353883254], [-3.3538656859701366, 53.36495192941314], [-3.2528997925112155, 53.3646759868285], [-3.151935535287658, 53.36430756281687], [-3.0509733690749683, 53.36384666033025]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -3.0509734&lt;dd&gt;Longitude: 53.363847&lt;dd&gt;Azimuth: 351.98109\u00b0&lt;dd&gt;Altitude: 66.760347\u00b0&lt;dd&gt;Slant Range: 589.11268km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0509733690749683, 53.36384666033025]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.555800562274528, 53.365226362026725], [-3.4548327608449996, 53.3651353883254], [-3.3538656859701366, 53.36495192941314], [-3.2528997925112155, 53.3646759868285], [-3.151935535287658, 53.36430756281687], [-3.0509733690749683, 53.36384666033025], [-2.95001374858079, 53.363293283027375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.9500137&lt;dd&gt;Longitude: 53.363293&lt;dd&gt;Azimuth: 353.76572\u00b0&lt;dd&gt;Altitude: 66.852078\u00b0&lt;dd&gt;Slant Range: 588.7472km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.95001374858079, 53.363293283027375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4548327608449996, 53.3651353883254], [-3.3538656859701366, 53.36495192941314], [-3.2528997925112155, 53.3646759868285], [-3.151935535287658, 53.36430756281687], [-3.0509733690749683, 53.36384666033025], [-2.95001374858079, 53.363293283027375], [-2.8490571284309376, 53.36264743527325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.8490571&lt;dd&gt;Longitude: 53.362647&lt;dd&gt;Azimuth: 355.56422\u00b0&lt;dd&gt;Altitude: 66.923449\u00b0&lt;dd&gt;Slant Range: 588.46445km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8490571284309376, 53.36264743527325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3538656859701366, 53.36495192941314], [-3.2528997925112155, 53.3646759868285], [-3.151935535287658, 53.36430756281687], [-3.0509733690749683, 53.36384666033025], [-2.95001374858079, 53.363293283027375], [-2.8490571284309376, 53.36264743527325], [-2.748103963167921, 53.3619091221393]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.748104&lt;dd&gt;Longitude: 53.361909&lt;dd&gt;Azimuth: 357.3732\u00b0&lt;dd&gt;Altitude: 66.974195\u00b0&lt;dd&gt;Slant Range: 588.26454km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.748103963167921, 53.3619091221393]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2528997925112155, 53.3646759868285], [-3.151935535287658, 53.36430756281687], [-3.0509733690749683, 53.36384666033025], [-2.95001374858079, 53.363293283027375], [-2.8490571284309376, 53.36264743527325], [-2.748103963167921, 53.3619091221393], [-2.6471547072217083, 53.361078349403016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.6471547&lt;dd&gt;Longitude: 53.361078&lt;dd&gt;Azimuth: 359.18915\u00b0&lt;dd&gt;Altitude: 67.004123\u00b0&lt;dd&gt;Slant Range: 588.14755km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6471547072217083, 53.361078349403016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.151935535287658, 53.36430756281687], [-3.0509733690749683, 53.36384666033025], [-2.95001374858079, 53.363293283027375], [-2.8490571284309376, 53.36264743527325], [-2.748103963167921, 53.3619091221393], [-2.6471547072217083, 53.361078349403016], [-2.546209814905758, 53.36015512354776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.5462098&lt;dd&gt;Longitude: 53.360155&lt;dd&gt;Azimuth: 1.0084688\u00b0&lt;dd&gt;Altitude: 67.013122\u00b0&lt;dd&gt;Slant Range: 588.11355km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.546209814905758, 53.36015512354776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0509733690749683, 53.36384666033025], [-2.95001374858079, 53.363293283027375], [-2.8490571284309376, 53.36264743527325], [-2.748103963167921, 53.3619091221393], [-2.6471547072217083, 53.361078349403016], [-2.546209814905758, 53.36015512354776], [-2.445269740394119, 53.35913945176256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.4452697&lt;dd&gt;Longitude: 53.359139&lt;dd&gt;Azimuth: 2.8275207\u00b0&lt;dd&gt;Altitude: 67.001156\u00b0&lt;dd&gt;Slant Range: 588.16254km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.445269740394119, 53.35913945176256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.95001374858079, 53.363293283027375], [-2.8490571284309376, 53.36264743527325], [-2.748103963167921, 53.3619091221393], [-2.6471547072217083, 53.361078349403016], [-2.546209814905758, 53.36015512354776], [-2.445269740394119, 53.35913945176256], [-2.3443349377225493, 53.35803134194173]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.3443349&lt;dd&gt;Longitude: 53.358031&lt;dd&gt;Azimuth: 4.6426701\u00b0&lt;dd&gt;Altitude: 66.968272\u00b0&lt;dd&gt;Slant Range: 588.2945km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3443349377225493, 53.35803134194173]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8490571284309376, 53.36264743527325], [-2.748103963167921, 53.3619091221393], [-2.6471547072217083, 53.361078349403016], [-2.546209814905758, 53.36015512354776], [-2.445269740394119, 53.35913945176256], [-2.3443349377225493, 53.35803134194173], [-2.2434058607535556, 53.35683080268478]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.2434059&lt;dd&gt;Longitude: 53.356831&lt;dd&gt;Azimuth: 6.4503291\u00b0&lt;dd&gt;Altitude: 66.914595\u00b0&lt;dd&gt;Slant Range: 588.50938km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2434058607535556, 53.35683080268478]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.748103963167921, 53.3619091221393], [-2.6471547072217083, 53.361078349403016], [-2.546209814905758, 53.36015512354776], [-2.445269740394119, 53.35913945176256], [-2.3443349377225493, 53.35803134194173], [-2.2434058607535556, 53.35683080268478], [-2.142482963182398, 53.35553784329593]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3390&lt;dd&gt;Latitude: -2.142483&lt;dd&gt;Longitude: 53.355538&lt;dd&gt;Azimuth: 8.2469987\u00b0&lt;dd&gt;Altitude: 66.840327\u00b0&lt;dd&gt;Slant Range: 588.80708km&quot;, &quot;name&quot;: &quot;STARLINK-3390&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.142482963182398, 53.35553784329593]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.160729185526363, 53.33451857657594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3363&lt;dd&gt;Latitude: 4.1607292&lt;dd&gt;Longitude: 53.334519&lt;dd&gt;Azimuth: 62.95098\u00b0&lt;dd&gt;Altitude: 43.699644\u00b0&lt;dd&gt;Slant Range: 757.59391km&quot;, &quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.160729185526363, 53.33451857657594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.160729185526363, 53.33451857657594], [4.26155777582399, 53.33682363041169]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3363&lt;dd&gt;Latitude: 4.2615578&lt;dd&gt;Longitude: 53.336824&lt;dd&gt;Azimuth: 63.202062\u00b0&lt;dd&gt;Altitude: 43.313685\u00b0&lt;dd&gt;Slant Range: 762.19597km&quot;, &quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.26155777582399, 53.33682363041169]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.160729185526363, 53.33451857657594], [4.26155777582399, 53.33682363041169], [4.3623973890744505, 53.33903640361692]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3363&lt;dd&gt;Latitude: 4.3623974&lt;dd&gt;Longitude: 53.339036&lt;dd&gt;Azimuth: 63.447084\u00b0&lt;dd&gt;Altitude: 42.931474\u00b0&lt;dd&gt;Slant Range: 766.83394km&quot;, &quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.3623973890744505, 53.33903640361692]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.160729185526363, 53.33451857657594], [4.26155777582399, 53.33682363041169], [4.3623973890744505, 53.33903640361692], [4.463247574353691, 53.34115687949031]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3363&lt;dd&gt;Latitude: 4.4632476&lt;dd&gt;Longitude: 53.341157&lt;dd&gt;Azimuth: 63.68626\u00b0&lt;dd&gt;Altitude: 42.552999\u00b0&lt;dd&gt;Slant Range: 771.50719km&quot;, &quot;name&quot;: &quot;STARLINK-3363&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.463247574353691, 53.34115687949031]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -4.3804869&lt;dd&gt;Longitude: 52.835694&lt;dd&gt;Azimuth: 322.2372\u00b0&lt;dd&gt;Altitude: 68.585557\u00b0&lt;dd&gt;Slant Range: 581.58226km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705], [-4.282034393196113, 52.84545182191505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -4.2820344&lt;dd&gt;Longitude: 52.845452&lt;dd&gt;Azimuth: 323.97401\u00b0&lt;dd&gt;Altitude: 68.9141\u00b0&lt;dd&gt;Slant Range: 580.40611km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.282034393196113, 52.84545182191505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705], [-4.282034393196113, 52.84545182191505], [-4.183536220267565, 52.8551213497418]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -4.1835362&lt;dd&gt;Longitude: 52.855121&lt;dd&gt;Azimuth: 325.76876\u00b0&lt;dd&gt;Altitude: 69.225444\u00b0&lt;dd&gt;Slant Range: 579.31192km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.183536220267565, 52.8551213497418]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705], [-4.282034393196113, 52.84545182191505], [-4.183536220267565, 52.8551213497418], [-4.084992721401143, 52.864702162884015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -4.0849927&lt;dd&gt;Longitude: 52.864702&lt;dd&gt;Azimuth: 327.62073\u00b0&lt;dd&gt;Altitude: 69.518463\u00b0&lt;dd&gt;Slant Range: 578.30018km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.084992721401143, 52.864702162884015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705], [-4.282034393196113, 52.84545182191505], [-4.183536220267565, 52.8551213497418], [-4.084992721401143, 52.864702162884015], [-3.986404279661146, 52.87419419213543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.9864043&lt;dd&gt;Longitude: 52.874194&lt;dd&gt;Azimuth: 329.52866\u00b0&lt;dd&gt;Altitude: 69.792038\u00b0&lt;dd&gt;Slant Range: 577.3713km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.986404279661146, 52.87419419213543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705], [-4.282034393196113, 52.84545182191505], [-4.183536220267565, 52.8551213497418], [-4.084992721401143, 52.864702162884015], [-3.986404279661146, 52.87419419213543], [-3.8877712793821653, 52.88359736886269]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.8877713&lt;dd&gt;Longitude: 52.883597&lt;dd&gt;Azimuth: 331.49076\u00b0&lt;dd&gt;Altitude: 70.045065\u00b0&lt;dd&gt;Slant Range: 576.52569km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8877712793821653, 52.88359736886269]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.380486858409695, 52.835693649180705], [-4.282034393196113, 52.84545182191505], [-4.183536220267565, 52.8551213497418], [-4.084992721401143, 52.864702162884015], [-3.986404279661146, 52.87419419213543], [-3.8877712793821653, 52.88359736886269], [-3.7890941061738603, 52.89291162500758]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.7890941&lt;dd&gt;Longitude: 52.892912&lt;dd&gt;Azimuth: 333.50461\u00b0&lt;dd&gt;Altitude: 70.276469\u00b0&lt;dd&gt;Slant Range: 575.76372km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7890941061738603, 52.89291162500758]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.282034393196113, 52.84545182191505], [-4.183536220267565, 52.8551213497418], [-4.084992721401143, 52.864702162884015], [-3.986404279661146, 52.87419419213543], [-3.8877712793821653, 52.88359736886269], [-3.7890941061738603, 52.89291162500758], [-3.6903731468911687, 52.9021368930896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.6903731&lt;dd&gt;Longitude: 52.902137&lt;dd&gt;Azimuth: 335.56713\u00b0&lt;dd&gt;Altitude: 70.485221\u00b0&lt;dd&gt;Slant Range: 575.08573km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6903731468911687, 52.9021368930896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.183536220267565, 52.8551213497418], [-4.084992721401143, 52.864702162884015], [-3.986404279661146, 52.87419419213543], [-3.8877712793821653, 52.88359736886269], [-3.7890941061738603, 52.89291162500758], [-3.6903731468911687, 52.9021368930896], [-3.591608789651071, 52.911273106208284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.5916088&lt;dd&gt;Longitude: 52.911273&lt;dd&gt;Azimuth: 337.67463\u00b0&lt;dd&gt;Altitude: 70.670351\u00b0&lt;dd&gt;Slant Range: 574.492km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.591608789651071, 52.911273106208284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.084992721401143, 52.864702162884015], [-3.986404279661146, 52.87419419213543], [-3.8877712793821653, 52.88359736886269], [-3.7890941061738603, 52.89291162500758], [-3.6903731468911687, 52.9021368930896], [-3.591608789651071, 52.911273106208284], [-3.4928014237981926, 52.920320198045125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.4928014&lt;dd&gt;Longitude: 52.92032&lt;dd&gt;Azimuth: 339.82275\u00b0&lt;dd&gt;Altitude: 70.830966\u00b0&lt;dd&gt;Slant Range: 573.9828km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4928014237981926, 52.920320198045125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.986404279661146, 52.87419419213543], [-3.8877712793821653, 52.88359736886269], [-3.7890941061738603, 52.89291162500758], [-3.6903731468911687, 52.9021368930896], [-3.591608789651071, 52.911273106208284], [-3.4928014237981926, 52.920320198045125], [-3.393951439919125, 52.92927810286646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.3939514&lt;dd&gt;Longitude: 52.929278&lt;dd&gt;Azimuth: 342.00651\u00b0&lt;dd&gt;Altitude: 70.966263\u00b0&lt;dd&gt;Slant Range: 573.55836km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.393951439919125, 52.92927810286646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8877712793821653, 52.88359736886269], [-3.7890941061738603, 52.89291162500758], [-3.6903731468911687, 52.9021368930896], [-3.591608789651071, 52.911273106208284], [-3.4928014237981926, 52.920320198045125], [-3.393951439919125, 52.92927810286646], [-3.295059229807597, 52.938146755525345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.2950592&lt;dd&gt;Longitude: 52.938147&lt;dd&gt;Azimuth: 344.22035\u00b0&lt;dd&gt;Altitude: 71.075544\u00b0&lt;dd&gt;Slant Range: 573.21887km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.295059229807597, 52.938146755525345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7890941061738603, 52.89291162500758], [-3.6903731468911687, 52.9021368930896], [-3.591608789651071, 52.911273106208284], [-3.4928014237981926, 52.920320198045125], [-3.393951439919125, 52.92927810286646], [-3.295059229807597, 52.938146755525345], [-3.1961251864780587, 52.94692609146403]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.1961252&lt;dd&gt;Longitude: 52.946926&lt;dd&gt;Azimuth: 346.4582\u00b0&lt;dd&gt;Altitude: 71.158233\u00b0&lt;dd&gt;Slant Range: 572.96448km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1961251864780587, 52.94692609146403]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6903731468911687, 52.9021368930896], [-3.591608789651071, 52.911273106208284], [-3.4928014237981926, 52.920320198045125], [-3.393951439919125, 52.92927810286646], [-3.295059229807597, 52.938146755525345], [-3.1961251864780587, 52.94692609146403], [-3.0971497041458607, 52.95561604671613]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -3.0971497&lt;dd&gt;Longitude: 52.955616&lt;dd&gt;Azimuth: 348.71359\u00b0&lt;dd&gt;Altitude: 71.213885\u00b0&lt;dd&gt;Slant Range: 572.79529km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0971497041458607, 52.95561604671613]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.591608789651071, 52.911273106208284], [-3.4928014237981926, 52.920320198045125], [-3.393951439919125, 52.92927810286646], [-3.295059229807597, 52.938146755525345], [-3.1961251864780587, 52.94692609146403], [-3.0971497041458607, 52.95561604671613], [-2.9981331782114795, 52.9642165579088]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.9981332&lt;dd&gt;Longitude: 52.964217&lt;dd&gt;Azimuth: 350.9797\u00b0&lt;dd&gt;Altitude: 71.242198\u00b0&lt;dd&gt;Slant Range: 572.71139km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9981331782114795, 52.9642165579088]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4928014237981926, 52.920320198045125], [-3.393951439919125, 52.92927810286646], [-3.295059229807597, 52.938146755525345], [-3.1961251864780587, 52.94692609146403], [-3.0971497041458607, 52.95561604671613], [-2.9981331782114795, 52.9642165579088], [-2.89907600526604, 52.97272756226511]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.899076&lt;dd&gt;Longitude: 52.972728&lt;dd&gt;Azimuth: 353.24952\u00b0&lt;dd&gt;Altitude: 71.243015\u00b0&lt;dd&gt;Slant Range: 572.71281km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.89907600526604, 52.97272756226511]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.393951439919125, 52.92927810286646], [-3.295059229807597, 52.938146755525345], [-3.1961251864780587, 52.94692609146403], [-3.0971497041458607, 52.95561604671613], [-2.9981331782114795, 52.9642165579088], [-2.89907600526604, 52.97272756226511], [-2.799978583066122, 52.981148997606134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.7999786&lt;dd&gt;Longitude: 52.981149&lt;dd&gt;Azimuth: 355.51598\u00b0&lt;dd&gt;Altitude: 71.216334\u00b0&lt;dd&gt;Slant Range: 572.79956km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.799978583066122, 52.981148997606134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.295059229807597, 52.938146755525345], [-3.1961251864780587, 52.94692609146403], [-3.0971497041458607, 52.95561604671613], [-2.9981331782114795, 52.9642165579088], [-2.89907600526604, 52.97272756226511], [-2.799978583066122, 52.981148997606134], [-2.7008413105383946, 52.98948080235304]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.7008413&lt;dd&gt;Longitude: 52.989481&lt;dd&gt;Azimuth: 357.77207\u00b0&lt;dd&gt;Altitude: 71.162302\u00b0&lt;dd&gt;Slant Range: 572.97159km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7008413105383946, 52.98948080235304]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1961251864780587, 52.94692609146403], [-3.0971497041458607, 52.95561604671613], [-2.9981331782114795, 52.9642165579088], [-2.89907600526604, 52.97272756226511], [-2.799978583066122, 52.981148997606134], [-2.7008413105383946, 52.98948080235304], [-2.601664587755061, 52.99772291552951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.6016646&lt;dd&gt;Longitude: 52.997723&lt;dd&gt;Azimuth: 0.010970803\u00b0&lt;dd&gt;Altitude: 71.081217\u00b0&lt;dd&gt;Slant Range: 573.22882km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.601664587755061, 52.99772291552951]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0971497041458607, 52.95561604671613], [-2.9981331782114795, 52.9642165579088], [-2.89907600526604, 52.97272756226511], [-2.799978583066122, 52.981148997606134], [-2.7008413105383946, 52.98948080235304], [-2.601664587755061, 52.99772291552951], [-2.5024488159366305, 53.00587527676369]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.5024488&lt;dd&gt;Longitude: 53.005875&lt;dd&gt;Azimuth: 2.226173\u00b0&lt;dd&gt;Altitude: 70.973518\u00b0&lt;dd&gt;Slant Range: 573.57115km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5024488159366305, 53.00587527676369]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9981331782114795, 52.9642165579088], [-2.89907600526604, 52.97272756226511], [-2.799978583066122, 52.981148997606134], [-2.7008413105383946, 52.98948080235304], [-2.601664587755061, 52.99772291552951], [-2.5024488159366305, 53.00587527676369], [-2.403194397431184, 53.01393782629039]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.4031944&lt;dd&gt;Longitude: 53.013938&lt;dd&gt;Azimuth: 4.4115861\u00b0&lt;dd&gt;Altitude: 70.839775\u00b0&lt;dd&gt;Slant Range: 573.99841km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.403194397431184, 53.01393782629039]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.89907600526604, 52.97272756226511], [-2.799978583066122, 52.981148997606134], [-2.7008413105383946, 52.98948080235304], [-2.601664587755061, 52.99772291552951], [-2.5024488159366305, 53.00587527676369], [-2.403194397431184, 53.01393782629039], [-2.3039017357147538, 53.02191050495325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.3039017&lt;dd&gt;Longitude: 53.021911&lt;dd&gt;Azimuth: 6.5616267\u00b0&lt;dd&gt;Altitude: 70.680682\u00b0&lt;dd&gt;Slant Range: 574.51042km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3039017357147538, 53.02191050495325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.799978583066122, 52.981148997606134], [-2.7008413105383946, 52.98948080235304], [-2.601664587755061, 52.99772291552951], [-2.5024488159366305, 53.00587527676369], [-2.403194397431184, 53.01393782629039], [-2.3039017357147538, 53.02191050495325], [-2.2045712353687548, 53.02979325420657]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.2045712&lt;dd&gt;Longitude: 53.029793&lt;dd&gt;Azimuth: 8.6712856\u00b0&lt;dd&gt;Altitude: 70.497035\u00b0&lt;dd&gt;Slant Range: 575.10695km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2045712353687548, 53.02979325420657]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7008413105383946, 52.98948080235304], [-2.601664587755061, 52.99772291552951], [-2.5024488159366305, 53.00587527676369], [-2.403194397431184, 53.01393782629039], [-2.3039017357147538, 53.02191050495325], [-2.2045712353687548, 53.02979325420657], [-2.1052033020816387, 53.03758601611781]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.1052033&lt;dd&gt;Longitude: 53.037586&lt;dd&gt;Azimuth: 10.736175\u00b0&lt;dd&gt;Altitude: 70.289726\u00b0&lt;dd&gt;Slant Range: 575.78774km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.1052033020816387, 53.03758601611781]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.601664587755061, 52.99772291552951], [-2.5024488159366305, 53.00587527676369], [-2.403194397431184, 53.01393782629039], [-2.3039017357147538, 53.02191050495325], [-2.2045712353687548, 53.02979325420657], [-2.1052033020816387, 53.03758601611781], [-2.0057983426322274, 53.04528873336934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -2.0057983&lt;dd&gt;Longitude: 53.045289&lt;dd&gt;Azimuth: 12.752553\u00b0&lt;dd&gt;Altitude: 70.059722\u00b0&lt;dd&gt;Slant Range: 576.55249km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0057983426322274, 53.04528873336934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5024488159366305, 53.00587527676369], [-2.403194397431184, 53.01393782629039], [-2.3039017357147538, 53.02191050495325], [-2.2045712353687548, 53.02979325420657], [-2.1052033020816387, 53.03758601611781], [-2.0057983426322274, 53.04528873336934], [-1.9063567648803759, 53.05290134926039]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.9063568&lt;dd&gt;Longitude: 53.052901&lt;dd&gt;Azimuth: 14.717329\u00b0&lt;dd&gt;Altitude: 69.808049\u00b0&lt;dd&gt;Slant Range: 577.40086km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9063567648803759, 53.05290134926039]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.403194397431184, 53.01393782629039], [-2.3039017357147538, 53.02191050495325], [-2.2045712353687548, 53.02979325420657], [-2.1052033020816387, 53.03758601611781], [-2.0057983426322274, 53.04528873336934], [-1.9063567648803759, 53.05290134926039], [-1.8068789777531542, 53.06042380770947]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.806879&lt;dd&gt;Longitude: 53.060424&lt;dd&gt;Azimuth: 16.62805\u00b0&lt;dd&gt;Altitude: 69.535781\u00b0&lt;dd&gt;Slant Range: 578.33248km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8068789777531542, 53.06042380770947]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3039017357147538, 53.02191050495325], [-2.2045712353687548, 53.02979325420657], [-2.1052033020816387, 53.03758601611781], [-2.0057983426322274, 53.04528873336934], [-1.9063567648803759, 53.05290134926039], [-1.8068789777531542, 53.06042380770947], [-1.7073653912440094, 53.06785605325598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.7073654&lt;dd&gt;Longitude: 53.067856&lt;dd&gt;Azimuth: 18.482876\u00b0&lt;dd&gt;Altitude: 69.244021\u00b0&lt;dd&gt;Slant Range: 579.34696km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7073653912440094, 53.06785605325598]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.2045712353687548, 53.02979325420657], [-2.1052033020816387, 53.03758601611781], [-2.0057983426322274, 53.04528873336934], [-1.9063567648803759, 53.05290134926039], [-1.8068789777531542, 53.06042380770947], [-1.7073653912440094, 53.06785605325598], [-1.60781641638386, 53.07519803106246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.6078164&lt;dd&gt;Longitude: 53.075198&lt;dd&gt;Azimuth: 20.280537\u00b0&lt;dd&gt;Altitude: 68.933888\u00b0&lt;dd&gt;Slant Range: 580.44385km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.60781641638386, 53.07519803106246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.1052033020816387, 53.03758601611781], [-2.0057983426322274, 53.04528873336934], [-1.9063567648803759, 53.05290134926039], [-1.8068789777531542, 53.06042380770947], [-1.7073653912440094, 53.06785605325598], [-1.60781641638386, 53.07519803106246], [-1.5082324652567694, 53.08244968691625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.5082325&lt;dd&gt;Longitude: 53.08245&lt;dd&gt;Azimuth: 22.020287\u00b0&lt;dd&gt;Altitude: 68.606509\u00b0&lt;dd&gt;Slant Range: 581.62269km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5082324652567694, 53.08244968691625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0057983426322274, 53.04528873336934], [-1.9063567648803759, 53.05290134926039], [-1.8068789777531542, 53.06042380770947], [-1.7073653912440094, 53.06785605325598], [-1.60781641638386, 53.07519803106246], [-1.5082324652567694, 53.08244968691625], [-1.4086139509617288, 53.089610967231806]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.408614&lt;dd&gt;Longitude: 53.089611&lt;dd&gt;Azimuth: 23.701856\u00b0&lt;dd&gt;Altitude: 68.263003\u00b0&lt;dd&gt;Slant Range: 582.88298km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4086139509617288, 53.089610967231806]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9063567648803759, 53.05290134926039], [-1.8068789777531542, 53.06042380770947], [-1.7073653912440094, 53.06785605325598], [-1.60781641638386, 53.07519803106246], [-1.5082324652567694, 53.08244968691625], [-1.4086139509617288, 53.089610967231806], [-1.3089612876224028, 53.096681819052336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.3089613&lt;dd&gt;Longitude: 53.096682&lt;dd&gt;Azimuth: 25.325385\u00b0&lt;dd&gt;Altitude: 67.904477\u00b0&lt;dd&gt;Slant Range: 584.22419km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3089612876224028, 53.096681819052336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8068789777531542, 53.06042380770947], [-1.7073653912440094, 53.06785605325598], [-1.60781641638386, 53.07519803106246], [-1.5082324652567694, 53.08244968691625], [-1.4086139509617288, 53.089610967231806], [-1.3089612876224028, 53.096681819052336], [-1.2092748903590127, 53.103662190051665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.2092749&lt;dd&gt;Longitude: 53.103662&lt;dd&gt;Azimuth: 26.891381\u00b0&lt;dd&gt;Altitude: 67.532013\u00b0&lt;dd&gt;Slant Range: 585.64576km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2092748903590127, 53.103662190051665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7073653912440094, 53.06785605325598], [-1.60781641638386, 53.07519803106246], [-1.5082324652567694, 53.08244968691625], [-1.4086139509617288, 53.089610967231806], [-1.3089612876224028, 53.096681819052336], [-1.2092748903590127, 53.103662190051665], [-1.1095551752968853, 53.11055202853649]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.1095552&lt;dd&gt;Longitude: 53.110552&lt;dd&gt;Azimuth: 28.400655\u00b0&lt;dd&gt;Altitude: 67.146669\u00b0&lt;dd&gt;Slant Range: 587.1471km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1095551752968853, 53.11055202853649]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.60781641638386, 53.07519803106246], [-1.5082324652567694, 53.08244968691625], [-1.4086139509617288, 53.089610967231806], [-1.3089612876224028, 53.096681819052336], [-1.2092748903590127, 53.103662190051665], [-1.1095551752968853, 53.11055202853649], [-1.0098025595353868, 53.117351283447775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -1.0098026&lt;dd&gt;Longitude: 53.117351&lt;dd&gt;Azimuth: 29.854275\u00b0&lt;dd&gt;Altitude: 66.749466\u00b0&lt;dd&gt;Slant Range: 588.72762km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0098025595353868, 53.117351283447775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5082324652567694, 53.08244968691625], [-1.4086139509617288, 53.089610967231806], [-1.3089612876224028, 53.096681819052336], [-1.2092748903590127, 53.103662190051665], [-1.1095551752968853, 53.11055202853649], [-1.0098025595353868, 53.117351283447775], [-0.910017461152018, 53.124059904362895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.91001746&lt;dd&gt;Longitude: 53.12406&lt;dd&gt;Azimuth: 31.253514\u00b0&lt;dd&gt;Altitude: 66.341389\u00b0&lt;dd&gt;Slant Range: 590.38666km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.910017461152018, 53.124059904362895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4086139509617288, 53.089610967231806], [-1.3089612876224028, 53.096681819052336], [-1.2092748903590127, 53.103662190051665], [-1.1095551752968853, 53.11055202853649], [-1.0098025595353868, 53.117351283447775], [-0.910017461152018, 53.124059904362895], [-0.8102002991796674, 53.130677841497366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.8102003&lt;dd&gt;Longitude: 53.130678&lt;dd&gt;Azimuth: 32.599813\u00b0&lt;dd&gt;Altitude: 65.923385\u00b0&lt;dd&gt;Slant Range: 592.12356km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8102002991796674, 53.130677841497366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3089612876224028, 53.096681819052336], [-1.2092748903590127, 53.103662190051665], [-1.1095551752968853, 53.11055202853649], [-1.0098025595353868, 53.117351283447775], [-0.910017461152018, 53.124059904362895], [-0.8102002991796674, 53.130677841497366], [-0.7103514936071458, 53.1372050457066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.71035149&lt;dd&gt;Longitude: 53.137205&lt;dd&gt;Azimuth: 33.894736\u00b0&lt;dd&gt;Altitude: 65.496358\u00b0&lt;dd&gt;Slant Range: 593.93765km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7103514936071458, 53.1372050457066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2092748903590127, 53.103662190051665], [-1.1095551752968853, 53.11055202853649], [-1.0098025595353868, 53.117351283447775], [-0.910017461152018, 53.124059904362895], [-0.8102002991796674, 53.130677841497366], [-0.7103514936071458, 53.1372050457066], [-0.6104714653528764, 53.14364146848778]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.61047147&lt;dd&gt;Longitude: 53.143641&lt;dd&gt;Azimuth: 35.13994\u00b0&lt;dd&gt;Altitude: 65.061172\u00b0&lt;dd&gt;Slant Range: 595.82821km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6104714653528764, 53.14364146848778]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1095551752968853, 53.11055202853649], [-1.0098025595353868, 53.117351283447775], [-0.910017461152018, 53.124059904362895], [-0.8102002991796674, 53.130677841497366], [-0.7103514936071458, 53.1372050457066], [-0.6104714653528764, 53.14364146848778], [-0.5105606362646404, 53.14998706198154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.51056064&lt;dd&gt;Longitude: 53.149987&lt;dd&gt;Azimuth: 36.337142\u00b0&lt;dd&gt;Altitude: 64.618644\u00b0&lt;dd&gt;Slant Range: 597.79451km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5105606362646404, 53.14998706198154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0098025595353868, 53.117351283447775], [-0.910017461152018, 53.124059904362895], [-0.8102002991796674, 53.130677841497366], [-0.7103514936071458, 53.1372050457066], [-0.6104714653528764, 53.14364146848778], [-0.5105606362646404, 53.14998706198154], [-0.41061942911311444, 53.15624177897364]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.41061943&lt;dd&gt;Longitude: 53.156242&lt;dd&gt;Azimuth: 37.488097\u00b0&lt;dd&gt;Altitude: 64.169554\u00b0&lt;dd&gt;Slant Range: 599.83581km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.41061942911311444, 53.15624177897364]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.910017461152018, 53.124059904362895], [-0.8102002991796674, 53.130677841497366], [-0.7103514936071458, 53.1372050457066], [-0.6104714653528764, 53.14364146848778], [-0.5105606362646404, 53.14998706198154], [-0.41061942911311444, 53.15624177897364], [-0.31064826755917396, 53.162405572896844]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.31064827&lt;dd&gt;Longitude: 53.162406&lt;dd&gt;Azimuth: 38.594575\u00b0&lt;dd&gt;Altitude: 63.714636\u00b0&lt;dd&gt;Slant Range: 601.95135km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.31064826755917396, 53.162405572896844]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8102002991796674, 53.130677841497366], [-0.7103514936071458, 53.1372050457066], [-0.6104714653528764, 53.14364146848778], [-0.5105606362646404, 53.14998706198154], [-0.41061942911311444, 53.15624177897364], [-0.31064826755917396, 53.162405572896844], [-0.21064757616501284, 53.1684783978325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.21064758&lt;dd&gt;Longitude: 53.168478&lt;dd&gt;Azimuth: 39.658343\u00b0&lt;dd&gt;Altitude: 63.254584\u00b0&lt;dd&gt;Slant Range: 604.14033km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.21064757616501284, 53.1684783978325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7103514936071458, 53.1372050457066], [-0.6104714653528764, 53.14364146848778], [-0.5105606362646404, 53.14998706198154], [-0.41061942911311444, 53.15624177897364], [-0.31064826755917396, 53.162405572896844], [-0.21064757616501284, 53.1684783978325], [-0.11061778036791009, 53.174460208512215]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.11061778&lt;dd&gt;Longitude: 53.17446&lt;dd&gt;Azimuth: 40.681151\u00b0&lt;dd&gt;Altitude: 62.790054\u00b0&lt;dd&gt;Slant Range: 606.40197km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.11061778036791009, 53.174460208512215]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6104714653528764, 53.14364146848778], [-0.5105606362646404, 53.14998706198154], [-0.41061942911311444, 53.15624177897364], [-0.31064826755917396, 53.162405572896844], [-0.21064757616501284, 53.1684783978325], [-0.11061778036791009, 53.174460208512215], [-0.010559306472749106, 53.18035096031955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: -0.010559306&lt;dd&gt;Longitude: 53.180351&lt;dd&gt;Azimuth: 41.664719\u00b0&lt;dd&gt;Altitude: 62.321659\u00b0&lt;dd&gt;Slant Range: 608.73544km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.010559306472749106, 53.18035096031955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5105606362646404, 53.14998706198154], [-0.41061942911311444, 53.15624177897364], [-0.31064826755917396, 53.162405572896844], [-0.21064757616501284, 53.1684783978325], [-0.11061778036791009, 53.174460208512215], [-0.010559306472749106, 53.18035096031955], [0.0895274183566334, 53.186150609291644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.089527418&lt;dd&gt;Longitude: 53.186151&lt;dd&gt;Azimuth: 42.610732\u00b0&lt;dd&gt;Altitude: 61.84998\u00b0&lt;dd&gt;Slant Range: 611.13993km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.0895274183566334, 53.186150609291644]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.41061942911311444, 53.15624177897364], [-0.31064826755917396, 53.162405572896844], [-0.21064757616501284, 53.1684783978325], [-0.11061778036791009, 53.174460208512215], [-0.010559306472749106, 53.18035096031955], [0.0895274183566334, 53.186150609291644], [0.18964196611235784, 53.19185911212081]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.18964197&lt;dd&gt;Longitude: 53.191859&lt;dd&gt;Azimuth: 43.520826\u00b0&lt;dd&gt;Altitude: 61.375559\u00b0&lt;dd&gt;Slant Range: 613.6146km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.18964196611235784, 53.19185911212081]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.31064826755917396, 53.162405572896844], [-0.21064757616501284, 53.1684783978325], [-0.11061778036791009, 53.174460208512215], [-0.010559306472749106, 53.18035096031955], [0.0895274183566334, 53.186150609291644], [0.18964196611235784, 53.19185911212081], [0.28978390795916786, 53.19747642615591]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.28978391&lt;dd&gt;Longitude: 53.197476&lt;dd&gt;Azimuth: 44.396589\u00b0&lt;dd&gt;Altitude: 60.898906\u00b0&lt;dd&gt;Slant Range: 616.15859km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.28978390795916786, 53.19747642615591]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.21064757616501284, 53.1684783978325], [-0.11061778036791009, 53.174460208512215], [-0.010559306472749106, 53.18035096031955], [0.0895274183566334, 53.186150609291644], [0.18964196611235784, 53.19185911212081], [0.28978390795916786, 53.19747642615591], [0.3899528142351427, 53.20300250940442]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.38995281&lt;dd&gt;Longitude: 53.203003&lt;dd&gt;Azimuth: 45.239555\u00b0&lt;dd&gt;Altitude: 60.420496\u00b0&lt;dd&gt;Slant Range: 618.77105km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3899528142351427, 53.20300250940442]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.11061778036791009, 53.174460208512215], [-0.010559306472749106, 53.18035096031955], [0.0895274183566334, 53.186150609291644], [0.18964196611235784, 53.19185911212081], [0.28978390795916786, 53.19747642615591], [0.3899528142351427, 53.20300250940442], [0.4901482544781088, 53.208437320533385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.49014825&lt;dd&gt;Longitude: 53.208437&lt;dd&gt;Azimuth: 46.051198\u00b0&lt;dd&gt;Altitude: 59.940775\u00b0&lt;dd&gt;Slant Range: 621.45112km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.4901482544781088, 53.208437320533385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.010559306472749106, 53.18035096031955], [0.0895274183566334, 53.186150609291644], [0.18964196611235784, 53.19185911212081], [0.28978390795916786, 53.19747642615591], [0.3899528142351427, 53.20300250940442], [0.4901482544781088, 53.208437320533385], [0.5903697974183367, 53.21378081887134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.5903698&lt;dd&gt;Longitude: 53.213781&lt;dd&gt;Azimuth: 46.832939\u00b0&lt;dd&gt;Altitude: 59.460161\u00b0&lt;dd&gt;Slant Range: 624.19792km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5903697974183367, 53.21378081887134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.0895274183566334, 53.186150609291644], [0.18964196611235784, 53.19185911212081], [0.28978390795916786, 53.19747642615591], [0.3899528142351427, 53.20300250940442], [0.4901482544781088, 53.208437320533385], [0.5903697974183367, 53.21378081887134], [0.6906170110173191, 53.21903296440968]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.69061701&lt;dd&gt;Longitude: 53.219033&lt;dd&gt;Azimuth: 47.586134\u00b0&lt;dd&gt;Altitude: 58.979042\u00b0&lt;dd&gt;Slant Range: 627.01056km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6906170110173191, 53.21903296440968]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.18964196611235784, 53.19185911212081], [0.28978390795916786, 53.19747642615591], [0.3899528142351427, 53.20300250940442], [0.4901482544781088, 53.208437320533385], [0.5903697974183367, 53.21378081887134], [0.6906170110173191, 53.21903296440968], [0.7908894624536994, 53.22419371780401]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.79088946&lt;dd&gt;Longitude: 53.224194&lt;dd&gt;Azimuth: 48.312085\u00b0&lt;dd&gt;Altitude: 58.49778\u00b0&lt;dd&gt;Slant Range: 629.88817km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7908894624536994, 53.22419371780401]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.28978390795916786, 53.19747642615591], [0.3899528142351427, 53.20300250940442], [0.4901482544781088, 53.208437320533385], [0.5903697974183367, 53.21378081887134], [0.6906170110173191, 53.21903296440968], [0.7908894624536994, 53.22419371780401], [0.8911867181543398, 53.22926304037582]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.89118672&lt;dd&gt;Longitude: 53.229263&lt;dd&gt;Azimuth: 49.012034\u00b0&lt;dd&gt;Altitude: 58.016714\u00b0&lt;dd&gt;Slant Range: 632.82985km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8911867181543398, 53.22926304037582]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3899528142351427, 53.20300250940442], [0.4901482544781088, 53.208437320533385], [0.5903697974183367, 53.21378081887134], [0.6906170110173191, 53.21903296440968], [0.7908894624536994, 53.22419371780401], [0.8911867181543398, 53.22926304037582], [0.9915083437932779, 53.23424089411374]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 0.99150834&lt;dd&gt;Longitude: 53.234241&lt;dd&gt;Azimuth: 49.687166\u00b0&lt;dd&gt;Altitude: 57.536157\u00b0&lt;dd&gt;Slant Range: 635.83472km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9915083437932779, 53.23424089411374]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.4901482544781088, 53.208437320533385], [0.5903697974183367, 53.21378081887134], [0.6906170110173191, 53.21903296440968], [0.7908894624536994, 53.22419371780401], [0.8911867181543398, 53.22926304037582], [0.9915083437932779, 53.23424089411374], [1.0918539043183162, 53.2391272416749]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.0918539&lt;dd&gt;Longitude: 53.239127&lt;dd&gt;Azimuth: 50.33861\u00b0&lt;dd&gt;Altitude: 57.056403\u00b0&lt;dd&gt;Slant Range: 638.90187km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0918539043183162, 53.2391272416749]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5903697974183367, 53.21378081887134], [0.6906170110173191, 53.21903296440968], [0.7908894624536994, 53.22419371780401], [0.8911867181543398, 53.22926304037582], [0.9915083437932779, 53.23424089411374], [1.0918539043183162, 53.2391272416749], [1.1922229639468742, 53.24392204638652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.192223&lt;dd&gt;Longitude: 53.243922&lt;dd&gt;Azimuth: 50.967441\u00b0&lt;dd&gt;Altitude: 56.577723\u00b0&lt;dd&gt;Slant Range: 642.03041km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1922229639468742, 53.24392204638652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6906170110173191, 53.21903296440968], [0.7908894624536994, 53.22419371780401], [0.8911867181543398, 53.22926304037582], [0.9915083437932779, 53.23424089411374], [1.0918539043183162, 53.2391272416749], [1.1922229639468742, 53.24392204638652], [1.2926150861974646, 53.248625272247104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.2926151&lt;dd&gt;Longitude: 53.248625&lt;dd&gt;Azimuth: 51.574682\u00b0&lt;dd&gt;Altitude: 56.100368\u00b0&lt;dd&gt;Slant Range: 645.21944km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2926150861974646, 53.248625272247104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7908894624536994, 53.22419371780401], [0.8911867181543398, 53.22926304037582], [0.9915083437932779, 53.23424089411374], [1.0918539043183162, 53.2391272416749], [1.1922229639468742, 53.24392204638652], [1.2926150861974646, 53.248625272247104], [1.3930298338836353, 53.25323688392779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.3930298&lt;dd&gt;Longitude: 53.253237&lt;dd&gt;Azimuth: 52.161307\u00b0&lt;dd&gt;Altitude: 55.624573\u00b0&lt;dd&gt;Slant Range: 648.46807km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3930298338836353, 53.25323688392779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8911867181543398, 53.22926304037582], [0.9915083437932779, 53.23424089411374], [1.0918539043183162, 53.2391272416749], [1.1922229639468742, 53.24392204638652], [1.2926150861974646, 53.248625272247104], [1.3930298338836353, 53.25323688392779], [1.4934667691404084, 53.25775684677359]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.4934668&lt;dd&gt;Longitude: 53.257757&lt;dd&gt;Azimuth: 52.728239\u00b0&lt;dd&gt;Altitude: 55.150553\u00b0&lt;dd&gt;Slant Range: 651.77541km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4934667691404084, 53.25775684677359]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9915083437932779, 53.23424089411374], [1.0918539043183162, 53.2391272416749], [1.1922229639468742, 53.24392204638652], [1.2926150861974646, 53.248625272247104], [1.3930298338836353, 53.25323688392779], [1.4934667691404084, 53.25775684677359], [1.5939254534287568, 53.26218512680493]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.5939255&lt;dd&gt;Longitude: 53.262185&lt;dd&gt;Azimuth: 53.276357\u00b0&lt;dd&gt;Altitude: 54.678508\u00b0&lt;dd&gt;Slant Range: 655.14055km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5939254534287568, 53.26218512680493]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0918539043183162, 53.2391272416749], [1.1922229639468742, 53.24392204638652], [1.2926150861974646, 53.248625272247104], [1.3930298338836353, 53.25323688392779], [1.4934667691404084, 53.25775684677359], [1.5939254534287568, 53.26218512680493], [1.694405447553645, 53.26652169071857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.6944054&lt;dd&gt;Longitude: 53.266522&lt;dd&gt;Azimuth: 53.806494\u00b0&lt;dd&gt;Altitude: 54.208622\u00b0&lt;dd&gt;Slant Range: 658.56261km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.694405447553645, 53.26652169071857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1922229639468742, 53.24392204638652], [1.2926150861974646, 53.248625272247104], [1.3930298338836353, 53.25323688392779], [1.4934667691404084, 53.25775684677359], [1.5939254534287568, 53.26218512680493], [1.694405447553645, 53.26652169071857], [1.7949063116760644, 53.2707665058891]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.7949063&lt;dd&gt;Longitude: 53.270767&lt;dd&gt;Azimuth: 54.319444\u00b0&lt;dd&gt;Altitude: 53.741065\u00b0&lt;dd&gt;Slant Range: 662.04071km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7949063116760644, 53.2707665058891]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2926150861974646, 53.248625272247104], [1.3930298338836353, 53.25323688392779], [1.4934667691404084, 53.25775684677359], [1.5939254534287568, 53.26218512680493], [1.694405447553645, 53.26652169071857], [1.7949063116760644, 53.2707665058891], [1.8954276053181474, 53.27491954036993]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.8954276&lt;dd&gt;Longitude: 53.27492&lt;dd&gt;Azimuth: 54.815957\u00b0&lt;dd&gt;Altitude: 53.275994\u00b0&lt;dd&gt;Slant Range: 665.57396km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8954276053181474, 53.27491954036993]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3930298338836353, 53.25323688392779], [1.4934667691404084, 53.25775684677359], [1.5939254534287568, 53.26218512680493], [1.694405447553645, 53.26652169071857], [1.7949063116760644, 53.2707665058891], [1.8954276053181474, 53.27491954036993], [1.9959688873921486, 53.278980762894754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 1.9959689&lt;dd&gt;Longitude: 53.278981&lt;dd&gt;Azimuth: 55.296748\u00b0&lt;dd&gt;Altitude: 52.81355\u00b0&lt;dd&gt;Slant Range: 669.16148km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9959688873921486, 53.278980762894754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4934667691404084, 53.25775684677359], [1.5939254534287568, 53.26218512680493], [1.694405447553645, 53.26652169071857], [1.7949063116760644, 53.2707665058891], [1.8954276053181474, 53.27491954036993], [1.9959688873921486, 53.278980762894754], [2.096529716197188, 53.282950142878406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.0965297&lt;dd&gt;Longitude: 53.28295&lt;dd&gt;Azimuth: 55.762496\u00b0&lt;dd&gt;Altitude: 52.353867\u00b0&lt;dd&gt;Slant Range: 672.8024km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.096529716197188, 53.282950142878406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5939254534287568, 53.26218512680493], [1.694405447553645, 53.26652169071857], [1.7949063116760644, 53.2707665058891], [1.8954276053181474, 53.27491954036993], [1.9959688873921486, 53.278980762894754], [2.096529716197188, 53.282950142878406], [2.197109649438004, 53.28682765041824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.1971096&lt;dd&gt;Longitude: 53.286828&lt;dd&gt;Azimuth: 56.213842\u00b0&lt;dd&gt;Altitude: 51.897063\u00b0&lt;dd&gt;Slant Range: 676.49585km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.197109649438004, 53.28682765041824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.694405447553645, 53.26652169071857], [1.7949063116760644, 53.2707665058891], [1.8954276053181474, 53.27491954036993], [1.9959688873921486, 53.278980762894754], [2.096529716197188, 53.282950142878406], [2.197109649438004, 53.28682765041824], [2.297708244243374, 53.29061325629512]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.2977082&lt;dd&gt;Longitude: 53.290613&lt;dd&gt;Azimuth: 56.651399\u00b0&lt;dd&gt;Altitude: 51.443248\u00b0&lt;dd&gt;Slant Range: 680.24098km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.297708244243374, 53.29061325629512]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7949063116760644, 53.2707665058891], [1.8954276053181474, 53.27491954036993], [1.9959688873921486, 53.278980762894754], [2.096529716197188, 53.282950142878406], [2.197109649438004, 53.28682765041824], [2.297708244243374, 53.29061325629512], [2.398325057173698, 53.29430693197451]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.3983251&lt;dd&gt;Longitude: 53.294307&lt;dd&gt;Azimuth: 57.075747\u00b0&lt;dd&gt;Altitude: 50.992521\u00b0&lt;dd&gt;Slant Range: 684.03693km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.398325057173698, 53.29430693197451]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8954276053181474, 53.27491954036993], [1.9959688873921486, 53.278980762894754], [2.096529716197188, 53.282950142878406], [2.197109649438004, 53.28682765041824], [2.297708244243374, 53.29061325629512], [2.398325057173698, 53.29430693197451], [2.498959644229954, 53.29790864960762]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.4989596&lt;dd&gt;Longitude: 53.297909&lt;dd&gt;Azimuth: 57.487437\u00b0&lt;dd&gt;Altitude: 50.544972\u00b0&lt;dd&gt;Slant Range: 687.88286km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.498959644229954, 53.29790864960762]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9959688873921486, 53.278980762894754], [2.096529716197188, 53.282950142878406], [2.197109649438004, 53.28682765041824], [2.297708244243374, 53.29061325629512], [2.398325057173698, 53.29430693197451], [2.498959644229954, 53.29790864960762], [2.5996115608839276, 53.30141838203232]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.5996116&lt;dd&gt;Longitude: 53.301418&lt;dd&gt;Azimuth: 57.886993\u00b0&lt;dd&gt;Altitude: 50.100682\u00b0&lt;dd&gt;Slant Range: 691.77792km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.5996115608839276, 53.30141838203232]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.096529716197188, 53.282950142878406], [2.197109649438004, 53.28682765041824], [2.297708244243374, 53.29061325629512], [2.398325057173698, 53.29430693197451], [2.498959644229954, 53.29790864960762], [2.5996115608839276, 53.30141838203232], [2.7002803620608824, 53.30483610277424]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.7002804&lt;dd&gt;Longitude: 53.304836&lt;dd&gt;Azimuth: 58.274912\u00b0&lt;dd&gt;Altitude: 49.659723\u00b0&lt;dd&gt;Slant Range: 695.72129km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7002803620608824, 53.30483610277424]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.197109649438004, 53.28682765041824], [2.297708244243374, 53.29061325629512], [2.398325057173698, 53.29430693197451], [2.498959644229954, 53.29790864960762], [2.5996115608839276, 53.30141838203232], [2.7002803620608824, 53.30483610277424], [2.8009656021908578, 53.30816178604779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.8009656&lt;dd&gt;Longitude: 53.308162&lt;dd&gt;Azimuth: 58.651667\u00b0&lt;dd&gt;Altitude: 49.222161\u00b0&lt;dd&gt;Slant Range: 699.71215km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.8009656021908578, 53.30816178604779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.297708244243374, 53.29061325629512], [2.398325057173698, 53.29430693197451], [2.498959644229954, 53.29790864960762], [2.5996115608839276, 53.30141838203232], [2.7002803620608824, 53.30483610277424], [2.8009656021908578, 53.30816178604779], [2.901666835190271, 53.31139540675704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 2.9016668&lt;dd&gt;Longitude: 53.311395&lt;dd&gt;Azimuth: 59.017708\u00b0&lt;dd&gt;Altitude: 48.788052\u00b0&lt;dd&gt;Slant Range: 703.74968km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.901666835190271, 53.31139540675704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.398325057173698, 53.29430693197451], [2.498959644229954, 53.29790864960762], [2.5996115608839276, 53.30141838203232], [2.7002803620608824, 53.30483610277424], [2.8009656021908578, 53.30816178604779], [2.901666835190271, 53.31139540675704], [3.0023836144930365, 53.31453694049665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.0023836&lt;dd&gt;Longitude: 53.314537&lt;dd&gt;Azimuth: 59.373463\u00b0&lt;dd&gt;Altitude: 48.357449\u00b0&lt;dd&gt;Slant Range: 707.83309km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0023836144930365, 53.31453694049665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.498959644229954, 53.29790864960762], [2.5996115608839276, 53.30141838203232], [2.7002803620608824, 53.30483610277424], [2.8009656021908578, 53.30816178604779], [2.901666835190271, 53.31139540675704], [3.0023836144930365, 53.31453694049665], [3.103115493055655, 53.31758636355291]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.1031155&lt;dd&gt;Longitude: 53.317586&lt;dd&gt;Azimuth: 59.719337\u00b0&lt;dd&gt;Altitude: 47.930394\u00b0&lt;dd&gt;Slant Range: 711.96157km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.103115493055655, 53.31758636355291]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.5996115608839276, 53.30141838203232], [2.7002803620608824, 53.30483610277424], [2.8009656021908578, 53.30816178604779], [2.901666835190271, 53.31139540675704], [3.0023836144930365, 53.31453694049665], [3.103115493055655, 53.31758636355291], [3.2038620233770088, 53.320543652904504]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.203862&lt;dd&gt;Longitude: 53.320544&lt;dd&gt;Azimuth: 60.055719\u00b0&lt;dd&gt;Altitude: 47.506927\u00b0&lt;dd&gt;Slant Range: 716.13434km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.2038620233770088, 53.320543652904504]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7002803620608824, 53.30483610277424], [2.8009656021908578, 53.30816178604779], [2.901666835190271, 53.31139540675704], [3.0023836144930365, 53.31453694049665], [3.103115493055655, 53.31758636355291], [3.2038620233770088, 53.320543652904504], [3.3046227575023064, 53.323408786223375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.3046228&lt;dd&gt;Longitude: 53.323409&lt;dd&gt;Azimuth: 60.382977\u00b0&lt;dd&gt;Altitude: 47.08708\u00b0&lt;dd&gt;Slant Range: 720.35064km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3046227575023064, 53.323408786223375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.8009656021908578, 53.30816178604779], [2.901666835190271, 53.31139540675704], [3.0023836144930365, 53.31453694049665], [3.103115493055655, 53.31758636355291], [3.2038620233770088, 53.320543652904504], [3.3046227575023064, 53.323408786223375], [3.4053972470496197, 53.326181741875686]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.4053972&lt;dd&gt;Longitude: 53.326182&lt;dd&gt;Azimuth: 60.701461\u00b0&lt;dd&gt;Altitude: 46.67088\u00b0&lt;dd&gt;Slant Range: 724.60968km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4053972470496197, 53.326181741875686]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.901666835190271, 53.31139540675704], [3.0023836144930365, 53.31453694049665], [3.103115493055655, 53.31758636355291], [3.2038620233770088, 53.320543652904504], [3.3046227575023064, 53.323408786223375], [3.4053972470496197, 53.326181741875686], [3.5061850432075956, 53.32886249892244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.506185&lt;dd&gt;Longitude: 53.328862&lt;dd&gt;Azimuth: 61.011505\u00b0&lt;dd&gt;Altitude: 46.25835\u00b0&lt;dd&gt;Slant Range: 728.91073km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5061850432075956, 53.32886249892244]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0023836144930365, 53.31453694049665], [3.103115493055655, 53.31758636355291], [3.2038620233770088, 53.320543652904504], [3.3046227575023064, 53.323408786223375], [3.4053972470496197, 53.326181741875686], [3.5061850432075956, 53.32886249892244], [3.6069856967697285, 53.3314510371205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.6069857&lt;dd&gt;Longitude: 53.331451&lt;dd&gt;Azimuth: 61.313428\u00b0&lt;dd&gt;Altitude: 45.849508\u00b0&lt;dd&gt;Slant Range: 733.25303km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6069856967697285, 53.3314510371205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.103115493055655, 53.31758636355291], [3.2038620233770088, 53.320543652904504], [3.3046227575023064, 53.323408786223375], [3.4053972470496197, 53.326181741875686], [3.5061850432075956, 53.32886249892244], [3.6069856967697285, 53.3314510371205], [3.707798758124768, 53.33394733692307]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.7077988&lt;dd&gt;Longitude: 53.333947&lt;dd&gt;Azimuth: 61.607533\u00b0&lt;dd&gt;Altitude: 45.444368\u00b0&lt;dd&gt;Slant Range: 737.63585km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.707798758124768, 53.33394733692307]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.2038620233770088, 53.320543652904504], [3.3046227575023064, 53.323408786223375], [3.4053972470496197, 53.326181741875686], [3.5061850432075956, 53.32886249892244], [3.6069856967697285, 53.3314510371205], [3.707798758124768, 53.33394733692307], [3.808623777285268, 53.33635137948077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.8086238&lt;dd&gt;Longitude: 53.336351&lt;dd&gt;Azimuth: 61.89411\u00b0&lt;dd&gt;Altitude: 45.042938\u00b0&lt;dd&gt;Slant Range: 742.05848km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.808623777285268, 53.33635137948077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.3046227575023064, 53.323408786223375], [3.4053972470496197, 53.326181741875686], [3.5061850432075956, 53.32886249892244], [3.6069856967697285, 53.3314510371205], [3.707798758124768, 53.33394733692307], [3.808623777285268, 53.33635137948077], [3.90946030389896, 53.33866314664195]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 3.9094603&lt;dd&gt;Longitude: 53.338663&lt;dd&gt;Azimuth: 62.173435\u00b0&lt;dd&gt;Altitude: 44.645224\u00b0&lt;dd&gt;Slant Range: 746.52019km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.90946030389896, 53.33866314664195]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4053972470496197, 53.326181741875686], [3.5061850432075956, 53.32886249892244], [3.6069856967697285, 53.3314510371205], [3.707798758124768, 53.33394733692307], [3.808623777285268, 53.33635137948077], [3.90946030389896, 53.33866314664195], [4.010307887260966, 53.34088262095376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.0103079&lt;dd&gt;Longitude: 53.340883&lt;dd&gt;Azimuth: 62.44577\u00b0&lt;dd&gt;Altitude: 44.25123\u00b0&lt;dd&gt;Slant Range: 751.02028km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.010307887260966, 53.34088262095376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5061850432075956, 53.32886249892244], [3.6069856967697285, 53.3314510371205], [3.707798758124768, 53.33394733692307], [3.808623777285268, 53.33635137948077], [3.90946030389896, 53.33866314664195], [4.010307887260966, 53.34088262095376], [4.111166076320848, 53.34300978566246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.1111661&lt;dd&gt;Longitude: 53.34301&lt;dd&gt;Azimuth: 62.711368\u00b0&lt;dd&gt;Altitude: 43.860953\u00b0&lt;dd&gt;Slant Range: 755.55807km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.111166076320848, 53.34300978566246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6069856967697285, 53.3314510371205], [3.707798758124768, 53.33394733692307], [3.808623777285268, 53.33635137948077], [3.90946030389896, 53.33866314664195], [4.010307887260966, 53.34088262095376], [4.111166076320848, 53.34300978566246], [4.212034419713522, 53.345044624714376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.2120344&lt;dd&gt;Longitude: 53.345045&lt;dd&gt;Azimuth: 62.970468\u00b0&lt;dd&gt;Altitude: 43.47439\u00b0&lt;dd&gt;Slant Range: 760.13288km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.212034419713522, 53.345044624714376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.707798758124768, 53.33394733692307], [3.808623777285268, 53.33635137948077], [3.90946030389896, 53.33866314664195], [4.010307887260966, 53.34088262095376], [4.111166076320848, 53.34300978566246], [4.212034419713522, 53.345044624714376], [4.312912465754015, 53.346987122756204]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.3129125&lt;dd&gt;Longitude: 53.346987&lt;dd&gt;Azimuth: 63.2233\u00b0&lt;dd&gt;Altitude: 43.091534\u00b0&lt;dd&gt;Slant Range: 764.74402km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.312912465754015, 53.346987122756204]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.808623777285268, 53.33635137948077], [3.90946030389896, 53.33866314664195], [4.010307887260966, 53.34088262095376], [4.111166076320848, 53.34300978566246], [4.212034419713522, 53.345044624714376], [4.312912465754015, 53.346987122756204], [4.413799762459733, 53.348837265135884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.4137998&lt;dd&gt;Longitude: 53.348837&lt;dd&gt;Azimuth: 63.470082\u00b0&lt;dd&gt;Altitude: 42.712375\u00b0&lt;dd&gt;Slant Range: 769.39086km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.413799762459733, 53.348837265135884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.90946030389896, 53.33866314664195], [4.010307887260966, 53.34088262095376], [4.111166076320848, 53.34300978566246], [4.212034419713522, 53.345044624714376], [4.312912465754015, 53.346987122756204], [4.413799762459733, 53.348837265135884], [4.514695857570607, 53.35059503790283]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.5146959&lt;dd&gt;Longitude: 53.350595&lt;dd&gt;Azimuth: 63.711025\u00b0&lt;dd&gt;Altitude: 42.336901\u00b0&lt;dd&gt;Slant Range: 774.07273km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.514695857570607, 53.35059503790283]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.010307887260966, 53.34088262095376], [4.111166076320848, 53.34300978566246], [4.212034419713522, 53.345044624714376], [4.312912465754015, 53.346987122756204], [4.413799762459733, 53.348837265135884], [4.514695857570607, 53.35059503790283], [4.615600298548973, 53.35226042780879]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.6156003&lt;dd&gt;Longitude: 53.35226&lt;dd&gt;Azimuth: 63.946328\u00b0&lt;dd&gt;Altitude: 41.965099\u00b0&lt;dd&gt;Slant Range: 778.789km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.615600298548973, 53.35226042780879]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.111166076320848, 53.34300978566246], [4.212034419713522, 53.345044624714376], [4.312912465754015, 53.346987122756204], [4.413799762459733, 53.348837265135884], [4.514695857570607, 53.35059503790283], [4.615600298548973, 53.35226042780879], [4.716512632605976, 53.35383342230803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.7165126&lt;dd&gt;Longitude: 53.353833&lt;dd&gt;Azimuth: 64.176184\u00b0&lt;dd&gt;Altitude: 41.596951\u00b0&lt;dd&gt;Slant Range: 783.53905km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.716512632605976, 53.35383342230803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.212034419713522, 53.345044624714376], [4.312912465754015, 53.346987122756204], [4.413799762459733, 53.348837265135884], [4.514695857570607, 53.35059503790283], [4.615600298548973, 53.35226042780879], [4.716512632605976, 53.35383342230803], [4.817432406704172, 53.355314009558086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.8174324&lt;dd&gt;Longitude: 53.355314&lt;dd&gt;Azimuth: 64.400775\u00b0&lt;dd&gt;Altitude: 41.23244\u00b0&lt;dd&gt;Slant Range: 788.32225km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.817432406704172, 53.355314009558086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.312912465754015, 53.346987122756204], [4.413799762459733, 53.348837265135884], [4.514695857570607, 53.35059503790283], [4.615600298548973, 53.35226042780879], [4.716512632605976, 53.35383342230803], [4.817432406704172, 53.355314009558086], [4.918359167585105, 53.356702178420036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 4.9183592&lt;dd&gt;Longitude: 53.356702&lt;dd&gt;Azimuth: 64.620277\u00b0&lt;dd&gt;Altitude: 40.871546\u00b0&lt;dd&gt;Slant Range: 793.13801km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.918359167585105, 53.356702178420036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.413799762459733, 53.348837265135884], [4.514695857570607, 53.35059503790283], [4.615600298548973, 53.35226042780879], [4.716512632605976, 53.35383342230803], [4.817432406704172, 53.355314009558086], [4.918359167585105, 53.356702178420036], [5.019292461764294, 53.357997918458885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.0192925&lt;dd&gt;Longitude: 53.357998&lt;dd&gt;Azimuth: 64.834858\u00b0&lt;dd&gt;Altitude: 40.514247\u00b0&lt;dd&gt;Slant Range: 797.98573km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.019292461764294, 53.357997918458885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.514695857570607, 53.35059503790283], [4.615600298548973, 53.35226042780879], [4.716512632605976, 53.35383342230803], [4.817432406704172, 53.355314009558086], [4.918359167585105, 53.356702178420036], [5.019292461764294, 53.357997918458885], [5.120231835570553, 53.35920121994421]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.1202318&lt;dd&gt;Longitude: 53.359201&lt;dd&gt;Azimuth: 65.044679\u00b0&lt;dd&gt;Altitude: 40.16052\u00b0&lt;dd&gt;Slant Range: 802.86482km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.120231835570553, 53.35920121994421]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.615600298548973, 53.35226042780879], [4.716512632605976, 53.35383342230803], [4.817432406704172, 53.355314009558086], [4.918359167585105, 53.356702178420036], [5.019292461764294, 53.357997918458885], [5.120231835570553, 53.35920121994421], [5.221176835133356, 53.36031207385029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.2211768&lt;dd&gt;Longitude: 53.360312&lt;dd&gt;Azimuth: 65.249896\u00b0&lt;dd&gt;Altitude: 39.810341\u00b0&lt;dd&gt;Slant Range: 807.77471km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.221176835133356, 53.36031207385029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.716512632605976, 53.35383342230803], [4.817432406704172, 53.355314009558086], [4.918359167585105, 53.356702178420036], [5.019292461764294, 53.357997918458885], [5.120231835570553, 53.35920121994421], [5.221176835133356, 53.36031207385029], [5.322127006417431, 53.361330471856476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.322127&lt;dd&gt;Longitude: 53.36133&lt;dd&gt;Azimuth: 65.450654\u00b0&lt;dd&gt;Altitude: 39.463684\u00b0&lt;dd&gt;Slant Range: 812.71484km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.322127006417431, 53.361330471856476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.817432406704172, 53.355314009558086], [4.918359167585105, 53.356702178420036], [5.019292461764294, 53.357997918458885], [5.120231835570553, 53.35920121994421], [5.221176835133356, 53.36031207385029], [5.322127006417431, 53.361330471856476], [5.42308189521789, 53.36225640634762]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.4230819&lt;dd&gt;Longitude: 53.362256&lt;dd&gt;Azimuth: 65.647098\u00b0&lt;dd&gt;Altitude: 39.120521\u00b0&lt;dd&gt;Slant Range: 817.68465km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.42308189521789, 53.36225640634762]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.918359167585105, 53.356702178420036], [5.019292461764294, 53.357997918458885], [5.120231835570553, 53.35920121994421], [5.221176835133356, 53.36031207385029], [5.322127006417431, 53.361330471856476], [5.42308189521789, 53.36225640634762], [5.5240410471985015, 53.36308987041426]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.524041&lt;dd&gt;Longitude: 53.36309&lt;dd&gt;Azimuth: 65.839362\u00b0&lt;dd&gt;Altitude: 38.780825\u00b0&lt;dd&gt;Slant Range: 822.6836km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.5240410471985015, 53.36308987041426]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.019292461764294, 53.357997918458885], [5.120231835570553, 53.35920121994421], [5.221176835133356, 53.36031207385029], [5.322127006417431, 53.361330471856476], [5.42308189521789, 53.36225640634762], [5.5240410471985015, 53.36308987041426], [5.625004007879248, 53.36383085785293]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.625004&lt;dd&gt;Longitude: 53.363831&lt;dd&gt;Azimuth: 66.027578\u00b0&lt;dd&gt;Altitude: 38.444568\u00b0&lt;dd&gt;Slant Range: 827.71115km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.625004007879248, 53.36383085785293]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.120231835570553, 53.35920121994421], [5.221176835133356, 53.36031207385029], [5.322127006417431, 53.361330471856476], [5.42308189521789, 53.36225640634762], [5.5240410471985015, 53.36308987041426], [5.625004007879248, 53.36383085785293], [5.725970322669047, 53.36447936316637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3253&lt;dd&gt;Latitude: 5.7259703&lt;dd&gt;Longitude: 53.364479&lt;dd&gt;Azimuth: 66.211871\u00b0&lt;dd&gt;Altitude: 38.111719\u00b0&lt;dd&gt;Slant Range: 832.76679km&quot;, &quot;name&quot;: &quot;STARLINK-3253&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.725970322669047, 53.36447936316637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -2.2187627&lt;dd&gt;Longitude: 46.260869&lt;dd&gt;Azimuth: 177.0689\u00b0&lt;dd&gt;Altitude: 39.381684\u00b0&lt;dd&gt;Slant Range: 811.46118km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064], [-2.144471135912978, 46.292594600484996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -2.1444711&lt;dd&gt;Longitude: 46.292595&lt;dd&gt;Azimuth: 176.4827\u00b0&lt;dd&gt;Altitude: 39.556435\u00b0&lt;dd&gt;Slant Range: 808.9722km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.144471135912978, 46.292594600484996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064], [-2.144471135912978, 46.292594600484996], [-2.0700891811703936, 46.32426575850058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -2.0700892&lt;dd&gt;Longitude: 46.324266&lt;dd&gt;Azimuth: 175.88992\u00b0&lt;dd&gt;Altitude: 39.728843\u00b0&lt;dd&gt;Slant Range: 806.53661km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0700891811703936, 46.32426575850058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064], [-2.144471135912978, 46.292594600484996], [-2.0700891811703936, 46.32426575850058], [-1.995616745315252, 46.35588277569944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.9956167&lt;dd&gt;Longitude: 46.355883&lt;dd&gt;Azimuth: 175.29059\u00b0&lt;dd&gt;Altitude: 39.898803\u00b0&lt;dd&gt;Slant Range: 804.15491km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.995616745315252, 46.35588277569944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064], [-2.144471135912978, 46.292594600484996], [-2.0700891811703936, 46.32426575850058], [-1.995616745315252, 46.35588277569944], [-1.92105377894303, 46.38744553136253]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.9210538&lt;dd&gt;Longitude: 46.387446&lt;dd&gt;Azimuth: 174.68474\u00b0&lt;dd&gt;Altitude: 40.066211\u00b0&lt;dd&gt;Slant Range: 801.82757km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.92105377894303, 46.38744553136253]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064], [-2.144471135912978, 46.292594600484996], [-2.0700891811703936, 46.32426575850058], [-1.995616745315252, 46.35588277569944], [-1.92105377894303, 46.38744553136253], [-1.8464002334757166, 46.41895390463369]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.8464002&lt;dd&gt;Longitude: 46.418954&lt;dd&gt;Azimuth: 174.07238\u00b0&lt;dd&gt;Altitude: 40.230958\u00b0&lt;dd&gt;Slant Range: 799.55508km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8464002334757166, 46.41895390463369]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.218762659748747, 46.260869422237064], [-2.144471135912978, 46.292594600484996], [-2.0700891811703936, 46.32426575850058], [-1.995616745315252, 46.35588277569944], [-1.92105377894303, 46.38744553136253], [-1.8464002334757166, 46.41895390463369], [-1.7716560611513548, 46.45040777452298]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.7716561&lt;dd&gt;Longitude: 46.450408&lt;dd&gt;Azimuth: 173.45357\u00b0&lt;dd&gt;Altitude: 40.392939\u00b0&lt;dd&gt;Slant Range: 797.33791km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7716560611513548, 46.45040777452298]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.144471135912978, 46.292594600484996], [-2.0700891811703936, 46.32426575850058], [-1.995616745315252, 46.35588277569944], [-1.92105377894303, 46.38744553136253], [-1.8464002334757166, 46.41895390463369], [-1.7716560611513548, 46.45040777452298], [-1.696821215042972, 46.481807019906505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.6968212&lt;dd&gt;Longitude: 46.481807&lt;dd&gt;Azimuth: 172.82835\u00b0&lt;dd&gt;Altitude: 40.552044\u00b0&lt;dd&gt;Slant Range: 795.17652km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.696821215042972, 46.481807019906505]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0700891811703936, 46.32426575850058], [-1.995616745315252, 46.35588277569944], [-1.92105377894303, 46.38744553136253], [-1.8464002334757166, 46.41895390463369], [-1.7716560611513548, 46.45040777452298], [-1.696821215042972, 46.481807019906505], [-1.6218956490514052, 46.51315151952842]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.6218956&lt;dd&gt;Longitude: 46.513152&lt;dd&gt;Azimuth: 172.19677\u00b0&lt;dd&gt;Altitude: 40.708165\u00b0&lt;dd&gt;Slant Range: 793.07136km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6218956490514052, 46.51315151952842]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.995616745315252, 46.35588277569944], [-1.92105377894303, 46.38744553136253], [-1.8464002334757166, 46.41895390463369], [-1.7716560611513548, 46.45040777452298], [-1.696821215042972, 46.481807019906505], [-1.6218956490514052, 46.51315151952842], [-1.5468793179248927, 46.5444411520008]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.5468793&lt;dd&gt;Longitude: 46.544441&lt;dd&gt;Azimuth: 171.55888\u00b0&lt;dd&gt;Altitude: 40.861195\u00b0&lt;dd&gt;Slant Range: 791.0229km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5468793179248927, 46.5444411520008]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.92105377894303, 46.38744553136253], [-1.8464002334757166, 46.41895390463369], [-1.7716560611513548, 46.45040777452298], [-1.696821215042972, 46.481807019906505], [-1.6218956490514052, 46.51315151952842], [-1.5468793179248927, 46.5444411520008], [-1.47177217724821, 46.57567579580557]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.4717722&lt;dd&gt;Longitude: 46.575676&lt;dd&gt;Azimuth: 170.91476\u00b0&lt;dd&gt;Altitude: 41.011024\u00b0&lt;dd&gt;Slant Range: 789.03158km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.47177217724821, 46.57567579580557]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8464002334757166, 46.41895390463369], [-1.7716560611513548, 46.45040777452298], [-1.696821215042972, 46.481807019906505], [-1.6218956490514052, 46.51315151952842], [-1.5468793179248927, 46.5444411520008], [-1.47177217724821, 46.57567579580557], [-1.3965741834667647, 46.60685532929428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.3965742&lt;dd&gt;Longitude: 46.606855&lt;dd&gt;Azimuth: 170.26448\u00b0&lt;dd&gt;Altitude: 41.157545\u00b0&lt;dd&gt;Slant Range: 787.09782km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3965741834667647, 46.60685532929428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7716560611513548, 46.45040777452298], [-1.696821215042972, 46.481807019906505], [-1.6218956490514052, 46.51315151952842], [-1.5468793179248927, 46.5444411520008], [-1.47177217724821, 46.57567579580557], [-1.3965741834667647, 46.60685532929428], [-1.3212852938775137, 46.63797963069194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.3212853&lt;dd&gt;Longitude: 46.63798&lt;dd&gt;Azimuth: 169.60813\u00b0&lt;dd&gt;Altitude: 41.300648\u00b0&lt;dd&gt;Slant Range: 785.22206km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3212852938775137, 46.63797963069194]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.696821215042972, 46.481807019906505], [-1.6218956490514052, 46.51315151952842], [-1.5468793179248927, 46.5444411520008], [-1.47177217724821, 46.57567579580557], [-1.3965741834667647, 46.60685532929428], [-1.3212852938775137, 46.63797963069194], [-1.2459054666422196, 46.66904857809402]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.2459055&lt;dd&gt;Longitude: 46.669049&lt;dd&gt;Azimuth: 168.94579\u00b0&lt;dd&gt;Altitude: 41.440228\u00b0&lt;dd&gt;Slant Range: 783.40472km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2459054666422196, 46.66904857809402]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6218956490514052, 46.51315151952842], [-1.5468793179248927, 46.5444411520008], [-1.47177217724821, 46.57567579580557], [-1.3965741834667647, 46.60685532929428], [-1.3212852938775137, 46.63797963069194], [-1.2459054666422196, 46.66904857809402], [-1.170434660788188, 46.70006204947118]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.1704347&lt;dd&gt;Longitude: 46.700062&lt;dd&gt;Azimuth: 168.27756\u00b0&lt;dd&gt;Altitude: 41.576176\u00b0&lt;dd&gt;Slant Range: 781.6462km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.170434660788188, 46.70006204947118]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5468793179248927, 46.5444411520008], [-1.47177217724821, 46.57567579580557], [-1.3965741834667647, 46.60685532929428], [-1.3212852938775137, 46.63797963069194], [-1.2459054666422196, 46.66904857809402], [-1.170434660788188, 46.70006204947118], [-1.0948728362230258, 46.73101992266826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.0948728&lt;dd&gt;Longitude: 46.73102&lt;dd&gt;Azimuth: 167.60355\u00b0&lt;dd&gt;Altitude: 41.708387\u00b0&lt;dd&gt;Slant Range: 779.94692km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0948728362230258, 46.73101992266826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.47177217724821, 46.57567579580557], [-1.3965741834667647, 46.60685532929428], [-1.3212852938775137, 46.63797963069194], [-1.2459054666422196, 46.66904857809402], [-1.170434660788188, 46.70006204947118], [-1.0948728362230258, 46.73101992266826], [-1.0192199537230133, 46.76192207540629]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -1.01922&lt;dd&gt;Longitude: 46.761922&lt;dd&gt;Azimuth: 166.92387\u00b0&lt;dd&gt;Altitude: 41.836756\u00b0&lt;dd&gt;Slant Range: 778.30724km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0192199537230133, 46.76192207540629]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3965741834667647, 46.60685532929428], [-1.3212852938775137, 46.63797963069194], [-1.2459054666422196, 46.66904857809402], [-1.170434660788188, 46.70006204947118], [-1.0948728362230258, 46.73101992266826], [-1.0192199537230133, 46.76192207540629], [-0.9434759749651127, 46.792768385282365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.94347597&lt;dd&gt;Longitude: 46.792768&lt;dd&gt;Azimuth: 166.23865\u00b0&lt;dd&gt;Altitude: 41.96118\u00b0&lt;dd&gt;Slant Range: 776.72757km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9434759749651127, 46.792768385282365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3212852938775137, 46.63797963069194], [-1.2459054666422196, 46.66904857809402], [-1.170434660788188, 46.70006204947118], [-1.0948728362230258, 46.73101992266826], [-1.0192199537230133, 46.76192207540629], [-0.9434759749651127, 46.792768385282365], [-0.8676408625027965, 46.82355872977344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.86764086&lt;dd&gt;Longitude: 46.823559&lt;dd&gt;Azimuth: 165.54802\u00b0&lt;dd&gt;Altitude: 42.081557\u00b0&lt;dd&gt;Slant Range: 775.20825km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8676408625027965, 46.82355872977344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2459054666422196, 46.66904857809402], [-1.170434660788188, 46.70006204947118], [-1.0948728362230258, 46.73101992266826], [-1.0192199537230133, 46.76192207540629], [-0.9434759749651127, 46.792768385282365], [-0.8676408625027965, 46.82355872977344], [-0.7917145797989719, 46.85429298623389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.79171458&lt;dd&gt;Longitude: 46.854293&lt;dd&gt;Azimuth: 164.85212\u00b0&lt;dd&gt;Altitude: 42.197787\u00b0&lt;dd&gt;Slant Range: 773.74966km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7917145797989719, 46.85429298623389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.170434660788188, 46.70006204947118], [-1.0948728362230258, 46.73101992266826], [-1.0192199537230133, 46.76192207540629], [-0.9434759749651127, 46.792768385282365], [-0.8676408625027965, 46.82355872977344], [-0.7917145797989719, 46.85429298623389], [-0.7156970912064401, 46.884971031899234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.71569709&lt;dd&gt;Longitude: 46.884971&lt;dd&gt;Azimuth: 164.15109\u00b0&lt;dd&gt;Altitude: 42.309772\u00b0&lt;dd&gt;Slant Range: 772.35214km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7156970912064401, 46.884971031899234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0948728362230258, 46.73101992266826], [-1.0192199537230133, 46.76192207540629], [-0.9434759749651127, 46.792768385282365], [-0.8676408625027965, 46.82355872977344], [-0.7917145797989719, 46.85429298623389], [-0.7156970912064401, 46.884971031899234], [-0.6395883620000576, 46.91559274388631]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.63958836&lt;dd&gt;Longitude: 46.915593&lt;dd&gt;Azimuth: 163.4451\u00b0&lt;dd&gt;Altitude: 42.417415\u00b0&lt;dd&gt;Slant Range: 771.01601km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6395883620000576, 46.91559274388631]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0192199537230133, 46.76192207540629], [-0.9434759749651127, 46.792768385282365], [-0.8676408625027965, 46.82355872977344], [-0.7917145797989719, 46.85429298623389], [-0.7156970912064401, 46.884971031899234], [-0.6395883620000576, 46.91559274388631], [-0.5633883583577808, 46.94615799919495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.56338836&lt;dd&gt;Longitude: 46.946158&lt;dd&gt;Azimuth: 162.73431\u00b0&lt;dd&gt;Altitude: 42.520624\u00b0&lt;dd&gt;Slant Range: 769.74161km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5633883583577808, 46.94615799919495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9434759749651127, 46.792768385282365], [-0.8676408625027965, 46.82355872977344], [-0.7917145797989719, 46.85429298623389], [-0.7156970912064401, 46.884971031899234], [-0.6395883620000576, 46.91559274388631], [-0.5633883583577808, 46.94615799919495], [-0.4870970473853968, 46.9766666747082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.48709705&lt;dd&gt;Longitude: 46.976667&lt;dd&gt;Azimuth: 162.01889\u00b0&lt;dd&gt;Altitude: 42.619308\u00b0&lt;dd&gt;Slant Range: 768.52923km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4870970473853968, 46.9766666747082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8676408625027965, 46.82355872977344], [-0.7917145797989719, 46.85429298623389], [-0.7156970912064401, 46.884971031899234], [-0.6395883620000576, 46.91559274388631], [-0.5633883583577808, 46.94615799919495], [-0.4870970473853968, 46.9766666747082], [-0.4107143971079245, 47.007118647194666]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.4107144&lt;dd&gt;Longitude: 47.007119&lt;dd&gt;Azimuth: 161.29902\u00b0&lt;dd&gt;Altitude: 42.713378\u00b0&lt;dd&gt;Slant Range: 767.37919km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4107143971079245, 47.007118647194666]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7917145797989719, 46.85429298623389], [-0.7156970912064401, 46.884971031899234], [-0.6395883620000576, 46.91559274388631], [-0.5633883583577808, 46.94615799919495], [-0.4870970473853968, 46.9766666747082], [-0.4107143971079245, 47.007118647194666], [-0.33424037649032556, 47.03751379330824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.33424038&lt;dd&gt;Longitude: 47.037514&lt;dd&gt;Azimuth: 160.5749\u00b0&lt;dd&gt;Altitude: 42.80275\u00b0&lt;dd&gt;Slant Range: 766.29175km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.33424037649032556, 47.03751379330824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7156970912064401, 46.884971031899234], [-0.6395883620000576, 46.91559274388631], [-0.5633883583577808, 46.94615799919495], [-0.4870970473853968, 46.9766666747082], [-0.4107143971079245, 47.007118647194666], [-0.33424037649032556, 47.03751379330824], [-0.2576749554242988, 47.06785198959149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.25767496&lt;dd&gt;Longitude: 47.067852&lt;dd&gt;Azimuth: 159.84672\u00b0&lt;dd&gt;Altitude: 42.887343\u00b0&lt;dd&gt;Slant Range: 765.26718km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.2576749554242988, 47.06785198959149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6395883620000576, 46.91559274388631], [-0.5633883583577808, 46.94615799919495], [-0.4870970473853968, 46.9766666747082], [-0.4107143971079245, 47.007118647194666], [-0.33424037649032556, 47.03751379330824], [-0.2576749554242988, 47.06785198959149], [-0.18101810475097696, 47.098133112474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.1810181&lt;dd&gt;Longitude: 47.098133&lt;dd&gt;Azimuth: 159.11468\u00b0&lt;dd&gt;Altitude: 42.967078\u00b0&lt;dd&gt;Slant Range: 764.30575km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.18101810475097696, 47.098133112474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5633883583577808, 46.94615799919495], [-0.4870970473853968, 46.9766666747082], [-0.4107143971079245, 47.007118647194666], [-0.33424037649032556, 47.03751379330824], [-0.2576749554242988, 47.06785198959149], [-0.18101810475097696, 47.098133112474], [-0.10426979626408159, 47.12835703827676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.1042698&lt;dd&gt;Longitude: 47.128357&lt;dd&gt;Azimuth: 158.37899\u00b0&lt;dd&gt;Altitude: 43.041882\u00b0&lt;dd&gt;Slant Range: 763.40768km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.10426979626408159, 47.12835703827676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4870970473853968, 46.9766666747082], [-0.4107143971079245, 47.007118647194666], [-0.33424037649032556, 47.03751379330824], [-0.2576749554242988, 47.06785198959149], [-0.18101810475097696, 47.098133112474], [-0.10426979626408159, 47.12835703827676], [-0.027430002703358377, 47.15852364321024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: -0.027430003&lt;dd&gt;Longitude: 47.158524&lt;dd&gt;Azimuth: 157.63989\u00b0&lt;dd&gt;Altitude: 43.111684\u00b0&lt;dd&gt;Slant Range: 762.57321km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.027430002703358377, 47.15852364321024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4107143971079245, 47.007118647194666], [-0.33424037649032556, 47.03751379330824], [-0.2576749554242988, 47.06785198959149], [-0.18101810475097696, 47.098133112474], [-0.10426979626408159, 47.12835703827676], [-0.027430002703358377, 47.15852364321024], [0.049501302223438785, 47.18863280337821]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.049501302&lt;dd&gt;Longitude: 47.188633&lt;dd&gt;Azimuth: 156.89758\u00b0&lt;dd&gt;Altitude: 43.176418\u00b0&lt;dd&gt;Slant Range: 761.80254km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.049501302223438785, 47.18863280337821]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.33424037649032556, 47.03751379330824], [-0.2576749554242988, 47.06785198959149], [-0.18101810475097696, 47.098133112474], [-0.10426979626408159, 47.12835703827676], [-0.027430002703358377, 47.15852364321024], [0.049501302223438785, 47.18863280337821], [0.1265241438459166, 47.218684394777476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.12652414&lt;dd&gt;Longitude: 47.218684&lt;dd&gt;Azimuth: 156.1523\u00b0&lt;dd&gt;Altitude: 43.236022\u00b0&lt;dd&gt;Slant Range: 761.09587km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.1265241438459166, 47.218684394777476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.2576749554242988, 47.06785198959149], [-0.18101810475097696, 47.098133112474], [-0.10426979626408159, 47.12835703827676], [-0.027430002703358377, 47.15852364321024], [0.049501302223438785, 47.18863280337821], [0.1265241438459166, 47.218684394777476], [0.20363854652211136, 47.24867829329988]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.20363855&lt;dd&gt;Longitude: 47.248678&lt;dd&gt;Azimuth: 155.40429\u00b0&lt;dd&gt;Altitude: 43.290439\u00b0&lt;dd&gt;Slant Range: 760.45338km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.20363854652211136, 47.24867829329988]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.18101810475097696, 47.098133112474], [-0.10426979626408159, 47.12835703827676], [-0.027430002703358377, 47.15852364321024], [0.049501302223438785, 47.18863280337821], [0.1265241438459166, 47.218684394777476], [0.20363854652211136, 47.24867829329988], [0.28084453362823486, 47.27861437473291]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.28084453&lt;dd&gt;Longitude: 47.278614&lt;dd&gt;Azimuth: 154.65379\u00b0&lt;dd&gt;Altitude: 43.339617\u00b0&lt;dd&gt;Slant Range: 759.87522km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.28084453362823486, 47.27861437473291]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.10426979626408159, 47.12835703827676], [-0.027430002703358377, 47.15852364321024], [0.049501302223438785, 47.18863280337821], [0.1265241438459166, 47.218684394777476], [0.20363854652211136, 47.24867829329988], [0.28084453362823486, 47.27861437473291], [0.3581421275571223, 47.30849251476203]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.35814213&lt;dd&gt;Longitude: 47.308493&lt;dd&gt;Azimuth: 153.90105\u00b0&lt;dd&gt;Altitude: 43.383507\u00b0&lt;dd&gt;Slant Range: 759.36156km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3581421275571223, 47.30849251476203]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.027430002703358377, 47.15852364321024], [0.049501302223438785, 47.18863280337821], [0.1265241438459166, 47.218684394777476], [0.20363854652211136, 47.24867829329988], [0.28084453362823486, 47.27861437473291], [0.3581421275571223, 47.30849251476203], [0.4355313497174435, 47.3383125889706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.43553135&lt;dd&gt;Longitude: 47.338313&lt;dd&gt;Azimuth: 153.14632\u00b0&lt;dd&gt;Altitude: 43.422067\u00b0&lt;dd&gt;Slant Range: 758.91252km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.4355313497174435, 47.3383125889706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.049501302223438785, 47.18863280337821], [0.1265241438459166, 47.218684394777476], [0.20363854652211136, 47.24867829329988], [0.28084453362823486, 47.27861437473291], [0.3581421275571223, 47.30849251476203], [0.4355313497174435, 47.3383125889706], [0.5130122205141106, 47.368074472842366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.51301222&lt;dd&gt;Longitude: 47.368074&lt;dd&gt;Azimuth: 152.38986\u00b0&lt;dd&gt;Altitude: 43.455258\u00b0&lt;dd&gt;Slant Range: 758.52821km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5130122205141106, 47.368074472842366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.1265241438459166, 47.218684394777476], [0.20363854652211136, 47.24867829329988], [0.28084453362823486, 47.27861437473291], [0.3581421275571223, 47.30849251476203], [0.4355313497174435, 47.3383125889706], [0.5130122205141106, 47.368074472842366], [0.5905847593587866, 47.39777804176226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.59058476&lt;dd&gt;Longitude: 47.397778&lt;dd&gt;Azimuth: 151.63193\u00b0&lt;dd&gt;Altitude: 43.483049\u00b0&lt;dd&gt;Slant Range: 758.20874km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5905847593587866, 47.39777804176226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.20363854652211136, 47.24867829329988], [0.28084453362823486, 47.27861437473291], [0.3581421275571223, 47.30849251476203], [0.4355313497174435, 47.3383125889706], [0.5130122205141106, 47.368074472842366], [0.5905847593587866, 47.39777804176226], [0.6682489846454591, 47.42742317101802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.66824898&lt;dd&gt;Longitude: 47.427423&lt;dd&gt;Azimuth: 150.87279\u00b0&lt;dd&gt;Altitude: 43.505412\u00b0&lt;dd&gt;Slant Range: 757.95418km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6682489846454591, 47.42742317101802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.28084453362823486, 47.27861437473291], [0.3581421275571223, 47.30849251476203], [0.4355313497174435, 47.3383125889706], [0.5130122205141106, 47.368074472842366], [0.5905847593587866, 47.39777804176226], [0.6682489846454591, 47.42742317101802], [0.7460049137650702, 47.45700973580031]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.74600491&lt;dd&gt;Longitude: 47.45701&lt;dd&gt;Azimuth: 150.11271\u00b0&lt;dd&gt;Altitude: 43.522324\u00b0&lt;dd&gt;Slant Range: 757.7646km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7460049137650702, 47.45700973580031]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3581421275571223, 47.30849251476203], [0.4355313497174435, 47.3383125889706], [0.5130122205141106, 47.368074472842366], [0.5905847593587866, 47.39777804176226], [0.6682489846454591, 47.42742317101802], [0.7460049137650702, 47.45700973580031], [0.8238525630838127, 47.48653761120671]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.82385256&lt;dd&gt;Longitude: 47.486538&lt;dd&gt;Azimuth: 149.35195\u00b0&lt;dd&gt;Altitude: 43.53377\u00b0&lt;dd&gt;Slant Range: 757.64006km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8238525630838127, 47.48653761120671]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.4355313497174435, 47.3383125889706], [0.5130122205141106, 47.368074472842366], [0.5905847593587866, 47.39777804176226], [0.6682489846454591, 47.42742317101802], [0.7460049137650702, 47.45700973580031], [0.8238525630838127, 47.48653761120671], [0.9017919479441993, 47.51600667223965]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.90179195&lt;dd&gt;Longitude: 47.516007&lt;dd&gt;Azimuth: 148.59078\u00b0&lt;dd&gt;Altitude: 43.539738\u00b0&lt;dd&gt;Slant Range: 757.58058km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9017919479441993, 47.51600667223965]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5130122205141106, 47.368074472842366], [0.5905847593587866, 47.39777804176226], [0.6682489846454591, 47.42742317101802], [0.7460049137650702, 47.45700973580031], [0.8238525630838127, 47.48653761120671], [0.9017919479441993, 47.51600667223965], [0.9798230826568174, 47.545416793811484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 0.97982308&lt;dd&gt;Longitude: 47.545417&lt;dd&gt;Azimuth: 147.82948\u00b0&lt;dd&gt;Altitude: 43.540223\u00b0&lt;dd&gt;Slant Range: 757.58618km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9798230826568174, 47.545416793811484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5905847593587866, 47.39777804176226], [0.6682489846454591, 47.42742317101802], [0.7460049137650702, 47.45700973580031], [0.8238525630838127, 47.48653761120671], [0.9017919479441993, 47.51600667223965], [0.9798230826568174, 47.545416793811484], [1.057945980499516, 47.574767850742205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.057946&lt;dd&gt;Longitude: 47.574768&lt;dd&gt;Azimuth: 147.06832\u00b0&lt;dd&gt;Altitude: 43.535224\u00b0&lt;dd&gt;Slant Range: 757.65685km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.057945980499516, 47.574767850742205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6682489846454591, 47.42742317101802], [0.7460049137650702, 47.45700973580031], [0.8238525630838127, 47.48653761120671], [0.9017919479441993, 47.51600667223965], [0.9798230826568174, 47.545416793811484], [1.057945980499516, 47.574767850742205], [1.1361606537004847, 47.604059717763704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.1361607&lt;dd&gt;Longitude: 47.60406&lt;dd&gt;Azimuth: 146.30756\u00b0&lt;dd&gt;Altitude: 43.524748\u00b0&lt;dd&gt;Slant Range: 757.79259km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1361606537004847, 47.604059717763704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7460049137650702, 47.45700973580031], [0.8238525630838127, 47.48653761120671], [0.9017919479441993, 47.51600667223965], [0.9798230826568174, 47.545416793811484], [1.057945980499516, 47.574767850742205], [1.1361606537004847, 47.604059717763704], [1.2144671134480498, 47.63329226951962]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.2144671&lt;dd&gt;Longitude: 47.633292&lt;dd&gt;Azimuth: 145.54747\u00b0&lt;dd&gt;Altitude: 43.508804\u00b0&lt;dd&gt;Slant Range: 757.99335km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2144671134480498, 47.63329226951962]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8238525630838127, 47.48653761120671], [0.9017919479441993, 47.51600667223965], [0.9798230826568174, 47.545416793811484], [1.057945980499516, 47.574767850742205], [1.1361606537004847, 47.604059717763704], [1.2144671134480498, 47.63329226951962], [1.2928653698688428, 47.662465380567774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.2928654&lt;dd&gt;Longitude: 47.662465&lt;dd&gt;Azimuth: 144.78832\u00b0&lt;dd&gt;Altitude: 43.487411\u00b0&lt;dd&gt;Slant Range: 758.25908km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2928653698688428, 47.662465380567774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9017919479441993, 47.51600667223965], [0.9798230826568174, 47.545416793811484], [1.057945980499516, 47.574767850742205], [1.1361606537004847, 47.604059717763704], [1.2144671134480498, 47.63329226951962], [1.2928653698688428, 47.662465380567774], [1.3713554320326606, 47.69157892537994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.3713554&lt;dd&gt;Longitude: 47.691579&lt;dd&gt;Azimuth: 144.03038\u00b0&lt;dd&gt;Altitude: 43.460589\u00b0&lt;dd&gt;Slant Range: 758.58971km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3713554320326606, 47.69157892537994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9798230826568174, 47.545416793811484], [1.057945980499516, 47.574767850742205], [1.1361606537004847, 47.604059717763704], [1.2144671134480498, 47.63329226951962], [1.2928653698688428, 47.662465380567774], [1.3713554320326606, 47.69157892537994], [1.4499373079416773, 47.72063277834588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.4499373&lt;dd&gt;Longitude: 47.720633&lt;dd&gt;Azimuth: 143.27391\u00b0&lt;dd&gt;Altitude: 43.428366\u00b0&lt;dd&gt;Slant Range: 758.98516km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4499373079416773, 47.72063277834588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.057945980499516, 47.574767850742205], [1.1361606537004847, 47.604059717763704], [1.2144671134480498, 47.63329226951962], [1.2928653698688428, 47.662465380567774], [1.3713554320326606, 47.69157892537994], [1.4499373079416773, 47.72063277834588], [1.528611004527034, 47.74962681377209]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.528611&lt;dd&gt;Longitude: 47.749627&lt;dd&gt;Azimuth: 142.51917\u00b0&lt;dd&gt;Altitude: 43.390774\u00b0&lt;dd&gt;Slant Range: 759.44533km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.528611004527034, 47.74962681377209]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1361606537004847, 47.604059717763704], [1.2144671134480498, 47.63329226951962], [1.2928653698688428, 47.662465380567774], [1.3713554320326606, 47.69157892537994], [1.4499373079416773, 47.72063277834588], [1.528611004527034, 47.74962681377209], [1.6073765276444114, 47.77856090588551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.6073765&lt;dd&gt;Longitude: 47.778561&lt;dd&gt;Azimuth: 141.76642\u00b0&lt;dd&gt;Altitude: 43.347851\u00b0&lt;dd&gt;Slant Range: 759.97009km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6073765276444114, 47.77856090588551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2144671134480498, 47.63329226951962], [1.2928653698688428, 47.662465380567774], [1.3713554320326606, 47.69157892537994], [1.4499373079416773, 47.72063277834588], [1.528611004527034, 47.74962681377209], [1.6073765276444114, 47.77856090588551], [1.6862338820573899, 47.807434928832954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.6862339&lt;dd&gt;Longitude: 47.807435&lt;dd&gt;Azimuth: 141.01591\u00b0&lt;dd&gt;Altitude: 43.299641\u00b0&lt;dd&gt;Slant Range: 760.55932km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6862338820573899, 47.807434928832954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2928653698688428, 47.662465380567774], [1.3713554320326606, 47.69157892537994], [1.4499373079416773, 47.72063277834588], [1.528611004527034, 47.74962681377209], [1.6073765276444114, 47.77856090588551], [1.6862338820573899, 47.807434928832954], [1.765183071451495, 47.83624875668447]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.7651831&lt;dd&gt;Longitude: 47.836249&lt;dd&gt;Azimuth: 140.26789\u00b0&lt;dd&gt;Altitude: 43.24619\u00b0&lt;dd&gt;Slant Range: 761.21287km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.765183071451495, 47.83624875668447]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3713554320326606, 47.69157892537994], [1.4499373079416773, 47.72063277834588], [1.528611004527034, 47.74962681377209], [1.6073765276444114, 47.77856090588551], [1.6862338820573899, 47.807434928832954], [1.765183071451495, 47.83624875668447], [1.8442240984086493, 47.8650022634339]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.8442241&lt;dd&gt;Longitude: 47.865002&lt;dd&gt;Azimuth: 139.52259\u00b0&lt;dd&gt;Altitude: 43.187551\u00b0&lt;dd&gt;Slant Range: 761.93056km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8442240984086493, 47.8650022634339]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4499373079416773, 47.72063277834588], [1.528611004527034, 47.74962681377209], [1.6073765276444114, 47.77856090588551], [1.6862338820573899, 47.807434928832954], [1.765183071451495, 47.83624875668447], [1.8442240984086493, 47.8650022634339], [1.9233569644096942, 47.89369532300032]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 1.923357&lt;dd&gt;Longitude: 47.893695&lt;dd&gt;Azimuth: 138.78027\u00b0&lt;dd&gt;Altitude: 43.123782\u00b0&lt;dd&gt;Slant Range: 762.71221km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9233569644096942, 47.89369532300032]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.528611004527034, 47.74962681377209], [1.6073765276444114, 47.77856090588551], [1.6862338820573899, 47.807434928832954], [1.765183071451495, 47.83624875668447], [1.8442240984086493, 47.8650022634339], [1.9233569644096942, 47.89369532300032], [2.0025816698300622, 47.922327809229415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.0025817&lt;dd&gt;Longitude: 47.922328&lt;dd&gt;Azimuth: 138.04114\u00b0&lt;dd&gt;Altitude: 43.054945\u00b0&lt;dd&gt;Slant Range: 763.55764km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0025816698300622, 47.922327809229415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6073765276444114, 47.77856090588551], [1.6862338820573899, 47.807434928832954], [1.765183071451495, 47.83624875668447], [1.8442240984086493, 47.8650022634339], [1.9233569644096942, 47.89369532300032], [2.0025816698300622, 47.922327809229415], [2.081898213934562, 47.95089959589635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.0818982&lt;dd&gt;Longitude: 47.9509&lt;dd&gt;Azimuth: 137.30544\u00b0&lt;dd&gt;Altitude: 42.981104\u00b0&lt;dd&gt;Slant Range: 764.46661km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.081898213934562, 47.95089959589635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6862338820573899, 47.807434928832954], [1.765183071451495, 47.83624875668447], [1.8442240984086493, 47.8650022634339], [1.9233569644096942, 47.89369532300032], [2.0025816698300622, 47.922327809229415], [2.081898213934562, 47.95089959589635], [2.1613065948612964, 47.9794105567054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.1613066&lt;dd&gt;Longitude: 47.979411&lt;dd&gt;Azimuth: 136.57338\u00b0&lt;dd&gt;Altitude: 42.902332\u00b0&lt;dd&gt;Slant Range: 765.43892km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1613065948612964, 47.9794105567054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.765183071451495, 47.83624875668447], [1.8442240984086493, 47.8650022634339], [1.9233569644096942, 47.89369532300032], [2.0025816698300622, 47.922327809229415], [2.081898213934562, 47.95089959589635], [2.1613065948612964, 47.9794105567054], [2.2408068096359384, 48.0078605652928]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.2408068&lt;dd&gt;Longitude: 48.007861&lt;dd&gt;Azimuth: 135.84518\u00b0&lt;dd&gt;Altitude: 42.8187\u00b0&lt;dd&gt;Slant Range: 766.47431km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2408068096359384, 48.0078605652928]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8442240984086493, 47.8650022634339], [1.9233569644096942, 47.89369532300032], [2.0025816698300622, 47.922327809229415], [2.081898213934562, 47.95089959589635], [2.1613065948612964, 47.9794105567054], [2.2408068096359384, 48.0078605652928], [2.320398854135318, 48.0362494952281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.3203989&lt;dd&gt;Longitude: 48.036249&lt;dd&gt;Azimuth: 135.12103\u00b0&lt;dd&gt;Altitude: 42.730288\u00b0&lt;dd&gt;Slant Range: 767.57254km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.320398854135318, 48.0362494952281]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9233569644096942, 47.89369532300032], [2.0025816698300622, 47.922327809229415], [2.081898213934562, 47.95089959589635], [2.1613065948612964, 47.9794105567054], [2.2408068096359384, 48.0078605652928], [2.320398854135318, 48.0362494952281], [2.4000827231183144, 48.064577220015714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.4000827&lt;dd&gt;Longitude: 48.064577&lt;dd&gt;Azimuth: 134.40114\u00b0&lt;dd&gt;Altitude: 42.637177\u00b0&lt;dd&gt;Slant Range: 768.73332km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.4000827231183144, 48.064577220015714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0025816698300622, 47.922327809229415], [2.081898213934562, 47.95089959589635], [2.1613065948612964, 47.9794105567054], [2.2408068096359384, 48.0078605652928], [2.320398854135318, 48.0362494952281], [2.4000827231183144, 48.064577220015714], [2.479858410186694, 48.09284361309539]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.4798584&lt;dd&gt;Longitude: 48.092844&lt;dd&gt;Azimuth: 133.6857\u00b0&lt;dd&gt;Altitude: 42.539451\u00b0&lt;dd&gt;Slant Range: 769.95637km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.479858410186694, 48.09284361309539]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.081898213934562, 47.95089959589635], [2.1613065948612964, 47.9794105567054], [2.2408068096359384, 48.0078605652928], [2.320398854135318, 48.0362494952281], [2.4000827231183144, 48.064577220015714], [2.479858410186694, 48.09284361309539], [2.55972590780524, 48.121048547846634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.5597259&lt;dd&gt;Longitude: 48.121049&lt;dd&gt;Azimuth: 132.97489\u00b0&lt;dd&gt;Altitude: 42.437199\u00b0&lt;dd&gt;Slant Range: 771.2414km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.55972590780524, 48.121048547846634]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1613065948612964, 47.9794105567054], [2.2408068096359384, 48.0078605652928], [2.320398854135318, 48.0362494952281], [2.4000827231183144, 48.064577220015714], [2.479858410186694, 48.09284361309539], [2.55972590780524, 48.121048547846634], [2.6396852072737866, 48.14919189758668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.6396852&lt;dd&gt;Longitude: 48.149192&lt;dd&gt;Azimuth: 132.26887\u00b0&lt;dd&gt;Altitude: 42.330511\u00b0&lt;dd&gt;Slant Range: 772.5881km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.6396852072737866, 48.14919189758668]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2408068096359384, 48.0078605652928], [2.320398854135318, 48.0362494952281], [2.4000827231183144, 48.064577220015714], [2.479858410186694, 48.09284361309539], [2.55972590780524, 48.121048547846634], [2.6396852072737866, 48.14919189758668], [2.7197362987419527, 48.17727353557561]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.7197363&lt;dd&gt;Longitude: 48.177274&lt;dd&gt;Azimuth: 131.56783\u00b0&lt;dd&gt;Altitude: 42.219479\u00b0&lt;dd&gt;Slant Range: 773.99614km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7197362987419527, 48.17727353557561]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.320398854135318, 48.0362494952281], [2.4000827231183144, 48.064577220015714], [2.479858410186694, 48.09284361309539], [2.55972590780524, 48.121048547846634], [2.6396852072737866, 48.14919189758668], [2.7197362987419527, 48.17727353557561], [2.7998791711851205, 48.20529333501516]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.7998792&lt;dd&gt;Longitude: 48.205293&lt;dd&gt;Azimuth: 130.8719\u00b0&lt;dd&gt;Altitude: 42.104201\u00b0&lt;dd&gt;Slant Range: 775.46519km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7998791711851205, 48.20529333501516]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.4000827231183144, 48.064577220015714], [2.479858410186694, 48.09284361309539], [2.55972590780524, 48.121048547846634], [2.6396852072737866, 48.14919189758668], [2.7197362987419527, 48.17727353557561], [2.7998791711851205, 48.20529333501516], [2.880113812412683, 48.23325116905205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.8801138&lt;dd&gt;Longitude: 48.233251&lt;dd&gt;Azimuth: 130.18125\u00b0&lt;dd&gt;Altitude: 41.984774\u00b0&lt;dd&gt;Slant Range: 776.9949km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.880113812412683, 48.23325116905205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.479858410186694, 48.09284361309539], [2.55972590780524, 48.121048547846634], [2.6396852072737866, 48.14919189758668], [2.7197362987419527, 48.17727353557561], [2.7998791711851205, 48.20529333501516], [2.880113812412683, 48.23325116905205], [2.960440209050891, 48.26114691077939]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 2.9604402&lt;dd&gt;Longitude: 48.261147&lt;dd&gt;Azimuth: 129.496\u00b0&lt;dd&gt;Altitude: 41.861298\u00b0&lt;dd&gt;Slant Range: 778.5849km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.960440209050891, 48.26114691077939]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.55972590780524, 48.121048547846634], [2.6396852072737866, 48.14919189758668], [2.7197362987419527, 48.17727353557561], [2.7998791711851205, 48.20529333501516], [2.880113812412683, 48.23325116905205], [2.960440209050891, 48.26114691077939], [3.0408583465501824, 48.28898043323772]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.0408583&lt;dd&gt;Longitude: 48.28898&lt;dd&gt;Azimuth: 128.8163\u00b0&lt;dd&gt;Altitude: 41.733875\u00b0&lt;dd&gt;Slant Range: 780.23484km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0408583465501824, 48.28898043323772]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.6396852072737866, 48.14919189758668], [2.7197362987419527, 48.17727353557561], [2.7998791711851205, 48.20529333501516], [2.880113812412683, 48.23325116905205], [2.960440209050891, 48.26114691077939], [3.0408583465501824, 48.28898043323772], [3.1213682091654626, 48.316751609417544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.1213682&lt;dd&gt;Longitude: 48.316752&lt;dd&gt;Azimuth: 128.14227\u00b0&lt;dd&gt;Altitude: 41.602608\u00b0&lt;dd&gt;Slant Range: 781.94432km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.1213682091654626, 48.316751609417544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7197362987419527, 48.17727353557561], [2.7998791711851205, 48.20529333501516], [2.880113812412683, 48.23325116905205], [2.960440209050891, 48.26114691077939], [3.0408583465501824, 48.28898043323772], [3.1213682091654626, 48.316751609417544], [3.201969779957378, 48.344460312260686]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.2019698&lt;dd&gt;Longitude: 48.34446&lt;dd&gt;Azimuth: 127.47402\u00b0&lt;dd&gt;Altitude: 41.467602\u00b0&lt;dd&gt;Slant Range: 783.71296km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.201969779957378, 48.344460312260686]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7998791711851205, 48.20529333501516], [2.880113812412683, 48.23325116905205], [2.960440209050891, 48.26114691077939], [3.0408583465501824, 48.28898043323772], [3.1213682091654626, 48.316751609417544], [3.201969779957378, 48.344460312260686], [3.2826630407859527, 48.37210641466106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.282663&lt;dd&gt;Longitude: 48.372106&lt;dd&gt;Azimuth: 126.81166\u00b0&lt;dd&gt;Altitude: 41.328962\u00b0&lt;dd&gt;Slant Range: 785.54036km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.2826630407859527, 48.37210641466106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.880113812412683, 48.23325116905205], [2.960440209050891, 48.26114691077939], [3.0408583465501824, 48.28898043323772], [3.1213682091654626, 48.316751609417544], [3.201969779957378, 48.344460312260686], [3.2826630407859527, 48.37210641466106], [3.3634479723081725, 48.39968978946858]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.363448&lt;dd&gt;Longitude: 48.39969&lt;dd&gt;Azimuth: 126.15528\u00b0&lt;dd&gt;Altitude: 41.186795\u00b0&lt;dd&gt;Slant Range: 787.4261km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3634479723081725, 48.39968978946858]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.960440209050891, 48.26114691077939], [3.0408583465501824, 48.28898043323772], [3.1213682091654626, 48.316751609417544], [3.201969779957378, 48.344460312260686], [3.2826630407859527, 48.37210641466106], [3.3634479723081725, 48.39968978946858], [3.444324553960632, 48.427210309488636]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.4443246&lt;dd&gt;Longitude: 48.42721&lt;dd&gt;Azimuth: 125.50499\u00b0&lt;dd&gt;Altitude: 41.04121\u00b0&lt;dd&gt;Slant Range: 789.36976km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.444324553960632, 48.427210309488636]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0408583465501824, 48.28898043323772], [3.1213682091654626, 48.316751609417544], [3.201969779957378, 48.344460312260686], [3.2826630407859527, 48.37210641466106], [3.3634479723081725, 48.39968978946858], [3.444324553960632, 48.427210309488636], [3.5252927639715184, 48.454667847485084]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.5252928&lt;dd&gt;Longitude: 48.454668&lt;dd&gt;Azimuth: 124.86085\u00b0&lt;dd&gt;Altitude: 40.892312\u00b0&lt;dd&gt;Slant Range: 791.37092km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5252927639715184, 48.454667847485084]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.1213682091654626, 48.316751609417544], [3.201969779957378, 48.344460312260686], [3.2826630407859527, 48.37210641466106], [3.3634479723081725, 48.39968978946858], [3.444324553960632, 48.427210309488636], [3.5252927639715184, 48.454667847485084], [3.6063525793380427, 48.48206227618207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.6063526&lt;dd&gt;Longitude: 48.482062&lt;dd&gt;Azimuth: 124.22295\u00b0&lt;dd&gt;Altitude: 40.740212\u00b0&lt;dd&gt;Slant Range: 793.42914km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6063525793380427, 48.48206227618207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.201969779957378, 48.344460312260686], [3.2826630407859527, 48.37210641466106], [3.3634479723081725, 48.39968978946858], [3.444324553960632, 48.427210309488636], [3.5252927639715184, 48.454667847485084], [3.6063525793380427, 48.48206227618207], [3.68750397582682, 48.50939346826525]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.687504&lt;dd&gt;Longitude: 48.509393&lt;dd&gt;Azimuth: 123.59135\u00b0&lt;dd&gt;Altitude: 40.585017\u00b0&lt;dd&gt;Slant Range: 795.54396km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.68750397582682, 48.50939346826525]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.2826630407859527, 48.37210641466106], [3.3634479723081725, 48.39968978946858], [3.444324553960632, 48.427210309488636], [3.5252927639715184, 48.454667847485084], [3.6063525793380427, 48.48206227618207], [3.68750397582682, 48.50939346826525], [3.7687469279745853, 48.53666129638306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.7687469&lt;dd&gt;Longitude: 48.536661&lt;dd&gt;Azimuth: 122.96611\u00b0&lt;dd&gt;Altitude: 40.426835\u00b0&lt;dd&gt;Slant Range: 797.71495km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.7687469279745853, 48.53666129638306]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.3634479723081725, 48.39968978946858], [3.444324553960632, 48.427210309488636], [3.5252927639715184, 48.454667847485084], [3.6063525793380427, 48.48206227618207], [3.68750397582682, 48.50939346826525], [3.7687469279745853, 48.53666129638306], [3.8500814090725664, 48.56386563315089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.8500814&lt;dd&gt;Longitude: 48.563866&lt;dd&gt;Azimuth: 122.34729\u00b0&lt;dd&gt;Altitude: 40.265775\u00b0&lt;dd&gt;Slant Range: 799.94164km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8500814090725664, 48.56386563315089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.444324553960632, 48.427210309488636], [3.5252927639715184, 48.454667847485084], [3.6063525793380427, 48.48206227618207], [3.68750397582682, 48.50939346826525], [3.7687469279745853, 48.53666129638306], [3.8500814090725664, 48.56386563315089], [3.9315073911665115, 48.591006351149595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 3.9315074&lt;dd&gt;Longitude: 48.591006&lt;dd&gt;Azimuth: 121.73492\u00b0&lt;dd&gt;Altitude: 40.101945\u00b0&lt;dd&gt;Slant Range: 802.22356km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9315073911665115, 48.591006351149595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5252927639715184, 48.454667847485084], [3.6063525793380427, 48.48206227618207], [3.68750397582682, 48.50939346826525], [3.7687469279745853, 48.53666129638306], [3.8500814090725664, 48.56386563315089], [3.9315073911665115, 48.591006351149595], [4.013024845046818, 48.61808332292991]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.0130248&lt;dd&gt;Longitude: 48.618083&lt;dd&gt;Azimuth: 121.12905\u00b0&lt;dd&gt;Altitude: 39.935451\u00b0&lt;dd&gt;Slant Range: 804.56024km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.013024845046818, 48.61808332292991]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6063525793380427, 48.48206227618207], [3.68750397582682, 48.50939346826525], [3.7687469279745853, 48.53666129638306], [3.8500814090725664, 48.56386563315089], [3.9315073911665115, 48.591006351149595], [4.013024845046818, 48.61808332292991], [4.094633740251532, 48.64509642101321]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.0946337&lt;dd&gt;Longitude: 48.645096&lt;dd&gt;Azimuth: 120.52972\u00b0&lt;dd&gt;Altitude: 39.766401\u00b0&lt;dd&gt;Slant Range: 806.9512km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.094633740251532, 48.64509642101321]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.68750397582682, 48.50939346826525], [3.7687469279745853, 48.53666129638306], [3.8500814090725664, 48.56386563315089], [3.9315073911665115, 48.591006351149595], [4.013024845046818, 48.61808332292991], [4.094633740251532, 48.64509642101321], [4.1763340450433235, 48.672045517893174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.176334&lt;dd&gt;Longitude: 48.672046&lt;dd&gt;Azimuth: 119.93693\u00b0&lt;dd&gt;Altitude: 39.594899\u00b0&lt;dd&gt;Slant Range: 809.39596km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.1763340450433235, 48.672045517893174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.7687469279745853, 48.53666129638306], [3.8500814090725664, 48.56386563315089], [3.9315073911665115, 48.591006351149595], [4.013024845046818, 48.61808332292991], [4.094633740251532, 48.64509642101321], [4.1763340450433235, 48.672045517893174], [4.258125726429077, 48.69893048603839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.2581257&lt;dd&gt;Longitude: 48.69893&lt;dd&gt;Azimuth: 119.35072\u00b0&lt;dd&gt;Altitude: 39.421052\u00b0&lt;dd&gt;Slant Range: 811.89404km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.258125726429077, 48.69893048603839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8500814090725664, 48.56386563315089], [3.9315073911665115, 48.591006351149595], [4.013024845046818, 48.61808332292991], [4.094633740251532, 48.64509642101321], [4.1763340450433235, 48.672045517893174], [4.258125726429077, 48.69893048603839], [4.340008750129436, 48.72575119789375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.3400088&lt;dd&gt;Longitude: 48.725751&lt;dd&gt;Azimuth: 118.7711\u00b0&lt;dd&gt;Altitude: 39.244962\u00b0&lt;dd&gt;Slant Range: 814.44492km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.340008750129436, 48.72575119789375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9315073911665115, 48.591006351149595], [4.013024845046818, 48.61808332292991], [4.094633740251532, 48.64509642101321], [4.1763340450433235, 48.672045517893174], [4.258125726429077, 48.69893048603839], [4.340008750129436, 48.72575119789375], [4.421983080589718, 48.75250752588174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.4219831&lt;dd&gt;Longitude: 48.752508&lt;dd&gt;Azimuth: 118.19808\u00b0&lt;dd&gt;Altitude: 39.066733\u00b0&lt;dd&gt;Slant Range: 817.04813km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.421983080589718, 48.75250752588174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.013024845046818, 48.61808332292991], [4.094633740251532, 48.64509642101321], [4.1763340450433235, 48.672045517893174], [4.258125726429077, 48.69893048603839], [4.340008750129436, 48.72575119789375], [4.421983080589718, 48.75250752588174], [4.504048680961822, 48.77919934240606]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.5040487&lt;dd&gt;Longitude: 48.779199&lt;dd&gt;Azimuth: 117.63165\u00b0&lt;dd&gt;Altitude: 38.886465\u00b0&lt;dd&gt;Slant Range: 819.70316km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.504048680961822, 48.77919934240606]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.094633740251532, 48.64509642101321], [4.1763340450433235, 48.672045517893174], [4.258125726429077, 48.69893048603839], [4.340008750129436, 48.72575119789375], [4.421983080589718, 48.75250752588174], [4.504048680961822, 48.77919934240606], [4.586205513114715, 48.805826519851514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.5862055&lt;dd&gt;Longitude: 48.805827&lt;dd&gt;Azimuth: 117.07181\u00b0&lt;dd&gt;Altitude: 38.704258\u00b0&lt;dd&gt;Slant Range: 822.4095km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.586205513114715, 48.805826519851514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.1763340450433235, 48.672045517893174], [4.258125726429077, 48.69893048603839], [4.340008750129436, 48.72575119789375], [4.421983080589718, 48.75250752588174], [4.504048680961822, 48.77919934240606], [4.586205513114715, 48.805826519851514], [4.668453537610002, 48.83238893058714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.6684535&lt;dd&gt;Longitude: 48.832389&lt;dd&gt;Azimuth: 116.51856\u00b0&lt;dd&gt;Altitude: 38.520211\u00b0&lt;dd&gt;Slant Range: 825.16664km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.668453537610002, 48.83238893058714]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.258125726429077, 48.69893048603839], [4.340008750129436, 48.72575119789375], [4.421983080589718, 48.75250752588174], [4.504048680961822, 48.77919934240606], [4.586205513114715, 48.805826519851514], [4.668453537610002, 48.83238893058714], [4.750792713711775, 48.85888644696822]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.7507927&lt;dd&gt;Longitude: 48.858886&lt;dd&gt;Azimuth: 115.97188\u00b0&lt;dd&gt;Altitude: 38.334422\u00b0&lt;dd&gt;Slant Range: 827.97408km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.750792713711775, 48.85888644696822]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.340008750129436, 48.72575119789375], [4.421983080589718, 48.75250752588174], [4.504048680961822, 48.77919934240606], [4.586205513114715, 48.805826519851514], [4.668453537610002, 48.83238893058714], [4.750792713711775, 48.85888644696822], [4.8332229993730245, 48.88531894133721]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.833223&lt;dd&gt;Longitude: 48.885319&lt;dd&gt;Azimuth: 115.43175\u00b0&lt;dd&gt;Altitude: 38.146984\u00b0&lt;dd&gt;Slant Range: 830.83129km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.8332229993730245, 48.88531894133721]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.421983080589718, 48.75250752588174], [4.504048680961822, 48.77919934240606], [4.586205513114715, 48.805826519851514], [4.668453537610002, 48.83238893058714], [4.750792713711775, 48.85888644696822], [4.8332229993730245, 48.88531894133721], [4.915744351231264, 48.91168628602703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.9157444&lt;dd&gt;Longitude: 48.911686&lt;dd&gt;Azimuth: 114.89816\u00b0&lt;dd&gt;Altitude: 37.957992\u00b0&lt;dd&gt;Slant Range: 833.73778km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.915744351231264, 48.91168628602703]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.504048680961822, 48.77919934240606], [4.586205513114715, 48.805826519851514], [4.668453537610002, 48.83238893058714], [4.750792713711775, 48.85888644696822], [4.8332229993730245, 48.88531894133721], [4.915744351231264, 48.91168628602703], [4.998356724601099, 48.93798835336186]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 4.9983567&lt;dd&gt;Longitude: 48.937988&lt;dd&gt;Azimuth: 114.37108\u00b0&lt;dd&gt;Altitude: 37.767537\u00b0&lt;dd&gt;Slant Range: 836.69301km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.998356724601099, 48.93798835336186]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.586205513114715, 48.805826519851514], [4.668453537610002, 48.83238893058714], [4.750792713711775, 48.85888644696822], [4.8332229993730245, 48.88531894133721], [4.915744351231264, 48.91168628602703], [4.998356724601099, 48.93798835336186], [5.081060073478022, 48.96422501565948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.0810601&lt;dd&gt;Longitude: 48.964225&lt;dd&gt;Azimuth: 113.85047\u00b0&lt;dd&gt;Altitude: 37.575709\u00b0&lt;dd&gt;Slant Range: 839.69648km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.081060073478022, 48.96422501565948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.668453537610002, 48.83238893058714], [4.750792713711775, 48.85888644696822], [4.8332229993730245, 48.88531894133721], [4.915744351231264, 48.91168628602703], [4.998356724601099, 48.93798835336186], [5.081060073478022, 48.96422501565948], [5.16385435051988, 48.99039614523405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.1638544&lt;dd&gt;Longitude: 48.990396&lt;dd&gt;Azimuth: 113.33631\u00b0&lt;dd&gt;Altitude: 37.382598\u00b0&lt;dd&gt;Slant Range: 842.74766km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.16385435051988, 48.99039614523405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.750792713711775, 48.85888644696822], [4.8332229993730245, 48.88531894133721], [4.915744351231264, 48.91168628602703], [4.998356724601099, 48.93798835336186], [5.081060073478022, 48.96422501565948], [5.16385435051988, 48.99039614523405], [5.246739507051519, 49.016501614396766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.2467395&lt;dd&gt;Longitude: 49.016502&lt;dd&gt;Azimuth: 112.82856\u00b0&lt;dd&gt;Altitude: 37.188288\u00b0&lt;dd&gt;Slant Range: 845.84603km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.246739507051519, 49.016501614396766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.8332229993730245, 48.88531894133721], [4.915744351231264, 48.91168628602703], [4.998356724601099, 48.93798835336186], [5.081060073478022, 48.96422501565948], [5.16385435051988, 48.99039614523405], [5.246739507051519, 49.016501614396766], [5.329715493050724, 49.042541295458726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.3297155&lt;dd&gt;Longitude: 49.042541&lt;dd&gt;Azimuth: 112.32717\u00b0&lt;dd&gt;Altitude: 36.992864\u00b0&lt;dd&gt;Slant Range: 848.99107km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.329715493050724, 49.042541295458726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.915744351231264, 48.91168628602703], [4.998356724601099, 48.93798835336186], [5.081060073478022, 48.96422501565948], [5.16385435051988, 48.99039614523405], [5.246739507051519, 49.016501614396766], [5.329715493050724, 49.042541295458726], [5.412782257153166, 49.068515060732906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.4127823&lt;dd&gt;Longitude: 49.068515&lt;dd&gt;Azimuth: 111.83211\u00b0&lt;dd&gt;Altitude: 36.796408\u00b0&lt;dd&gt;Slant Range: 852.18226km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.412782257153166, 49.068515060732906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.998356724601099, 48.93798835336186], [5.081060073478022, 48.96422501565948], [5.16385435051988, 48.99039614523405], [5.246739507051519, 49.016501614396766], [5.329715493050724, 49.042541295458726], [5.412782257153166, 49.068515060732906], [5.495939746636419, 49.09442278253616]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.4959397&lt;dd&gt;Longitude: 49.094423&lt;dd&gt;Azimuth: 111.34334\u00b0&lt;dd&gt;Altitude: 36.599001\u00b0&lt;dd&gt;Slant Range: 855.41909km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.495939746636419, 49.09442278253616]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.081060073478022, 48.96422501565948], [5.16385435051988, 48.99039614523405], [5.246739507051519, 49.016501614396766], [5.329715493050724, 49.042541295458726], [5.412782257153166, 49.068515060732906], [5.495939746636419, 49.09442278253616], [5.579187907419299, 49.12026433319043]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.5791879&lt;dd&gt;Longitude: 49.120264&lt;dd&gt;Azimuth: 110.86079\u00b0&lt;dd&gt;Altitude: 36.400721\u00b0&lt;dd&gt;Slant Range: 858.70103km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.579187907419299, 49.12026433319043]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.16385435051988, 48.99039614523405], [5.246739507051519, 49.016501614396766], [5.329715493050724, 49.042541295458726], [5.412782257153166, 49.068515060732906], [5.495939746636419, 49.09442278253616], [5.579187907419299, 49.12026433319043], [5.662526684064228, 49.14603958502673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.6625267&lt;dd&gt;Longitude: 49.14604&lt;dd&gt;Azimuth: 110.38442\u00b0&lt;dd&gt;Altitude: 36.201644\u00b0&lt;dd&gt;Slant Range: 862.02756km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.662526684064228, 49.14603958502673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.246739507051519, 49.016501614396766], [5.329715493050724, 49.042541295458726], [5.412782257153166, 49.068515060732906], [5.495939746636419, 49.09442278253616], [5.579187907419299, 49.12026433319043], [5.662526684064228, 49.14603958502673], [5.745956019754184, 49.17174841038488]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.745956&lt;dd&gt;Longitude: 49.171748&lt;dd&gt;Azimuth: 109.91419\u00b0&lt;dd&gt;Altitude: 36.001845\u00b0&lt;dd&gt;Slant Range: 865.39817km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.745956019754184, 49.17174841038488]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.329715493050724, 49.042541295458726], [5.412782257153166, 49.068515060732906], [5.495939746636419, 49.09442278253616], [5.579187907419299, 49.12026433319043], [5.662526684064228, 49.14603958502673], [5.745956019754184, 49.17174841038488], [5.829475856300435, 49.1973906816174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.8294759&lt;dd&gt;Longitude: 49.197391&lt;dd&gt;Azimuth: 109.45003\u00b0&lt;dd&gt;Altitude: 35.801396\u00b0&lt;dd&gt;Slant Range: 868.81234km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.829475856300435, 49.1973906816174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.412782257153166, 49.068515060732906], [5.495939746636419, 49.09442278253616], [5.579187907419299, 49.12026433319043], [5.662526684064228, 49.14603958502673], [5.745956019754184, 49.17174841038488], [5.829475856300435, 49.1973906816174], [5.913086134136283, 49.22296627109082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.9130861&lt;dd&gt;Longitude: 49.222966&lt;dd&gt;Azimuth: 108.99189\u00b0&lt;dd&gt;Altitude: 35.600367\u00b0&lt;dd&gt;Slant Range: 872.26955km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.913086134136283, 49.22296627109082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.495939746636419, 49.09442278253616], [5.579187907419299, 49.12026433319043], [5.662526684064228, 49.14603958502673], [5.745956019754184, 49.17174841038488], [5.829475856300435, 49.1973906816174], [5.913086134136283, 49.22296627109082], [5.996786792310213, 49.24847505118778]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3540&lt;dd&gt;Latitude: 5.9967868&lt;dd&gt;Longitude: 49.248475&lt;dd&gt;Azimuth: 108.53971\u00b0&lt;dd&gt;Altitude: 35.398826\u00b0&lt;dd&gt;Slant Range: 875.76929km&quot;, &quot;name&quot;: &quot;STARLINK-3540&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.996786792310213, 49.24847505118778]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.5904695&lt;dd&gt;Longitude: 50.293062&lt;dd&gt;Azimuth: 257.95775\u00b0&lt;dd&gt;Altitude: 43.466971\u00b0&lt;dd&gt;Slant Range: 759.45597km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953], [-9.502821760809548, 50.31546057982707]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.5028218&lt;dd&gt;Longitude: 50.315461&lt;dd&gt;Azimuth: 258.01569\u00b0&lt;dd&gt;Altitude: 43.877762\u00b0&lt;dd&gt;Slant Range: 754.61204km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.502821760809548, 50.31546057982707]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953], [-9.502821760809548, 50.31546057982707], [-9.415087969956268, 50.33778643896701]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.415088&lt;dd&gt;Longitude: 50.337786&lt;dd&gt;Azimuth: 258.07511\u00b0&lt;dd&gt;Altitude: 44.293425\u00b0&lt;dd&gt;Slant Range: 749.80198km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.415087969956268, 50.33778643896701]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953], [-9.502821760809548, 50.31546057982707], [-9.415087969956268, 50.33778643896701], [-9.327268275945551, 50.360039597500396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.3272683&lt;dd&gt;Longitude: 50.36004&lt;dd&gt;Azimuth: 258.13606\u00b0&lt;dd&gt;Altitude: 44.714017\u00b0&lt;dd&gt;Slant Range: 745.02646km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.327268275945551, 50.360039597500396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953], [-9.502821760809548, 50.31546057982707], [-9.415087969956268, 50.33778643896701], [-9.327268275945551, 50.360039597500396], [-9.239362811319914, 50.38221993124785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.2393628&lt;dd&gt;Longitude: 50.38222&lt;dd&gt;Azimuth: 258.19862\u00b0&lt;dd&gt;Altitude: 45.139595\u00b0&lt;dd&gt;Slant Range: 740.28614km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.239362811319914, 50.38221993124785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953], [-9.502821760809548, 50.31546057982707], [-9.415087969956268, 50.33778643896701], [-9.327268275945551, 50.360039597500396], [-9.239362811319914, 50.38221993124785], [-9.15137171022373, 50.40432731616181]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.1513717&lt;dd&gt;Longitude: 50.404327&lt;dd&gt;Azimuth: 258.26285\u00b0&lt;dd&gt;Altitude: 45.570218\u00b0&lt;dd&gt;Slant Range: 735.5817km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.15137171022373, 50.40432731616181]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590469517569689, 50.29306214438953], [-9.502821760809548, 50.31546057982707], [-9.415087969956268, 50.33778643896701], [-9.327268275945551, 50.360039597500396], [-9.239362811319914, 50.38221993124785], [-9.15137171022373, 50.40432731616181], [-9.063295108417575, 50.42636162832932]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -9.0632951&lt;dd&gt;Longitude: 50.426362&lt;dd&gt;Azimuth: 258.32882\u00b0&lt;dd&gt;Altitude: 46.005939\u00b0&lt;dd&gt;Slant Range: 730.91386km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.063295108417575, 50.42636162832932]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.502821760809548, 50.31546057982707], [-9.415087969956268, 50.33778643896701], [-9.327268275945551, 50.360039597500396], [-9.239362811319914, 50.38221993124785], [-9.15137171022373, 50.40432731616181], [-9.063295108417575, 50.42636162832932], [-8.975133143264262, 50.44832274397478]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.9751331&lt;dd&gt;Longitude: 50.448323&lt;dd&gt;Azimuth: 258.3966\u00b0&lt;dd&gt;Altitude: 46.446816\u00b0&lt;dd&gt;Slant Range: 726.28332km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.975133143264262, 50.44832274397478]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.415087969956268, 50.33778643896701], [-9.327268275945551, 50.360039597500396], [-9.239362811319914, 50.38221993124785], [-9.15137171022373, 50.40432731616181], [-9.063295108417575, 50.42636162832932], [-8.975133143264262, 50.44832274397478], [-8.88688595375795, 50.47021053946236]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.886886&lt;dd&gt;Longitude: 50.470211&lt;dd&gt;Azimuth: 258.46629\u00b0&lt;dd&gt;Altitude: 46.892902\u00b0&lt;dd&gt;Slant Range: 721.6908km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.88688595375795, 50.47021053946236]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.327268275945551, 50.360039597500396], [-9.239362811319914, 50.38221993124785], [-9.15137171022373, 50.40432731616181], [-9.063295108417575, 50.42636162832932], [-8.975133143264262, 50.44832274397478], [-8.88688595375795, 50.47021053946236], [-8.798553680499053, 50.492024891298485]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.7985537&lt;dd&gt;Longitude: 50.492025&lt;dd&gt;Azimuth: 258.53796\u00b0&lt;dd&gt;Altitude: 47.34425\u00b0&lt;dd&gt;Slant Range: 717.13704km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.798553680499053, 50.492024891298485]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.239362811319914, 50.38221993124785], [-9.15137171022373, 50.40432731616181], [-9.063295108417575, 50.42636162832932], [-8.975133143264262, 50.44832274397478], [-8.88688595375795, 50.47021053946236], [-8.798553680499053, 50.492024891298485], [-8.71013646572274, 50.51376567613571]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.7101365&lt;dd&gt;Longitude: 50.513766&lt;dd&gt;Azimuth: 258.6117\u00b0&lt;dd&gt;Altitude: 47.800914\u00b0&lt;dd&gt;Slant Range: 712.62278km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.71013646572274, 50.51376567613571]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.15137171022373, 50.40432731616181], [-9.063295108417575, 50.42636162832932], [-8.975133143264262, 50.44832274397478], [-8.88688595375795, 50.47021053946236], [-8.798553680499053, 50.492024891298485], [-8.71013646572274, 50.51376567613571], [-8.62163445328186, 50.53543277077329]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.6216345&lt;dd&gt;Longitude: 50.535433&lt;dd&gt;Azimuth: 258.68761\u00b0&lt;dd&gt;Altitude: 48.262944\u00b0&lt;dd&gt;Slant Range: 708.14879km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.62163445328186, 50.53543277077329]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.063295108417575, 50.42636162832932], [-8.975133143264262, 50.44832274397478], [-8.88688595375795, 50.47021053946236], [-8.798553680499053, 50.492024891298485], [-8.71013646572274, 50.51376567613571], [-8.62163445328186, 50.53543277077329], [-8.533047788664222, 50.557026052161945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.5330478&lt;dd&gt;Longitude: 50.557026&lt;dd&gt;Azimuth: 258.7658\u00b0&lt;dd&gt;Altitude: 48.730391\u00b0&lt;dd&gt;Slant Range: 703.71584km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.533047788664222, 50.557026052161945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.975133143264262, 50.44832274397478], [-8.88688595375795, 50.47021053946236], [-8.798553680499053, 50.492024891298485], [-8.71013646572274, 50.51376567613571], [-8.62163445328186, 50.53543277077329], [-8.533047788664222, 50.557026052161945], [-8.444376618992896, 50.57854539740526]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.4443766&lt;dd&gt;Longitude: 50.578545&lt;dd&gt;Azimuth: 258.84635\u00b0&lt;dd&gt;Altitude: 49.203303\u00b0&lt;dd&gt;Slant Range: 699.32472km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.444376618992896, 50.57854539740526]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.88688595375795, 50.47021053946236], [-8.798553680499053, 50.492024891298485], [-8.71013646572274, 50.51376567613571], [-8.62163445328186, 50.53543277077329], [-8.533047788664222, 50.557026052161945], [-8.444376618992896, 50.57854539740526], [-8.355621093018861, 50.59999068376297]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.3556211&lt;dd&gt;Longitude: 50.599991&lt;dd&gt;Azimuth: 258.92941\u00b0&lt;dd&gt;Altitude: 49.681726\u00b0&lt;dd&gt;Slant Range: 694.97621km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.355621093018861, 50.59999068376297]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.798553680499053, 50.492024891298485], [-8.71013646572274, 50.51376567613571], [-8.62163445328186, 50.53543277077329], [-8.533047788664222, 50.557026052161945], [-8.444376618992896, 50.57854539740526], [-8.355621093018861, 50.59999068376297], [-8.266781361141438, 50.6213617886534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.2667814&lt;dd&gt;Longitude: 50.621362&lt;dd&gt;Azimuth: 259.01507\u00b0&lt;dd&gt;Altitude: 50.165707\u00b0&lt;dd&gt;Slant Range: 690.67114km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.266781361141438, 50.6213617886534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.71013646572274, 50.51376567613571], [-8.62163445328186, 50.53543277077329], [-8.533047788664222, 50.557026052161945], [-8.444376618992896, 50.57854539740526], [-8.355621093018861, 50.59999068376297], [-8.266781361141438, 50.6213617886534], [-8.17785757539542, 50.642658589656406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.1778576&lt;dd&gt;Longitude: 50.642659&lt;dd&gt;Azimuth: 259.10349\u00b0&lt;dd&gt;Altitude: 50.655288\u00b0&lt;dd&gt;Slant Range: 686.41032km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.17785757539542, 50.642658589656406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.62163445328186, 50.53543277077329], [-8.533047788664222, 50.557026052161945], [-8.444376618992896, 50.57854539740526], [-8.355621093018861, 50.59999068376297], [-8.266781361141438, 50.6213617886534], [-8.17785757539542, 50.642658589656406], [-8.08884988946757, 50.6638809645157]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -8.0888499&lt;dd&gt;Longitude: 50.663881&lt;dd&gt;Azimuth: 259.19479\u00b0&lt;dd&gt;Altitude: 51.150511\u00b0&lt;dd&gt;Slant Range: 682.19458km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.08884988946757, 50.6638809645157]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.533047788664222, 50.557026052161945], [-8.444376618992896, 50.57854539740526], [-8.355621093018861, 50.59999068376297], [-8.266781361141438, 50.6213617886534], [-8.17785757539542, 50.642658589656406], [-8.08884988946757, 50.6638809645157], [-7.999758458686768, 50.685028791142045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.9997585&lt;dd&gt;Longitude: 50.685029&lt;dd&gt;Azimuth: 259.28912\u00b0&lt;dd&gt;Altitude: 51.651415\u00b0&lt;dd&gt;Slant Range: 678.02478km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.999758458686768, 50.685028791142045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.444376618992896, 50.57854539740526], [-8.355621093018861, 50.59999068376297], [-8.266781361141438, 50.6213617886534], [-8.17785757539542, 50.642658589656406], [-8.08884988946757, 50.6638809645157], [-7.999758458686768, 50.685028791142045], [-7.910583440037736, 50.70610194761593]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.9105834&lt;dd&gt;Longitude: 50.706102&lt;dd&gt;Azimuth: 259.38665\u00b0&lt;dd&gt;Altitude: 52.158035\u00b0&lt;dd&gt;Slant Range: 673.90177km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.910583440037736, 50.70610194761593]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.355621093018861, 50.59999068376297], [-8.266781361141438, 50.6213617886534], [-8.17785757539542, 50.642658589656406], [-8.08884988946757, 50.6638809645157], [-7.999758458686768, 50.685028791142045], [-7.910583440037736, 50.70610194761593], [-7.821324992154533, 50.72710031219002]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.821325&lt;dd&gt;Longitude: 50.7271&lt;dd&gt;Azimuth: 259.48754\u00b0&lt;dd&gt;Altitude: 52.670406\u00b0&lt;dd&gt;Slant Range: 669.82642km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.821324992154533, 50.72710031219002]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.266781361141438, 50.6213617886534], [-8.17785757539542, 50.642658589656406], [-8.08884988946757, 50.6638809645157], [-7.999758458686768, 50.685028791142045], [-7.910583440037736, 50.70610194761593], [-7.821324992154533, 50.72710031219002], [-7.731983275333832, 50.74802376329221]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.7319833&lt;dd&gt;Longitude: 50.748024&lt;dd&gt;Azimuth: 259.59198\u00b0&lt;dd&gt;Altitude: 53.188559\u00b0&lt;dd&gt;Slant Range: 665.7996km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.731983275333832, 50.74802376329221]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.17785757539542, 50.642658589656406], [-8.08884988946757, 50.6638809645157], [-7.999758458686768, 50.685028791142045], [-7.910583440037736, 50.70610194761593], [-7.821324992154533, 50.72710031219002], [-7.731983275333832, 50.74802376329221], [-7.64255845152309, 50.76887217952828]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.6425585&lt;dd&gt;Longitude: 50.768872&lt;dd&gt;Azimuth: 259.70016\u00b0&lt;dd&gt;Altitude: 53.712522\u00b0&lt;dd&gt;Slant Range: 661.82221km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.64255845152309, 50.76887217952828]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.08884988946757, 50.6638809645157], [-7.999758458686768, 50.685028791142045], [-7.910583440037736, 50.70610194761593], [-7.821324992154533, 50.72710031219002], [-7.731983275333832, 50.74802376329221], [-7.64255845152309, 50.76887217952828], [-7.553050684340219, 50.78964543968439]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.5530507&lt;dd&gt;Longitude: 50.789645&lt;dd&gt;Azimuth: 259.81229\u00b0&lt;dd&gt;Altitude: 54.242319\u00b0&lt;dd&gt;Slant Range: 657.89515km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.553050684340219, 50.78964543968439]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.999758458686768, 50.685028791142045], [-7.910583440037736, 50.70610194761593], [-7.821324992154533, 50.72710031219002], [-7.731983275333832, 50.74802376329221], [-7.64255845152309, 50.76887217952828], [-7.553050684340219, 50.78964543968439], [-7.463460139063531, 50.810343422730845]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.4634601&lt;dd&gt;Longitude: 50.810343&lt;dd&gt;Azimuth: 259.92861\u00b0&lt;dd&gt;Altitude: 54.777973\u00b0&lt;dd&gt;Slant Range: 654.01933km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.463460139063531, 50.810343422730845]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.910583440037736, 50.70610194761593], [-7.821324992154533, 50.72710031219002], [-7.731983275333832, 50.74802376329221], [-7.64255845152309, 50.76887217952828], [-7.553050684340219, 50.78964543968439], [-7.463460139063531, 50.810343422730845], [-7.373786982638891, 50.830966007823356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.373787&lt;dd&gt;Longitude: 50.830966&lt;dd&gt;Azimuth: 260.04936\u00b0&lt;dd&gt;Altitude: 55.319499\u00b0&lt;dd&gt;Slant Range: 650.19567km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.373786982638891, 50.830966007823356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.821324992154533, 50.72710031219002], [-7.731983275333832, 50.74802376329221], [-7.64255845152309, 50.76887217952828], [-7.553050684340219, 50.78964543968439], [-7.463460139063531, 50.810343422730845], [-7.373786982638891, 50.830966007823356], [-7.284031383680149, 50.85151307430717]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.2840314&lt;dd&gt;Longitude: 50.851513&lt;dd&gt;Azimuth: 260.17479\u00b0&lt;dd&gt;Altitude: 55.866912\u00b0&lt;dd&gt;Slant Range: 646.42509km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.284031383680149, 50.85151307430717]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.731983275333832, 50.74802376329221], [-7.64255845152309, 50.76887217952828], [-7.553050684340219, 50.78964543968439], [-7.463460139063531, 50.810343422730845], [-7.373786982638891, 50.830966007823356], [-7.284031383680149, 50.85151307430717], [-7.194193512477712, 50.87198450171934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.1941935&lt;dd&gt;Longitude: 50.871985&lt;dd&gt;Azimuth: 260.30521\u00b0&lt;dd&gt;Altitude: 56.420222\u00b0&lt;dd&gt;Slant Range: 642.70855km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.194193512477712, 50.87198450171934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.64255845152309, 50.76887217952828], [-7.553050684340219, 50.78964543968439], [-7.463460139063531, 50.810343422730845], [-7.373786982638891, 50.830966007823356], [-7.284031383680149, 50.85151307430717], [-7.194193512477712, 50.87198450171934], [-7.104273540986847, 50.892380169791394]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.1042735&lt;dd&gt;Longitude: 50.89238&lt;dd&gt;Azimuth: 260.4409\u00b0&lt;dd&gt;Altitude: 56.979432\u00b0&lt;dd&gt;Slant Range: 639.04698km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.104273540986847, 50.892380169791394]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.553050684340219, 50.78964543968439], [-7.463460139063531, 50.810343422730845], [-7.373786982638891, 50.830966007823356], [-7.284031383680149, 50.85151307430717], [-7.194193512477712, 50.87198450171934], [-7.104273540986847, 50.892380169791394], [-7.014271642851309, 50.91269995845248]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -7.0142716&lt;dd&gt;Longitude: 50.9127&lt;dd&gt;Azimuth: 260.58223\u00b0&lt;dd&gt;Altitude: 57.544543\u00b0&lt;dd&gt;Slant Range: 635.44133km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.014271642851309, 50.91269995845248]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.463460139063531, 50.810343422730845], [-7.373786982638891, 50.830966007823356], [-7.284031383680149, 50.85151307430717], [-7.194193512477712, 50.87198450171934], [-7.104273540986847, 50.892380169791394], [-7.014271642851309, 50.91269995845248], [-6.924187993382891, 50.93294374783206]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.924188&lt;dd&gt;Longitude: 50.932944&lt;dd&gt;Azimuth: 260.72953\u00b0&lt;dd&gt;Altitude: 58.11555\u00b0&lt;dd&gt;Slant Range: 631.89258km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.924187993382891, 50.93294374783206]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.373786982638891, 50.830966007823356], [-7.284031383680149, 50.85151307430717], [-7.194193512477712, 50.87198450171934], [-7.104273540986847, 50.892380169791394], [-7.014271642851309, 50.91269995845248], [-6.924187993382891, 50.93294374783206], [-6.834022769584117, 50.95311141826239]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.8340228&lt;dd&gt;Longitude: 50.953111&lt;dd&gt;Azimuth: 260.88322\u00b0&lt;dd&gt;Altitude: 58.692442\u00b0&lt;dd&gt;Slant Range: 628.40168km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.834022769584117, 50.95311141826239]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.284031383680149, 50.85151307430717], [-7.194193512477712, 50.87198450171934], [-7.104273540986847, 50.892380169791394], [-7.014271642851309, 50.91269995845248], [-6.924187993382891, 50.93294374783206], [-6.834022769584117, 50.95311141826239], [-6.743776150125955, 50.97320285028232]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.7437762&lt;dd&gt;Longitude: 50.973203&lt;dd&gt;Azimuth: 261.04372\u00b0&lt;dd&gt;Altitude: 59.275202\u00b0&lt;dd&gt;Slant Range: 624.96962km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.743776150125955, 50.97320285028232]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.194193512477712, 50.87198450171934], [-7.104273540986847, 50.892380169791394], [-7.014271642851309, 50.91269995845248], [-6.924187993382891, 50.93294374783206], [-6.834022769584117, 50.95311141826239], [-6.743776150125955, 50.97320285028232], [-6.653448315380916, 50.99321792463884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.6534483&lt;dd&gt;Longitude: 50.993218&lt;dd&gt;Azimuth: 261.21151\u00b0&lt;dd&gt;Altitude: 59.863809\u00b0&lt;dd&gt;Slant Range: 621.59736km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.653448315380916, 50.99321792463884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.104273540986847, 50.892380169791394], [-7.014271642851309, 50.91269995845248], [-6.924187993382891, 50.93294374783206], [-6.834022769584117, 50.95311141826239], [-6.743776150125955, 50.97320285028232], [-6.653448315380916, 50.99321792463884], [-6.563039447395732, 51.013156522291]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.5630394&lt;dd&gt;Longitude: 51.013157&lt;dd&gt;Azimuth: 261.3871\u00b0&lt;dd&gt;Altitude: 60.458233\u00b0&lt;dd&gt;Slant Range: 618.28589km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.563039447395732, 51.013156522291]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.014271642851309, 50.91269995845248], [-6.924187993382891, 50.93294374783206], [-6.834022769584117, 50.95311141826239], [-6.743776150125955, 50.97320285028232], [-6.653448315380916, 50.99321792463884], [-6.563039447395732, 51.013156522291], [-6.472549729912957, 51.03301852441226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.4725497&lt;dd&gt;Longitude: 51.033019&lt;dd&gt;Azimuth: 261.57106\u00b0&lt;dd&gt;Altitude: 61.058439\u00b0&lt;dd&gt;Slant Range: 615.0362km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.472549729912957, 51.03301852441226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.924187993382891, 50.93294374783206], [-6.834022769584117, 50.95311141826239], [-6.743776150125955, 50.97320285028232], [-6.653448315380916, 50.99321792463884], [-6.563039447395732, 51.013156522291], [-6.472549729912957, 51.03301852441226], [-6.381979348360199, 51.05280381239351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.3819793&lt;dd&gt;Longitude: 51.052804&lt;dd&gt;Azimuth: 261.76401\u00b0&lt;dd&gt;Altitude: 61.664384\u00b0&lt;dd&gt;Slant Range: 611.84927km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.381979348360199, 51.05280381239351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.834022769584117, 50.95311141826239], [-6.743776150125955, 50.97320285028232], [-6.653448315380916, 50.99321792463884], [-6.563039447395732, 51.013156522291], [-6.472549729912957, 51.03301852441226], [-6.381979348360199, 51.05280381239351], [-6.291328489863434, 51.07251226784583]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.2913285&lt;dd&gt;Longitude: 51.072512&lt;dd&gt;Azimuth: 261.96662\u00b0&lt;dd&gt;Altitude: 62.276016\u00b0&lt;dd&gt;Slant Range: 608.72609km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.291328489863434, 51.07251226784583]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.743776150125955, 50.97320285028232], [-6.653448315380916, 50.99321792463884], [-6.563039447395732, 51.013156522291], [-6.472549729912957, 51.03301852441226], [-6.381979348360199, 51.05280381239351], [-6.291328489863434, 51.07251226784583], [-6.200597343234536, 51.09214377260365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.2005973&lt;dd&gt;Longitude: 51.092144&lt;dd&gt;Azimuth: 262.17967\u00b0&lt;dd&gt;Altitude: 62.893278\u00b0&lt;dd&gt;Slant Range: 605.66766km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.200597343234536, 51.09214377260365]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.653448315380916, 50.99321792463884], [-6.563039447395732, 51.013156522291], [-6.472549729912957, 51.03301852441226], [-6.381979348360199, 51.05280381239351], [-6.291328489863434, 51.07251226784583], [-6.200597343234536, 51.09214377260365], [-6.109786098985015, 51.111698208726914]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.1097861&lt;dd&gt;Longitude: 51.111698&lt;dd&gt;Azimuth: 262.40397\u00b0&lt;dd&gt;Altitude: 63.5161\u00b0&lt;dd&gt;Slant Range: 602.67496km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.109786098985015, 51.111698208726914]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.563039447395732, 51.013156522291], [-6.472549729912957, 51.03301852441226], [-6.381979348360199, 51.05280381239351], [-6.291328489863434, 51.07251226784583], [-6.200597343234536, 51.09214377260365], [-6.109786098985015, 51.111698208726914], [-6.018894949329351, 51.13117545850492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -6.0188949&lt;dd&gt;Longitude: 51.131175&lt;dd&gt;Azimuth: 262.64046\u00b0&lt;dd&gt;Altitude: 64.144406\u00b0&lt;dd&gt;Slant Range: 599.74897km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.018894949329351, 51.13117545850492]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.472549729912957, 51.03301852441226], [-6.381979348360199, 51.05280381239351], [-6.291328489863434, 51.07251226784583], [-6.200597343234536, 51.09214377260365], [-6.109786098985015, 51.111698208726914], [-6.018894949329351, 51.13117545850492], [-5.927924088168001, 51.15057540445866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.9279241&lt;dd&gt;Longitude: 51.150575&lt;dd&gt;Azimuth: 262.89016\u00b0&lt;dd&gt;Altitude: 64.778108\u00b0&lt;dd&gt;Slant Range: 596.89069km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.927924088168001, 51.15057540445866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.381979348360199, 51.05280381239351], [-6.291328489863434, 51.07251226784583], [-6.200597343234536, 51.09214377260365], [-6.109786098985015, 51.111698208726914], [-6.018894949329351, 51.13117545850492], [-5.927924088168001, 51.15057540445866], [-5.836873711111795, 51.16989792934375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.8368737&lt;dd&gt;Longitude: 51.169898&lt;dd&gt;Azimuth: 263.15422\u00b0&lt;dd&gt;Altitude: 65.41711\u00b0&lt;dd&gt;Slant Range: 594.10109km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.836873711111795, 51.16989792934375]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.291328489863434, 51.07251226784583], [-6.200597343234536, 51.09214377260365], [-6.109786098985015, 51.111698208726914], [-6.018894949329351, 51.13117545850492], [-5.927924088168001, 51.15057540445866], [-5.836873711111795, 51.16989792934375], [-5.745744015467484, 51.18914291615343]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.745744&lt;dd&gt;Longitude: 51.189143&lt;dd&gt;Azimuth: 263.43392\u00b0&lt;dd&gt;Altitude: 66.061301\u00b0&lt;dd&gt;Slant Range: 591.38115km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.745744015467484, 51.18914291615343]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.200597343234536, 51.09214377260365], [-6.109786098985015, 51.111698208726914], [-6.018894949329351, 51.13117545850492], [-5.927924088168001, 51.15057540445866], [-5.836873711111795, 51.16989792934375], [-5.745744015467484, 51.18914291615343], [-5.654535200244438, 51.20831024812144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.6545352&lt;dd&gt;Longitude: 51.20831&lt;dd&gt;Azimuth: 263.73071\u00b0&lt;dd&gt;Altitude: 66.710561\u00b0&lt;dd&gt;Slant Range: 588.73183km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.654535200244438, 51.20831024812144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.109786098985015, 51.111698208726914], [-6.018894949329351, 51.13117545850492], [-5.927924088168001, 51.15057540445866], [-5.836873711111795, 51.16989792934375], [-5.745744015467484, 51.18914291615343], [-5.654535200244438, 51.20831024812144], [-5.5632474661578435, 51.227399808724996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.5632475&lt;dd&gt;Longitude: 51.2274&lt;dd&gt;Azimuth: 264.04618\u00b0&lt;dd&gt;Altitude: 67.364753\u00b0&lt;dd&gt;Slant Range: 586.1541km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.5632474661578435, 51.227399808724996]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.018894949329351, 51.13117545850492], [-5.927924088168001, 51.15057540445866], [-5.836873711111795, 51.16989792934375], [-5.745744015467484, 51.18914291615343], [-5.654535200244438, 51.20831024812144], [-5.5632474661578435, 51.227399808724996], [-5.47188101562876, 51.24641148168773]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.471881&lt;dd&gt;Longitude: 51.246411&lt;dd&gt;Azimuth: 264.38218\u00b0&lt;dd&gt;Altitude: 68.023728\u00b0&lt;dd&gt;Slant Range: 583.6489km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.47188101562876, 51.24641148168773]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.927924088168001, 51.15057540445866], [-5.836873711111795, 51.16989792934375], [-5.745744015467484, 51.18914291615343], [-5.654535200244438, 51.20831024812144], [-5.5632474661578435, 51.227399808724996], [-5.47188101562876, 51.24641148168773], [-5.3804360527777835, 51.26534515098219]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.3804361&lt;dd&gt;Longitude: 51.265345&lt;dd&gt;Azimuth: 264.74077\u00b0&lt;dd&gt;Altitude: 68.68732\u00b0&lt;dd&gt;Slant Range: 581.21719km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.3804360527777835, 51.26534515098219]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.836873711111795, 51.16989792934375], [-5.745744015467484, 51.18914291615343], [-5.654535200244438, 51.20831024812144], [-5.5632474661578435, 51.227399808724996], [-5.47188101562876, 51.24641148168773], [-5.3804360527777835, 51.26534515098219], [-5.2889127834400815, 51.284200700833445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.2889128&lt;dd&gt;Longitude: 51.284201&lt;dd&gt;Azimuth: 265.12429\u00b0&lt;dd&gt;Altitude: 69.355345\u00b0&lt;dd&gt;Slant Range: 578.85987km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.2889127834400815, 51.284200700833445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.745744015467484, 51.18914291615343], [-5.654535200244438, 51.20831024812144], [-5.5632474661578435, 51.227399808724996], [-5.47188101562876, 51.24641148168773], [-5.3804360527777835, 51.26534515098219], [-5.2889127834400815, 51.284200700833445], [-5.197311415150765, 51.302978015721585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.1973114&lt;dd&gt;Longitude: 51.302978&lt;dd&gt;Azimuth: 265.53544\u00b0&lt;dd&gt;Altitude: 70.027601\u00b0&lt;dd&gt;Slant Range: 576.57788km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.197311415150765, 51.302978015721585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.654535200244438, 51.20831024812144], [-5.5632474661578435, 51.227399808724996], [-5.47188101562876, 51.24641148168773], [-5.3804360527777835, 51.26534515098219], [-5.2889127834400815, 51.284200700833445], [-5.197311415150765, 51.302978015721585], [-5.1056321571644565, 51.32167698038474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.1056322&lt;dd&gt;Longitude: 51.321677&lt;dd&gt;Azimuth: 265.9773\u00b0&lt;dd&gt;Altitude: 70.703862\u00b0&lt;dd&gt;Slant Range: 574.37211km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.1056321571644565, 51.32167698038474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.5632474661578435, 51.227399808724996], [-5.47188101562876, 51.24641148168773], [-5.3804360527777835, 51.26534515098219], [-5.2889127834400815, 51.284200700833445], [-5.197311415150765, 51.302978015721585], [-5.1056321571644565, 51.32167698038474], [-5.013875220431139, 51.3402974798222]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -5.0138752&lt;dd&gt;Longitude: 51.340297&lt;dd&gt;Azimuth: 266.4534\u00b0&lt;dd&gt;Altitude: 71.383878\u00b0&lt;dd&gt;Slant Range: 572.24345km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.013875220431139, 51.3402974798222]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.47188101562876, 51.24641148168773], [-5.3804360527777835, 51.26534515098219], [-5.2889127834400815, 51.284200700833445], [-5.197311415150765, 51.302978015721585], [-5.1056321571644565, 51.32167698038474], [-5.013875220431139, 51.3402974798222], [-4.922040817621553, 51.358839399297125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.9220408&lt;dd&gt;Longitude: 51.358839&lt;dd&gt;Azimuth: 266.96786\u00b0&lt;dd&gt;Altitude: 72.06737\u00b0&lt;dd&gt;Slant Range: 570.19275km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.922040817621553, 51.358839399297125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.3804360527777835, 51.26534515098219], [-5.2889127834400815, 51.284200700833445], [-5.197311415150765, 51.302978015721585], [-5.1056321571644565, 51.32167698038474], [-5.013875220431139, 51.3402974798222], [-4.922040817621553, 51.358839399297125], [-4.830129163112743, 51.37730262433924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.8301292&lt;dd&gt;Longitude: 51.377303&lt;dd&gt;Azimuth: 267.52544\u00b0&lt;dd&gt;Altitude: 72.754028\u00b0&lt;dd&gt;Slant Range: 568.22087km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.830129163112743, 51.37730262433924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.2889127834400815, 51.284200700833445], [-5.197311415150765, 51.302978015721585], [-5.1056321571644565, 51.32167698038474], [-5.013875220431139, 51.3402974798222], [-4.922040817621553, 51.358839399297125], [-4.830129163112743, 51.37730262433924], [-4.73814047299485, 51.39568704074885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.7381405&lt;dd&gt;Longitude: 51.395687&lt;dd&gt;Azimuth: 268.13173\u00b0&lt;dd&gt;Altitude: 73.4435\u00b0&lt;dd&gt;Slant Range: 566.32863km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.73814047299485, 51.39568704074885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.197311415150765, 51.302978015721585], [-5.1056321571644565, 51.32167698038474], [-5.013875220431139, 51.3402974798222], [-4.922040817621553, 51.358839399297125], [-4.830129163112743, 51.37730262433924], [-4.73814047299485, 51.39568704074885], [-4.64607496506483, 51.41399253459834]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.646075&lt;dd&gt;Longitude: 51.413993&lt;dd&gt;Azimuth: 268.79329\u00b0&lt;dd&gt;Altitude: 74.135393\u00b0&lt;dd&gt;Slant Range: 564.51684km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.64607496506483, 51.41399253459834]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.1056321571644565, 51.32167698038474], [-5.013875220431139, 51.3402974798222], [-4.922040817621553, 51.358839399297125], [-4.830129163112743, 51.37730262433924], [-4.73814047299485, 51.39568704074885], [-4.64607496506483, 51.41399253459834], [-4.553932858839886, 51.43221899223633]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.5539329&lt;dd&gt;Longitude: 51.432219&lt;dd&gt;Azimuth: 269.51788\u00b0&lt;dd&gt;Altitude: 74.829258\u00b0&lt;dd&gt;Slant Range: 562.78627km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.553932858839886, 51.43221899223633]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.013875220431139, 51.3402974798222], [-4.922040817621553, 51.358839399297125], [-4.830129163112743, 51.37730262433924], [-4.73814047299485, 51.39568704074885], [-4.64607496506483, 51.41399253459834], [-4.553932858839886, 51.43221899223633], [-4.461714375539654, 51.45036630029001]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.4617144&lt;dd&gt;Longitude: 51.450366&lt;dd&gt;Azimuth: 270.31476\u00b0&lt;dd&gt;Altitude: 75.524581\u00b0&lt;dd&gt;Slant Range: 561.13767km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.461714375539654, 51.45036630029001]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.922040817621553, 51.358839399297125], [-4.830129163112743, 51.37730262433924], [-4.73814047299485, 51.39568704074885], [-4.64607496506483, 51.41399253459834], [-4.553932858839886, 51.43221899223633], [-4.461714375539654, 51.45036630029001], [-4.369419738105016, 51.46843434566835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.3694197&lt;dd&gt;Longitude: 51.468434&lt;dd&gt;Azimuth: 271.19499\u00b0&lt;dd&gt;Altitude: 76.220768\u00b0&lt;dd&gt;Slant Range: 559.57178km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.369419738105016, 51.46843434566835]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.830129163112743, 51.37730262433924], [-4.73814047299485, 51.39568704074885], [-4.64607496506483, 51.41399253459834], [-4.553932858839886, 51.43221899223633], [-4.461714375539654, 51.45036630029001], [-4.369419738105016, 51.46843434566835], [-4.27704917118366, 51.486423015564945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.2770492&lt;dd&gt;Longitude: 51.486423&lt;dd&gt;Azimuth: 272.17198\u00b0&lt;dd&gt;Altitude: 76.917128\u00b0&lt;dd&gt;Slant Range: 558.08929km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.27704917118366, 51.486423015564945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.73814047299485, 51.39568704074885], [-4.64607496506483, 51.41399253459834], [-4.553932858839886, 51.43221899223633], [-4.461714375539654, 51.45036630029001], [-4.369419738105016, 51.46843434566835], [-4.27704917118366, 51.486423015564945], [-4.1846029011401695, 51.50433219746117]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.1846029&lt;dd&gt;Longitude: 51.504332&lt;dd&gt;Azimuth: 273.26198\u00b0&lt;dd&gt;Altitude: 77.612843\u00b0&lt;dd&gt;Slant Range: 556.69086km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.1846029011401695, 51.50433219746117]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.64607496506483, 51.41399253459834], [-4.553932858839886, 51.43221899223633], [-4.461714375539654, 51.45036630029001], [-4.369419738105016, 51.46843434566835], [-4.27704917118366, 51.486423015564945], [-4.1846029011401695, 51.50433219746117], [-4.092081156049981, 51.52216177912878]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -4.0920812&lt;dd&gt;Longitude: 51.522162&lt;dd&gt;Azimuth: 274.48497\u00b0&lt;dd&gt;Altitude: 78.30694\u00b0&lt;dd&gt;Slant Range: 555.37714km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.092081156049981, 51.52216177912878]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.553932858839886, 51.43221899223633], [-4.461714375539654, 51.45036630029001], [-4.369419738105016, 51.46843434566835], [-4.27704917118366, 51.486423015564945], [-4.1846029011401695, 51.50433219746117], [-4.092081156049981, 51.52216177912878], [-3.9994841656995717, 51.539911648633314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.9994842&lt;dd&gt;Longitude: 51.539912&lt;dd&gt;Azimuth: 275.8656\u00b0&lt;dd&gt;Altitude: 78.998238\u00b0&lt;dd&gt;Slant Range: 554.14873km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9994841656995717, 51.539911648633314]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.461714375539654, 51.45036630029001], [-4.369419738105016, 51.46843434566835], [-4.27704917118366, 51.486423015564945], [-4.1846029011401695, 51.50433219746117], [-4.092081156049981, 51.52216177912878], [-3.9994841656995717, 51.539911648633314], [-3.906812161593603, 51.557581694336925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.9068122&lt;dd&gt;Longitude: 51.557582&lt;dd&gt;Azimuth: 277.43461\u00b0&lt;dd&gt;Altitude: 79.685293\u00b0&lt;dd&gt;Slant Range: 553.00619km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.906812161593603, 51.557581694336925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.369419738105016, 51.46843434566835], [-4.27704917118366, 51.486423015564945], [-4.1846029011401695, 51.50433219746117], [-4.092081156049981, 51.52216177912878], [-3.9994841656995717, 51.539911648633314], [-3.906812161593603, 51.557581694336925], [-3.8140653769402415, 51.575171804901316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.8140654&lt;dd&gt;Longitude: 51.575172&lt;dd&gt;Azimuth: 279.23058\u00b0&lt;dd&gt;Altitude: 80.366302\u00b0&lt;dd&gt;Slant Range: 551.95007km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8140653769402415, 51.575171804901316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.27704917118366, 51.486423015564945], [-4.1846029011401695, 51.50433219746117], [-4.092081156049981, 51.52216177912878], [-3.9994841656995717, 51.539911648633314], [-3.906812161593603, 51.557581694336925], [-3.8140653769402415, 51.575171804901316], [-3.721244046666758, 51.59268186929072]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.721244&lt;dd&gt;Longitude: 51.592682&lt;dd&gt;Azimuth: 281.3023\u00b0&lt;dd&gt;Altitude: 81.038989\u00b0&lt;dd&gt;Slant Range: 550.98085km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.721244046666758, 51.59268186929072]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.1846029011401695, 51.50433219746117], [-4.092081156049981, 51.52216177912878], [-3.9994841656995717, 51.539911648633314], [-3.906812161593603, 51.557581694336925], [-3.8140653769402415, 51.575171804901316], [-3.721244046666758, 51.59268186929072], [-3.6283484074115337, 51.610111776775014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.6283484&lt;dd&gt;Longitude: 51.610112&lt;dd&gt;Azimuth: 283.71186\u00b0&lt;dd&gt;Altitude: 81.700429\u00b0&lt;dd&gt;Slant Range: 550.099km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6283484074115337, 51.610111776775014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.092081156049981, 51.52216177912878], [-3.9994841656995717, 51.539911648633314], [-3.906812161593603, 51.557581694336925], [-3.8140653769402415, 51.575171804901316], [-3.721244046666758, 51.59268186929072], [-3.6283484074115337, 51.610111776775014], [-3.535378697520987, 51.627461416932555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.5353787&lt;dd&gt;Longitude: 51.627461&lt;dd&gt;Azimuth: 286.53839\u00b0&lt;dd&gt;Altitude: 82.346803\u00b0&lt;dd&gt;Slant Range: 549.30495km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.535378697520987, 51.627461416932555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9994841656995717, 51.539911648633314], [-3.906812161593603, 51.557581694336925], [-3.8140653769402415, 51.575171804901316], [-3.721244046666758, 51.59268186929072], [-3.6283484074115337, 51.610111776775014], [-3.535378697520987, 51.627461416932555], [-3.442335157052061, 51.64473067965327]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.4423352&lt;dd&gt;Longitude: 51.644731&lt;dd&gt;Azimuth: 289.88259\u00b0&lt;dd&gt;Altitude: 82.973062\u00b0&lt;dd&gt;Slant Range: 548.59906km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.442335157052061, 51.64473067965327]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.906812161593603, 51.557581694336925], [-3.8140653769402415, 51.575171804901316], [-3.721244046666758, 51.59268186929072], [-3.6283484074115337, 51.610111776775014], [-3.535378697520987, 51.627461416932555], [-3.442335157052061, 51.64473067965327], [-3.349218027778743, 51.661919455141344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.349218&lt;dd&gt;Longitude: 51.661919&lt;dd&gt;Azimuth: 293.87091\u00b0&lt;dd&gt;Altitude: 83.572448\u00b0&lt;dd&gt;Slant Range: 547.98169km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.349218027778743, 51.661919455141344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8140653769402415, 51.575171804901316], [-3.721244046666758, 51.59268186929072], [-3.6283484074115337, 51.610111776775014], [-3.535378697520987, 51.627461416932555], [-3.442335157052061, 51.64473067965327], [-3.349218027778743, 51.661919455141344], [-3.256027553168244, 51.67902763391918]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.2560276&lt;dd&gt;Longitude: 51.679028&lt;dd&gt;Azimuth: 298.65747\u00b0&lt;dd&gt;Altitude: 84.135868\u00b0&lt;dd&gt;Slant Range: 547.45314km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.256027553168244, 51.67902763391918]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.721244046666758, 51.59268186929072], [-3.6283484074115337, 51.610111776775014], [-3.535378697520987, 51.627461416932555], [-3.442335157052061, 51.64473067965327], [-3.349218027778743, 51.661919455141344], [-3.256027553168244, 51.67902763391918], [-3.1627639784192954, 51.696055106828915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.162764&lt;dd&gt;Longitude: 51.696055&lt;dd&gt;Azimuth: 304.41813\u00b0&lt;dd&gt;Altitude: 84.651145\u00b0&lt;dd&gt;Slant Range: 547.01365km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1627639784192954, 51.696055106828915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6283484074115337, 51.610111776775014], [-3.535378697520987, 51.627461416932555], [-3.442335157052061, 51.64473067965327], [-3.349218027778743, 51.661919455141344], [-3.256027553168244, 51.67902763391918], [-3.1627639784192954, 51.696055106828915], [-3.069427550416932, 51.71300176503673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -3.0694276&lt;dd&gt;Longitude: 51.713002&lt;dd&gt;Azimuth: 311.32631\u00b0&lt;dd&gt;Altitude: 85.102327\u00b0&lt;dd&gt;Slant Range: 546.66345km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.069427550416932, 51.71300176503673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.535378697520987, 51.627461416932555], [-3.442335157052061, 51.64473067965327], [-3.349218027778743, 51.661919455141344], [-3.256027553168244, 51.67902763391918], [-3.1627639784192954, 51.696055106828915], [-3.069427550416932, 51.71300176503673], [-2.9760185177654206, 51.7298675000351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.9760185&lt;dd&gt;Longitude: 51.729868&lt;dd&gt;Azimuth: 319.49553\u00b0&lt;dd&gt;Altitude: 85.469589\u00b0&lt;dd&gt;Slant Range: 546.40271km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9760185177654206, 51.7298675000351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.442335157052061, 51.64473067965327], [-3.349218027778743, 51.661919455141344], [-3.256027553168244, 51.67902763391918], [-3.1627639784192954, 51.696055106828915], [-3.069427550416932, 51.71300176503673], [-2.9760185177654206, 51.7298675000351], [-2.8825371307676457, 51.74665220364617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.8825371&lt;dd&gt;Longitude: 51.746652&lt;dd&gt;Azimuth: 328.88151\u00b0&lt;dd&gt;Altitude: 85.730713\u00b0&lt;dd&gt;Slant Range: 546.23156km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8825371307676457, 51.74665220364617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.349218027778743, 51.661919455141344], [-3.256027553168244, 51.67902763391918], [-3.1627639784192954, 51.696055106828915], [-3.069427550416932, 51.71300176503673], [-2.9760185177654206, 51.7298675000351], [-2.8825371307676457, 51.74665220364617], [-2.7889836414367912, 51.7633557680245]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.7889836&lt;dd&gt;Longitude: 51.763356&lt;dd&gt;Azimuth: 339.17755\u00b0&lt;dd&gt;Altitude: 85.865199\u00b0&lt;dd&gt;Slant Range: 546.15008km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7889836414367912, 51.7633557680245]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.256027553168244, 51.67902763391918], [-3.1627639784192954, 51.696055106828915], [-3.069427550416932, 51.71300176503673], [-2.9760185177654206, 51.7298675000351], [-2.8825371307676457, 51.74665220364617], [-2.7889836414367912, 51.7633557680245], [-2.6953583034829567, 51.7799780856603]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.6953583&lt;dd&gt;Longitude: 51.779978&lt;dd&gt;Azimuth: 349.80089\u00b0&lt;dd&gt;Altitude: 85.86052\u00b0&lt;dd&gt;Slant Range: 546.15831km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6953583034829567, 51.7799780856603]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1627639784192954, 51.696055106828915], [-3.069427550416932, 51.71300176503673], [-2.9760185177654206, 51.7298675000351], [-2.8825371307676457, 51.74665220364617], [-2.7889836414367912, 51.7633557680245], [-2.6953583034829567, 51.7799780856603], [-2.601661372325139, 51.796519049382034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.6016614&lt;dd&gt;Longitude: 51.796519&lt;dd&gt;Azimuth: 0.051696973\u00b0&lt;dd&gt;Altitude: 85.717146\u00b0&lt;dd&gt;Slant Range: 546.25624km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.601661372325139, 51.796519049382034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.069427550416932, 51.71300176503673], [-2.9760185177654206, 51.7298675000351], [-2.8825371307676457, 51.74665220364617], [-2.7889836414367912, 51.7633557680245], [-2.6953583034829567, 51.7799780856603], [-2.601661372325139, 51.796519049382034], [-2.5078931050757927, 51.812978552360036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.5078931&lt;dd&gt;Longitude: 51.812979&lt;dd&gt;Azimuth: 9.3626497\u00b0&lt;dd&gt;Altitude: 85.448339\u00b0&lt;dd&gt;Slant Range: 546.44383km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5078931050757927, 51.812978552360036]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9760185177654206, 51.7298675000351], [-2.8825371307676457, 51.74665220364617], [-2.7889836414367912, 51.7633557680245], [-2.6953583034829567, 51.7799780856603], [-2.601661372325139, 51.796519049382034], [-2.5078931050757927, 51.812978552360036], [-2.414053760553928, 51.82935648810893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.4140538&lt;dd&gt;Longitude: 51.829356&lt;dd&gt;Azimuth: 17.446643\u00b0&lt;dd&gt;Altitude: 85.074904\u00b0&lt;dd&gt;Slant Range: 546.72099km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.414053760553928, 51.82935648810893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8825371307676457, 51.74665220364617], [-2.7889836414367912, 51.7633557680245], [-2.6953583034829567, 51.7799780856603], [-2.601661372325139, 51.796519049382034], [-2.5078931050757927, 51.812978552360036], [-2.414053760553928, 51.82935648810893], [-2.3201435992667943, 51.845652750491006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.3201436&lt;dd&gt;Longitude: 51.845653&lt;dd&gt;Azimuth: 24.273519\u00b0&lt;dd&gt;Altitude: 84.618998\u00b0&lt;dd&gt;Slant Range: 547.08757km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3201435992667943, 51.845652750491006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7889836414367912, 51.7633557680245], [-2.6953583034829567, 51.7799780856603], [-2.601661372325139, 51.796519049382034], [-2.5078931050757927, 51.812978552360036], [-2.414053760553928, 51.82935648810893], [-2.3201435992667943, 51.845652750491006], [-2.226162883424485, 51.86186723371906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.2261629&lt;dd&gt;Longitude: 51.861867&lt;dd&gt;Azimuth: 29.963467\u00b0&lt;dd&gt;Altitude: 84.100212\u00b0&lt;dd&gt;Slant Range: 547.54341km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.226162883424485, 51.86186723371906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6953583034829567, 51.7799780856603], [-2.601661372325139, 51.796519049382034], [-2.5078931050757927, 51.812978552360036], [-2.414053760553928, 51.82935648810893], [-2.3201435992667943, 51.845652750491006], [-2.226162883424485, 51.86186723371906], [-2.1321118769310825, 51.87799983235943]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.1321119&lt;dd&gt;Longitude: 51.878&lt;dd&gt;Azimuth: 34.691403\u00b0&lt;dd&gt;Altitude: 83.534233\u00b0&lt;dd&gt;Slant Range: 548.08826km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.1321118769310825, 51.87799983235943]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.601661372325139, 51.796519049382034], [-2.5078931050757927, 51.812978552360036], [-2.414053760553928, 51.82935648810893], [-2.3201435992667943, 51.845652750491006], [-2.226162883424485, 51.86186723371906], [-2.1321118769310825, 51.87799983235943], [-2.0379908453796958, 51.894050441334926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -2.0379908&lt;dd&gt;Longitude: 51.89405&lt;dd&gt;Azimuth: 38.632199\u00b0&lt;dd&gt;Altitude: 82.933009\u00b0&lt;dd&gt;Slant Range: 548.72188km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0379908453796958, 51.894050441334926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5078931050757927, 51.812978552360036], [-2.414053760553928, 51.82935648810893], [-2.3201435992667943, 51.845652750491006], [-2.226162883424485, 51.86186723371906], [-2.1321118769310825, 51.87799983235943], [-2.0379908453796958, 51.894050441334926], [-1.94380005605353, 51.91001895592803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.9438001&lt;dd&gt;Longitude: 51.910019&lt;dd&gt;Azimuth: 41.938183\u00b0&lt;dd&gt;Altitude: 82.305456\u00b0&lt;dd&gt;Slant Range: 549.44395km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.94380005605353, 51.91001895592803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.414053760553928, 51.82935648810893], [-2.3201435992667943, 51.845652750491006], [-2.226162883424485, 51.86186723371906], [-2.1321118769310825, 51.87799983235943], [-2.0379908453796958, 51.894050441334926], [-1.94380005605353, 51.91001895592803], [-1.8495397779307967, 51.92590527178351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.8495398&lt;dd&gt;Longitude: 51.925905&lt;dd&gt;Azimuth: 44.733999\u00b0&lt;dd&gt;Altitude: 81.658198\u00b0&lt;dd&gt;Slant Range: 550.25411km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8495397779307967, 51.92590527178351]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3201435992667943, 51.845652750491006], [-2.226162883424485, 51.86186723371906], [-2.1321118769310825, 51.87799983235943], [-2.0379908453796958, 51.894050441334926], [-1.94380005605353, 51.91001895592803], [-1.8495397779307967, 51.92590527178351], [-1.7552102816658093, 51.94170928491182]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.7552103&lt;dd&gt;Longitude: 51.941709&lt;dd&gt;Azimuth: 47.118742\u00b0&lt;dd&gt;Altitude: 80.996191\u00b0&lt;dd&gt;Slant Range: 551.15199km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7552102816658093, 51.94170928491182]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.226162883424485, 51.86186723371906], [-2.1321118769310825, 51.87799983235943], [-2.0379908453796958, 51.894050441334926], [-1.94380005605353, 51.91001895592803], [-1.8495397779307967, 51.92590527178351], [-1.7552102816658093, 51.94170928491182], [-1.6608118396044524, 51.95743089169208]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.6608118&lt;dd&gt;Longitude: 51.957431&lt;dd&gt;Azimuth: 49.170291\u00b0&lt;dd&gt;Altitude: 80.323182\u00b0&lt;dd&gt;Slant Range: 552.13715km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6608118396044524, 51.95743089169208]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.1321118769310825, 51.87799983235943], [-2.0379908453796958, 51.894050441334926], [-1.94380005605353, 51.91001895592803], [-1.8495397779307967, 51.92590527178351], [-1.7552102816658093, 51.94170928491182], [-1.6608118396044524, 51.95743089169208], [-1.5663447257757352, 51.97306998887464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.5663447&lt;dd&gt;Longitude: 51.97307&lt;dd&gt;Azimuth: 50.949715\u00b0&lt;dd&gt;Altitude: 79.642047\u00b0&lt;dd&gt;Slant Range: 553.20912km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5663447257757352, 51.97306998887464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0379908453796958, 51.894050441334926], [-1.94380005605353, 51.91001895592803], [-1.8495397779307967, 51.92590527178351], [-1.7552102816658093, 51.94170928491182], [-1.6608118396044524, 51.95743089169208], [-1.5663447257757352, 51.97306998887464], [-1.471809215879348, 51.988626473584624]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.4718092&lt;dd&gt;Longitude: 51.988626&lt;dd&gt;Azimuth: 52.505047\u00b0&lt;dd&gt;Altitude: 78.955025\u00b0&lt;dd&gt;Slant Range: 554.36741km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.471809215879348, 51.988626473584624]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.94380005605353, 51.91001895592803], [-1.8495397779307967, 51.92590527178351], [-1.7552102816658093, 51.94170928491182], [-1.6608118396044524, 51.95743089169208], [-1.5663447257757352, 51.97306998887464], [-1.471809215879348, 51.988626473584624], [-1.377205587302228, 52.00410024332445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.3772056&lt;dd&gt;Longitude: 52.0041&lt;dd&gt;Azimuth: 53.874282\u00b0&lt;dd&gt;Altitude: 78.263891\u00b0&lt;dd&gt;Slant Range: 555.61146km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.377205587302228, 52.00410024332445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8495397779307967, 51.92590527178351], [-1.7552102816658093, 51.94170928491182], [-1.6608118396044524, 51.95743089169208], [-1.5663447257757352, 51.97306998887464], [-1.471809215879348, 51.988626473584624], [-1.377205587302228, 52.00410024332445], [-1.282534119098609, 52.01949119597713]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.2825341&lt;dd&gt;Longitude: 52.019491&lt;dd&gt;Azimuth: 55.087692\u00b0&lt;dd&gt;Altitude: 77.570068\u00b0&lt;dd&gt;Slant Range: 556.9407km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.282534119098609, 52.01949119597713]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7552102816658093, 51.94170928491182], [-1.6608118396044524, 51.95743089169208], [-1.5663447257757352, 51.97306998887464], [-1.471809215879348, 51.988626473584624], [-1.377205587302228, 52.00410024332445], [-1.282534119098609, 52.01949119597713], [-1.1877950919998708, 52.03479922980926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.1877951&lt;dd&gt;Longitude: 52.034799&lt;dd&gt;Azimuth: 56.169589\u00b0&lt;dd&gt;Altitude: 76.874721\u00b0&lt;dd&gt;Slant Range: 558.35453km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1877950919998708, 52.03479922980926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6608118396044524, 51.95743089169208], [-1.5663447257757352, 51.97306998887464], [-1.471809215879348, 51.988626473584624], [-1.377205587302228, 52.00410024332445], [-1.282534119098609, 52.01949119597713], [-1.1877950919998708, 52.03479922980926], [-1.0929887884020435, 52.050024243473594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -1.0929888&lt;dd&gt;Longitude: 52.050024&lt;dd&gt;Azimuth: 57.139655\u00b0&lt;dd&gt;Altitude: 76.178811\u00b0&lt;dd&gt;Slant Range: 559.85229km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0929887884020435, 52.050024243473594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5663447257757352, 51.97306998887464], [-1.471809215879348, 51.988626473584624], [-1.377205587302228, 52.00410024332445], [-1.282534119098609, 52.01949119597713], [-1.1877950919998708, 52.03479922980926], [-1.0929887884020435, 52.050024243473594], [-0.9981154923760885, 52.06516613601251]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.99811549&lt;dd&gt;Longitude: 52.065166&lt;dd&gt;Azimuth: 58.013953\u00b0&lt;dd&gt;Altitude: 75.483145\u00b0&lt;dd&gt;Slant Range: 561.43332km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9981154923760885, 52.06516613601251]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.471809215879348, 51.988626473584624], [-1.377205587302228, 52.00410024332445], [-1.282534119098609, 52.01949119597713], [-1.1877950919998708, 52.03479922980926], [-1.0929887884020435, 52.050024243473594], [-0.9981154923760885, 52.06516613601251], [-0.9031754896440062, 52.08022480686087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.90317549&lt;dd&gt;Longitude: 52.080225&lt;dd&gt;Azimuth: 58.805695\u00b0&lt;dd&gt;Altitude: 74.788407\u00b0&lt;dd&gt;Slant Range: 563.09691km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9031754896440062, 52.08022480686087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.377205587302228, 52.00410024332445], [-1.282534119098609, 52.01949119597713], [-1.1877950919998708, 52.03479922980926], [-1.0929887884020435, 52.050024243473594], [-0.9981154923760885, 52.06516613601251], [-0.9031754896440062, 52.08022480686087], [-0.8081690675996742, 52.09520015584885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.80816907&lt;dd&gt;Longitude: 52.0952&lt;dd&gt;Azimuth: 59.525829\u00b0&lt;dd&gt;Altitude: 74.095183\u00b0&lt;dd&gt;Slant Range: 564.84233km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8081690675996742, 52.09520015584885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.282534119098609, 52.01949119597713], [-1.1877950919998708, 52.03479922980926], [-1.0929887884020435, 52.050024243473594], [-0.9981154923760885, 52.06516613601251], [-0.9031754896440062, 52.08022480686087], [-0.8081690675996742, 52.09520015584885], [-0.713096515286508, 52.110092083205004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.71309652&lt;dd&gt;Longitude: 52.110092&lt;dd&gt;Azimuth: 60.18349\u00b0&lt;dd&gt;Altitude: 73.403983\u00b0&lt;dd&gt;Slant Range: 566.66883km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.713096515286508, 52.110092083205004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1877950919998708, 52.03479922980926], [-1.0929887884020435, 52.050024243473594], [-0.9981154923760885, 52.06516613601251], [-0.9031754896440062, 52.08022480686087], [-0.8081690675996742, 52.09520015584885], [-0.713096515286508, 52.110092083205004], [-0.6179581234119886, 52.12490048955926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.61795812&lt;dd&gt;Longitude: 52.1249&lt;dd&gt;Azimuth: 60.786356\u00b0&lt;dd&gt;Altitude: 72.715249\u00b0&lt;dd&gt;Slant Range: 568.57561km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6179581234119886, 52.12490048955926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0929887884020435, 52.050024243473594], [-0.9981154923760885, 52.06516613601251], [-0.9031754896440062, 52.08022480686087], [-0.8081690675996742, 52.09520015584885], [-0.713096515286508, 52.110092083205004], [-0.6179581234119886, 52.12490048955926], [-0.5227541843238735, 52.1396252759457]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.52275418&lt;dd&gt;Longitude: 52.139625&lt;dd&gt;Azimuth: 61.340918\u00b0&lt;dd&gt;Altitude: 72.029372\u00b0&lt;dd&gt;Slant Range: 570.56187km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5227541843238735, 52.1396252759457]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9981154923760885, 52.06516613601251], [-0.9031754896440062, 52.08022480686087], [-0.8081690675996742, 52.09520015584885], [-0.713096515286508, 52.110092083205004], [-0.6179581234119886, 52.12490048955926], [-0.5227541843238735, 52.1396252759457], [-0.42748499202668333, 52.15426634380574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.42748499&lt;dd&gt;Longitude: 52.154266&lt;dd&gt;Azimuth: 61.852697\u00b0&lt;dd&gt;Altitude: 71.3467\u00b0&lt;dd&gt;Slant Range: 572.62679km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.42748499202668333, 52.15426634380574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9031754896440062, 52.08022480686087], [-0.8081690675996742, 52.09520015584885], [-0.713096515286508, 52.110092083205004], [-0.6179581234119886, 52.12490048955926], [-0.5227541843238735, 52.1396252759457], [-0.42748499202668333, 52.15426634380574], [-0.33215084216496005, 52.16882359499108]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.33215084&lt;dd&gt;Longitude: 52.168824&lt;dd&gt;Azimuth: 62.326418\u00b0&lt;dd&gt;Altitude: 70.667538\u00b0&lt;dd&gt;Slant Range: 574.7695km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.33215084216496005, 52.16882359499108]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8081690675996742, 52.09520015584885], [-0.713096515286508, 52.110092083205004], [-0.6179581234119886, 52.12490048955926], [-0.5227541843238735, 52.1396252759457], [-0.42748499202668333, 52.15426634380574], [-0.33215084216496005, 52.16882359499108], [-0.23675203202336856, 52.18329693176665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.23675203&lt;dd&gt;Longitude: 52.183297&lt;dd&gt;Azimuth: 62.766144\u00b0&lt;dd&gt;Altitude: 69.992165\u00b0&lt;dd&gt;Slant Range: 576.98915km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.23675203202336856, 52.18329693176665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.713096515286508, 52.110092083205004], [-0.6179581234119886, 52.12490048955926], [-0.5227541843238735, 52.1396252759457], [-0.42748499202668333, 52.15426634380574], [-0.33215084216496005, 52.16882359499108], [-0.23675203202336856, 52.18329693176665], [-0.1412888605279691, 52.19768625681326]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.14128886&lt;dd&gt;Longitude: 52.197686&lt;dd&gt;Azimuth: 63.175386\u00b0&lt;dd&gt;Altitude: 69.320826\u00b0&lt;dd&gt;Slant Range: 579.28484km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.1412888605279691, 52.19768625681326]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6179581234119886, 52.12490048955926], [-0.5227541843238735, 52.1396252759457], [-0.42748499202668333, 52.15426634380574], [-0.33215084216496005, 52.16882359499108], [-0.23675203202336856, 52.18329693176665], [-0.1412888605279691, 52.19768625681326], [-0.04576162823896543, 52.21199147323099]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: -0.045761628&lt;dd&gt;Longitude: 52.211991&lt;dd&gt;Azimuth: 63.557196\u00b0&lt;dd&gt;Altitude: 68.653744\u00b0&lt;dd&gt;Slant Range: 581.65567km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.04576162823896543, 52.21199147323099]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5227541843238735, 52.1396252759457], [-0.42748499202668333, 52.15426634380574], [-0.33215084216496005, 52.16882359499108], [-0.23675203202336856, 52.18329693176665], [-0.1412888605279691, 52.19768625681326], [-0.04576162823896543, 52.21199147323099], [0.04982936266077064, 52.22621248454188]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.049829363&lt;dd&gt;Longitude: 52.226212&lt;dd&gt;Azimuth: 63.914233\u00b0&lt;dd&gt;Altitude: 67.991122\u00b0&lt;dd&gt;Slant Range: 584.10073km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.04982936266077064, 52.22621248454188]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.42748499202668333, 52.15426634380574], [-0.33215084216496005, 52.16882359499108], [-0.23675203202336856, 52.18329693176665], [-0.1412888605279691, 52.19768625681326], [-0.04576162823896543, 52.21199147323099], [0.04982936266077064, 52.22621248454188], [0.1454838083541474, 52.240349194692925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.14548381&lt;dd&gt;Longitude: 52.240349&lt;dd&gt;Azimuth: 64.248829\u00b0&lt;dd&gt;Altitude: 67.333139\u00b0&lt;dd&gt;Slant Range: 586.61908km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.1454838083541474, 52.240349194692925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.33215084216496005, 52.16882359499108], [-0.23675203202336856, 52.18329693176665], [-0.1412888605279691, 52.19768625681326], [-0.04576162823896543, 52.21199147323099], [0.04982936266077064, 52.22621248454188], [0.1454838083541474, 52.240349194692925], [0.2412014034062903, 52.254401508058805]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.2412014&lt;dd&gt;Longitude: 52.254402&lt;dd&gt;Azimuth: 64.563034\u00b0&lt;dd&gt;Altitude: 66.679961\u00b0&lt;dd&gt;Slant Range: 589.20978km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.2412014034062903, 52.254401508058805]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.23675203202336856, 52.18329693176665], [-0.1412888605279691, 52.19768625681326], [-0.04576162823896543, 52.21199147323099], [0.04982936266077064, 52.22621248454188], [0.1454838083541474, 52.240349194692925], [0.2412014034062903, 52.254401508058805], [0.3369818407610053, 52.268369329445235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.33698184&lt;dd&gt;Longitude: 52.268369&lt;dd&gt;Azimuth: 64.85866\u00b0&lt;dd&gt;Altitude: 66.031734\u00b0&lt;dd&gt;Slant Range: 591.87187km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3369818407610053, 52.268369329445235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.1412888605279691, 52.19768625681326], [-0.04576162823896543, 52.21199147323099], [0.04982936266077064, 52.22621248454188], [0.1454838083541474, 52.240349194692925], [0.2412014034062903, 52.254401508058805], [0.3369818407610053, 52.268369329445235], [0.43282481175271226, 52.282252564091536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.43282481&lt;dd&gt;Longitude: 52.282253&lt;dd&gt;Azimuth: 65.137309\u00b0&lt;dd&gt;Altitude: 65.388593\u00b0&lt;dd&gt;Slant Range: 594.6044km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.43282481175271226, 52.282252564091536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.04576162823896543, 52.21199147323099], [0.04982936266077064, 52.22621248454188], [0.1454838083541474, 52.240349194692925], [0.2412014034062903, 52.254401508058805], [0.3369818407610053, 52.268369329445235], [0.43282481175271226, 52.282252564091536], [0.5287300061009235, 52.2960511176737]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.52873001&lt;dd&gt;Longitude: 52.296051&lt;dd&gt;Azimuth: 65.400408\u00b0&lt;dd&gt;Altitude: 64.750657\u00b0&lt;dd&gt;Slant Range: 597.4064km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5287300061009235, 52.2960511176737]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.04982936266077064, 52.22621248454188], [0.1454838083541474, 52.240349194692925], [0.2412014034062903, 52.254401508058805], [0.3369818407610053, 52.268369329445235], [0.43282481175271226, 52.282252564091536], [0.5287300061009235, 52.2960511176737], [0.6246971119224823, 52.30976489630721]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.62469711&lt;dd&gt;Longitude: 52.309765&lt;dd&gt;Azimuth: 65.649229\u00b0&lt;dd&gt;Altitude: 64.118034\u00b0&lt;dd&gt;Slant Range: 600.27688km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6246971119224823, 52.30976489630721]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.1454838083541474, 52.240349194692925], [0.2412014034062903, 52.254401508058805], [0.3369818407610053, 52.268369329445235], [0.43282481175271226, 52.282252564091536], [0.5287300061009235, 52.2960511176737], [0.6246971119224823, 52.30976489630721], [0.7207258157372123, 52.32339380655008]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.72072582&lt;dd&gt;Longitude: 52.323394&lt;dd&gt;Azimuth: 65.88491\u00b0&lt;dd&gt;Altitude: 63.49082\u00b0&lt;dd&gt;Slant Range: 603.21488km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7207258157372123, 52.32339380655008]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.2412014034062903, 52.254401508058805], [0.3369818407610053, 52.268369329445235], [0.43282481175271226, 52.282252564091536], [0.5287300061009235, 52.2960511176737], [0.6246971119224823, 52.30976489630721], [0.7207258157372123, 52.32339380655008], [0.8168158024616318, 52.33693775540547]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.8168158&lt;dd&gt;Longitude: 52.336938&lt;dd&gt;Azimuth: 66.108471\u00b0&lt;dd&gt;Altitude: 62.869102\u00b0&lt;dd&gt;Slant Range: 606.21939km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8168158024616318, 52.33693775540547]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3369818407610053, 52.268369329445235], [0.43282481175271226, 52.282252564091536], [0.5287300061009235, 52.2960511176737], [0.6246971119224823, 52.30976489630721], [0.7207258157372123, 52.32339380655008], [0.8168158024616318, 52.33693775540547], [0.9129667554232033, 52.35039665032508]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 0.91296676&lt;dd&gt;Longitude: 52.350397&lt;dd&gt;Azimuth: 66.320832\u00b0&lt;dd&gt;Altitude: 62.252954\u00b0&lt;dd&gt;Slant Range: 609.28944km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9129667554232033, 52.35039665032508]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.43282481175271226, 52.282252564091536], [0.5287300061009235, 52.2960511176737], [0.6246971119224823, 52.30976489630721], [0.7207258157372123, 52.32339380655008], [0.8168158024616318, 52.33693775540547], [0.9129667554232033, 52.35039665032508], [1.0091783563619108, 52.36377039921126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 1.0091784&lt;dd&gt;Longitude: 52.36377&lt;dd&gt;Azimuth: 66.522821\u00b0&lt;dd&gt;Altitude: 61.642443\u00b0&lt;dd&gt;Slant Range: 612.42403km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0091783563619108, 52.36377039921126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5287300061009235, 52.2960511176737], [0.6246971119224823, 52.30976489630721], [0.7207258157372123, 52.32339380655008], [0.8168158024616318, 52.33693775540547], [0.9129667554232033, 52.35039665032508], [1.0091783563619108, 52.36377039921126], [1.1054502854394455, 52.377058910420786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 1.1054503&lt;dd&gt;Longitude: 52.377059&lt;dd&gt;Azimuth: 66.715187\u00b0&lt;dd&gt;Altitude: 61.037627\u00b0&lt;dd&gt;Slant Range: 615.62218km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1054502854394455, 52.377058910420786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6246971119224823, 52.30976489630721], [0.7207258157372123, 52.32339380655008], [0.8168158024616318, 52.33693775540547], [0.9129667554232033, 52.35039665032508], [1.0091783563619108, 52.36377039921126], [1.1054502854394455, 52.377058910420786], [1.2017822212301215, 52.39026209276701]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 1.2017822&lt;dd&gt;Longitude: 52.390262&lt;dd&gt;Azimuth: 66.898609\u00b0&lt;dd&gt;Altitude: 60.438556\u00b0&lt;dd&gt;Slant Range: 618.8829km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2017822212301215, 52.39026209276701]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7207258157372123, 52.32339380655008], [0.8168158024616318, 52.33693775540547], [0.9129667554232033, 52.35039665032508], [1.0091783563619108, 52.36377039921126], [1.1054502854394455, 52.377058910420786], [1.2017822212301215, 52.39026209276701], [1.2981738407476442, 52.40337985552318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 1.2981738&lt;dd&gt;Longitude: 52.40338&lt;dd&gt;Azimuth: 67.073705\u00b0&lt;dd&gt;Altitude: 59.845271\u00b0&lt;dd&gt;Slant Range: 622.2052km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2981738407476442, 52.40337985552318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8168158024616318, 52.33693775540547], [0.9129667554232033, 52.35039665032508], [1.0091783563619108, 52.36377039921126], [1.1054502854394455, 52.377058910420786], [1.2017822212301215, 52.39026209276701], [1.2981738407476442, 52.40337985552318], [1.3946248194311914, 52.41641210842495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3513&lt;dd&gt;Latitude: 1.3946248&lt;dd&gt;Longitude: 52.416412&lt;dd&gt;Azimuth: 67.241036\u00b0&lt;dd&gt;Altitude: 59.257807\u00b0&lt;dd&gt;Slant Range: 625.58809km&quot;, &quot;name&quot;: &quot;STARLINK-3513&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3946248194311914, 52.41641210842495]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 0.73764292&lt;dd&gt;Longitude: 52.547479&lt;dd&gt;Azimuth: 60.843696\u00b0&lt;dd&gt;Altitude: 62.448974\u00b0&lt;dd&gt;Slant Range: 608.38171km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625], [0.8346880603329208, 52.53532695198637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 0.83468806&lt;dd&gt;Longitude: 52.535327&lt;dd&gt;Azimuth: 61.74167\u00b0&lt;dd&gt;Altitude: 61.958707\u00b0&lt;dd&gt;Slant Range: 610.86281km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8346880603329208, 52.53532695198637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625], [0.8346880603329208, 52.53532695198637], [0.9316771532244514, 52.52308888435058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 0.93167715&lt;dd&gt;Longitude: 52.523089&lt;dd&gt;Azimuth: 62.604194\u00b0&lt;dd&gt;Altitude: 61.466608\u00b0&lt;dd&gt;Slant Range: 613.41351km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9316771532244514, 52.52308888435058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625], [0.8346880603329208, 52.53532695198637], [0.9316771532244514, 52.52308888435058], [1.0286098556873307, 52.510764499913805]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.0286099&lt;dd&gt;Longitude: 52.510764&lt;dd&gt;Azimuth: 63.43297\u00b0&lt;dd&gt;Altitude: 60.973152\u00b0&lt;dd&gt;Slant Range: 616.03294km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0286098556873307, 52.510764499913805]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625], [0.8346880603329208, 52.53532695198637], [0.9316771532244514, 52.52308888435058], [1.0286098556873307, 52.510764499913805], [1.1254858290174456, 52.498353884788074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.1254858&lt;dd&gt;Longitude: 52.498354&lt;dd&gt;Azimuth: 64.229628\u00b0&lt;dd&gt;Altitude: 60.478783\u00b0&lt;dd&gt;Slant Range: 618.72023km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1254858290174456, 52.498353884788074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625], [0.8346880603329208, 52.53532695198637], [0.9316771532244514, 52.52308888435058], [1.0286098556873307, 52.510764499913805], [1.1254858290174456, 52.498353884788074], [1.222304736039971, 52.48585712557295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.2223047&lt;dd&gt;Longitude: 52.485857&lt;dd&gt;Azimuth: 64.995721\u00b0&lt;dd&gt;Altitude: 59.983912\u00b0&lt;dd&gt;Slant Range: 621.47448km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.222304736039971, 52.48585712557295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7376429172198539, 52.547478617200625], [0.8346880603329208, 52.53532695198637], [0.9316771532244514, 52.52308888435058], [1.0286098556873307, 52.510764499913805], [1.1254858290174456, 52.498353884788074], [1.222304736039971, 52.48585712557295], [1.3190662410921168, 52.47327430935402]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.3190662&lt;dd&gt;Longitude: 52.473274&lt;dd&gt;Azimuth: 65.732728\u00b0&lt;dd&gt;Altitude: 59.488924\u00b0&lt;dd&gt;Slant Range: 624.29482km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3190662410921168, 52.47327430935402]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8346880603329208, 52.53532695198637], [0.9316771532244514, 52.52308888435058], [1.0286098556873307, 52.510764499913805], [1.1254858290174456, 52.498353884788074], [1.222304736039971, 52.48585712557295], [1.3190662410921168, 52.47327430935402], [1.415770010055952, 52.460605523699]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.41577&lt;dd&gt;Longitude: 52.460606&lt;dd&gt;Azimuth: 66.442056\u00b0&lt;dd&gt;Altitude: 58.994175\u00b0&lt;dd&gt;Slant Range: 627.18035km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.415770010055952, 52.460605523699]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9316771532244514, 52.52308888435058], [1.0286098556873307, 52.510764499913805], [1.1254858290174456, 52.498353884788074], [1.222304736039971, 52.48585712557295], [1.3190662410921168, 52.47327430935402], [1.415770010055952, 52.460605523699], [1.5124157103326044, 52.447850856655705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.5124157&lt;dd&gt;Longitude: 52.447851&lt;dd&gt;Azimuth: 67.125041\u00b0&lt;dd&gt;Altitude: 58.499996\u00b0&lt;dd&gt;Slant Range: 630.13016km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5124157103326044, 52.447850856655705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0286098556873307, 52.510764499913805], [1.1254858290174456, 52.498353884788074], [1.222304736039971, 52.48585712557295], [1.3190662410921168, 52.47327430935402], [1.415770010055952, 52.460605523699], [1.5124157103326044, 52.447850856655705], [1.6090030108822075, 52.435010396748744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.609003&lt;dd&gt;Longitude: 52.43501&lt;dd&gt;Azimuth: 67.78295\u00b0&lt;dd&gt;Altitude: 58.006694\u00b0&lt;dd&gt;Slant Range: 633.14336km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6090030108822075, 52.435010396748744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1254858290174456, 52.498353884788074], [1.222304736039971, 52.48585712557295], [1.3190662410921168, 52.47327430935402], [1.415770010055952, 52.460605523699], [1.5124157103326044, 52.447850856655705], [1.6090030108822075, 52.435010396748744], [1.7055315821959887, 52.42208423297689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.7055316&lt;dd&gt;Longitude: 52.422084&lt;dd&gt;Azimuth: 68.416987\u00b0&lt;dd&gt;Altitude: 57.514554\u00b0&lt;dd&gt;Slant Range: 636.21905km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7055315821959887, 52.42208423297689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.222304736039971, 52.48585712557295], [1.3190662410921168, 52.47327430935402], [1.415770010055952, 52.460605523699], [1.5124157103326044, 52.447850856655705], [1.6090030108822075, 52.435010396748744], [1.7055315821959887, 52.42208423297689], [1.802001096332247, 52.40907245481027]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.8020011&lt;dd&gt;Longitude: 52.409072&lt;dd&gt;Azimuth: 69.028289\u00b0&lt;dd&gt;Altitude: 57.023839\u00b0&lt;dd&gt;Slant Range: 639.35631km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.802001096332247, 52.40907245481027]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3190662410921168, 52.47327430935402], [1.415770010055952, 52.460605523699], [1.5124157103326044, 52.447850856655705], [1.6090030108822075, 52.435010396748744], [1.7055315821959887, 52.42208423297689], [1.802001096332247, 52.40907245481027], [1.8984112268963544, 52.39597515218775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.8984112&lt;dd&gt;Longitude: 52.395975&lt;dd&gt;Azimuth: 69.617937\u00b0&lt;dd&gt;Altitude: 56.534792\u00b0&lt;dd&gt;Slant Range: 642.55425km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8984112268963544, 52.39597515218775]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.415770010055952, 52.460605523699], [1.5124157103326044, 52.447850856655705], [1.6090030108822075, 52.435010396748744], [1.7055315821959887, 52.42208423297689], [1.802001096332247, 52.40907245481027], [1.8984112268963544, 52.39597515218775], [1.9947616490605007, 52.38279241551337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 1.9947616&lt;dd&gt;Longitude: 52.382792&lt;dd&gt;Azimuth: 70.186951\u00b0&lt;dd&gt;Altitude: 56.047639\u00b0&lt;dd&gt;Slant Range: 645.81195km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9947616490605007, 52.38279241551337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5124157103326044, 52.447850856655705], [1.6090030108822075, 52.435010396748744], [1.7055315821959887, 52.42208423297689], [1.802001096332247, 52.40907245481027], [1.8984112268963544, 52.39597515218775], [1.9947616490605007, 52.38279241551337], [2.0910520395694685, 52.369524335654475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.091052&lt;dd&gt;Longitude: 52.369524&lt;dd&gt;Azimuth: 70.736298\u00b0&lt;dd&gt;Altitude: 55.562586\u00b0&lt;dd&gt;Slant Range: 649.12852km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0910520395694685, 52.369524335654475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6090030108822075, 52.435010396748744], [1.7055315821959887, 52.42208423297689], [1.802001096332247, 52.40907245481027], [1.8984112268963544, 52.39597515218775], [1.9947616490605007, 52.38279241551337], [2.0910520395694685, 52.369524335654475], [2.1872820767348835, 52.356171003938016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.1872821&lt;dd&gt;Longitude: 52.356171&lt;dd&gt;Azimuth: 71.266894\u00b0&lt;dd&gt;Altitude: 55.079825\u00b0&lt;dd&gt;Slant Range: 652.50305km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1872820767348835, 52.356171003938016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7055315821959887, 52.42208423297689], [1.802001096332247, 52.40907245481027], [1.8984112268963544, 52.39597515218775], [1.9947616490605007, 52.38279241551337], [2.0910520395694685, 52.369524335654475], [2.1872820767348835, 52.356171003938016], [2.2834514404525175, 52.34273251214814]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.2834514&lt;dd&gt;Longitude: 52.342733&lt;dd&gt;Azimuth: 71.779604\u00b0&lt;dd&gt;Altitude: 54.599531\u00b0&lt;dd&gt;Slant Range: 655.93465km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2834514404525175, 52.34273251214814]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.802001096332247, 52.40907245481027], [1.8984112268963544, 52.39597515218775], [1.9947616490605007, 52.38279241551337], [2.0910520395694685, 52.369524335654475], [2.1872820767348835, 52.356171003938016], [2.2834514404525175, 52.34273251214814], [2.3795598121965615, 52.32920895252318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.3795598&lt;dd&gt;Longitude: 52.329209&lt;dd&gt;Azimuth: 72.275248\u00b0&lt;dd&gt;Altitude: 54.121866\u00b0&lt;dd&gt;Slant Range: 659.42242km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3795598121965615, 52.32920895252318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8984112268963544, 52.39597515218775], [1.9947616490605007, 52.38279241551337], [2.0910520395694685, 52.369524335654475], [2.1872820767348835, 52.356171003938016], [2.2834514404525175, 52.34273251214814], [2.3795598121965615, 52.32920895252318], [2.4756068750335456, 52.31560041775299]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.4756069&lt;dd&gt;Longitude: 52.3156&lt;dd&gt;Azimuth: 72.7546\u00b0&lt;dd&gt;Altitude: 53.646976\u00b0&lt;dd&gt;Slant Range: 662.96546km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.4756068750335456, 52.31560041775299]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9947616490605007, 52.38279241551337], [2.0910520395694685, 52.369524335654475], [2.1872820767348835, 52.356171003938016], [2.2834514404525175, 52.34273251214814], [2.3795598121965615, 52.32920895252318], [2.4756068750335456, 52.31560041775299], [2.57159231362076, 52.30190700097538]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.5715923&lt;dd&gt;Longitude: 52.301907&lt;dd&gt;Azimuth: 73.218396\u00b0&lt;dd&gt;Altitude: 53.174997\u00b0&lt;dd&gt;Slant Range: 666.56291km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.57159231362076, 52.30190700097538]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0910520395694685, 52.369524335654475], [2.1872820767348835, 52.356171003938016], [2.2834514404525175, 52.34273251214814], [2.3795598121965615, 52.32920895252318], [2.4756068750335456, 52.31560041775299], [2.57159231362076, 52.30190700097538], [2.66751581421478, 52.28812879577421]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.6675158&lt;dd&gt;Longitude: 52.288129&lt;dd&gt;Azimuth: 73.667329\u00b0&lt;dd&gt;Altitude: 52.706051\u00b0&lt;dd&gt;Slant Range: 670.21386km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.66751581421478, 52.28812879577421]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1872820767348835, 52.356171003938016], [2.2834514404525175, 52.34273251214814], [2.3795598121965615, 52.32920895252318], [2.4756068750335456, 52.31560041775299], [2.57159231362076, 52.30190700097538], [2.66751581421478, 52.28812879577421], [2.763377064669481, 52.2742658961758]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.7633771&lt;dd&gt;Longitude: 52.274266&lt;dd&gt;Azimuth: 74.102057\u00b0&lt;dd&gt;Altitude: 52.240251\u00b0&lt;dd&gt;Slant Range: 673.91746km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.763377064669481, 52.2742658961758]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2834514404525175, 52.34273251214814], [2.3795598121965615, 52.32920895252318], [2.4756068750335456, 52.31560041775299], [2.57159231362076, 52.30190700097538], [2.66751581421478, 52.28812879577421], [2.763377064669481, 52.2742658961758], [2.859175754454384, 52.26031839664609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.8591758&lt;dd&gt;Longitude: 52.260318&lt;dd&gt;Azimuth: 74.523204\u00b0&lt;dd&gt;Altitude: 51.777697\u00b0&lt;dd&gt;Slant Range: 677.67284km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.859175754454384, 52.26031839664609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3795598121965615, 52.32920895252318], [2.4756068750335456, 52.31560041775299], [2.57159231362076, 52.30190700097538], [2.66751581421478, 52.28812879577421], [2.763377064669481, 52.2742658961758], [2.859175754454384, 52.26031839664609], [2.9549115746415, 52.24628639208809]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 2.9549116&lt;dd&gt;Longitude: 52.246286&lt;dd&gt;Azimuth: 74.931358\u00b0&lt;dd&gt;Altitude: 51.318482\u00b0&lt;dd&gt;Slant Range: 681.47913km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9549115746415, 52.24628639208809]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.4756068750335456, 52.31560041775299], [2.57159231362076, 52.30190700097538], [2.66751581421478, 52.28812879577421], [2.763377064669481, 52.2742658961758], [2.859175754454384, 52.26031839664609], [2.9549115746415, 52.24628639208809], [3.050584217919935, 52.232169977838474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.0505842&lt;dd&gt;Longitude: 52.23217&lt;dd&gt;Azimuth: 75.327079\u00b0&lt;dd&gt;Altitude: 50.862686\u00b0&lt;dd&gt;Slant Range: 685.33548km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.050584217919935, 52.232169977838474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.57159231362076, 52.30190700097538], [2.66751581421478, 52.28812879577421], [2.763377064669481, 52.2742658961758], [2.859175754454384, 52.26031839664609], [2.9549115746415, 52.24628639208809], [3.050584217919935, 52.232169977838474], [3.14619337860139, 52.2179692496649]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.1461934&lt;dd&gt;Longitude: 52.217969&lt;dd&gt;Azimuth: 75.710897\u00b0&lt;dd&gt;Altitude: 50.410384\u00b0&lt;dd&gt;Slant Range: 689.24104km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.14619337860139, 52.2179692496649]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.66751581421478, 52.28812879577421], [2.763377064669481, 52.2742658961758], [2.859175754454384, 52.26031839664609], [2.9549115746415, 52.24628639208809], [3.050584217919935, 52.232169977838474], [3.14619337860139, 52.2179692496649], [3.241738752616872, 52.203684303763595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.2417388&lt;dd&gt;Longitude: 52.203684&lt;dd&gt;Azimuth: 76.083314\u00b0&lt;dd&gt;Altitude: 49.961641\u00b0&lt;dd&gt;Slant Range: 693.19499km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.241738752616872, 52.203684303763595]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.763377064669481, 52.2742658961758], [2.859175754454384, 52.26031839664609], [2.9549115746415, 52.24628639208809], [3.050584217919935, 52.232169977838474], [3.14619337860139, 52.2179692496649], [3.241738752616872, 52.203684303763595], [3.3372200375257064, 52.18931523675506]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.33722&lt;dd&gt;Longitude: 52.189315&lt;dd&gt;Azimuth: 76.444806\u00b0&lt;dd&gt;Altitude: 49.516516\u00b0&lt;dd&gt;Slant Range: 697.1965km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3372200375257064, 52.18931523675506]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.859175754454384, 52.26031839664609], [2.9549115746415, 52.24628639208809], [3.050584217919935, 52.232169977838474], [3.14619337860139, 52.2179692496649], [3.241738752616872, 52.203684303763595], [3.3372200375257064, 52.18931523675506], [3.4326369325235246, 52.174862145682745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.4326369&lt;dd&gt;Longitude: 52.174862&lt;dd&gt;Azimuth: 76.795826\u00b0&lt;dd&gt;Altitude: 49.075058\u00b0&lt;dd&gt;Slant Range: 701.24473km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4326369325235246, 52.174862145682745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9549115746415, 52.24628639208809], [3.050584217919935, 52.232169977838474], [3.14619337860139, 52.2179692496649], [3.241738752616872, 52.203684303763595], [3.3372200375257064, 52.18931523675506], [3.4326369325235246, 52.174862145682745], [3.5279891384306876, 52.16032512800896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.5279891&lt;dd&gt;Longitude: 52.160325&lt;dd&gt;Azimuth: 77.136801\u00b0&lt;dd&gt;Altitude: 48.637312\u00b0&lt;dd&gt;Slant Range: 705.3389km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5279891384306876, 52.16032512800896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.050584217919935, 52.232169977838474], [3.14619337860139, 52.2179692496649], [3.241738752616872, 52.203684303763595], [3.3372200375257064, 52.18931523675506], [3.4326369325235246, 52.174862145682745], [3.5279891384306876, 52.16032512800896], [3.623276357716355, 52.14570428161227]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.6232764&lt;dd&gt;Longitude: 52.145704&lt;dd&gt;Azimuth: 77.46814\u00b0&lt;dd&gt;Altitude: 48.203316\u00b0&lt;dd&gt;Slant Range: 709.47819km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.623276357716355, 52.14570428161227]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.14619337860139, 52.2179692496649], [3.241738752616872, 52.203684303763595], [3.3372200375257064, 52.18931523675506], [3.4326369325235246, 52.174862145682745], [3.5279891384306876, 52.16032512800896], [3.623276357716355, 52.14570428161227], [3.718498294483296, 52.13099970478481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.7184983&lt;dd&gt;Longitude: 52.131&lt;dd&gt;Azimuth: 77.790229\u00b0&lt;dd&gt;Altitude: 47.773102\u00b0&lt;dd&gt;Slant Range: 713.66182km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.718498294483296, 52.13099970478481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.241738752616872, 52.203684303763595], [3.3372200375257064, 52.18931523675506], [3.4326369325235246, 52.174862145682745], [3.5279891384306876, 52.16032512800896], [3.623276357716355, 52.14570428161227], [3.718498294483296, 52.13099970478481], [3.813654654490815, 52.11621149622895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.8136547&lt;dd&gt;Longitude: 52.116211&lt;dd&gt;Azimuth: 78.103436\u00b0&lt;dd&gt;Altitude: 47.346696\u00b0&lt;dd&gt;Slant Range: 717.88901km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.813654654490815, 52.11621149622895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.3372200375257064, 52.18931523675506], [3.4326369325235246, 52.174862145682745], [3.5279891384306876, 52.16032512800896], [3.623276357716355, 52.14570428161227], [3.718498294483296, 52.13099970478481], [3.813654654490815, 52.11621149622895], [3.9087451451353874, 52.1013397550545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 3.9087451&lt;dd&gt;Longitude: 52.10134&lt;dd&gt;Azimuth: 78.40811\u00b0&lt;dd&gt;Altitude: 46.92412\u00b0&lt;dd&gt;Slant Range: 722.15898km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9087451451353874, 52.1013397550545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4326369325235246, 52.174862145682745], [3.5279891384306876, 52.16032512800896], [3.623276357716355, 52.14570428161227], [3.718498294483296, 52.13099970478481], [3.813654654490815, 52.11621149622895], [3.9087451451353874, 52.1013397550545], [4.003769475473738, 52.08638458077588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.0037695&lt;dd&gt;Longitude: 52.086385&lt;dd&gt;Azimuth: 78.704583\u00b0&lt;dd&gt;Altitude: 46.505391\u00b0&lt;dd&gt;Slant Range: 726.47099km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.003769475473738, 52.08638458077588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5279891384306876, 52.16032512800896], [3.623276357716355, 52.14570428161227], [3.718498294483296, 52.13099970478481], [3.813654654490815, 52.11621149622895], [3.9087451451353874, 52.1013397550545], [4.003769475473738, 52.08638458077588], [4.098727356216709, 52.07134607330853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.0987274&lt;dd&gt;Longitude: 52.071346&lt;dd&gt;Azimuth: 78.993172\u00b0&lt;dd&gt;Altitude: 46.090521\u00b0&lt;dd&gt;Slant Range: 730.82427km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.098727356216709, 52.07134607330853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.623276357716355, 52.14570428161227], [3.718498294483296, 52.13099970478481], [3.813654654490815, 52.11621149622895], [3.9087451451353874, 52.1013397550545], [4.003769475473738, 52.08638458077588], [4.098727356216709, 52.07134607330853], [4.193618499733484, 52.05622433296712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.1936185&lt;dd&gt;Longitude: 52.056224&lt;dd&gt;Azimuth: 79.274177\u00b0&lt;dd&gt;Altitude: 45.679519\u00b0&lt;dd&gt;Slant Range: 735.2181km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.193618499733484, 52.05622433296712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.718498294483296, 52.13099970478481], [3.813654654490815, 52.11621149622895], [3.9087451451353874, 52.1013397550545], [4.003769475473738, 52.08638458077588], [4.098727356216709, 52.07134607330853], [4.193618499733484, 52.05622433296712], [4.288442620053318, 52.04101946046121]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.2884426&lt;dd&gt;Longitude: 52.041019&lt;dd&gt;Azimuth: 79.547886\u00b0&lt;dd&gt;Altitude: 45.272388\u00b0&lt;dd&gt;Slant Range: 739.65174km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.288442620053318, 52.04101946046121]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.813654654490815, 52.11621149622895], [3.9087451451353874, 52.1013397550545], [4.003769475473738, 52.08638458077588], [4.098727356216709, 52.07134607330853], [4.193618499733484, 52.05622433296712], [4.288442620053318, 52.04101946046121], [4.383199432875309, 52.025731556893376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.3831994&lt;dd&gt;Longitude: 52.025732&lt;dd&gt;Azimuth: 79.814569\u00b0&lt;dd&gt;Altitude: 44.869129\u00b0&lt;dd&gt;Slant Range: 744.12448km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.383199432875309, 52.025731556893376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9087451451353874, 52.1013397550545], [4.003769475473738, 52.08638458077588], [4.098727356216709, 52.07134607330853], [4.193618499733484, 52.05622433296712], [4.288442620053318, 52.04101946046121], [4.383199432875309, 52.025731556893376], [4.477888655567123, 52.01036072375528]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.4778887&lt;dd&gt;Longitude: 52.010361&lt;dd&gt;Azimuth: 80.074489\u00b0&lt;dd&gt;Altitude: 44.469741\u00b0&lt;dd&gt;Slant Range: 748.63561km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.477888655567123, 52.01036072375528]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.003769475473738, 52.08638458077588], [4.098727356216709, 52.07134607330853], [4.193618499733484, 52.05622433296712], [4.288442620053318, 52.04101946046121], [4.383199432875309, 52.025731556893376], [4.477888655567123, 52.01036072375528], [4.572510007154209, 51.99490706292592]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.57251&lt;dd&gt;Longitude: 51.994907&lt;dd&gt;Azimuth: 80.327892\u00b0&lt;dd&gt;Altitude: 44.074216\u00b0&lt;dd&gt;Slant Range: 753.18444km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.572510007154209, 51.99490706292592]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.098727356216709, 52.07134607330853], [4.193618499733484, 52.05622433296712], [4.288442620053318, 52.04101946046121], [4.383199432875309, 52.025731556893376], [4.477888655567123, 52.01036072375528], [4.572510007154209, 51.99490706292592], [4.667063208353689, 51.97937067666709]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.6670632&lt;dd&gt;Longitude: 51.979371&lt;dd&gt;Azimuth: 80.575016\u00b0&lt;dd&gt;Altitude: 43.682547\u00b0&lt;dd&gt;Slant Range: 757.77029km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.667063208353689, 51.97937067666709]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.193618499733484, 52.05622433296712], [4.288442620053318, 52.04101946046121], [4.383199432875309, 52.025731556893376], [4.477888655567123, 52.01036072375528], [4.572510007154209, 51.99490706292592], [4.667063208353689, 51.97937067666709], [4.761547981544104, 51.963751667621864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.761548&lt;dd&gt;Longitude: 51.963752&lt;dd&gt;Azimuth: 80.816085\u00b0&lt;dd&gt;Altitude: 43.294722\u00b0&lt;dd&gt;Slant Range: 762.39248km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.761547981544104, 51.963751667621864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.288442620053318, 52.04101946046121], [4.383199432875309, 52.025731556893376], [4.477888655567123, 52.01036072375528], [4.572510007154209, 51.99490706292592], [4.667063208353689, 51.97937067666709], [4.761547981544104, 51.963751667621864], [4.855964050791218, 51.948050138810345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.8559641&lt;dd&gt;Longitude: 51.94805&lt;dd&gt;Azimuth: 81.051316\u00b0&lt;dd&gt;Altitude: 42.910728\u00b0&lt;dd&gt;Slant Range: 767.05034km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.855964050791218, 51.948050138810345]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.383199432875309, 52.025731556893376], [4.477888655567123, 52.01036072375528], [4.572510007154209, 51.99490706292592], [4.667063208353689, 51.97937067666709], [4.761547981544104, 51.963751667621864], [4.855964050791218, 51.948050138810345], [4.950311141837961, 51.93226619362787]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 4.9503111&lt;dd&gt;Longitude: 51.932266&lt;dd&gt;Azimuth: 81.280913\u00b0&lt;dd&gt;Altitude: 42.530548\u00b0&lt;dd&gt;Slant Range: 771.74324km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.950311141837961, 51.93226619362787]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.477888655567123, 52.01036072375528], [4.572510007154209, 51.99490706292592], [4.667063208353689, 51.97937067666709], [4.761547981544104, 51.963751667621864], [4.855964050791218, 51.948050138810345], [4.950311141837961, 51.93226619362787], [5.044588982110392, 51.91639993584106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.044589&lt;dd&gt;Longitude: 51.9164&lt;dd&gt;Azimuth: 81.505074\u00b0&lt;dd&gt;Altitude: 42.154164\u00b0&lt;dd&gt;Slant Range: 776.47052km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.044588982110392, 51.91639993584106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.572510007154209, 51.99490706292592], [4.667063208353689, 51.97937067666709], [4.761547981544104, 51.963751667621864], [4.855964050791218, 51.948050138810345], [4.950311141837961, 51.93226619362787], [5.044588982110392, 51.91639993584106], [5.138797300719168, 51.90045146958508]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.1387973&lt;dd&gt;Longitude: 51.900451&lt;dd&gt;Azimuth: 81.723985\u00b0&lt;dd&gt;Altitude: 41.781557\u00b0&lt;dd&gt;Slant Range: 781.23156km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.138797300719168, 51.90045146958508]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.667063208353689, 51.97937067666709], [4.761547981544104, 51.963751667621864], [4.855964050791218, 51.948050138810345], [4.950311141837961, 51.93226619362787], [5.044588982110392, 51.91639993584106], [5.138797300719168, 51.90045146958508], [5.232935828469008, 51.884420899360855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.2329358&lt;dd&gt;Longitude: 51.884421&lt;dd&gt;Azimuth: 81.937827\u00b0&lt;dd&gt;Altitude: 41.412704\u00b0&lt;dd&gt;Slant Range: 786.02575km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.232935828469008, 51.884420899360855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.761547981544104, 51.963751667621864], [4.855964050791218, 51.948050138810345], [4.950311141837961, 51.93226619362787], [5.044588982110392, 51.91639993584106], [5.138797300719168, 51.90045146958508], [5.232935828469008, 51.884420899360855], [5.327004297843766, 51.86830833003242]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.3270043&lt;dd&gt;Longitude: 51.868308&lt;dd&gt;Azimuth: 82.146771\u00b0&lt;dd&gt;Altitude: 41.047582\u00b0&lt;dd&gt;Slant Range: 790.85246km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.327004297843766, 51.86830833003242]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.855964050791218, 51.948050138810345], [4.950311141837961, 51.93226619362787], [5.044588982110392, 51.91639993584106], [5.138797300719168, 51.90045146958508], [5.232935828469008, 51.884420899360855], [5.327004297843766, 51.86830833003242], [5.421002443031178, 51.85211386682248]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.4210024&lt;dd&gt;Longitude: 51.852114&lt;dd&gt;Azimuth: 82.350982\u00b0&lt;dd&gt;Altitude: 40.686165\u00b0&lt;dd&gt;Slant Range: 795.71111km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.421002443031178, 51.85211386682248]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.950311141837961, 51.93226619362787], [5.044588982110392, 51.91639993584106], [5.138797300719168, 51.90045146958508], [5.232935828469008, 51.884420899360855], [5.327004297843766, 51.86830833003242], [5.421002443031178, 51.85211386682248], [5.5149299998984675, 51.8358376153112]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.51493&lt;dd&gt;Longitude: 51.835838&lt;dd&gt;Azimuth: 82.550616\u00b0&lt;dd&gt;Altitude: 40.328428\u00b0&lt;dd&gt;Slant Range: 800.60111km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.5149299998984675, 51.8358376153112]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.044588982110392, 51.91639993584106], [5.138797300719168, 51.90045146958508], [5.232935828469008, 51.884420899360855], [5.327004297843766, 51.86830833003242], [5.421002443031178, 51.85211386682248], [5.5149299998984675, 51.8358376153112], [5.608786706023564, 51.8194796814319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.6087867&lt;dd&gt;Longitude: 51.81948&lt;dd&gt;Azimuth: 82.745824\u00b0&lt;dd&gt;Altitude: 39.974342\u00b0&lt;dd&gt;Slant Range: 805.52188km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.608786706023564, 51.8194796814319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.138797300719168, 51.90045146958508], [5.232935828469008, 51.884420899360855], [5.327004297843766, 51.86830833003242], [5.421002443031178, 51.85211386682248], [5.5149299998984675, 51.8358376153112], [5.608786706023564, 51.8194796814319], [5.702572300669431, 51.803040171468766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.7025723&lt;dd&gt;Longitude: 51.80304&lt;dd&gt;Azimuth: 82.936751\u00b0&lt;dd&gt;Altitude: 39.623878\u00b0&lt;dd&gt;Slant Range: 810.47285km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.702572300669431, 51.803040171468766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.232935828469008, 51.884420899360855], [5.327004297843766, 51.86830833003242], [5.421002443031178, 51.85211386682248], [5.5149299998984675, 51.8358376153112], [5.608786706023564, 51.8194796814319], [5.702572300669431, 51.803040171468766], [5.796286524804694, 51.786519192053724]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.7962865&lt;dd&gt;Longitude: 51.786519&lt;dd&gt;Azimuth: 83.123535\u00b0&lt;dd&gt;Altitude: 39.277008\u00b0&lt;dd&gt;Slant Range: 815.45348km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.796286524804694, 51.786519192053724]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.327004297843766, 51.86830833003242], [5.421002443031178, 51.85211386682248], [5.5149299998984675, 51.8358376153112], [5.608786706023564, 51.8194796814319], [5.702572300669431, 51.803040171468766], [5.796286524804694, 51.786519192053724], [5.889929121093502, 51.769916850162836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.8899291&lt;dd&gt;Longitude: 51.769917&lt;dd&gt;Azimuth: 83.306308\u00b0&lt;dd&gt;Altitude: 38.933699\u00b0&lt;dd&gt;Slant Range: 820.46321km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.889929121093502, 51.769916850162836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.421002443031178, 51.85211386682248], [5.5149299998984675, 51.8358376153112], [5.608786706023564, 51.8194796814319], [5.702572300669431, 51.803040171468766], [5.796286524804694, 51.786519192053724], [5.889929121093502, 51.769916850162836], [5.983499833909609, 51.753233253114125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 5.9834998&lt;dd&gt;Longitude: 51.753233&lt;dd&gt;Azimuth: 83.485196\u00b0&lt;dd&gt;Altitude: 38.59392\u00b0&lt;dd&gt;Slant Range: 825.50151km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.983499833909609, 51.753233253114125]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.5149299998984675, 51.8358376153112], [5.608786706023564, 51.8194796814319], [5.702572300669431, 51.803040171468766], [5.796286524804694, 51.786519192053724], [5.889929121093502, 51.769916850162836], [5.983499833909609, 51.753233253114125], [6.07699840931832, 51.73646850856443]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 6.0769984&lt;dd&gt;Longitude: 51.736469&lt;dd&gt;Azimuth: 83.660323\u00b0&lt;dd&gt;Altitude: 38.257639\u00b0&lt;dd&gt;Slant Range: 830.56786km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.07699840931832, 51.73646850856443]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.608786706023564, 51.8194796814319], [5.702572300669431, 51.803040171468766], [5.796286524804694, 51.786519192053724], [5.889929121093502, 51.769916850162836], [5.983499833909609, 51.753233253114125], [6.07699840931832, 51.73646850856443], [6.1704245951037855, 51.71962272450551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 6.1704246&lt;dd&gt;Longitude: 51.719623&lt;dd&gt;Azimuth: 83.831806\u00b0&lt;dd&gt;Altitude: 37.924822\u00b0&lt;dd&gt;Slant Range: 835.66174km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.1704245951037855, 51.71962272450551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.702572300669431, 51.803040171468766], [5.796286524804694, 51.786519192053724], [5.889929121093502, 51.769916850162836], [5.983499833909609, 51.753233253114125], [6.07699840931832, 51.73646850856443], [6.1704245951037855, 51.71962272450551], [6.263778140742771, 51.702696009262404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 6.2637781&lt;dd&gt;Longitude: 51.702696&lt;dd&gt;Azimuth: 83.999755\u00b0&lt;dd&gt;Altitude: 37.595436\u00b0&lt;dd&gt;Slant Range: 840.78263km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.263778140742771, 51.702696009262404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.796286524804694, 51.786519192053724], [5.889929121093502, 51.769916850162836], [5.983499833909609, 51.753233253114125], [6.07699840931832, 51.73646850856443], [6.1704245951037855, 51.71962272450551], [6.263778140742771, 51.702696009262404], [6.357058797427099, 51.68568847148943]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 6.3570588&lt;dd&gt;Longitude: 51.685688&lt;dd&gt;Azimuth: 84.16428\u00b0&lt;dd&gt;Altitude: 37.269447\u00b0&lt;dd&gt;Slant Range: 845.93006km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.357058797427099, 51.68568847148943]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.889929121093502, 51.769916850162836], [5.983499833909609, 51.753233253114125], [6.07699840931832, 51.73646850856443], [6.1704245951037855, 51.71962272450551], [6.263778140742771, 51.702696009262404], [6.357058797427099, 51.68568847148943], [6.450266318051946, 51.66860022016744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4026&lt;dd&gt;Latitude: 6.4502663&lt;dd&gt;Longitude: 51.6686&lt;dd&gt;Azimuth: 84.325484\u00b0&lt;dd&gt;Altitude: 36.946819\u00b0&lt;dd&gt;Slant Range: 851.10352km&quot;, &quot;name&quot;: &quot;STARLINK-4026&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.450266318051946, 51.66860022016744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -11.488942&lt;dd&gt;Longitude: 52.766819&lt;dd&gt;Azimuth: 286.93187\u00b0&lt;dd&gt;Altitude: 37.063111\u00b0&lt;dd&gt;Slant Range: 849.37043km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013], [-11.390878747409806, 52.756354076538706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -11.390879&lt;dd&gt;Longitude: 52.756354&lt;dd&gt;Azimuth: 286.93158\u00b0&lt;dd&gt;Altitude: 37.398498\u00b0&lt;dd&gt;Slant Range: 844.01774km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.390878747409806, 52.756354076538706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013], [-11.390878747409806, 52.756354076538706], [-11.292864189769714, 52.74580166854359]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -11.292864&lt;dd&gt;Longitude: 52.745802&lt;dd&gt;Azimuth: 286.9312\u00b0&lt;dd&gt;Altitude: 37.737771\u00b0&lt;dd&gt;Slant Range: 838.68906km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.292864189769714, 52.74580166854359]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013], [-11.390878747409806, 52.756354076538706], [-11.292864189769714, 52.74580166854359], [-11.194899165381667, 52.73516137106256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -11.194899&lt;dd&gt;Longitude: 52.735161&lt;dd&gt;Azimuth: 286.93075\u00b0&lt;dd&gt;Altitude: 38.080987\u00b0&lt;dd&gt;Slant Range: 833.38487km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.194899165381667, 52.73516137106256]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013], [-11.390878747409806, 52.756354076538706], [-11.292864189769714, 52.74580166854359], [-11.194899165381667, 52.73516137106256], [-11.096984041101601, 52.72443326018431]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -11.096984&lt;dd&gt;Longitude: 52.724433&lt;dd&gt;Azimuth: 286.9302\u00b0&lt;dd&gt;Altitude: 38.428205\u00b0&lt;dd&gt;Slant Range: 828.10563km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.096984041101601, 52.72443326018431]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013], [-11.390878747409806, 52.756354076538706], [-11.292864189769714, 52.74580166854359], [-11.194899165381667, 52.73516137106256], [-11.096984041101601, 52.72443326018431], [-10.999119182404282, 52.71361741253843]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.999119&lt;dd&gt;Longitude: 52.713617&lt;dd&gt;Azimuth: 286.92957\u00b0&lt;dd&gt;Altitude: 38.77948\u00b0&lt;dd&gt;Slant Range: 822.85184km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.999119182404282, 52.71361741253843]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.488942470070779, 52.7668185195013], [-11.390878747409806, 52.756354076538706], [-11.292864189769714, 52.74580166854359], [-11.194899165381667, 52.73516137106256], [-11.096984041101601, 52.72443326018431], [-10.999119182404282, 52.71361741253843], [-10.901304953365184, 52.70271390529155]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.901305&lt;dd&gt;Longitude: 52.702714&lt;dd&gt;Azimuth: 286.92885\u00b0&lt;dd&gt;Altitude: 39.134871\u00b0&lt;dd&gt;Slant Range: 817.62399km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.901304953365184, 52.70271390529155]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.390878747409806, 52.756354076538706], [-11.292864189769714, 52.74580166854359], [-11.194899165381667, 52.73516137106256], [-11.096984041101601, 52.72443326018431], [-10.999119182404282, 52.71361741253843], [-10.901304953365184, 52.70271390529155], [-10.803541716659854, 52.69172281614544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.803542&lt;dd&gt;Longitude: 52.691723&lt;dd&gt;Azimuth: 286.92804\u00b0&lt;dd&gt;Altitude: 39.494437\u00b0&lt;dd&gt;Slant Range: 812.42259km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.803541716659854, 52.69172281614544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.292864189769714, 52.74580166854359], [-11.194899165381667, 52.73516137106256], [-11.096984041101601, 52.72443326018431], [-10.999119182404282, 52.71361741253843], [-10.901304953365184, 52.70271390529155], [-10.803541716659854, 52.69172281614544], [-10.705829833561237, 52.680644223334404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.70583&lt;dd&gt;Longitude: 52.680644&lt;dd&gt;Azimuth: 286.92713\u00b0&lt;dd&gt;Altitude: 39.858237\u00b0&lt;dd&gt;Slant Range: 807.24815km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.705829833561237, 52.680644223334404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.194899165381667, 52.73516137106256], [-11.096984041101601, 52.72443326018431], [-10.999119182404282, 52.71361741253843], [-10.901304953365184, 52.70271390529155], [-10.803541716659854, 52.69172281614544], [-10.705829833561237, 52.680644223334404], [-10.60816966391312, 52.669478205622205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.60817&lt;dd&gt;Longitude: 52.669478&lt;dd&gt;Azimuth: 286.92611\u00b0&lt;dd&gt;Altitude: 40.226329\u00b0&lt;dd&gt;Slant Range: 802.10121km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.60816966391312, 52.669478205622205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.096984041101601, 52.72443326018431], [-10.999119182404282, 52.71361741253843], [-10.901304953365184, 52.70271390529155], [-10.803541716659854, 52.69172281614544], [-10.705829833561237, 52.680644223334404], [-10.60816966391312, 52.669478205622205], [-10.510561566155769, 52.658224842300015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.510562&lt;dd&gt;Longitude: 52.658225&lt;dd&gt;Azimuth: 286.92499\u00b0&lt;dd&gt;Altitude: 40.598774\u00b0&lt;dd&gt;Slant Range: 796.9823km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.510561566155769, 52.658224842300015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.999119182404282, 52.71361741253843], [-10.901304953365184, 52.70271390529155], [-10.803541716659854, 52.69172281614544], [-10.705829833561237, 52.680644223334404], [-10.60816966391312, 52.669478205622205], [-10.510561566155769, 52.658224842300015], [-10.413005897280568, 52.64688421318354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.413006&lt;dd&gt;Longitude: 52.646884&lt;dd&gt;Azimuth: 286.92376\u00b0&lt;dd&gt;Altitude: 40.975632\u00b0&lt;dd&gt;Slant Range: 791.89197km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.413005897280568, 52.64688421318354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.901304953365184, 52.70271390529155], [-10.803541716659854, 52.69172281614544], [-10.705829833561237, 52.680644223334404], [-10.60816966391312, 52.669478205622205], [-10.510561566155769, 52.658224842300015], [-10.413005897280568, 52.64688421318354], [-10.315503012853766, 52.63545639861035]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.315503&lt;dd&gt;Longitude: 52.635456&lt;dd&gt;Azimuth: 286.92242\u00b0&lt;dd&gt;Altitude: 41.356961\u00b0&lt;dd&gt;Slant Range: 786.83078km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.315503012853766, 52.63545639861035]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.803541716659854, 52.69172281614544], [-10.705829833561237, 52.680644223334404], [-10.60816966391312, 52.669478205622205], [-10.510561566155769, 52.658224842300015], [-10.413005897280568, 52.64688421318354], [-10.315503012853766, 52.63545639861035], [-10.218053266988036, 52.6239414794371]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.218053&lt;dd&gt;Longitude: 52.623941&lt;dd&gt;Azimuth: 286.92096\u00b0&lt;dd&gt;Altitude: 41.742824\u00b0&lt;dd&gt;Slant Range: 781.79931km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.218053266988036, 52.6239414794371]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.705829833561237, 52.680644223334404], [-10.60816966391312, 52.669478205622205], [-10.510561566155769, 52.658224842300015], [-10.413005897280568, 52.64688421318354], [-10.315503012853766, 52.63545639861035], [-10.218053266988036, 52.6239414794371], [-10.120657012352622, 52.61233953703723]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.120657&lt;dd&gt;Longitude: 52.61234&lt;dd&gt;Azimuth: 286.91939\u00b0&lt;dd&gt;Altitude: 42.13328\u00b0&lt;dd&gt;Slant Range: 776.79813km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.120657012352622, 52.61233953703723]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.60816966391312, 52.669478205622205], [-10.510561566155769, 52.658224842300015], [-10.413005897280568, 52.64688421318354], [-10.315503012853766, 52.63545639861035], [-10.218053266988036, 52.6239414794371], [-10.120657012352622, 52.61233953703723], [-10.023314600150478, 52.60065065329776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -10.023315&lt;dd&gt;Longitude: 52.600651&lt;dd&gt;Azimuth: 286.91768\u00b0&lt;dd&gt;Altitude: 42.528391\u00b0&lt;dd&gt;Slant Range: 771.82784km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.023314600150478, 52.60065065329776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.510561566155769, 52.658224842300015], [-10.413005897280568, 52.64688421318354], [-10.315503012853766, 52.63545639861035], [-10.218053266988036, 52.6239414794371], [-10.120657012352622, 52.61233953703723], [-10.023314600150478, 52.60065065329776], [-9.926026380126872, 52.58887491061738]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.9260264&lt;dd&gt;Longitude: 52.588875&lt;dd&gt;Azimuth: 286.91585\u00b0&lt;dd&gt;Altitude: 42.928217\u00b0&lt;dd&gt;Slant Range: 766.88905km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.926026380126872, 52.58887491061738]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.413005897280568, 52.64688421318354], [-10.315503012853766, 52.63545639861035], [-10.218053266988036, 52.6239414794371], [-10.120657012352622, 52.61233953703723], [-10.023314600150478, 52.60065065329776], [-9.926026380126872, 52.58887491061738], [-9.82879270054753, 52.577012391902784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.8287927&lt;dd&gt;Longitude: 52.577012&lt;dd&gt;Azimuth: 286.91387\u00b0&lt;dd&gt;Altitude: 43.332818\u00b0&lt;dd&gt;Slant Range: 761.98237km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.82879270054753, 52.577012391902784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.315503012853766, 52.63545639861035], [-10.218053266988036, 52.6239414794371], [-10.120657012352622, 52.61233953703723], [-10.023314600150478, 52.60065065329776], [-9.926026380126872, 52.58887491061738], [-9.82879270054753, 52.577012391902784], [-9.731613908207361, 52.56506318056672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.7316139&lt;dd&gt;Longitude: 52.565063&lt;dd&gt;Azimuth: 286.91176\u00b0&lt;dd&gt;Altitude: 43.742257\u00b0&lt;dd&gt;Slant Range: 757.10845km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.731613908207361, 52.56506318056672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.218053266988036, 52.6239414794371], [-10.120657012352622, 52.61233953703723], [-10.023314600150478, 52.60065065329776], [-9.926026380126872, 52.58887491061738], [-9.82879270054753, 52.577012391902784], [-9.731613908207361, 52.56506318056672], [-9.634490348408601, 52.55302736052511]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.6344903&lt;dd&gt;Longitude: 52.553027&lt;dd&gt;Azimuth: 286.9095\u00b0&lt;dd&gt;Altitude: 44.156592\u00b0&lt;dd&gt;Slant Range: 752.26791km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.634490348408601, 52.55302736052511]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.120657012352622, 52.61233953703723], [-10.023314600150478, 52.60065065329776], [-9.926026380126872, 52.58887491061738], [-9.82879270054753, 52.577012391902784], [-9.731613908207361, 52.56506318056672], [-9.634490348408601, 52.55302736052511], [-9.537422364965598, 52.54090501619378]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.5374224&lt;dd&gt;Longitude: 52.540905&lt;dd&gt;Azimuth: 286.90709\u00b0&lt;dd&gt;Altitude: 44.575886\u00b0&lt;dd&gt;Slant Range: 747.46141km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.537422364965598, 52.54090501619378]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.023314600150478, 52.60065065329776], [-9.926026380126872, 52.58887491061738], [-9.82879270054753, 52.577012391902784], [-9.731613908207361, 52.56506318056672], [-9.634490348408601, 52.55302736052511], [-9.537422364965598, 52.54090501619378], [-9.44041030019761, 52.52869623248662]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.4404103&lt;dd&gt;Longitude: 52.528696&lt;dd&gt;Azimuth: 286.90452\u00b0&lt;dd&gt;Altitude: 45.000198\u00b0&lt;dd&gt;Slant Range: 742.68962km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.44041030019761, 52.52869623248662]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.926026380126872, 52.58887491061738], [-9.82879270054753, 52.577012391902784], [-9.731613908207361, 52.56506318056672], [-9.634490348408601, 52.55302736052511], [-9.537422364965598, 52.54090501619378], [-9.44041030019761, 52.52869623248662], [-9.343454494915044, 52.516401094812075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.3434545&lt;dd&gt;Longitude: 52.516401&lt;dd&gt;Azimuth: 286.90178\u00b0&lt;dd&gt;Altitude: 45.429587\u00b0&lt;dd&gt;Slant Range: 737.95321km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.343454494915044, 52.516401094812075]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.82879270054753, 52.577012391902784], [-9.731613908207361, 52.56506318056672], [-9.634490348408601, 52.55302736052511], [-9.537422364965598, 52.54090501619378], [-9.44041030019761, 52.52869623248662], [-9.343454494915044, 52.516401094812075], [-9.246555288418831, 52.50401968907078]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.2465553&lt;dd&gt;Longitude: 52.50402&lt;dd&gt;Azimuth: 286.89886\u00b0&lt;dd&gt;Altitude: 45.864114\u00b0&lt;dd&gt;Slant Range: 733.25289km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.246555288418831, 52.50401968907078]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.731613908207361, 52.56506318056672], [-9.634490348408601, 52.55302736052511], [-9.537422364965598, 52.54090501619378], [-9.44041030019761, 52.52869623248662], [-9.343454494915044, 52.516401094812075], [-9.246555288418831, 52.50401968907078], [-9.14971301849821, 52.4915521016526]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.149713&lt;dd&gt;Longitude: 52.491552&lt;dd&gt;Azimuth: 286.89577\u00b0&lt;dd&gt;Altitude: 46.303837\u00b0&lt;dd&gt;Slant Range: 728.58935km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.14971301849821, 52.4915521016526]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.634490348408601, 52.55302736052511], [-9.537422364965598, 52.54090501619378], [-9.44041030019761, 52.52869623248662], [-9.343454494915044, 52.516401094812075], [-9.246555288418831, 52.50401968907078], [-9.14971301849821, 52.4915521016526], [-9.052928021411185, 52.478998419434014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -9.052928&lt;dd&gt;Longitude: 52.478998&lt;dd&gt;Azimuth: 286.89249\u00b0&lt;dd&gt;Altitude: 46.748815\u00b0&lt;dd&gt;Slant Range: 723.9633km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.052928021411185, 52.478998419434014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.537422364965598, 52.54090501619378], [-9.44041030019761, 52.52869623248662], [-9.343454494915044, 52.516401094812075], [-9.246555288418831, 52.50401968907078], [-9.14971301849821, 52.4915521016526], [-9.052928021411185, 52.478998419434014], [-8.956200631895317, 52.466358729775024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.9562006&lt;dd&gt;Longitude: 52.466359&lt;dd&gt;Azimuth: 286.88901\u00b0&lt;dd&gt;Altitude: 47.199106\u00b0&lt;dd&gt;Slant Range: 719.37548km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.956200631895317, 52.466358729775024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.44041030019761, 52.52869623248662], [-9.343454494915044, 52.516401094812075], [-9.246555288418831, 52.50401968907078], [-9.14971301849821, 52.4915521016526], [-9.052928021411185, 52.478998419434014], [-8.956200631895317, 52.466358729775024], [-8.859531183155738, 52.45363312051696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.8595312&lt;dd&gt;Longitude: 52.453633&lt;dd&gt;Azimuth: 286.88533\u00b0&lt;dd&gt;Altitude: 47.654766\u00b0&lt;dd&gt;Slant Range: 714.82663km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.859531183155738, 52.45363312051696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.343454494915044, 52.516401094812075], [-9.246555288418831, 52.50401968907078], [-9.14971301849821, 52.4915521016526], [-9.052928021411185, 52.478998419434014], [-8.956200631895317, 52.466358729775024], [-8.859531183155738, 52.45363312051696], [-8.76292000684866, 52.44082167997903]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.76292&lt;dd&gt;Longitude: 52.440822&lt;dd&gt;Azimuth: 286.88143\u00b0&lt;dd&gt;Altitude: 48.115851\u00b0&lt;dd&gt;Slant Range: 710.31751km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.76292000684866, 52.44082167997903]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.246555288418831, 52.50401968907078], [-9.14971301849821, 52.4915521016526], [-9.052928021411185, 52.478998419434014], [-8.956200631895317, 52.466358729775024], [-8.859531183155738, 52.45363312051696], [-8.76292000684866, 52.44082167997903], [-8.666367433093695, 52.42792449695568]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.6663674&lt;dd&gt;Longitude: 52.427924&lt;dd&gt;Azimuth: 286.8773\u00b0&lt;dd&gt;Altitude: 48.582416\u00b0&lt;dd&gt;Slant Range: 705.84887km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.666367433093695, 52.42792449695568]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.14971301849821, 52.4915521016526], [-9.052928021411185, 52.478998419434014], [-8.956200631895317, 52.466358729775024], [-8.859531183155738, 52.45363312051696], [-8.76292000684866, 52.44082167997903], [-8.666367433093695, 52.42792449695568], [-8.569873790454562, 52.41494166071395]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.5698738&lt;dd&gt;Longitude: 52.414942&lt;dd&gt;Azimuth: 286.87294\u00b0&lt;dd&gt;Altitude: 49.054516\u00b0&lt;dd&gt;Slant Range: 701.4215km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.569873790454562, 52.41494166071395]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.052928021411185, 52.478998419434014], [-8.956200631895317, 52.466358729775024], [-8.859531183155738, 52.45363312051696], [-8.76292000684866, 52.44082167997903], [-8.666367433093695, 52.42792449695568], [-8.569873790454562, 52.41494166071395], [-8.473439405943601, 52.40187326099058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.4734394&lt;dd&gt;Longitude: 52.401873&lt;dd&gt;Azimuth: 286.86833\u00b0&lt;dd&gt;Altitude: 49.532203\u00b0&lt;dd&gt;Slant Range: 697.03619km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.473439405943601, 52.40187326099058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.956200631895317, 52.466358729775024], [-8.859531183155738, 52.45363312051696], [-8.76292000684866, 52.44082167997903], [-8.666367433093695, 52.42792449695568], [-8.569873790454562, 52.41494166071395], [-8.473439405943601, 52.40187326099058], [-8.377064605006442, 52.388719387989205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.3770646&lt;dd&gt;Longitude: 52.388719&lt;dd&gt;Azimuth: 286.86346\u00b0&lt;dd&gt;Altitude: 50.015527\u00b0&lt;dd&gt;Slant Range: 692.69374km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.377064605006442, 52.388719387989205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.859531183155738, 52.45363312051696], [-8.76292000684866, 52.44082167997903], [-8.666367433093695, 52.42792449695568], [-8.569873790454562, 52.41494166071395], [-8.473439405943601, 52.40187326099058], [-8.377064605006442, 52.388719387989205], [-8.2807497115295, 52.37548013237705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.2807497&lt;dd&gt;Longitude: 52.37548&lt;dd&gt;Azimuth: 286.85832\u00b0&lt;dd&gt;Altitude: 50.50454\u00b0&lt;dd&gt;Slant Range: 688.39497km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.2807497115295, 52.37548013237705]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.76292000684866, 52.44082167997903], [-8.666367433093695, 52.42792449695568], [-8.569873790454562, 52.41494166071395], [-8.473439405943601, 52.40187326099058], [-8.377064605006442, 52.388719387989205], [-8.2807497115295, 52.37548013237705], [-8.184495047817057, 52.362155585282814]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.184495&lt;dd&gt;Longitude: 52.362156&lt;dd&gt;Azimuth: 286.85289\u00b0&lt;dd&gt;Altitude: 50.999288\u00b0&lt;dd&gt;Slant Range: 684.14071km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.184495047817057, 52.362155585282814]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.666367433093695, 52.42792449695568], [-8.569873790454562, 52.41494166071395], [-8.473439405943601, 52.40187326099058], [-8.377064605006442, 52.388719387989205], [-8.2807497115295, 52.37548013237705], [-8.184495047817057, 52.362155585282814], [-8.088300934607089, 52.34874583829344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -8.0883009&lt;dd&gt;Longitude: 52.348746&lt;dd&gt;Azimuth: 286.84716\u00b0&lt;dd&gt;Altitude: 51.499818\u00b0&lt;dd&gt;Slant Range: 679.93179km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.088300934607089, 52.34874583829344]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.569873790454562, 52.41494166071395], [-8.473439405943601, 52.40187326099058], [-8.377064605006442, 52.388719387989205], [-8.2807497115295, 52.37548013237705], [-8.184495047817057, 52.362155585282814], [-8.088300934607089, 52.34874583829344], [-7.992167691047365, 52.33525098345114]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.9921677&lt;dd&gt;Longitude: 52.335251&lt;dd&gt;Azimuth: 286.84111\u00b0&lt;dd&gt;Altitude: 52.006174\u00b0&lt;dd&gt;Slant Range: 675.76908km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.992167691047365, 52.33525098345114]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.473439405943601, 52.40187326099058], [-8.377064605006442, 52.388719387989205], [-8.2807497115295, 52.37548013237705], [-8.184495047817057, 52.362155585282814], [-8.088300934607089, 52.34874583829344], [-7.992167691047365, 52.33525098345114], [-7.896095634708664, 52.32167111325054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.8960956&lt;dd&gt;Longitude: 52.321671&lt;dd&gt;Azimuth: 286.83473\u00b0&lt;dd&gt;Altitude: 52.518399\u00b0&lt;dd&gt;Slant Range: 671.65342km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.896095634708664, 52.32167111325054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.377064605006442, 52.388719387989205], [-8.2807497115295, 52.37548013237705], [-8.184495047817057, 52.362155585282814], [-8.088300934607089, 52.34874583829344], [-7.992167691047365, 52.33525098345114], [-7.896095634708664, 52.32167111325054], [-7.800085081559069, 52.30800632063605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.8000851&lt;dd&gt;Longitude: 52.308006&lt;dd&gt;Azimuth: 286.828\u00b0&lt;dd&gt;Altitude: 53.036532\u00b0&lt;dd&gt;Slant Range: 667.58571km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.800085081559069, 52.30800632063605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.2807497115295, 52.37548013237705], [-8.184495047817057, 52.362155585282814], [-8.088300934607089, 52.34874583829344], [-7.992167691047365, 52.33525098345114], [-7.896095634708664, 52.32167111325054], [-7.800085081559069, 52.30800632063605], [-7.7041363459801, 52.294256698998744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.7041363&lt;dd&gt;Longitude: 52.294257&lt;dd&gt;Azimuth: 286.82089\u00b0&lt;dd&gt;Altitude: 53.560611\u00b0&lt;dd&gt;Slant Range: 663.56683km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.7041363459801, 52.294256698998744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.184495047817057, 52.362155585282814], [-8.088300934607089, 52.34874583829344], [-7.992167691047365, 52.33525098345114], [-7.896095634708664, 52.32167111325054], [-7.800085081559069, 52.30800632063605], [-7.7041363459801, 52.294256698998744], [-7.608249740747809, 52.28042234217347]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.6082497&lt;dd&gt;Longitude: 52.280422&lt;dd&gt;Azimuth: 286.81339\u00b0&lt;dd&gt;Altitude: 54.09067\u00b0&lt;dd&gt;Slant Range: 659.59766km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.608249740747809, 52.28042234217347]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.088300934607089, 52.34874583829344], [-7.992167691047365, 52.33525098345114], [-7.896095634708664, 52.32167111325054], [-7.800085081559069, 52.30800632063605], [-7.7041363459801, 52.294256698998744], [-7.608249740747809, 52.28042234217347], [-7.512425577033927, 52.26650334443614]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.5124256&lt;dd&gt;Longitude: 52.266503&lt;dd&gt;Azimuth: 286.80548\u00b0&lt;dd&gt;Altitude: 54.626742\u00b0&lt;dd&gt;Slant Range: 655.67913km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.512425577033927, 52.26650334443614]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.992167691047365, 52.33525098345114], [-7.896095634708664, 52.32167111325054], [-7.800085081559069, 52.30800632063605], [-7.7041363459801, 52.294256698998744], [-7.608249740747809, 52.28042234217347], [-7.512425577033927, 52.26650334443614], [-7.416664164401636, 52.25249980050045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.4166642&lt;dd&gt;Longitude: 52.2525&lt;dd&gt;Azimuth: 286.79713\u00b0&lt;dd&gt;Altitude: 55.168856\u00b0&lt;dd&gt;Slant Range: 651.81214km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.416664164401636, 52.25249980050045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.896095634708664, 52.32167111325054], [-7.800085081559069, 52.30800632063605], [-7.7041363459801, 52.294256698998744], [-7.608249740747809, 52.28042234217347], [-7.512425577033927, 52.26650334443614], [-7.416664164401636, 52.25249980050045], [-7.32096581080494, 52.238411805515554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.3209658&lt;dd&gt;Longitude: 52.238412&lt;dd&gt;Azimuth: 286.78831\u00b0&lt;dd&gt;Altitude: 55.717037\u00b0&lt;dd&gt;Slant Range: 647.99763km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.32096581080494, 52.238411805515554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.800085081559069, 52.30800632063605], [-7.7041363459801, 52.294256698998744], [-7.608249740747809, 52.28042234217347], [-7.512425577033927, 52.26650334443614], [-7.416664164401636, 52.25249980050045], [-7.32096581080494, 52.238411805515554], [-7.2253308225687825, 52.224239455062424]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.2253308&lt;dd&gt;Longitude: 52.224239&lt;dd&gt;Azimuth: 286.77899\u00b0&lt;dd&gt;Altitude: 56.271309\u00b0&lt;dd&gt;Slant Range: 644.23653km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.2253308225687825, 52.224239455062424]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.7041363459801, 52.294256698998744], [-7.608249740747809, 52.28042234217347], [-7.512425577033927, 52.26650334443614], [-7.416664164401636, 52.25249980050045], [-7.32096581080494, 52.238411805515554], [-7.2253308225687825, 52.224239455062424], [-7.129759504407885, 52.209982845151536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.1297595&lt;dd&gt;Longitude: 52.209983&lt;dd&gt;Azimuth: 286.76915\u00b0&lt;dd&gt;Altitude: 56.831689\u00b0&lt;dd&gt;Slant Range: 640.52978km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.129759504407885, 52.209982845151536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.608249740747809, 52.28042234217347], [-7.512425577033927, 52.26650334443614], [-7.416664164401636, 52.25249980050045], [-7.32096581080494, 52.238411805515554], [-7.2253308225687825, 52.224239455062424], [-7.129759504407885, 52.209982845151536], [-7.034252159402621, 52.19564207221952]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -7.0342522&lt;dd&gt;Longitude: 52.195642&lt;dd&gt;Azimuth: 286.75875\u00b0&lt;dd&gt;Altitude: 57.398195\u00b0&lt;dd&gt;Slant Range: 636.87835km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.034252159402621, 52.19564207221952]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.512425577033927, 52.26650334443614], [-7.416664164401636, 52.25249980050045], [-7.32096581080494, 52.238411805515554], [-7.2253308225687825, 52.224239455062424], [-7.129759504407885, 52.209982845151536], [-7.034252159402621, 52.19564207221952], [-6.938809089010111, 52.1812172331265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.9388091&lt;dd&gt;Longitude: 52.181217&lt;dd&gt;Azimuth: 286.74776\u00b0&lt;dd&gt;Altitude: 57.970836\u00b0&lt;dd&gt;Slant Range: 633.28319km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.938809089010111, 52.1812172331265]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.416664164401636, 52.25249980050045], [-7.32096581080494, 52.238411805515554], [-7.2253308225687825, 52.224239455062424], [-7.129759504407885, 52.209982845151536], [-7.034252159402621, 52.19564207221952], [-6.938809089010111, 52.1812172331265], [-6.843430593047734, 52.166708425152954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.8434306&lt;dd&gt;Longitude: 52.166708&lt;dd&gt;Azimuth: 286.73613\u00b0&lt;dd&gt;Altitude: 58.54962\u00b0&lt;dd&gt;Slant Range: 629.74526km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.843430593047734, 52.166708425152954]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.32096581080494, 52.238411805515554], [-7.2253308225687825, 52.224239455062424], [-7.129759504407885, 52.209982845151536], [-7.034252159402621, 52.19564207221952], [-6.938809089010111, 52.1812172331265], [-6.843430593047734, 52.166708425152954], [-6.7481169697015755, 52.15211574599702]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.748117&lt;dd&gt;Longitude: 52.152116&lt;dd&gt;Azimuth: 286.72382\u00b0&lt;dd&gt;Altitude: 59.134549\u00b0&lt;dd&gt;Slant Range: 626.26555km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.7481169697015755, 52.15211574599702]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.2253308225687825, 52.224239455062424], [-7.129759504407885, 52.209982845151536], [-7.034252159402621, 52.19564207221952], [-6.938809089010111, 52.1812172331265], [-6.843430593047734, 52.166708425152954], [-6.7481169697015755, 52.15211574599702], [-6.652868515512761, 52.13743929377113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.6528685&lt;dd&gt;Longitude: 52.137439&lt;dd&gt;Azimuth: 286.71079\u00b0&lt;dd&gt;Altitude: 59.725623\u00b0&lt;dd&gt;Slant Range: 622.84503km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.652868515512761, 52.13743929377113]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.129759504407885, 52.209982845151536], [-7.034252159402621, 52.19564207221952], [-6.938809089010111, 52.1812172331265], [-6.843430593047734, 52.166708425152954], [-6.7481169697015755, 52.15211574599702], [-6.652868515512761, 52.13743929377113], [-6.557685525375757, 52.12267916699963]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.5576855&lt;dd&gt;Longitude: 52.122679&lt;dd&gt;Azimuth: 286.69698\u00b0&lt;dd&gt;Altitude: 60.322835\u00b0&lt;dd&gt;Slant Range: 619.48469km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.557685525375757, 52.12267916699963]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.034252159402621, 52.19564207221952], [-6.938809089010111, 52.1812172331265], [-6.843430593047734, 52.166708425152954], [-6.7481169697015755, 52.15211574599702], [-6.652868515512761, 52.13743929377113], [-6.557685525375757, 52.12267916699963], [-6.462568292541447, 52.10783546461515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.4625683&lt;dd&gt;Longitude: 52.107835&lt;dd&gt;Azimuth: 286.68234\u00b0&lt;dd&gt;Altitude: 60.926173\u00b0&lt;dd&gt;Slant Range: 616.18552km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.462568292541447, 52.10783546461515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.938809089010111, 52.1812172331265], [-6.843430593047734, 52.166708425152954], [-6.7481169697015755, 52.15211574599702], [-6.652868515512761, 52.13743929377113], [-6.557685525375757, 52.12267916699963], [-6.462568292541447, 52.10783546461515], [-6.367517108609189, 52.0929082859562]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.3675171&lt;dd&gt;Longitude: 52.092908&lt;dd&gt;Azimuth: 286.6668\u00b0&lt;dd&gt;Altitude: 61.53562\u00b0&lt;dd&gt;Slant Range: 612.9485km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.367517108609189, 52.0929082859562]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.843430593047734, 52.166708425152954], [-6.7481169697015755, 52.15211574599702], [-6.652868515512761, 52.13743929377113], [-6.557685525375757, 52.12267916699963], [-6.462568292541447, 52.10783546461515], [-6.367517108609189, 52.0929082859562], [-6.272532263521071, 52.07789773076396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.2725323&lt;dd&gt;Longitude: 52.077898&lt;dd&gt;Azimuth: 286.6503\u00b0&lt;dd&gt;Altitude: 62.151156\u00b0&lt;dd&gt;Slant Range: 609.77463km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.272532263521071, 52.07789773076396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.7481169697015755, 52.15211574599702], [-6.652868515512761, 52.13743929377113], [-6.557685525375757, 52.12267916699963], [-6.462568292541447, 52.10783546461515], [-6.367517108609189, 52.0929082859562], [-6.272532263521071, 52.07789773076396], [-6.177614045559719, 52.0628038991793]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.177614&lt;dd&gt;Longitude: 52.062804&lt;dd&gt;Azimuth: 286.63276\u00b0&lt;dd&gt;Altitude: 62.772751\u00b0&lt;dd&gt;Slant Range: 606.66491km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.177614045559719, 52.0628038991793]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.652868515512761, 52.13743929377113], [-6.557685525375757, 52.12267916699963], [-6.462568292541447, 52.10783546461515], [-6.367517108609189, 52.0929082859562], [-6.272532263521071, 52.07789773076396], [-6.177614045559719, 52.0628038991793], [-6.082762741354787, 52.04762689173971]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -6.0827627&lt;dd&gt;Longitude: 52.047627&lt;dd&gt;Azimuth: 286.61409\u00b0&lt;dd&gt;Altitude: 63.400374\u00b0&lt;dd&gt;Slant Range: 603.62033km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.082762741354787, 52.04762689173971]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.557685525375757, 52.12267916699963], [-6.462568292541447, 52.10783546461515], [-6.367517108609189, 52.0929082859562], [-6.272532263521071, 52.07789773076396], [-6.177614045559719, 52.0628038991793], [-6.082762741354787, 52.04762689173971], [-5.987978635863391, 52.032366809376924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -5.9879786&lt;dd&gt;Longitude: 52.032367&lt;dd&gt;Azimuth: 286.5942\u00b0&lt;dd&gt;Altitude: 64.033984\u00b0&lt;dd&gt;Slant Range: 600.64189km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.987978635863391, 52.032366809376924]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.462568292541447, 52.10783546461515], [-6.367517108609189, 52.0929082859562], [-6.272532263521071, 52.07789773076396], [-6.177614045559719, 52.0628038991793], [-6.082762741354787, 52.04762689173971], [-5.987978635863391, 52.032366809376924], [-5.893262012379215, 52.01702375341295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3988&lt;dd&gt;Latitude: -5.893262&lt;dd&gt;Longitude: 52.017024&lt;dd&gt;Azimuth: 286.57299\u00b0&lt;dd&gt;Altitude: 64.673536\u00b0&lt;dd&gt;Slant Range: 597.73057km&quot;, &quot;name&quot;: &quot;STARLINK-3988&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.893262012379215, 52.01702375341295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -4.0252877&lt;dd&gt;Longitude: 49.591855&lt;dd&gt;Azimuth: 206.46403\u00b0&lt;dd&gt;Altitude: 65.103706\u00b0&lt;dd&gt;Slant Range: 595.12558km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902], [-3.9403598352906073, 49.56727183328048]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.9403598&lt;dd&gt;Longitude: 49.567272&lt;dd&gt;Azimuth: 204.79527\u00b0&lt;dd&gt;Altitude: 65.109914\u00b0&lt;dd&gt;Slant Range: 595.09429km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9403598352906073, 49.56727183328048]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902], [-3.9403598352906073, 49.56727183328048], [-3.85552143102512, 49.54261998202625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.8555214&lt;dd&gt;Longitude: 49.54262&lt;dd&gt;Azimuth: 203.12698\u00b0&lt;dd&gt;Altitude: 65.097206\u00b0&lt;dd&gt;Slant Range: 595.14566km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.85552143102512, 49.54261998202625]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902], [-3.9403598352906073, 49.56727183328048], [-3.85552143102512, 49.54261998202625], [-3.770772600803338, 49.51789973281653]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.7707726&lt;dd&gt;Longitude: 49.5179&lt;dd&gt;Azimuth: 201.46199\u00b0&lt;dd&gt;Altitude: 65.065624\u00b0&lt;dd&gt;Slant Range: 595.27969km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.770772600803338, 49.51789973281653]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902], [-3.9403598352906073, 49.56727183328048], [-3.85552143102512, 49.54261998202625], [-3.770772600803338, 49.51789973281653], [-3.6861134233121073, 49.493111213068104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.6861134&lt;dd&gt;Longitude: 49.493111&lt;dd&gt;Azimuth: 199.8031\u00b0&lt;dd&gt;Altitude: 65.015273\u00b0&lt;dd&gt;Slant Range: 595.4963km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6861134233121073, 49.493111213068104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902], [-3.9403598352906073, 49.56727183328048], [-3.85552143102512, 49.54261998202625], [-3.770772600803338, 49.51789973281653], [-3.6861134233121073, 49.493111213068104], [-3.6015439757772296, 49.46825455023956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.601544&lt;dd&gt;Longitude: 49.468255&lt;dd&gt;Azimuth: 198.15304\u00b0&lt;dd&gt;Altitude: 64.946318\u00b0&lt;dd&gt;Slant Range: 595.79542km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6015439757772296, 49.46825455023956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.025287733465928, 49.59185515920902], [-3.9403598352906073, 49.56727183328048], [-3.85552143102512, 49.54261998202625], [-3.770772600803338, 49.51789973281653], [-3.6861134233121073, 49.493111213068104], [-3.6015439757772296, 49.46825455023956], [-3.517064333989135, 49.443329871831594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.5170643&lt;dd&gt;Longitude: 49.44333&lt;dd&gt;Azimuth: 196.51449\u00b0&lt;dd&gt;Altitude: 64.858985\u00b0&lt;dd&gt;Slant Range: 596.17692km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.517064333989135, 49.443329871831594]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9403598352906073, 49.56727183328048], [-3.85552143102512, 49.54261998202625], [-3.770772600803338, 49.51789973281653], [-3.6861134233121073, 49.493111213068104], [-3.6015439757772296, 49.46825455023956], [-3.517064333989135, 49.443329871831594], [-3.432674572284154, 49.41833730538274]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.4326746&lt;dd&gt;Longitude: 49.418337&lt;dd&gt;Azimuth: 194.88997\u00b0&lt;dd&gt;Altitude: 64.753555\u00b0&lt;dd&gt;Slant Range: 596.64064km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.432674572284154, 49.41833730538274]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.85552143102512, 49.54261998202625], [-3.770772600803338, 49.51789973281653], [-3.6861134233121073, 49.493111213068104], [-3.6015439757772296, 49.46825455023956], [-3.517064333989135, 49.443329871831594], [-3.432674572284154, 49.41833730538274], [-3.348374763577012, 49.39327697846819]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.3483748&lt;dd&gt;Longitude: 49.393277&lt;dd&gt;Azimuth: 193.28189\u00b0&lt;dd&gt;Altitude: 64.630365\u00b0&lt;dd&gt;Slant Range: 597.18638km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.348374763577012, 49.39327697846819]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.770772600803338, 49.51789973281653], [-3.6861134233121073, 49.493111213068104], [-3.6015439757772296, 49.46825455023956], [-3.517064333989135, 49.443329871831594], [-3.432674572284154, 49.41833730538274], [-3.348374763577012, 49.39327697846819], [-3.264164979336401, 49.36814901869729]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.264165&lt;dd&gt;Longitude: 49.368149&lt;dd&gt;Azimuth: 191.69251\u00b0&lt;dd&gt;Altitude: 64.489798\u00b0&lt;dd&gt;Slant Range: 597.81393km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.264164979336401, 49.36814901869729]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6861134233121073, 49.493111213068104], [-3.6015439757772296, 49.46825455023956], [-3.517064333989135, 49.443329871831594], [-3.432674572284154, 49.41833730538274], [-3.348374763577012, 49.39327697846819], [-3.264164979336401, 49.36814901869729], [-3.1800452896199407, 49.342953553711325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.1800453&lt;dd&gt;Longitude: 49.342954&lt;dd&gt;Azimuth: 190.12391\u00b0&lt;dd&gt;Altitude: 64.332285\u00b0&lt;dd&gt;Slant Range: 598.52303km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1800452896199407, 49.342953553711325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6015439757772296, 49.46825455023956], [-3.517064333989135, 49.443329871831594], [-3.432674572284154, 49.41833730538274], [-3.348374763577012, 49.39327697846819], [-3.264164979336401, 49.36814901869729], [-3.1800452896199407, 49.342953553711325], [-3.096015763050058, 49.31769071118116]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.0960158&lt;dd&gt;Longitude: 49.317691&lt;dd&gt;Azimuth: 188.57801\u00b0&lt;dd&gt;Altitude: 64.158297\u00b0&lt;dd&gt;Slant Range: 599.31338km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.096015763050058, 49.31769071118116]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.517064333989135, 49.443329871831594], [-3.432674572284154, 49.41833730538274], [-3.348374763577012, 49.39327697846819], [-3.264164979336401, 49.36814901869729], [-3.1800452896199407, 49.342953553711325], [-3.096015763050058, 49.31769071118116], [-3.0120764668442397, 49.29236061880586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -3.0120765&lt;dd&gt;Longitude: 49.292361&lt;dd&gt;Azimuth: 187.05652\u00b0&lt;dd&gt;Altitude: 63.968343\u00b0&lt;dd&gt;Slant Range: 600.18466km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0120764668442397, 49.29236061880586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.432674572284154, 49.41833730538274], [-3.348374763577012, 49.39327697846819], [-3.264164979336401, 49.36814901869729], [-3.1800452896199407, 49.342953553711325], [-3.096015763050058, 49.31769071118116], [-3.0120764668442397, 49.29236061880586], [-2.9282274668064563, 49.266963404309024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.9282275&lt;dd&gt;Longitude: 49.266963&lt;dd&gt;Azimuth: 185.56098\u00b0&lt;dd&gt;Altitude: 63.762959\u00b0&lt;dd&gt;Slant Range: 601.13652km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9282274668064563, 49.266963404309024]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.348374763577012, 49.39327697846819], [-3.264164979336401, 49.36814901869729], [-3.1800452896199407, 49.342953553711325], [-3.096015763050058, 49.31769071118116], [-3.0120764668442397, 49.29236061880586], [-2.9282274668064563, 49.266963404309024], [-2.844468827330906, 49.24149919543832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.8444688&lt;dd&gt;Longitude: 49.241499&lt;dd&gt;Azimuth: 184.09272\u00b0&lt;dd&gt;Altitude: 63.542713\u00b0&lt;dd&gt;Slant Range: 602.16858km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.844468827330906, 49.24149919543832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.264164979336401, 49.36814901869729], [-3.1800452896199407, 49.342953553711325], [-3.096015763050058, 49.31769071118116], [-3.0120764668442397, 49.29236061880586], [-2.9282274668064563, 49.266963404309024], [-2.844468827330906, 49.24149919543832], [-2.7608006114186763, 49.21596811996208]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.7608006&lt;dd&gt;Longitude: 49.215968&lt;dd&gt;Azimuth: 182.65289\u00b0&lt;dd&gt;Altitude: 63.30819\u00b0&lt;dd&gt;Slant Range: 603.28042km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7608006114186763, 49.21596811996208]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1800452896199407, 49.342953553711325], [-3.096015763050058, 49.31769071118116], [-3.0120764668442397, 49.29236061880586], [-2.9282274668064563, 49.266963404309024], [-2.844468827330906, 49.24149919543832], [-2.7608006114186763, 49.21596811996208], [-2.6772228806705733, 49.19037030566769]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.6772229&lt;dd&gt;Longitude: 49.19037&lt;dd&gt;Azimuth: 181.24244\u00b0&lt;dd&gt;Altitude: 63.059993\u00b0&lt;dd&gt;Slant Range: 604.47161km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6772228806705733, 49.19037030566769]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.096015763050058, 49.31769071118116], [-3.0120764668442397, 49.29236061880586], [-2.9282274668064563, 49.266963404309024], [-2.844468827330906, 49.24149919543832], [-2.7608006114186763, 49.21596811996208], [-2.6772228806705733, 49.19037030566769], [-2.5937356953021804, 49.16470588035931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.5937357&lt;dd&gt;Longitude: 49.164706&lt;dd&gt;Azimuth: 179.86216\u00b0&lt;dd&gt;Altitude: 62.798739\u00b0&lt;dd&gt;Slant Range: 605.74167km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5937356953021804, 49.16470588035931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0120764668442397, 49.29236061880586], [-2.9282274668064563, 49.266963404309024], [-2.844468827330906, 49.24149919543832], [-2.7608006114186763, 49.21596811996208], [-2.6772228806705733, 49.19037030566769], [-2.5937356953021804, 49.16470588035931], [-2.5103391141423352, 49.13897497185643]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.5103391&lt;dd&gt;Longitude: 49.138975&lt;dd&gt;Azimuth: 178.51264\u00b0&lt;dd&gt;Altitude: 62.525052\u00b0&lt;dd&gt;Slant Range: 607.0901km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5103391141423352, 49.13897497185643]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9282274668064563, 49.266963404309024], [-2.844468827330906, 49.24149919543832], [-2.7608006114186763, 49.21596811996208], [-2.6772228806705733, 49.19037030566769], [-2.5937356953021804, 49.16470588035931], [-2.5103391141423352, 49.13897497185643], [-2.427033194641575, 49.113177707989855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.4270332&lt;dd&gt;Longitude: 49.113178&lt;dd&gt;Azimuth: 177.19432\u00b0&lt;dd&gt;Altitude: 62.23956\u00b0&lt;dd&gt;Slant Range: 608.51639km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.427033194641575, 49.113177707989855]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.844468827330906, 49.24149919543832], [-2.7608006114186763, 49.21596811996208], [-2.6772228806705733, 49.19037030566769], [-2.5937356953021804, 49.16470588035931], [-2.5103391141423352, 49.13897497185643], [-2.427033194641575, 49.113177707989855], [-2.343817992876972, 49.087314216602415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.343818&lt;dd&gt;Longitude: 49.087314&lt;dd&gt;Azimuth: 175.90749\u00b0&lt;dd&gt;Altitude: 61.942893\u00b0&lt;dd&gt;Slant Range: 610.01999km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.343817992876972, 49.087314216602415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7608006114186763, 49.21596811996208], [-2.6772228806705733, 49.19037030566769], [-2.5937356953021804, 49.16470588035931], [-2.5103391141423352, 49.13897497185643], [-2.427033194641575, 49.113177707989855], [-2.343817992876972, 49.087314216602415], [-2.2606935635605034, 49.06138462554449]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.2606936&lt;dd&gt;Longitude: 49.061385&lt;dd&gt;Azimuth: 174.6523\u00b0&lt;dd&gt;Altitude: 61.635676\u00b0&lt;dd&gt;Slant Range: 611.60033km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2606935635605034, 49.06138462554449]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6772228806705733, 49.19037030566769], [-2.5937356953021804, 49.16470588035931], [-2.5103391141423352, 49.13897497185643], [-2.427033194641575, 49.113177707989855], [-2.343817992876972, 49.087314216602415], [-2.2606935635605034, 49.06138462554449], [-2.177659960034347, 49.03538906267324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.17766&lt;dd&gt;Longitude: 49.035389&lt;dd&gt;Azimuth: 173.42877\u00b0&lt;dd&gt;Altitude: 61.318529\u00b0&lt;dd&gt;Slant Range: 613.2568km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.177659960034347, 49.03538906267324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5937356953021804, 49.16470588035931], [-2.5103391141423352, 49.13897497185643], [-2.427033194641575, 49.113177707989855], [-2.343817992876972, 49.087314216602415], [-2.2606935635605034, 49.06138462554449], [-2.177659960034347, 49.03538906267324], [-2.094717234289604, 49.00932765584985]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.0947172&lt;dd&gt;Longitude: 49.009328&lt;dd&gt;Azimuth: 172.23679\u00b0&lt;dd&gt;Altitude: 60.992066\u00b0&lt;dd&gt;Slant Range: 614.9888km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.094717234289604, 49.00932765584985]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5103391141423352, 49.13897497185643], [-2.427033194641575, 49.113177707989855], [-2.343817992876972, 49.087314216602415], [-2.2606935635605034, 49.06138462554449], [-2.177659960034347, 49.03538906267324], [-2.094717234289604, 49.00932765584985], [-2.011865436965744, 48.98320053293818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -2.0118654&lt;dd&gt;Longitude: 48.983201&lt;dd&gt;Azimuth: 171.07615\u00b0&lt;dd&gt;Altitude: 60.656889\u00b0&lt;dd&gt;Slant Range: 616.79568km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.011865436965744, 48.98320053293818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.427033194641575, 49.113177707989855], [-2.343817992876972, 49.087314216602415], [-2.2606935635605034, 49.06138462554449], [-2.177659960034347, 49.03538906267324], [-2.094717234289604, 49.00932765584985], [-2.011865436965744, 48.98320053293818], [-1.9291046173516189, 48.9570078218018]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.9291046&lt;dd&gt;Longitude: 48.957008&lt;dd&gt;Azimuth: 169.94657\u00b0&lt;dd&gt;Altitude: 60.313586\u00b0&lt;dd&gt;Slant Range: 618.67679km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9291046173516189, 48.9570078218018]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.343817992876972, 49.087314216602415], [-2.2606935635605034, 49.06138462554449], [-2.177659960034347, 49.03538906267324], [-2.094717234289604, 49.00932765584985], [-2.011865436965744, 48.98320053293818], [-1.9291046173516189, 48.9570078218018], [-1.8464348233985177, 48.93074965030362]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.8464348&lt;dd&gt;Longitude: 48.93075&lt;dd&gt;Azimuth: 168.84767\u00b0&lt;dd&gt;Altitude: 59.962733\u00b0&lt;dd&gt;Slant Range: 620.63146km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8464348233985177, 48.93074965030362]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.2606935635605034, 49.06138462554449], [-2.177659960034347, 49.03538906267324], [-2.094717234289604, 49.00932765584985], [-2.011865436965744, 48.98320053293818], [-1.9291046173516189, 48.9570078218018], [-1.8464348233985177, 48.93074965030362], [-1.7638561017228385, 48.904426146301276]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.7638561&lt;dd&gt;Longitude: 48.904426&lt;dd&gt;Azimuth: 167.77899\u00b0&lt;dd&gt;Altitude: 59.60489\u00b0&lt;dd&gt;Slant Range: 622.65897km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7638561017228385, 48.904426146301276]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.177659960034347, 49.03538906267324], [-2.094717234289604, 49.00932765584985], [-2.011865436965744, 48.98320053293818], [-1.9291046173516189, 48.9570078218018], [-1.8464348233985177, 48.93074965030362], [-1.7638561017228385, 48.904426146301276], [-1.6813684976054764, 48.87803743764807]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.6813685&lt;dd&gt;Longitude: 48.878037&lt;dd&gt;Azimuth: 166.74002\u00b0&lt;dd&gt;Altitude: 59.240599\u00b0&lt;dd&gt;Slant Range: 624.75863km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6813684976054764, 48.87803743764807]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.094717234289604, 49.00932765584985], [-2.011865436965744, 48.98320053293818], [-1.9291046173516189, 48.9570078218018], [-1.8464348233985177, 48.93074965030362], [-1.7638561017228385, 48.904426146301276], [-1.6813684976054764, 48.87803743764807], [-1.5989720550116713, 48.85158365218839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.5989721&lt;dd&gt;Longitude: 48.851584&lt;dd&gt;Azimuth: 165.73022\u00b0&lt;dd&gt;Altitude: 58.870387\u00b0&lt;dd&gt;Slant Range: 626.92971km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5989720550116713, 48.85158365218839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.011865436965744, 48.98320053293818], [-1.9291046173516189, 48.9570078218018], [-1.8464348233985177, 48.93074965030362], [-1.7638561017228385, 48.904426146301276], [-1.6813684976054764, 48.87803743764807], [-1.5989720550116713, 48.85158365218839], [-1.5166668165811352, 48.82506491775783]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.5166668&lt;dd&gt;Longitude: 48.825065&lt;dd&gt;Azimuth: 164.74896\u00b0&lt;dd&gt;Altitude: 58.494761\u00b0&lt;dd&gt;Slant Range: 629.17146km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5166668165811352, 48.82506491775783]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9291046173516189, 48.9570078218018], [-1.8464348233985177, 48.93074965030362], [-1.7638561017228385, 48.904426146301276], [-1.6813684976054764, 48.87803743764807], [-1.5989720550116713, 48.85158365218839], [-1.5166668165811352, 48.82506491775783], [-1.4344528236463976, 48.79848136217985]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.4344528&lt;dd&gt;Longitude: 48.798481&lt;dd&gt;Azimuth: 163.79563\u00b0&lt;dd&gt;Altitude: 58.11421\u00b0&lt;dd&gt;Slant Range: 631.48314km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4344528236463976, 48.79848136217985]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8464348233985177, 48.93074965030362], [-1.7638561017228385, 48.904426146301276], [-1.6813684976054764, 48.87803743764807], [-1.5989720550116713, 48.85158365218839], [-1.5166668165811352, 48.82506491775783], [-1.4344528236463976, 48.79848136217985], [-1.352330116222424, 48.77183311326439]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.3523301&lt;dd&gt;Longitude: 48.771833&lt;dd&gt;Azimuth: 162.86955\u00b0&lt;dd&gt;Altitude: 57.729204\u00b0&lt;dd&gt;Slant Range: 633.86396km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.352330116222424, 48.77183311326439]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7638561017228385, 48.904426146301276], [-1.6813684976054764, 48.87803743764807], [-1.5989720550116713, 48.85158365218839], [-1.5166668165811352, 48.82506491775783], [-1.4344528236463976, 48.79848136217985], [-1.352330116222424, 48.77183311326439], [-1.2702987330343507, 48.74512029880564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.2702987&lt;dd&gt;Longitude: 48.74512&lt;dd&gt;Azimuth: 161.97004\u00b0&lt;dd&gt;Altitude: 57.340194\u00b0&lt;dd&gt;Slant Range: 636.31316km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2702987330343507, 48.74512029880564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6813684976054764, 48.87803743764807], [-1.5989720550116713, 48.85158365218839], [-1.5166668165811352, 48.82506491775783], [-1.4344528236463976, 48.79848136217985], [-1.352330116222424, 48.77183311326439], [-1.2702987330343507, 48.74512029880564], [-1.1883587115028535, 48.718343046580934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.1883587&lt;dd&gt;Longitude: 48.718343&lt;dd&gt;Azimuth: 161.09642\u00b0&lt;dd&gt;Altitude: 56.947611\u00b0&lt;dd&gt;Slant Range: 638.82995km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1883587115028535, 48.718343046580934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5989720550116713, 48.85158365218839], [-1.5166668165811352, 48.82506491775783], [-1.4344528236463976, 48.79848136217985], [-1.352330116222424, 48.77183311326439], [-1.2702987330343507, 48.74512029880564], [-1.1883587115028535, 48.718343046580934], [-1.1065100877610694, 48.69150148434719]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.1065101&lt;dd&gt;Longitude: 48.691501&lt;dd&gt;Azimuth: 160.24796\u00b0&lt;dd&gt;Altitude: 56.55187\u00b0&lt;dd&gt;Slant Range: 641.41352km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1065100877610694, 48.69150148434719]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5166668165811352, 48.82506491775783], [-1.4344528236463976, 48.79848136217985], [-1.352330116222424, 48.77183311326439], [-1.2702987330343507, 48.74512029880564], [-1.1883587115028535, 48.718343046580934], [-1.1065100877610694, 48.69150148434719], [-1.0247528966549775, 48.66459573984107]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -1.0247529&lt;dd&gt;Longitude: 48.664596&lt;dd&gt;Azimuth: 159.42397\u00b0&lt;dd&gt;Altitude: 56.153363\u00b0&lt;dd&gt;Slant Range: 644.06307km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0247528966549775, 48.66459573984107]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4344528236463976, 48.79848136217985], [-1.352330116222424, 48.77183311326439], [-1.2702987330343507, 48.74512029880564], [-1.1883587115028535, 48.718343046580934], [-1.1065100877610694, 48.69150148434719], [-1.0247528966549775, 48.66459573984107], [-0.9430871717554847, 48.63762594077534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.94308717&lt;dd&gt;Longitude: 48.637626&lt;dd&gt;Azimuth: 158.62373\u00b0&lt;dd&gt;Altitude: 55.752467\u00b0&lt;dd&gt;Slant Range: 646.77778km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9430871717554847, 48.63762594077534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.352330116222424, 48.77183311326439], [-1.2702987330343507, 48.74512029880564], [-1.1883587115028535, 48.718343046580934], [-1.1065100877610694, 48.69150148434719], [-1.0247528966549775, 48.66459573984107], [-0.9430871717554847, 48.63762594077534], [-0.8615129453530583, 48.61059221483808]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.86151295&lt;dd&gt;Longitude: 48.610592&lt;dd&gt;Azimuth: 157.84653\u00b0&lt;dd&gt;Altitude: 55.34954\u00b0&lt;dd&gt;Slant Range: 649.55685km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8615129453530583, 48.61059221483808]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2702987330343507, 48.74512029880564], [-1.1883587115028535, 48.718343046580934], [-1.1065100877610694, 48.69150148434719], [-1.0247528966549775, 48.66459573984107], [-0.9430871717554847, 48.63762594077534], [-0.8615129453530583, 48.61059221483808], [-0.7800302484715664, 48.58349468969002]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.78003025&lt;dd&gt;Longitude: 48.583495&lt;dd&gt;Azimuth: 157.09167\u00b0&lt;dd&gt;Altitude: 54.944922\u00b0&lt;dd&gt;Slant Range: 652.39943km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7800302484715664, 48.58349468969002]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1883587115028535, 48.718343046580934], [-1.1065100877610694, 48.69150148434719], [-1.0247528966549775, 48.66459573984107], [-0.9430871717554847, 48.63762594077534], [-0.8615129453530583, 48.61059221483808], [-0.7800302484715664, 48.58349468969002], [-0.6986391108830874, 48.55633349296405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.69863911&lt;dd&gt;Longitude: 48.556333&lt;dd&gt;Azimuth: 156.35847\u00b0&lt;dd&gt;Altitude: 54.538934\u00b0&lt;dd&gt;Slant Range: 655.30471km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6986391108830874, 48.55633349296405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1065100877610694, 48.69150148434719], [-1.0247528966549775, 48.66459573984107], [-0.9430871717554847, 48.63762594077534], [-0.8615129453530583, 48.61059221483808], [-0.7800302484715664, 48.58349468969002], [-0.6986391108830874, 48.55633349296405], [-0.6173395610854927, 48.52910875226093]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.61733956&lt;dd&gt;Longitude: 48.529109&lt;dd&gt;Azimuth: 155.64622\u00b0&lt;dd&gt;Altitude: 54.131884\u00b0&lt;dd&gt;Slant Range: 658.27184km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6173395610854927, 48.52910875226093]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0247528966549775, 48.66459573984107], [-0.9430871717554847, 48.63762594077534], [-0.8615129453530583, 48.61059221483808], [-0.7800302484715664, 48.58349468969002], [-0.6986391108830874, 48.55633349296405], [-0.6173395610854927, 48.52910875226093], [-0.5361316263412251, 48.5018205951507]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.53613163&lt;dd&gt;Longitude: 48.501821&lt;dd&gt;Azimuth: 154.95428\u00b0&lt;dd&gt;Altitude: 53.72406\u00b0&lt;dd&gt;Slant Range: 661.3km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5361316263412251, 48.5018205951507]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9430871717554847, 48.63762594077534], [-0.8615129453530583, 48.61059221483808], [-0.7800302484715664, 48.58349468969002], [-0.6986391108830874, 48.55633349296405], [-0.6173395610854927, 48.52910875226093], [-0.5361316263412251, 48.5018205951507], [-0.455015332657273, 48.474469149167376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.45501533&lt;dd&gt;Longitude: 48.474469&lt;dd&gt;Azimuth: 154.28197\u00b0&lt;dd&gt;Altitude: 53.315737\u00b0&lt;dd&gt;Slant Range: 664.38834km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.455015332657273, 48.474469149167376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8615129453530583, 48.61059221483808], [-0.7800302484715664, 48.58349468969002], [-0.6986391108830874, 48.55633349296405], [-0.6173395610854927, 48.52910875226093], [-0.5361316263412251, 48.5018205951507], [-0.455015332657273, 48.474469149167376], [-0.37399070480580643, 48.44705454181049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.3739907&lt;dd&gt;Longitude: 48.447055&lt;dd&gt;Azimuth: 153.62865\u00b0&lt;dd&gt;Altitude: 52.907174\u00b0&lt;dd&gt;Slant Range: 667.53602km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.37399070480580643, 48.44705454181049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7800302484715664, 48.58349468969002], [-0.6986391108830874, 48.55633349296405], [-0.6173395610854927, 48.52910875226093], [-0.5361316263412251, 48.5018205951507], [-0.455015332657273, 48.474469149167376], [-0.37399070480580643, 48.44705454181049], [-0.29305776632481284, 48.41957690054063]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.29305777&lt;dd&gt;Longitude: 48.419577&lt;dd&gt;Azimuth: 152.99371\u00b0&lt;dd&gt;Altitude: 52.498613\u00b0&lt;dd&gt;Slant Range: 670.74222km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.29305776632481284, 48.41957690054063]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6986391108830874, 48.55633349296405], [-0.6173395610854927, 48.52910875226093], [-0.5361316263412251, 48.5018205951507], [-0.455015332657273, 48.474469149167376], [-0.37399070480580643, 48.44705454181049], [-0.29305776632481284, 48.41957690054063], [-0.2122165395270284, 48.39203635277926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.21221654&lt;dd&gt;Longitude: 48.392036&lt;dd&gt;Azimuth: 152.37653\u00b0&lt;dd&gt;Altitude: 52.090286\u00b0&lt;dd&gt;Slant Range: 674.00608km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.2122165395270284, 48.39203635277926]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6173395610854927, 48.52910875226093], [-0.5361316263412251, 48.5018205951507], [-0.455015332657273, 48.474469149167376], [-0.37399070480580643, 48.44705454181049], [-0.29305776632481284, 48.41957690054063], [-0.2122165395270284, 48.39203635277926], [-0.13146704549446717, 48.36443302590606]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.13146705&lt;dd&gt;Longitude: 48.364433&lt;dd&gt;Azimuth: 151.77651\u00b0&lt;dd&gt;Altitude: 51.682407\u00b0&lt;dd&gt;Slant Range: 677.32677km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.13146704549446717, 48.36443302590606]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5361316263412251, 48.5018205951507], [-0.455015332657273, 48.474469149167376], [-0.37399070480580643, 48.44705454181049], [-0.29305776632481284, 48.41957690054063], [-0.2122165395270284, 48.39203635277926], [-0.13146704549446717, 48.36443302590606], [-0.05080930410358577, 48.336767047258185]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: -0.050809304&lt;dd&gt;Longitude: 48.336767&lt;dd&gt;Azimuth: 151.19308\u00b0&lt;dd&gt;Altitude: 51.275182\u00b0&lt;dd&gt;Slant Range: 680.70346km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.05080930410358577, 48.336767047258185]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.455015332657273, 48.474469149167376], [-0.37399070480580643, 48.44705454181049], [-0.29305776632481284, 48.41957690054063], [-0.2122165395270284, 48.39203635277926], [-0.13146704549446717, 48.36443302590606], [-0.05080930410358577, 48.336767047258185], [0.029756665990644773, 48.30903854412673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.029756666&lt;dd&gt;Longitude: 48.309039&lt;dd&gt;Azimuth: 150.62569\u00b0&lt;dd&gt;Altitude: 50.8688\u00b0&lt;dd&gt;Slant Range: 684.13531km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.029756665990644773, 48.30903854412673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.37399070480580643, 48.44705454181049], [-0.29305776632481284, 48.41957690054063], [-0.2122165395270284, 48.39203635277926], [-0.13146704549446717, 48.36443302590606], [-0.05080930410358577, 48.336767047258185], [0.029756665990644773, 48.30903854412673], [0.11023084732362061, 48.2812476437576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.11023085&lt;dd&gt;Longitude: 48.281248&lt;dd&gt;Azimuth: 150.07378\u00b0&lt;dd&gt;Altitude: 50.46344\u00b0&lt;dd&gt;Slant Range: 687.62149km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.11023084732362061, 48.2812476437576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.29305776632481284, 48.41957690054063], [-0.2122165395270284, 48.39203635277926], [-0.13146704549446717, 48.36443302590606], [-0.05080930410358577, 48.336767047258185], [0.029756665990644773, 48.30903854412673], [0.11023084732362061, 48.2812476437576], [0.1906132236470583, 48.25339447334672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.19061322&lt;dd&gt;Longitude: 48.253394&lt;dd&gt;Azimuth: 149.53685\u00b0&lt;dd&gt;Altitude: 50.059269\u00b0&lt;dd&gt;Slant Range: 691.16119km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.1906132236470583, 48.25339447334672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.2122165395270284, 48.39203635277926], [-0.13146704549446717, 48.36443302590606], [-0.05080930410358577, 48.336767047258185], [0.029756665990644773, 48.30903854412673], [0.11023084732362061, 48.2812476437576], [0.1906132236470583, 48.25339447334672], [0.2709037798912099, 48.22547916004136]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.27090378&lt;dd&gt;Longitude: 48.225479&lt;dd&gt;Azimuth: 149.01437\u00b0&lt;dd&gt;Altitude: 49.656445\u00b0&lt;dd&gt;Slant Range: 694.75356km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.2709037798912099, 48.22547916004136]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.13146704549446717, 48.36443302590606], [-0.05080930410358577, 48.336767047258185], [0.029756665990644773, 48.30903854412673], [0.11023084732362061, 48.2812476437576], [0.1906132236470583, 48.25339447334672], [0.2709037798912099, 48.22547916004136], [0.3511025021827503, 48.19750183093617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.3511025&lt;dd&gt;Longitude: 48.197502&lt;dd&gt;Azimuth: 148.50587\u00b0&lt;dd&gt;Altitude: 49.255113\u00b0&lt;dd&gt;Slant Range: 698.39781km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3511025021827503, 48.19750183093617]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.05080930410358577, 48.336767047258185], [0.029756665990644773, 48.30903854412673], [0.11023084732362061, 48.2812476437576], [0.1906132236470583, 48.25339447334672], [0.2709037798912099, 48.22547916004136], [0.3511025021827503, 48.19750183093617], [0.431209377822488, 48.16946261307254]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.43120938&lt;dd&gt;Longitude: 48.169463&lt;dd&gt;Azimuth: 148.01086\u00b0&lt;dd&gt;Altitude: 48.855409\u00b0&lt;dd&gt;Slant Range: 702.09311km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.431209377822488, 48.16946261307254]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.029756665990644773, 48.30903854412673], [0.11023084732362061, 48.2812476437576], [0.1906132236470583, 48.25339447334672], [0.2709037798912099, 48.22547916004136], [0.3511025021827503, 48.19750183093617], [0.431209377822488, 48.16946261307254], [0.5112243952965098, 48.141361633436524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.5112244&lt;dd&gt;Longitude: 48.141362&lt;dd&gt;Azimuth: 147.5289\u00b0&lt;dd&gt;Altitude: 48.45746\u00b0&lt;dd&gt;Slant Range: 705.83867km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5112243952965098, 48.141361633436524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.11023084732362061, 48.2812476437576], [0.1906132236470583, 48.25339447334672], [0.2709037798912099, 48.22547916004136], [0.3511025021827503, 48.19750183093617], [0.431209377822488, 48.16946261307254], [0.5112243952965098, 48.141361633436524], [0.5911475442480899, 48.11319901895816]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.59114754&lt;dd&gt;Longitude: 48.113199&lt;dd&gt;Azimuth: 147.05954\u00b0&lt;dd&gt;Altitude: 48.061383\u00b0&lt;dd&gt;Slant Range: 709.63367km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5911475442480899, 48.11319901895816]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.1906132236470583, 48.25339447334672], [0.2709037798912099, 48.22547916004136], [0.3511025021827503, 48.19750183093617], [0.431209377822488, 48.16946261307254], [0.5112243952965098, 48.141361633436524], [0.5911475442480899, 48.11319901895816], [0.6709788154988854, 48.08497489650755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.67097882&lt;dd&gt;Longitude: 48.084975&lt;dd&gt;Azimuth: 146.60237\u00b0&lt;dd&gt;Altitude: 47.667288\u00b0&lt;dd&gt;Slant Range: 713.47734km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6709788154988854, 48.08497489650755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.2709037798912099, 48.22547916004136], [0.3511025021827503, 48.19750183093617], [0.431209377822488, 48.16946261307254], [0.5112243952965098, 48.141361633436524], [0.5911475442480899, 48.11319901895816], [0.6709788154988854, 48.08497489650755], [0.7507182010152985, 48.056689392896224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.7507182&lt;dd&gt;Longitude: 48.056689&lt;dd&gt;Azimuth: 146.15696\u00b0&lt;dd&gt;Altitude: 47.275275\u00b0&lt;dd&gt;Slant Range: 717.36887km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7507182010152985, 48.056689392896224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3511025021827503, 48.19750183093617], [0.431209377822488, 48.16946261307254], [0.5112243952965098, 48.141361633436524], [0.5911475442480899, 48.11319901895816], [0.6709788154988854, 48.08497489650755], [0.7507182010152985, 48.056689392896224], [0.8303656939249395, 48.028342634873006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.83036569&lt;dd&gt;Longitude: 48.028343&lt;dd&gt;Azimuth: 145.72293\u00b0&lt;dd&gt;Altitude: 46.885438\u00b0&lt;dd&gt;Slant Range: 721.3075km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8303656939249395, 48.028342634873006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.431209377822488, 48.16946261307254], [0.5112243952965098, 48.141361633436524], [0.5911475442480899, 48.11319901895816], [0.6709788154988854, 48.08497489650755], [0.7507182010152985, 48.056689392896224], [0.8303656939249395, 48.028342634873006], [0.9099212884954565, 47.99993474912383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.90992129&lt;dd&gt;Longitude: 47.999935&lt;dd&gt;Azimuth: 145.29989\u00b0&lt;dd&gt;Altitude: 46.497862\u00b0&lt;dd&gt;Slant Range: 725.29245km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9099212884954565, 47.99993474912383]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5112243952965098, 48.141361633436524], [0.5911475442480899, 48.11319901895816], [0.6709788154988854, 48.08497489650755], [0.7507182010152985, 48.056689392896224], [0.8303656939249395, 48.028342634873006], [0.9099212884954565, 47.99993474912383], [0.9893849801403624, 47.9714658622692]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 0.98938498&lt;dd&gt;Longitude: 47.971466&lt;dd&gt;Azimuth: 144.88749\u00b0&lt;dd&gt;Altitude: 46.112626\u00b0&lt;dd&gt;Slant Range: 729.32296km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9893849801403624, 47.9714658622692]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5911475442480899, 48.11319901895816], [0.6709788154988854, 48.08497489650755], [0.7507182010152985, 48.056689392896224], [0.8303656939249395, 48.028342634873006], [0.9099212884954565, 47.99993474912383], [0.9893849801403624, 47.9714658622692], [1.0687567654044552, 47.94293610086404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.0687568&lt;dd&gt;Longitude: 47.942936&lt;dd&gt;Azimuth: 144.48537\u00b0&lt;dd&gt;Altitude: 45.729802\u00b0&lt;dd&gt;Slant Range: 733.39827km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0687567654044552, 47.94293610086404]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6709788154988854, 48.08497489650755], [0.7507182010152985, 48.056689392896224], [0.8303656939249395, 48.028342634873006], [0.9099212884954565, 47.99993474912383], [0.9893849801403624, 47.9714658622692], [1.0687567654044552, 47.94293610086404], [1.148036641960612, 47.914345591393804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.1480366&lt;dd&gt;Longitude: 47.914346&lt;dd&gt;Azimuth: 144.09318\u00b0&lt;dd&gt;Altitude: 45.349456\u00b0&lt;dd&gt;Slant Range: 737.51763km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.148036641960612, 47.914345591393804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7507182010152985, 48.056689392896224], [0.8303656939249395, 48.028342634873006], [0.9099212884954565, 47.99993474912383], [0.9893849801403624, 47.9714658622692], [1.0687567654044552, 47.94293610086404], [1.148036641960612, 47.914345591393804], [1.2272246086089245, 47.8856944602757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.2272246&lt;dd&gt;Longitude: 47.885694&lt;dd&gt;Azimuth: 143.71062\u00b0&lt;dd&gt;Altitude: 44.971648\u00b0&lt;dd&gt;Slant Range: 741.68031km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2272246086089245, 47.8856944602757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8303656939249395, 48.028342634873006], [0.9099212884954565, 47.99993474912383], [0.9893849801403624, 47.9714658622692], [1.0687567654044552, 47.94293610086404], [1.148036641960612, 47.914345591393804], [1.2272246086089245, 47.8856944602757], [1.3063206652630592, 47.85698283385423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.3063207&lt;dd&gt;Longitude: 47.856983&lt;dd&gt;Azimuth: 143.33735\u00b0&lt;dd&gt;Altitude: 44.596432\u00b0&lt;dd&gt;Slant Range: 745.88558km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3063206652630592, 47.85698283385423]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9099212884954565, 47.99993474912383], [0.9893849801403624, 47.9714658622692], [1.0687567654044552, 47.94293610086404], [1.148036641960612, 47.914345591393804], [1.2272246086089245, 47.8856944602757], [1.3063206652630592, 47.85698283385423], [1.3853248129453737, 47.82821083840237]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.3853248&lt;dd&gt;Longitude: 47.828211&lt;dd&gt;Azimuth: 142.97309\u00b0&lt;dd&gt;Altitude: 44.223858\u00b0&lt;dd&gt;Slant Range: 750.13271km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3853248129453737, 47.82821083840237]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9893849801403624, 47.9714658622692], [1.0687567654044552, 47.94293610086404], [1.148036641960612, 47.914345591393804], [1.2272246086089245, 47.8856944602757], [1.3063206652630592, 47.85698283385423], [1.3853248129453737, 47.82821083840237], [1.4642370537876286, 47.799378600118196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.4642371&lt;dd&gt;Longitude: 47.799379&lt;dd&gt;Azimuth: 142.61754\u00b0&lt;dd&gt;Altitude: 43.853968\u00b0&lt;dd&gt;Slant Range: 754.421km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4642370537876286, 47.799378600118196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0687567654044552, 47.94293610086404], [1.148036641960612, 47.914345591393804], [1.2272246086089245, 47.8856944602757], [1.3063206652630592, 47.85698283385423], [1.3853248129453737, 47.82821083840237], [1.4642370537876286, 47.799378600118196], [1.543057391020911, 47.77048624512379]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.5430574&lt;dd&gt;Longitude: 47.770486&lt;dd&gt;Azimuth: 142.27041\u00b0&lt;dd&gt;Altitude: 43.486802\u00b0&lt;dd&gt;Slant Range: 758.74973km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.543057391020911, 47.77048624512379]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.148036641960612, 47.914345591393804], [1.2272246086089245, 47.8856944602757], [1.3063206652630592, 47.85698283385423], [1.3853248129453737, 47.82821083840237], [1.4642370537876286, 47.799378600118196], [1.543057391020911, 47.77048624512379], [1.6217858289644145, 47.741533899464216]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.6217858&lt;dd&gt;Longitude: 47.741534&lt;dd&gt;Azimuth: 141.93144\u00b0&lt;dd&gt;Altitude: 43.122395\u00b0&lt;dd&gt;Slant Range: 763.11823km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6217858289644145, 47.741533899464216]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2272246086089245, 47.8856944602757], [1.3063206652630592, 47.85698283385423], [1.3853248129453737, 47.82821083840237], [1.4642370537876286, 47.799378600118196], [1.543057391020911, 47.77048624512379], [1.6217858289644145, 47.741533899464216], [1.7004223730359465, 47.712521689105536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.7004224&lt;dd&gt;Longitude: 47.712522&lt;dd&gt;Azimuth: 141.60038\u00b0&lt;dd&gt;Altitude: 42.760777\u00b0&lt;dd&gt;Slant Range: 767.5258km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7004223730359465, 47.712521689105536]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3063206652630592, 47.85698283385423], [1.3853248129453737, 47.82821083840237], [1.4642370537876286, 47.799378600118196], [1.543057391020911, 47.77048624512379], [1.6217858289644145, 47.741533899464216], [1.7004223730359465, 47.712521689105536], [1.7789670297181646, 47.68344973993317]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.778967&lt;dd&gt;Longitude: 47.68345&lt;dd&gt;Azimuth: 141.27697\u00b0&lt;dd&gt;Altitude: 42.401975\u00b0&lt;dd&gt;Slant Range: 771.97177km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7789670297181646, 47.68344973993317]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3853248129453737, 47.82821083840237], [1.4642370537876286, 47.799378600118196], [1.543057391020911, 47.77048624512379], [1.6217858289644145, 47.741533899464216], [1.7004223730359465, 47.712521689105536], [1.7789670297181646, 47.68344973993317], [1.8574198065840204, 47.65431817775192]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.8574198&lt;dd&gt;Longitude: 47.654318&lt;dd&gt;Azimuth: 140.96096\u00b0&lt;dd&gt;Altitude: 42.046011\u00b0&lt;dd&gt;Slant Range: 776.45548km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8574198065840204, 47.65431817775192]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4642370537876286, 47.799378600118196], [1.543057391020911, 47.77048624512379], [1.6217858289644145, 47.741533899464216], [1.7004223730359465, 47.712521689105536], [1.7789670297181646, 47.68344973993317], [1.8574198065840204, 47.65431817775192], [1.9357807122699155, 47.625127128281406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 1.9357807&lt;dd&gt;Longitude: 47.625127&lt;dd&gt;Azimuth: 140.65214\u00b0&lt;dd&gt;Altitude: 41.692905\u00b0&lt;dd&gt;Slant Range: 780.97627km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9357807122699155, 47.625127128281406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.543057391020911, 47.77048624512379], [1.6217858289644145, 47.741533899464216], [1.7004223730359465, 47.712521689105536], [1.7789670297181646, 47.68344973993317], [1.8574198065840204, 47.65431817775192], [1.9357807122699155, 47.625127128281406], [2.0140497564780944, 47.59587671715824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 2.0140498&lt;dd&gt;Longitude: 47.595877&lt;dd&gt;Azimuth: 140.35028\u00b0&lt;dd&gt;Altitude: 41.342672\u00b0&lt;dd&gt;Slant Range: 785.5335km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0140497564780944, 47.59587671715824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6217858289644145, 47.741533899464216], [1.7004223730359465, 47.712521689105536], [1.7789670297181646, 47.68344973993317], [1.8574198065840204, 47.65431817775192], [1.9357807122699155, 47.625127128281406], [2.0140497564780944, 47.59587671715824], [2.0922269499658026, 47.5665670699319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-3832&lt;dd&gt;Latitude: 2.0922269&lt;dd&gt;Longitude: 47.566567&lt;dd&gt;Azimuth: 140.05516\u00b0&lt;dd&gt;Altitude: 40.995324\u00b0&lt;dd&gt;Slant Range: 790.12652km&quot;, &quot;name&quot;: &quot;STARLINK-3832&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0922269499658026, 47.5665670699319]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -10.438251&lt;dd&gt;Longitude: 52.000203&lt;dd&gt;Azimuth: 279.41887\u00b0&lt;dd&gt;Altitude: 41.393068\u00b0&lt;dd&gt;Slant Range: 786.7664km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675], [-10.343683888515635, 51.984696195052074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -10.343684&lt;dd&gt;Longitude: 51.984696&lt;dd&gt;Azimuth: 279.27501\u00b0&lt;dd&gt;Altitude: 41.771102\u00b0&lt;dd&gt;Slant Range: 781.84052km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.343683888515635, 51.984696195052074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675], [-10.343683888515635, 51.984696195052074], [-10.249184756657804, 51.96910636206785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -10.249185&lt;dd&gt;Longitude: 51.969106&lt;dd&gt;Azimuth: 279.12751\u00b0&lt;dd&gt;Altitude: 42.15333\u00b0&lt;dd&gt;Slant Range: 776.94639km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.249184756657804, 51.96910636206785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675], [-10.343683888515635, 51.984696195052074], [-10.249184756657804, 51.96910636206785], [-10.154754195869115, 51.95343398470865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -10.154754&lt;dd&gt;Longitude: 51.953434&lt;dd&gt;Azimuth: 278.97624\u00b0&lt;dd&gt;Altitude: 42.539793\u00b0&lt;dd&gt;Slant Range: 772.08462km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.154754195869115, 51.95343398470865]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675], [-10.343683888515635, 51.984696195052074], [-10.249184756657804, 51.96910636206785], [-10.154754195869115, 51.95343398470865], [-10.060392480956082, 51.9376791661446]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -10.060392&lt;dd&gt;Longitude: 51.937679&lt;dd&gt;Azimuth: 278.82106\u00b0&lt;dd&gt;Altitude: 42.930533\u00b0&lt;dd&gt;Slant Range: 767.25584km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.060392480956082, 51.9376791661446]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675], [-10.343683888515635, 51.984696195052074], [-10.249184756657804, 51.96910636206785], [-10.154754195869115, 51.95343398470865], [-10.060392480956082, 51.9376791661446], [-9.966099885033472, 51.921842009917725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.9660999&lt;dd&gt;Longitude: 51.921842&lt;dd&gt;Azimuth: 278.66182\u00b0&lt;dd&gt;Altitude: 43.325589\u00b0&lt;dd&gt;Slant Range: 762.46068km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.966099885033472, 51.921842009917725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.438251314966454, 52.0002033808675], [-10.343683888515635, 51.984696195052074], [-10.249184756657804, 51.96910636206785], [-10.154754195869115, 51.95343398470865], [-10.060392480956082, 51.9376791661446], [-9.966099885033472, 51.921842009917725], [-9.87187667954371, 51.90592261994049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.8718767&lt;dd&gt;Longitude: 51.905923&lt;dd&gt;Azimuth: 278.49836\u00b0&lt;dd&gt;Altitude: 43.724999\u00b0&lt;dd&gt;Slant Range: 757.69977km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.87187667954371, 51.90592261994049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.343683888515635, 51.984696195052074], [-10.249184756657804, 51.96910636206785], [-10.154754195869115, 51.95343398470865], [-10.060392480956082, 51.9376791661446], [-9.966099885033472, 51.921842009917725], [-9.87187667954371, 51.90592261994049], [-9.777723134230609, 51.88992110049158]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.7777231&lt;dd&gt;Longitude: 51.889921&lt;dd&gt;Azimuth: 278.33051\u00b0&lt;dd&gt;Altitude: 44.128801\u00b0&lt;dd&gt;Slant Range: 752.97379km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.777723134230609, 51.88992110049158]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.249184756657804, 51.96910636206785], [-10.154754195869115, 51.95343398470865], [-10.060392480956082, 51.9376791661446], [-9.966099885033472, 51.921842009917725], [-9.87187667954371, 51.90592261994049], [-9.777723134230609, 51.88992110049158], [-9.683639517163606, 51.87383755621327]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.6836395&lt;dd&gt;Longitude: 51.873838&lt;dd&gt;Azimuth: 278.15812\u00b0&lt;dd&gt;Altitude: 44.53703\u00b0&lt;dd&gt;Slant Range: 748.28338km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.683639517163606, 51.87383755621327]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.154754195869115, 51.95343398470865], [-10.060392480956082, 51.9376791661446], [-9.966099885033472, 51.921842009917725], [-9.87187667954371, 51.90592261994049], [-9.777723134230609, 51.88992110049158], [-9.683639517163606, 51.87383755621327], [-9.589626094708915, 51.857672092109006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.5896261&lt;dd&gt;Longitude: 51.857672&lt;dd&gt;Azimuth: 277.98099\u00b0&lt;dd&gt;Altitude: 44.949722\u00b0&lt;dd&gt;Slant Range: 743.62924km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.589626094708915, 51.857672092109006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.060392480956082, 51.9376791661446], [-9.966099885033472, 51.921842009917725], [-9.87187667954371, 51.90592261994049], [-9.777723134230609, 51.88992110049158], [-9.683639517163606, 51.87383755621327], [-9.589626094708915, 51.857672092109006], [-9.495683131554355, 51.84142481353944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.4956831&lt;dd&gt;Longitude: 51.841425&lt;dd&gt;Azimuth: 277.79894\u00b0&lt;dd&gt;Altitude: 45.366907\u00b0&lt;dd&gt;Slant Range: 739.01205km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.495683131554355, 51.84142481353944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.966099885033472, 51.921842009917725], [-9.87187667954371, 51.90592261994049], [-9.777723134230609, 51.88992110049158], [-9.683639517163606, 51.87383755621327], [-9.589626094708915, 51.857672092109006], [-9.495683131554355, 51.84142481353944], [-9.401810890679691, 51.825095826219936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.4018109&lt;dd&gt;Longitude: 51.825096&lt;dd&gt;Azimuth: 277.61176\u00b0&lt;dd&gt;Altitude: 45.788619\u00b0&lt;dd&gt;Slant Range: 734.43251km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.401810890679691, 51.825095826219936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.87187667954371, 51.90592261994049], [-9.777723134230609, 51.88992110049158], [-9.683639517163606, 51.87383755621327], [-9.589626094708915, 51.857672092109006], [-9.495683131554355, 51.84142481353944], [-9.401810890679691, 51.825095826219936], [-9.308009633381966, 51.80868523621822]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.3080096&lt;dd&gt;Longitude: 51.808685&lt;dd&gt;Azimuth: 277.41924\u00b0&lt;dd&gt;Altitude: 46.214884\u00b0&lt;dd&gt;Slant Range: 729.89134km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.308009633381966, 51.80868523621822]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.777723134230609, 51.88992110049158], [-9.683639517163606, 51.87383755621327], [-9.589626094708915, 51.857672092109006], [-9.495683131554355, 51.84142481353944], [-9.401810890679691, 51.825095826219936], [-9.308009633381966, 51.80868523621822], [-9.214279619254338, 51.79219314994948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.2142796&lt;dd&gt;Longitude: 51.792193&lt;dd&gt;Azimuth: 277.22116\u00b0&lt;dd&gt;Altitude: 46.645729\u00b0&lt;dd&gt;Slant Range: 725.38926km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.214279619254338, 51.79219314994948]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.683639517163606, 51.87383755621327], [-9.589626094708915, 51.857672092109006], [-9.495683131554355, 51.84142481353944], [-9.401810890679691, 51.825095826219936], [-9.308009633381966, 51.80868523621822], [-9.214279619254338, 51.79219314994948], [-9.120621106189795, 51.77561967417576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.1206211&lt;dd&gt;Longitude: 51.77562&lt;dd&gt;Azimuth: 277.01729\u00b0&lt;dd&gt;Altitude: 47.081179\u00b0&lt;dd&gt;Slant Range: 720.92702km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.120621106189795, 51.77561967417576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.589626094708915, 51.857672092109006], [-9.495683131554355, 51.84142481353944], [-9.401810890679691, 51.825095826219936], [-9.308009633381966, 51.80868523621822], [-9.214279619254338, 51.79219314994948], [-9.120621106189795, 51.77561967417576], [-9.027034350386469, 51.75896491600107]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -9.0270344&lt;dd&gt;Longitude: 51.758965&lt;dd&gt;Azimuth: 276.80737\u00b0&lt;dd&gt;Altitude: 47.521255\u00b0&lt;dd&gt;Slant Range: 716.50536km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.027034350386469, 51.75896491600107]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.495683131554355, 51.84142481353944], [-9.401810890679691, 51.825095826219936], [-9.308009633381966, 51.80868523621822], [-9.214279619254338, 51.79219314994948], [-9.120621106189795, 51.77561967417576], [-9.027034350386469, 51.75896491600107], [-8.93351960633578, 51.74222898286936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.9335196&lt;dd&gt;Longitude: 51.742229&lt;dd&gt;Azimuth: 276.59114\u00b0&lt;dd&gt;Altitude: 47.965975\u00b0&lt;dd&gt;Slant Range: 712.12504km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.93351960633578, 51.74222898286936]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.401810890679691, 51.825095826219936], [-9.308009633381966, 51.80868523621822], [-9.214279619254338, 51.79219314994948], [-9.120621106189795, 51.77561967417576], [-9.027034350386469, 51.75896491600107], [-8.93351960633578, 51.74222898286936], [-8.840077126829156, 51.72541198256101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.8400771&lt;dd&gt;Longitude: 51.725412&lt;dd&gt;Azimuth: 276.36833\u00b0&lt;dd&gt;Altitude: 48.415355\u00b0&lt;dd&gt;Slant Range: 707.78683km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.840077126829156, 51.72541198256101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.308009633381966, 51.80868523621822], [-9.214279619254338, 51.79219314994948], [-9.120621106189795, 51.77561967417576], [-9.027034350386469, 51.75896491600107], [-8.93351960633578, 51.74222898286936], [-8.840077126829156, 51.72541198256101], [-8.746707162952688, 51.70851402319056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.7467072&lt;dd&gt;Longitude: 51.708514&lt;dd&gt;Azimuth: 276.13864\u00b0&lt;dd&gt;Altitude: 48.869408\u00b0&lt;dd&gt;Slant Range: 703.49153km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.746707162952688, 51.70851402319056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.214279619254338, 51.79219314994948], [-9.120621106189795, 51.77561967417576], [-9.027034350386469, 51.75896491600107], [-8.93351960633578, 51.74222898286936], [-8.840077126829156, 51.72541198256101], [-8.746707162952688, 51.70851402319056], [-8.653409964086773, 51.691535213202435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.65341&lt;dd&gt;Longitude: 51.691535&lt;dd&gt;Azimuth: 275.90176\u00b0&lt;dd&gt;Altitude: 49.328141\u00b0&lt;dd&gt;Slant Range: 699.23992km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.653409964086773, 51.691535213202435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.120621106189795, 51.77561967417576], [-9.027034350386469, 51.75896491600107], [-8.93351960633578, 51.74222898286936], [-8.840077126829156, 51.72541198256101], [-8.746707162952688, 51.70851402319056], [-8.653409964086773, 51.691535213202435], [-8.560185777905454, 51.67447566136961]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.5601858&lt;dd&gt;Longitude: 51.674476&lt;dd&gt;Azimuth: 275.65736\u00b0&lt;dd&gt;Altitude: 49.79156\u00b0&lt;dd&gt;Slant Range: 695.03281km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.560185777905454, 51.67447566136961]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.027034350386469, 51.75896491600107], [-8.93351960633578, 51.74222898286936], [-8.840077126829156, 51.72541198256101], [-8.746707162952688, 51.70851402319056], [-8.653409964086773, 51.691535213202435], [-8.560185777905454, 51.67447566136961], [-8.467034850377358, 51.657335476789]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.4670349&lt;dd&gt;Longitude: 51.657335&lt;dd&gt;Azimuth: 275.40509\u00b0&lt;dd&gt;Altitude: 50.259665\u00b0&lt;dd&gt;Slant Range: 690.87101km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.467034850377358, 51.657335476789]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.93351960633578, 51.74222898286936], [-8.840077126829156, 51.72541198256101], [-8.746707162952688, 51.70851402319056], [-8.653409964086773, 51.691535213202435], [-8.560185777905454, 51.67447566136961], [-8.467034850377358, 51.657335476789], [-8.373957425756084, 51.64011476887953]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.3739574&lt;dd&gt;Longitude: 51.640115&lt;dd&gt;Azimuth: 275.14458\u00b0&lt;dd&gt;Altitude: 50.732451\u00b0&lt;dd&gt;Slant Range: 686.75537km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.373957425756084, 51.64011476887953]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.840077126829156, 51.72541198256101], [-8.746707162952688, 51.70851402319056], [-8.653409964086773, 51.691535213202435], [-8.560185777905454, 51.67447566136961], [-8.467034850377358, 51.657335476789], [-8.373957425756084, 51.64011476887953], [-8.280953746593097, 51.62281364737876]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.2809537&lt;dd&gt;Longitude: 51.622814&lt;dd&gt;Azimuth: 274.87544\u00b0&lt;dd&gt;Altitude: 51.20991\u00b0&lt;dd&gt;Slant Range: 682.68671km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.280953746593097, 51.62281364737876]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.746707162952688, 51.70851402319056], [-8.653409964086773, 51.691535213202435], [-8.560185777905454, 51.67447566136961], [-8.467034850377358, 51.657335476789], [-8.373957425756084, 51.64011476887953], [-8.280953746593097, 51.62281364737876], [-8.188024053727455, 51.60543222233974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.1880241&lt;dd&gt;Longitude: 51.605432&lt;dd&gt;Azimuth: 274.59724\u00b0&lt;dd&gt;Altitude: 51.692028\u00b0&lt;dd&gt;Slant Range: 678.66589km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.188024053727455, 51.60543222233974]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.653409964086773, 51.691535213202435], [-8.560185777905454, 51.67447566136961], [-8.467034850377358, 51.657335476789], [-8.373957425756084, 51.64011476887953], [-8.280953746593097, 51.62281364737876], [-8.188024053727455, 51.60543222233974], [-8.09516858628524, 51.58797060412818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.0951686&lt;dd&gt;Longitude: 51.587971&lt;dd&gt;Azimuth: 274.30954\u00b0&lt;dd&gt;Altitude: 52.178784\u00b0&lt;dd&gt;Slant Range: 674.69377km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.09516858628524, 51.58797060412818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.560185777905454, 51.67447566136961], [-8.467034850377358, 51.657335476789], [-8.373957425756084, 51.64011476887953], [-8.280953746593097, 51.62281364737876], [-8.188024053727455, 51.60543222233974], [-8.09516858628524, 51.58797060412818], [-8.002387581684047, 51.57042890341998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -8.0023876&lt;dd&gt;Longitude: 51.570429&lt;dd&gt;Azimuth: 274.01187\u00b0&lt;dd&gt;Altitude: 52.670152\u00b0&lt;dd&gt;Slant Range: 670.77121km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.002387581684047, 51.57042890341998]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.467034850377358, 51.657335476789], [-8.373957425756084, 51.64011476887953], [-8.280953746593097, 51.62281364737876], [-8.188024053727455, 51.60543222233974], [-8.09516858628524, 51.58797060412818], [-8.002387581684047, 51.57042890341998], [-7.909681275629924, 51.552807231196894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.9096813&lt;dd&gt;Longitude: 51.552807&lt;dd&gt;Azimuth: 273.70372\u00b0&lt;dd&gt;Altitude: 53.166101\u00b0&lt;dd&gt;Slant Range: 666.8991km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.909681275629924, 51.552807231196894]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.373957425756084, 51.64011476887953], [-8.280953746593097, 51.62281364737876], [-8.188024053727455, 51.60543222233974], [-8.09516858628524, 51.58797060412818], [-8.002387581684047, 51.57042890341998], [-7.909681275629924, 51.552807231196894], [-7.8170499021112665, 51.53510569874524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.8170499&lt;dd&gt;Longitude: 51.535106&lt;dd&gt;Azimuth: 273.38456\u00b0&lt;dd&gt;Altitude: 53.666591\u00b0&lt;dd&gt;Slant Range: 663.07832km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.8170499021112665, 51.53510569874524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.280953746593097, 51.62281364737876], [-8.188024053727455, 51.60543222233974], [-8.09516858628524, 51.58797060412818], [-8.002387581684047, 51.57042890341998], [-7.909681275629924, 51.552807231196894], [-7.8170499021112665, 51.53510569874524], [-7.724493693411131, 51.51732441765098]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.7244937&lt;dd&gt;Longitude: 51.517324&lt;dd&gt;Azimuth: 273.05381\u00b0&lt;dd&gt;Altitude: 54.171574\u00b0&lt;dd&gt;Slant Range: 659.30977km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.724493693411131, 51.51732441765098]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.188024053727455, 51.60543222233974], [-8.09516858628524, 51.58797060412818], [-8.002387581684047, 51.57042890341998], [-7.909681275629924, 51.552807231196894], [-7.8170499021112665, 51.53510569874524], [-7.724493693411131, 51.51732441765098], [-7.63201288009551, 51.499463499798935]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.6320129&lt;dd&gt;Longitude: 51.499463&lt;dd&gt;Azimuth: 272.71085\u00b0&lt;dd&gt;Altitude: 54.680995\u00b0&lt;dd&gt;Slant Range: 655.59436km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.63201288009551, 51.499463499798935]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.09516858628524, 51.58797060412818], [-8.002387581684047, 51.57042890341998], [-7.909681275629924, 51.552807231196894], [-7.8170499021112665, 51.53510569874524], [-7.724493693411131, 51.51732441765098], [-7.63201288009551, 51.499463499798935], [-7.539607691020554, 51.48152305736784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.5396077&lt;dd&gt;Longitude: 51.481523&lt;dd&gt;Azimuth: 272.35504\u00b0&lt;dd&gt;Altitude: 55.19479\u00b0&lt;dd&gt;Slant Range: 651.933km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.539607691020554, 51.48152305736784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.002387581684047, 51.57042890341998], [-7.909681275629924, 51.552807231196894], [-7.8170499021112665, 51.53510569874524], [-7.724493693411131, 51.51732441765098], [-7.63201288009551, 51.499463499798935], [-7.539607691020554, 51.48152305736784], [-7.447278353321402, 51.46350320282853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.4472784&lt;dd&gt;Longitude: 51.463503&lt;dd&gt;Azimuth: 271.98567\u00b0&lt;dd&gt;Altitude: 55.712887\u00b0&lt;dd&gt;Slant Range: 648.32661km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.447278353321402, 51.46350320282853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.909681275629924, 51.552807231196894], [-7.8170499021112665, 51.53510569874524], [-7.724493693411131, 51.51732441765098], [-7.63201288009551, 51.499463499798935], [-7.539607691020554, 51.48152305736784], [-7.447278353321402, 51.46350320282853], [-7.355025092430173, 51.44540404894029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.3550251&lt;dd&gt;Longitude: 51.445404&lt;dd&gt;Azimuth: 271.602\u00b0&lt;dd&gt;Altitude: 56.235201\u00b0&lt;dd&gt;Slant Range: 644.77611km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.355025092430173, 51.44540404894029]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.8170499021112665, 51.53510569874524], [-7.724493693411131, 51.51732441765098], [-7.63201288009551, 51.499463499798935], [-7.539607691020554, 51.48152305736784], [-7.447278353321402, 51.46350320282853], [-7.355025092430173, 51.44540404894029], [-7.262848132060264, 51.42722570874889]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.2628481&lt;dd&gt;Longitude: 51.427226&lt;dd&gt;Azimuth: 271.20321\u00b0&lt;dd&gt;Altitude: 56.761639\u00b0&lt;dd&gt;Slant Range: 641.28243km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.262848132060264, 51.42722570874889]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.724493693411131, 51.51732441765098], [-7.63201288009551, 51.499463499798935], [-7.539607691020554, 51.48152305736784], [-7.447278353321402, 51.46350320282853], [-7.355025092430173, 51.44540404894029], [-7.262848132060264, 51.42722570874889], [-7.1707476942124835, 51.40896829558192]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.1707477&lt;dd&gt;Longitude: 51.408968&lt;dd&gt;Azimuth: 270.78845\u00b0&lt;dd&gt;Altitude: 57.292095\u00b0&lt;dd&gt;Slant Range: 637.84653km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.1707476942124835, 51.40896829558192]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.63201288009551, 51.499463499798935], [-7.539607691020554, 51.48152305736784], [-7.447278353321402, 51.46350320282853], [-7.355025092430173, 51.44540404894029], [-7.262848132060264, 51.42722570874889], [-7.1707476942124835, 51.40896829558192], [-7.078723999174466, 51.39063192304761]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -7.078724&lt;dd&gt;Longitude: 51.390632&lt;dd&gt;Azimuth: 270.35678\u00b0&lt;dd&gt;Altitude: 57.82645\u00b0&lt;dd&gt;Slant Range: 634.46933km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.078723999174466, 51.39063192304761]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.539607691020554, 51.48152305736784], [-7.447278353321402, 51.46350320282853], [-7.355025092430173, 51.44540404894029], [-7.262848132060264, 51.42722570874889], [-7.1707476942124835, 51.40896829558192], [-7.078723999174466, 51.39063192304761], [-6.986777265525683, 51.372216705030795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.9867773&lt;dd&gt;Longitude: 51.372217&lt;dd&gt;Azimuth: 269.90723\u00b0&lt;dd&gt;Altitude: 58.364572\u00b0&lt;dd&gt;Slant Range: 631.15179km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.986777265525683, 51.372216705030795]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.447278353321402, 51.46350320282853], [-7.355025092430173, 51.44540404894029], [-7.262848132060264, 51.42722570874889], [-7.1707476942124835, 51.40896829558192], [-7.078723999174466, 51.39063192304761], [-6.986777265525683, 51.372216705030795], [-6.894907710125286, 51.353722755690086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.8949077&lt;dd&gt;Longitude: 51.353723&lt;dd&gt;Azimuth: 269.43872\u00b0&lt;dd&gt;Altitude: 58.906316\u00b0&lt;dd&gt;Slant Range: 627.89485km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.894907710125286, 51.353722755690086]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.355025092430173, 51.44540404894029], [-7.262848132060264, 51.42722570874889], [-7.1707476942124835, 51.40896829558192], [-7.078723999174466, 51.39063192304761], [-6.986777265525683, 51.372216705030795], [-6.894907710125286, 51.353722755690086], [-6.803115548123472, 51.33515018945512]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.8031155&lt;dd&gt;Longitude: 51.33515&lt;dd&gt;Azimuth: 268.9501\u00b0&lt;dd&gt;Altitude: 59.451519\u00b0&lt;dd&gt;Slant Range: 624.69946km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.803115548123472, 51.33515018945512]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.262848132060264, 51.42722570874889], [-7.1707476942124835, 51.40896829558192], [-7.078723999174466, 51.39063192304761], [-6.986777265525683, 51.372216705030795], [-6.894907710125286, 51.353722755690086], [-6.803115548123472, 51.33515018945512], [-6.711400992970091, 51.316499121024066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.711401&lt;dd&gt;Longitude: 51.316499&lt;dd&gt;Azimuth: 268.44013\u00b0&lt;dd&gt;Altitude: 60.000001\u00b0&lt;dd&gt;Slant Range: 621.56659km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.711400992970091, 51.316499121024066]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.1707476942124835, 51.40896829558192], [-7.078723999174466, 51.39063192304761], [-6.986777265525683, 51.372216705030795], [-6.894907710125286, 51.353722755690086], [-6.803115548123472, 51.33515018945512], [-6.711400992970091, 51.316499121024066], [-6.61976425638472, 51.29776966535893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.6197643&lt;dd&gt;Longitude: 51.29777&lt;dd&gt;Azimuth: 267.90748\u00b0&lt;dd&gt;Altitude: 60.551566\u00b0&lt;dd&gt;Slant Range: 618.49717km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.61976425638472, 51.29776966535893]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.078723999174466, 51.39063192304761], [-6.986777265525683, 51.372216705030795], [-6.894907710125286, 51.353722755690086], [-6.803115548123472, 51.33515018945512], [-6.711400992970091, 51.316499121024066], [-6.61976425638472, 51.29776966535893], [-6.528205548394727, 51.27896193768521]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.5282055&lt;dd&gt;Longitude: 51.278962&lt;dd&gt;Azimuth: 267.35072\u00b0&lt;dd&gt;Altitude: 61.105996\u00b0&lt;dd&gt;Slant Range: 615.49218km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.528205548394727, 51.27896193768521]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.986777265525683, 51.372216705030795], [-6.894907710125286, 51.353722755690086], [-6.803115548123472, 51.33515018945512], [-6.711400992970091, 51.316499121024066], [-6.61976425638472, 51.29776966535893], [-6.528205548394727, 51.27896193768521], [-6.436725077306316, 51.260076053486266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.4367251&lt;dd&gt;Longitude: 51.260076&lt;dd&gt;Azimuth: 266.76828\u00b0&lt;dd&gt;Altitude: 61.663053\u00b0&lt;dd&gt;Slant Range: 612.55254km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.436725077306316, 51.260076053486266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.894907710125286, 51.353722755690086], [-6.803115548123472, 51.33515018945512], [-6.711400992970091, 51.316499121024066], [-6.61976425638472, 51.29776966535893], [-6.528205548394727, 51.27896193768521], [-6.436725077306316, 51.260076053486266], [-6.345323049722392, 51.241112128502685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.345323&lt;dd&gt;Longitude: 51.241112&lt;dd&gt;Azimuth: 266.1585\u00b0&lt;dd&gt;Altitude: 62.222473\u00b0&lt;dd&gt;Slant Range: 609.67923km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.345323049722392, 51.241112128502685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.803115548123472, 51.33515018945512], [-6.711400992970091, 51.316499121024066], [-6.61976425638472, 51.29776966535893], [-6.528205548394727, 51.27896193768521], [-6.436725077306316, 51.260076053486266], [-6.345323049722392, 51.241112128502685], [-6.253999670538588, 51.2220702787279]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.2539997&lt;dd&gt;Longitude: 51.22207&lt;dd&gt;Azimuth: 265.51957\u00b0&lt;dd&gt;Altitude: 62.78397\u00b0&lt;dd&gt;Slant Range: 606.87317km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.253999670538588, 51.2220702787279]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.711400992970091, 51.316499121024066], [-6.61976425638472, 51.29776966535893], [-6.528205548394727, 51.27896193768521], [-6.436725077306316, 51.260076053486266], [-6.345323049722392, 51.241112128502685], [-6.253999670538588, 51.2220702787279], [-6.16275514294479, 51.202950620405545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.1627551&lt;dd&gt;Longitude: 51.202951&lt;dd&gt;Azimuth: 264.84951\u00b0&lt;dd&gt;Altitude: 63.347228\u00b0&lt;dd&gt;Slant Range: 604.13532km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.16275514294479, 51.202950620405545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.61976425638472, 51.29776966535893], [-6.528205548394727, 51.27896193768521], [-6.436725077306316, 51.260076053486266], [-6.345323049722392, 51.241112128502685], [-6.253999670538588, 51.2220702787279], [-6.16275514294479, 51.202950620405545], [-6.071589668417512, 51.18375327002673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -6.0715897&lt;dd&gt;Longitude: 51.183753&lt;dd&gt;Azimuth: 264.14622\u00b0&lt;dd&gt;Altitude: 63.911903\u00b0&lt;dd&gt;Slant Range: 601.4666km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.071589668417512, 51.18375327002673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.528205548394727, 51.27896193768521], [-6.436725077306316, 51.260076053486266], [-6.345323049722392, 51.241112128502685], [-6.253999670538588, 51.2220702787279], [-6.16275514294479, 51.202950620405545], [-6.071589668417512, 51.18375327002673], [-5.980503446740215, 51.16447834432754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.9805034&lt;dd&gt;Longitude: 51.164478&lt;dd&gt;Azimuth: 263.4074\u00b0&lt;dd&gt;Altitude: 64.477615\u00b0&lt;dd&gt;Slant Range: 598.86795km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.980503446740215, 51.16447834432754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.436725077306316, 51.260076053486266], [-6.345323049722392, 51.241112128502685], [-6.253999670538588, 51.2220702787279], [-6.16275514294479, 51.202950620405545], [-6.071589668417512, 51.18375327002673], [-5.980503446740215, 51.16447834432754], [-5.889496675981029, 51.1451259602847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.8894967&lt;dd&gt;Longitude: 51.145126&lt;dd&gt;Azimuth: 262.63057\u00b0&lt;dd&gt;Altitude: 65.04395\u00b0&lt;dd&gt;Slant Range: 596.34028km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.889496675981029, 51.1451259602847]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.345323049722392, 51.241112128502685], [-6.253999670538588, 51.2220702787279], [-6.16275514294479, 51.202950620405545], [-6.071589668417512, 51.18375327002673], [-5.980503446740215, 51.16447834432754], [-5.889496675981029, 51.1451259602847], [-5.798569552521365, 51.125696235114745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.7985696&lt;dd&gt;Longitude: 51.125696&lt;dd&gt;Azimuth: 261.81304\u00b0&lt;dd&gt;Altitude: 65.610457\u00b0&lt;dd&gt;Slant Range: 593.8845km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.798569552521365, 51.125696235114745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.253999670538588, 51.2220702787279], [-6.16275514294479, 51.202950620405545], [-6.071589668417512, 51.18375327002673], [-5.980503446740215, 51.16447834432754], [-5.889496675981029, 51.1451259602847], [-5.798569552521365, 51.125696235114745], [-5.7077222710223685, 51.10618928626862]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.7077223&lt;dd&gt;Longitude: 51.106189&lt;dd&gt;Azimuth: 260.95191\u00b0&lt;dd&gt;Altitude: 66.176637\u00b0&lt;dd&gt;Slant Range: 591.50151km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.7077222710223685, 51.10618928626862]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.16275514294479, 51.202950620405545], [-6.071589668417512, 51.18375327002673], [-5.980503446740215, 51.16447834432754], [-5.889496675981029, 51.1451259602847], [-5.798569552521365, 51.125696235114745], [-5.7077222710223685, 51.10618928626862], [-5.6169550244630475, 51.08660523143143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.616955&lt;dd&gt;Longitude: 51.086605&lt;dd&gt;Azimuth: 260.04403\u00b0&lt;dd&gt;Altitude: 66.741948\u00b0&lt;dd&gt;Slant Range: 589.19219km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.6169550244630475, 51.08660523143143]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.071589668417512, 51.18375327002673], [-5.980503446740215, 51.16447834432754], [-5.889496675981029, 51.1451259602847], [-5.798569552521365, 51.125696235114745], [-5.7077222710223685, 51.10618928626862], [-5.6169550244630475, 51.08660523143143], [-5.526268004113514, 51.06694418851746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.526268&lt;dd&gt;Longitude: 51.066944&lt;dd&gt;Azimuth: 259.086\u00b0&lt;dd&gt;Altitude: 67.305794\u00b0&lt;dd&gt;Slant Range: 586.95743km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.526268004113514, 51.06694418851746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.980503446740215, 51.16447834432754], [-5.889496675981029, 51.1451259602847], [-5.798569552521365, 51.125696235114745], [-5.7077222710223685, 51.10618928626862], [-5.6169550244630475, 51.08660523143143], [-5.526268004113514, 51.06694418851746], [-5.435661399554725, 51.04720627566823]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.4356614&lt;dd&gt;Longitude: 51.047206&lt;dd&gt;Azimuth: 258.07415\u00b0&lt;dd&gt;Altitude: 67.867523\u00b0&lt;dd&gt;Slant Range: 584.79807km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.435661399554725, 51.04720627566823]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.889496675981029, 51.1451259602847], [-5.798569552521365, 51.125696235114745], [-5.7077222710223685, 51.10618928626862], [-5.6169550244630475, 51.08660523143143], [-5.526268004113514, 51.06694418851746], [-5.435661399554725, 51.04720627566823], [-5.345135398663291, 51.02739161124923]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.3451354&lt;dd&gt;Longitude: 51.027392&lt;dd&gt;Azimuth: 257.00452\u00b0&lt;dd&gt;Altitude: 68.426421\u00b0&lt;dd&gt;Slant Range: 582.71496km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.345135398663291, 51.02739161124923]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.798569552521365, 51.125696235114745], [-5.7077222710223685, 51.10618928626862], [-5.6169550244630475, 51.08660523143143], [-5.526268004113514, 51.06694418851746], [-5.435661399554725, 51.04720627566823], [-5.345135398663291, 51.02739161124923], [-5.2546901876355765, 51.007500313847984]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.2546902&lt;dd&gt;Longitude: 51.0075&lt;dd&gt;Azimuth: 255.87286\u00b0&lt;dd&gt;Altitude: 68.981703\u00b0&lt;dd&gt;Slant Range: 580.70891km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.2546901876355765, 51.007500313847984]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.7077222710223685, 51.10618928626862], [-5.6169550244630475, 51.08660523143143], [-5.526268004113514, 51.06694418851746], [-5.435661399554725, 51.04720627566823], [-5.345135398663291, 51.02739161124923], [-5.2546901876355765, 51.007500313847984], [-5.16432595096141, 50.987532502269346]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.164326&lt;dd&gt;Longitude: 50.987533&lt;dd&gt;Azimuth: 254.67458\u00b0&lt;dd&gt;Altitude: 69.532512\u00b0&lt;dd&gt;Slant Range: 578.78075km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.16432595096141, 50.987532502269346]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.6169550244630475, 51.08660523143143], [-5.526268004113514, 51.06694418851746], [-5.435661399554725, 51.04720627566823], [-5.345135398663291, 51.02739161124923], [-5.2546901876355765, 51.007500313847984], [-5.16432595096141, 50.987532502269346], [-5.074042871454114, 50.96748829553469]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -5.0740429&lt;dd&gt;Longitude: 50.967488&lt;dd&gt;Azimuth: 253.40481\u00b0&lt;dd&gt;Altitude: 70.077905\u00b0&lt;dd&gt;Slant Range: 576.93123km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.074042871454114, 50.96748829553469]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.526268004113514, 51.06694418851746], [-5.435661399554725, 51.04720627566823], [-5.345135398663291, 51.02739161124923], [-5.2546901876355765, 51.007500313847984], [-5.16432595096141, 50.987532502269346], [-5.074042871454114, 50.96748829553469], [-4.983841130230704, 50.94736781287757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.9838411&lt;dd&gt;Longitude: 50.947368&lt;dd&gt;Azimuth: 252.05834\u00b0&lt;dd&gt;Altitude: 70.61685\u00b0&lt;dd&gt;Slant Range: 575.16114km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.983841130230704, 50.94736781287757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.435661399554725, 51.04720627566823], [-5.345135398663291, 51.02739161124923], [-5.2546901876355765, 51.007500313847984], [-5.16432595096141, 50.987532502269346], [-5.074042871454114, 50.96748829553469], [-4.983841130230704, 50.94736781287757], [-4.893720906727213, 50.92717117374148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.8937209&lt;dd&gt;Longitude: 50.927171&lt;dd&gt;Azimuth: 250.62966\u00b0&lt;dd&gt;Altitude: 71.148217\u00b0&lt;dd&gt;Slant Range: 573.4712km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.893720906727213, 50.92717117374148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.345135398663291, 51.02739161124923], [-5.2546901876355765, 51.007500313847984], [-5.16432595096141, 50.987532502269346], [-5.074042871454114, 50.96748829553469], [-4.983841130230704, 50.94736781287757], [-4.893720906727213, 50.92717117374148], [-4.803682378691176, 50.906898497776766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.8036824&lt;dd&gt;Longitude: 50.906898&lt;dd&gt;Azimuth: 249.11298\u00b0&lt;dd&gt;Altitude: 71.670767\u00b0&lt;dd&gt;Slant Range: 571.86213km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.803682378691176, 50.906898497776766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.2546901876355765, 51.007500313847984], [-5.16432595096141, 50.987532502269346], [-5.074042871454114, 50.96748829553469], [-4.983841130230704, 50.94736781287757], [-4.893720906727213, 50.92717117374148], [-4.803682378691176, 50.906898497776766], [-4.713725722191411, 50.88654990483849]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.7137257&lt;dd&gt;Longitude: 50.88655&lt;dd&gt;Azimuth: 247.50228\u00b0&lt;dd&gt;Altitude: 72.183147\u00b0&lt;dd&gt;Slant Range: 570.33461km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.713725722191411, 50.88654990483849]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.16432595096141, 50.987532502269346], [-5.074042871454114, 50.96748829553469], [-4.983841130230704, 50.94736781287757], [-4.893720906727213, 50.92717117374148], [-4.803682378691176, 50.906898497776766], [-4.713725722191411, 50.88654990483849], [-4.623851111616786, 50.866125514982095]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.6238511&lt;dd&gt;Longitude: 50.866126&lt;dd&gt;Azimuth: 245.79135\u00b0&lt;dd&gt;Altitude: 72.683879\u00b0&lt;dd&gt;Slant Range: 568.8893km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.623851111616786, 50.866125514982095]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.074042871454114, 50.96748829553469], [-4.983841130230704, 50.94736781287757], [-4.893720906727213, 50.92717117374148], [-4.803682378691176, 50.906898497776766], [-4.713725722191411, 50.88654990483849], [-4.623851111616786, 50.866125514982095], [-4.534058719675063, 50.84562544846258]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.5340587&lt;dd&gt;Longitude: 50.845625&lt;dd&gt;Azimuth: 243.97394\u00b0&lt;dd&gt;Altitude: 73.171354\u00b0&lt;dd&gt;Slant Range: 567.52684km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.534058719675063, 50.84562544846258]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.983841130230704, 50.94736781287757], [-4.893720906727213, 50.92717117374148], [-4.803682378691176, 50.906898497776766], [-4.713725722191411, 50.88654990483849], [-4.623851111616786, 50.866125514982095], [-4.534058719675063, 50.84562544846258], [-4.444348717400693, 50.825049825729465]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.4443487&lt;dd&gt;Longitude: 50.82505&lt;dd&gt;Azimuth: 242.04384\u00b0&lt;dd&gt;Altitude: 73.643823\u00b0&lt;dd&gt;Slant Range: 566.24782km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.444348717400693, 50.825049825729465]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.893720906727213, 50.92717117374148], [-4.803682378691176, 50.906898497776766], [-4.713725722191411, 50.88654990483849], [-4.623851111616786, 50.866125514982095], [-4.534058719675063, 50.84562544846258], [-4.444348717400693, 50.825049825729465], [-4.354721274158089, 50.8043987674261]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.3547213&lt;dd&gt;Longitude: 50.804399&lt;dd&gt;Azimuth: 239.99507\u00b0&lt;dd&gt;Altitude: 74.099399\u00b0&lt;dd&gt;Slant Range: 565.05282km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.354721274158089, 50.8043987674261]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.803682378691176, 50.906898497776766], [-4.713725722191411, 50.88654990483849], [-4.623851111616786, 50.866125514982095], [-4.534058719675063, 50.84562544846258], [-4.444348717400693, 50.825049825729465], [-4.354721274158089, 50.8043987674261], [-4.265176557636116, 50.783672394385356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.2651766&lt;dd&gt;Longitude: 50.783672&lt;dd&gt;Azimuth: 237.82213\u00b0&lt;dd&gt;Altitude: 74.536051\u00b0&lt;dd&gt;Slant Range: 563.94236km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.265176557636116, 50.783672394385356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.713725722191411, 50.88654990483849], [-4.623851111616786, 50.866125514982095], [-4.534058719675063, 50.84562544846258], [-4.444348717400693, 50.825049825729465], [-4.354721274158089, 50.8043987674261], [-4.265176557636116, 50.783672394385356], [-4.175714733854998, 50.7628708276273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.1757147&lt;dd&gt;Longitude: 50.762871&lt;dd&gt;Azimuth: 235.52026\u00b0&lt;dd&gt;Altitude: 74.951612\u00b0&lt;dd&gt;Slant Range: 562.91694km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.175714733854998, 50.7628708276273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.623851111616786, 50.866125514982095], [-4.534058719675063, 50.84562544846258], [-4.444348717400693, 50.825049825729465], [-4.354721274158089, 50.8043987674261], [-4.265176557636116, 50.783672394385356], [-4.175714733854998, 50.7628708276273], [-4.086335967175801, 50.74199418835687]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -4.086336&lt;dd&gt;Longitude: 50.741994&lt;dd&gt;Azimuth: 233.08579\u00b0&lt;dd&gt;Altitude: 75.343789\u00b0&lt;dd&gt;Slant Range: 561.97704km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.086335967175801, 50.74199418835687]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.534058719675063, 50.84562544846258], [-4.444348717400693, 50.825049825729465], [-4.354721274158089, 50.8043987674261], [-4.265176557636116, 50.783672394385356], [-4.175714733854998, 50.7628708276273], [-4.086335967175801, 50.74199418835687], [-3.997040420282293, 50.72104259796008]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.9970404&lt;dd&gt;Longitude: 50.721043&lt;dd&gt;Azimuth: 230.51654\u00b0&lt;dd&gt;Altitude: 75.710182\u00b0&lt;dd&gt;Slant Range: 561.12309km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.997040420282293, 50.72104259796008]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.444348717400693, 50.825049825729465], [-4.354721274158089, 50.8043987674261], [-4.265176557636116, 50.783672394385356], [-4.175714733854998, 50.7628708276273], [-4.086335967175801, 50.74199418835687], [-3.997040420282293, 50.72104259796008], [-3.9078282542164664, 50.700016178002045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.9078283&lt;dd&gt;Longitude: 50.700016&lt;dd&gt;Azimuth: 227.81224\u00b0&lt;dd&gt;Altitude: 76.048313\u00b0&lt;dd&gt;Slant Range: 560.35548km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9078282542164664, 50.700016178002045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.354721274158089, 50.8043987674261], [-4.265176557636116, 50.783672394385356], [-4.175714733854998, 50.7628708276273], [-4.086335967175801, 50.74199418835687], [-3.997040420282293, 50.72104259796008], [-3.9078282542164664, 50.700016178002045], [-3.818699628346197, 50.67891505022454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.8186996&lt;dd&gt;Longitude: 50.678915&lt;dd&gt;Azimuth: 224.97503\u00b0&lt;dd&gt;Altitude: 76.355666\u00b0&lt;dd&gt;Slant Range: 559.67457km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.818699628346197, 50.67891505022454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.265176557636116, 50.783672394385356], [-4.175714733854998, 50.7628708276273], [-4.086335967175801, 50.74199418835687], [-3.997040420282293, 50.72104259796008], [-3.9078282542164664, 50.700016178002045], [-3.818699628346197, 50.67891505022454], [-3.7296547003913996, 50.65773933654165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.7296547&lt;dd&gt;Longitude: 50.657739&lt;dd&gt;Azimuth: 222.00983\u00b0&lt;dd&gt;Altitude: 76.629741\u00b0&lt;dd&gt;Slant Range: 559.08066km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7296547003913996, 50.65773933654165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.175714733854998, 50.7628708276273], [-4.086335967175801, 50.74199418835687], [-3.997040420282293, 50.72104259796008], [-3.9078282542164664, 50.700016178002045], [-3.818699628346197, 50.67891505022454], [-3.7296547003913996, 50.65773933654165], [-3.6406936264164984, 50.63648915903896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.6406936&lt;dd&gt;Longitude: 50.636489&lt;dd&gt;Azimuth: 218.92476\u00b0&lt;dd&gt;Altitude: 76.868117\u00b0&lt;dd&gt;Slant Range: 558.57405km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6406936264164984, 50.63648915903896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.086335967175801, 50.74199418835687], [-3.997040420282293, 50.72104259796008], [-3.9078282542164664, 50.700016178002045], [-3.818699628346197, 50.67891505022454], [-3.7296547003913996, 50.65773933654165], [-3.6406936264164984, 50.63648915903896], [-3.551816560838823, 50.61516463996925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.5518166&lt;dd&gt;Longitude: 50.615165&lt;dd&gt;Azimuth: 215.73137\u00b0&lt;dd&gt;Altitude: 77.068523\u00b0&lt;dd&gt;Slant Range: 558.15498km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.551816560838823, 50.61516463996925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.997040420282293, 50.72104259796008], [-3.9078282542164664, 50.700016178002045], [-3.818699628346197, 50.67891505022454], [-3.7296547003913996, 50.65773933654165], [-3.6406936264164984, 50.63648915903896], [-3.551816560838823, 50.61516463996925], [-3.463023656425376, 50.59376590175087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.4630237&lt;dd&gt;Longitude: 50.593766&lt;dd&gt;Azimuth: 212.44471\u00b0&lt;dd&gt;Altitude: 77.228924\u00b0&lt;dd&gt;Slant Range: 557.82363km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.463023656425376, 50.59376590175087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9078282542164664, 50.700016178002045], [-3.818699628346197, 50.67891505022454], [-3.7296547003913996, 50.65773933654165], [-3.6406936264164984, 50.63648915903896], [-3.551816560838823, 50.61516463996925], [-3.463023656425376, 50.59376590175087], [-3.374315064301994, 50.57229306696405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.3743151&lt;dd&gt;Longitude: 50.572293&lt;dd&gt;Azimuth: 209.08316\u00b0&lt;dd&gt;Altitude: 77.3476\u00b0&lt;dd&gt;Slant Range: 557.58016km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.374315064301994, 50.57229306696405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.818699628346197, 50.67891505022454], [-3.7296547003913996, 50.65773933654165], [-3.6406936264164984, 50.63648915903896], [-3.551816560838823, 50.61516463996925], [-3.463023656425376, 50.59376590175087], [-3.374315064301994, 50.57229306696405], [-3.285690933951669, 50.550746258349356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.2856909&lt;dd&gt;Longitude: 50.550746&lt;dd&gt;Azimuth: 205.66797\u00b0&lt;dd&gt;Altitude: 77.423222\u00b0&lt;dd&gt;Slant Range: 557.4247km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.285690933951669, 50.550746258349356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7296547003913996, 50.65773933654165], [-3.6406936264164984, 50.63648915903896], [-3.551816560838823, 50.61516463996925], [-3.463023656425376, 50.59376590175087], [-3.374315064301994, 50.57229306696405], [-3.285690933951669, 50.550746258349356], [-3.1971514132217975, 50.52912559880334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.1971514&lt;dd&gt;Longitude: 50.529126&lt;dd&gt;Azimuth: 202.2226\u00b0&lt;dd&gt;Altitude: 77.454917\u00b0&lt;dd&gt;Slant Range: 557.35731km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1971514132217975, 50.52912559880334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6406936264164984, 50.63648915903896], [-3.551816560838823, 50.61516463996925], [-3.463023656425376, 50.59376590175087], [-3.374315064301994, 50.57229306696405], [-3.285690933951669, 50.550746258349356], [-3.1971514132217975, 50.52912559880334], [-3.1086966483198326, 50.507431211377735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.1086966&lt;dd&gt;Longitude: 50.507431&lt;dd&gt;Azimuth: 198.77178\u00b0&lt;dd&gt;Altitude: 77.442312\u00b0&lt;dd&gt;Slant Range: 557.37803km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1086966483198326, 50.507431211377735]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.551816560838823, 50.61516463996925], [-3.463023656425376, 50.59376590175087], [-3.374315064301994, 50.57229306696405], [-3.285690933951669, 50.550746258349356], [-3.1971514132217975, 50.52912559880334], [-3.1086966483198326, 50.507431211377735], [-3.0203267838260803, 50.485663219275054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -3.0203268&lt;dd&gt;Longitude: 50.485663&lt;dd&gt;Azimuth: 195.34046\u00b0&lt;dd&gt;Altitude: 77.385553\u00b0&lt;dd&gt;Slant Range: 557.48685km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0203267838260803, 50.485663219275054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.463023656425376, 50.59376590175087], [-3.374315064301994, 50.57229306696405], [-3.285690933951669, 50.550746258349356], [-3.1971514132217975, 50.52912559880334], [-3.1086966483198326, 50.507431211377735], [-3.0203267838260803, 50.485663219275054], [-2.9320419626930136, 50.46382174584708]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.932042&lt;dd&gt;Longitude: 50.463822&lt;dd&gt;Azimuth: 191.95278\u00b0&lt;dd&gt;Altitude: 77.285298\u00b0&lt;dd&gt;Slant Range: 557.68372km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9320419626930136, 50.46382174584708]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.374315064301994, 50.57229306696405], [-3.285690933951669, 50.550746258349356], [-3.1971514132217975, 50.52912559880334], [-3.1086966483198326, 50.507431211377735], [-3.0203267838260803, 50.485663219275054], [-2.9320419626930136, 50.46382174584708], [-2.8438423262445336, 50.441906914591584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.8438423&lt;dd&gt;Longitude: 50.441907&lt;dd&gt;Azimuth: 188.63106\u00b0&lt;dd&gt;Altitude: 77.142681\u00b0&lt;dd&gt;Slant Range: 557.96853km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8438423262445336, 50.441906914591584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.285690933951669, 50.550746258349356], [-3.1971514132217975, 50.52912559880334], [-3.1086966483198326, 50.507431211377735], [-3.0203267838260803, 50.485663219275054], [-2.9320419626930136, 50.46382174584708], [-2.8438423262445336, 50.441906914591584], [-2.7557280141830702, 50.419918849149866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.755728&lt;dd&gt;Longitude: 50.419919&lt;dd&gt;Azimuth: 185.39499\u00b0&lt;dd&gt;Altitude: 76.959259\u00b0&lt;dd&gt;Slant Range: 558.34117km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7557280141830702, 50.419918849149866]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1971514132217975, 50.52912559880334], [-3.1086966483198326, 50.507431211377735], [-3.0203267838260803, 50.485663219275054], [-2.9320419626930136, 50.46382174584708], [-2.8438423262445336, 50.441906914591584], [-2.7557280141830702, 50.419918849149866], [-2.6676991645960433, 50.397857673303704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.6676992&lt;dd&gt;Longitude: 50.397858&lt;dd&gt;Azimuth: 182.2611\u00b0&lt;dd&gt;Altitude: 76.73694\u00b0&lt;dd&gt;Slant Range: 558.80145km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6676991645960433, 50.397857673303704]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1086966483198326, 50.507431211377735], [-3.0203267838260803, 50.485663219275054], [-2.9320419626930136, 50.46382174584708], [-2.8438423262445336, 50.441906914591584], [-2.7557280141830702, 50.419918849149866], [-2.6676991645960433, 50.397857673303704], [-2.5797559139501383, 50.375723510973884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.5797559&lt;dd&gt;Longitude: 50.375724&lt;dd&gt;Azimuth: 179.24248\u00b0&lt;dd&gt;Altitude: 76.477899\u00b0&lt;dd&gt;Slant Range: 559.34915km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5797559139501383, 50.375723510973884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0203267838260803, 50.485663219275054], [-2.9320419626930136, 50.46382174584708], [-2.8438423262445336, 50.441906914591584], [-2.7557280141830702, 50.419918849149866], [-2.6676991645960433, 50.397857673303704], [-2.5797559139501383, 50.375723510973884], [-2.4918983971035202, 50.353516486215476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.4918984&lt;dd&gt;Longitude: 50.353516&lt;dd&gt;Azimuth: 176.34872\u00b0&lt;dd&gt;Altitude: 76.1845\u00b0&lt;dd&gt;Slant Range: 559.98402km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.4918983971035202, 50.353516486215476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9320419626930136, 50.46382174584708], [-2.8438423262445336, 50.441906914591584], [-2.7557280141830702, 50.419918849149866], [-2.6676991645960433, 50.397857673303704], [-2.5797559139501383, 50.375723510973884], [-2.4918983971035202, 50.353516486215476], [-2.4041267473104635, 50.33123672321759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.4041267&lt;dd&gt;Longitude: 50.331237&lt;dd&gt;Azimuth: 173.58611\u00b0&lt;dd&gt;Altitude: 75.859217\u00b0&lt;dd&gt;Slant Range: 560.70577km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.4041267473104635, 50.33123672321759]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8438423262445336, 50.441906914591584], [-2.7557280141830702, 50.419918849149866], [-2.6676991645960433, 50.397857673303704], [-2.5797559139501383, 50.375723510973884], [-2.4918983971035202, 50.353516486215476], [-2.4041267473104635, 50.33123672321759], [-2.316441096210132, 50.30888434629876]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.3164411&lt;dd&gt;Longitude: 50.308884&lt;dd&gt;Azimuth: 170.95793\u00b0&lt;dd&gt;Altitude: 75.504566\u00b0&lt;dd&gt;Slant Range: 561.51405km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.316441096210132, 50.30888434629876]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7557280141830702, 50.419918849149866], [-2.6676991645960433, 50.397857673303704], [-2.5797559139501383, 50.375723510973884], [-2.4918983971035202, 50.353516486215476], [-2.4041267473104635, 50.33123672321759], [-2.316441096210132, 50.30888434629876], [-2.22884157385159, 50.28645947990575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.2288416&lt;dd&gt;Longitude: 50.286459&lt;dd&gt;Azimuth: 168.4649\u00b0&lt;dd&gt;Altitude: 75.123046\u00b0&lt;dd&gt;Slant Range: 562.40849km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.22884157385159, 50.28645947990575]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6676991645960433, 50.397857673303704], [-2.5797559139501383, 50.375723510973884], [-2.4918983971035202, 50.353516486215476], [-2.4041267473104635, 50.33123672321759], [-2.316441096210132, 50.30888434629876], [-2.22884157385159, 50.28645947990575], [-2.1413283086788404, 50.26396224860984]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.1413283&lt;dd&gt;Longitude: 50.263962&lt;dd&gt;Azimuth: 166.10563\u00b0&lt;dd&gt;Altitude: 74.717094\u00b0&lt;dd&gt;Slant Range: 563.38868km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.1413283086788404, 50.26396224860984]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5797559139501383, 50.375723510973884], [-2.4918983971035202, 50.353516486215476], [-2.4041267473104635, 50.33123672321759], [-2.316441096210132, 50.30888434629876], [-2.22884157385159, 50.28645947990575], [-2.1413283086788404, 50.26396224860984], [-2.0539014275479253, 50.241392777105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -2.0539014&lt;dd&gt;Longitude: 50.241393&lt;dd&gt;Azimuth: 163.87704\u00b0&lt;dd&gt;Altitude: 74.289052\u00b0&lt;dd&gt;Slant Range: 564.45418km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0539014275479253, 50.241392777105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.4918983971035202, 50.353516486215476], [-2.4041267473104635, 50.33123672321759], [-2.316441096210132, 50.30888434629876], [-2.22884157385159, 50.28645947990575], [-2.1413283086788404, 50.26396224860984], [-2.0539014275479253, 50.241392777105], [-1.9665610557188848, 50.218751190204976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.9665611&lt;dd&gt;Longitude: 50.218751&lt;dd&gt;Azimuth: 161.77481\u00b0&lt;dd&gt;Altitude: 73.841144\u00b0&lt;dd&gt;Slant Range: 565.6045km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9665610557188848, 50.218751190204976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.4041267473104635, 50.33123672321759], [-2.316441096210132, 50.30888434629876], [-2.22884157385159, 50.28645947990575], [-2.1413283086788404, 50.26396224860984], [-2.0539014275479253, 50.241392777105], [-1.9665610557188848, 50.218751190204976], [-1.8793073168765437, 50.19603761284087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.8793073&lt;dd&gt;Longitude: 50.196038&lt;dd&gt;Azimuth: 159.79371\u00b0&lt;dd&gt;Altitude: 73.375461\u00b0&lt;dd&gt;Slant Range: 566.83912km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8793073168765437, 50.19603761284087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.316441096210132, 50.30888434629876], [-2.22884157385159, 50.28645947990575], [-2.1413283086788404, 50.26396224860984], [-2.0539014275479253, 50.241392777105], [-1.9665610557188848, 50.218751190204976], [-1.8793073168765437, 50.19603761284087], [-1.792140333108758, 50.17325217005809]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.7921403&lt;dd&gt;Longitude: 50.173252&lt;dd&gt;Azimuth: 157.92795\u00b0&lt;dd&gt;Altitude: 72.893954\u00b0&lt;dd&gt;Slant Range: 568.1575km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.792140333108758, 50.17325217005809]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.22884157385159, 50.28645947990575], [-2.1413283086788404, 50.26396224860984], [-2.0539014275479253, 50.241392777105], [-1.9665610557188848, 50.218751190204976], [-1.8793073168765437, 50.19603761284087], [-1.792140333108758, 50.17325217005809], [-1.7050602249376603, 50.15039498701461]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.7050602&lt;dd&gt;Longitude: 50.150395&lt;dd&gt;Azimuth: 156.17139\u00b0&lt;dd&gt;Altitude: 72.39843\u00b0&lt;dd&gt;Slant Range: 569.55904km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7050602249376603, 50.15039498701461]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.1413283086788404, 50.26396224860984], [-2.0539014275479253, 50.241392777105], [-1.9665610557188848, 50.218751190204976], [-1.8793073168765437, 50.19603761284087], [-1.792140333108758, 50.17325217005809], [-1.7050602249376603, 50.15039498701461], [-1.6180671113026117, 50.127466188977756]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.6180671&lt;dd&gt;Longitude: 50.127466&lt;dd&gt;Azimuth: 154.51778\u00b0&lt;dd&gt;Altitude: 71.890559\u00b0&lt;dd&gt;Slant Range: 571.04314km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6180671113026117, 50.127466188977756]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0539014275479253, 50.241392777105], [-1.9665610557188848, 50.218751190204976], [-1.8793073168765437, 50.19603761284087], [-1.792140333108758, 50.17325217005809], [-1.7050602249376603, 50.15039498701461], [-1.6180671113026117, 50.127466188977756], [-1.5311611095826447, 50.104465901321845]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.5311611&lt;dd&gt;Longitude: 50.104466&lt;dd&gt;Azimuth: 152.96087\u00b0&lt;dd&gt;Altitude: 71.371875\u00b0&lt;dd&gt;Slant Range: 572.60915km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5311611095826447, 50.104465901321845]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9665610557188848, 50.218751190204976], [-1.8793073168765437, 50.19603761284087], [-1.792140333108758, 50.17325217005809], [-1.7050602249376603, 50.15039498701461], [-1.6180671113026117, 50.127466188977756], [-1.5311611095826447, 50.104465901321845], [-1.444342335577353, 50.08139424952558]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.4443423&lt;dd&gt;Longitude: 50.081394&lt;dd&gt;Azimuth: 151.49456\u00b0&lt;dd&gt;Altitude: 70.843786\u00b0&lt;dd&gt;Slant Range: 574.2564km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.444342335577353, 50.08139424952558]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8793073168765437, 50.19603761284087], [-1.792140333108758, 50.17325217005809], [-1.7050602249376603, 50.15039498701461], [-1.6180671113026117, 50.127466188977756], [-1.5311611095826447, 50.104465901321845], [-1.444342335577353, 50.08139424952558], [-1.3576109035361283, 50.05825135917009]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.3576109&lt;dd&gt;Longitude: 50.058251&lt;dd&gt;Azimuth: 150.11294\u00b0&lt;dd&gt;Altitude: 70.30758\u00b0&lt;dd&gt;Slant Range: 575.9842km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3576109035361283, 50.05825135917009]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.792140333108758, 50.17325217005809], [-1.7050602249376603, 50.15039498701461], [-1.6180671113026117, 50.127466188977756], [-1.5311611095826447, 50.104465901321845], [-1.444342335577353, 50.08139424952558], [-1.3576109035361283, 50.05825135917009], [-1.270966926142461, 50.03503735593524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.2709669&lt;dd&gt;Longitude: 50.035037&lt;dd&gt;Azimuth: 148.81039\u00b0&lt;dd&gt;Altitude: 69.764434\u00b0&lt;dd&gt;Slant Range: 577.79181km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.270966926142461, 50.03503735593524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7050602249376603, 50.15039498701461], [-1.6180671113026117, 50.127466188977756], [-1.5311611095826447, 50.104465901321845], [-1.444342335577353, 50.08139424952558], [-1.3576109035361283, 50.05825135917009], [-1.270966926142461, 50.03503735593524], [-1.184410514528799, 50.011752365598554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.1844105&lt;dd&gt;Longitude: 50.011752&lt;dd&gt;Azimuth: 147.58157\u00b0&lt;dd&gt;Altitude: 69.215421\u00b0&lt;dd&gt;Slant Range: 579.67849km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.184410514528799, 50.011752365598554]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6180671113026117, 50.127466188977756], [-1.5311611095826447, 50.104465901321845], [-1.444342335577353, 50.08139424952558], [-1.3576109035361283, 50.05825135917009], [-1.270966926142461, 50.03503735593524], [-1.184410514528799, 50.011752365598554], [-1.0979417782782535, 49.988396514031535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.0979418&lt;dd&gt;Longitude: 49.988397&lt;dd&gt;Azimuth: 146.42144\u00b0&lt;dd&gt;Altitude: 68.661522\u00b0&lt;dd&gt;Slant Range: 581.64347km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0979417782782535, 49.988396514031535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5311611095826447, 50.104465901321845], [-1.444342335577353, 50.08139424952558], [-1.3576109035361283, 50.05825135917009], [-1.270966926142461, 50.03503735593524], [-1.184410514528799, 50.011752365598554], [-1.0979417782782535, 49.988396514031535], [-1.0115608254311879, 49.964969927197885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -1.0115608&lt;dd&gt;Longitude: 49.96497&lt;dd&gt;Azimuth: 145.3253\u00b0&lt;dd&gt;Altitude: 68.103632\u00b0&lt;dd&gt;Slant Range: 583.68595km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0115608254311879, 49.964969927197885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.444342335577353, 50.08139424952558], [-1.3576109035361283, 50.05825135917009], [-1.270966926142461, 50.03503735593524], [-1.184410514528799, 50.011752365598554], [-1.0979417782782535, 49.988396514031535], [-1.0115608254311879, 49.964969927197885], [-0.9252677624779927, 49.94147273115069]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.92526776&lt;dd&gt;Longitude: 49.941473&lt;dd&gt;Azimuth: 144.28875\u00b0&lt;dd&gt;Altitude: 67.542567\u00b0&lt;dd&gt;Slant Range: 585.80513km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9252677624779927, 49.94147273115069]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3576109035361283, 50.05825135917009], [-1.270966926142461, 50.03503735593524], [-1.184410514528799, 50.011752365598554], [-1.0979417782782535, 49.988396514031535], [-1.0115608254311879, 49.964969927197885], [-0.9252677624779927, 49.94147273115069], [-0.8390626943824685, 49.91790505203025]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.83906269&lt;dd&gt;Longitude: 49.917905&lt;dd&gt;Azimuth: 143.30771\u00b0&lt;dd&gt;Altitude: 66.979072\u00b0&lt;dd&gt;Slant Range: 588.00016km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8390626943824685, 49.91790505203025]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.270966926142461, 50.03503735593524], [-1.184410514528799, 50.011752365598554], [-1.0979417782782535, 49.988396514031535], [-1.0115608254311879, 49.964969927197885], [-0.9252677624779927, 49.94147273115069], [-0.8390626943824685, 49.91790505203025], [-0.7529457245671952, 49.89426701606103]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.75294572&lt;dd&gt;Longitude: 49.894267&lt;dd&gt;Azimuth: 142.37838\u00b0&lt;dd&gt;Altitude: 66.413824\u00b0&lt;dd&gt;Slant Range: 590.27021km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7529457245671952, 49.89426701606103]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.184410514528799, 50.011752365598554], [-1.0979417782782535, 49.988396514031535], [-1.0115608254311879, 49.964969927197885], [-0.9252677624779927, 49.94147273115069], [-0.8390626943824685, 49.91790505203025], [-0.7529457245671952, 49.89426701606103], [-0.6669169549357454, 49.87055874955052]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.66691695&lt;dd&gt;Longitude: 49.870559&lt;dd&gt;Azimuth: 141.49725\u00b0&lt;dd&gt;Altitude: 65.847445\u00b0&lt;dd&gt;Slant Range: 592.61441km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6669169549357454, 49.87055874955052]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0979417782782535, 49.988396514031535], [-1.0115608254311879, 49.964969927197885], [-0.9252677624779927, 49.94147273115069], [-0.8390626943824685, 49.91790505203025], [-0.7529457245671952, 49.89426701606103], [-0.6669169549357454, 49.87055874955052], [-0.5809764858579264, 49.84678037888468]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.58097649&lt;dd&gt;Longitude: 49.84678&lt;dd&gt;Azimuth: 140.66106\u00b0&lt;dd&gt;Altitude: 65.280501\u00b0&lt;dd&gt;Slant Range: 595.03187km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5809764858579264, 49.84678037888468]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0115608254311879, 49.964969927197885], [-0.9252677624779927, 49.94147273115069], [-0.8390626943824685, 49.91790505203025], [-0.7529457245671952, 49.89426701606103], [-0.6669169549357454, 49.87055874955052], [-0.5809764858579264, 49.84678037888468], [-0.49512441619479214, 49.82293203052818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.49512442&lt;dd&gt;Longitude: 49.822932&lt;dd&gt;Azimuth: 139.8668\u00b0&lt;dd&gt;Altitude: 64.713509\u00b0&lt;dd&gt;Slant Range: 597.52171km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.49512441619479214, 49.82293203052818]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9252677624779927, 49.94147273115069], [-0.8390626943824685, 49.91790505203025], [-0.7529457245671952, 49.89426701606103], [-0.6669169549357454, 49.87055874955052], [-0.5809764858579264, 49.84678037888468], [-0.49512441619479214, 49.82293203052818], [-0.40936084328508127, 49.799013831019266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.40936084&lt;dd&gt;Longitude: 49.799014&lt;dd&gt;Azimuth: 139.1117\u00b0&lt;dd&gt;Altitude: 64.14694\u00b0&lt;dd&gt;Slant Range: 600.08303km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.40936084328508127, 49.799013831019266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8390626943824685, 49.91790505203025], [-0.7529457245671952, 49.89426701606103], [-0.6669169549357454, 49.87055874955052], [-0.5809764858579264, 49.84678037888468], [-0.49512441619479214, 49.82293203052818], [-0.40936084328508127, 49.799013831019266], [-0.3236858629576851, 49.77502590696966]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.32368586&lt;dd&gt;Longitude: 49.775026&lt;dd&gt;Azimuth: 138.39318\u00b0&lt;dd&gt;Altitude: 63.581225\u00b0&lt;dd&gt;Slant Range: 602.7149km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3236858629576851, 49.77502590696966]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7529457245671952, 49.89426701606103], [-0.6669169549357454, 49.87055874955052], [-0.5809764858579264, 49.84678037888468], [-0.49512441619479214, 49.82293203052818], [-0.40936084328508127, 49.799013831019266], [-0.3236858629576851, 49.77502590696966], [-0.23809956954024755, 49.75096838506068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.23809957&lt;dd&gt;Longitude: 49.750968&lt;dd&gt;Azimuth: 137.70887\u00b0&lt;dd&gt;Altitude: 63.01676\u00b0&lt;dd&gt;Slant Range: 605.41642km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.23809956954024755, 49.75096838506068]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6669169549357454, 49.87055874955052], [-0.5809764858579264, 49.84678037888468], [-0.49512441619479214, 49.82293203052818], [-0.40936084328508127, 49.799013831019266], [-0.3236858629576851, 49.77502590696966], [-0.23809956954024755, 49.75096838506068], [-0.15260205585850375, 49.726841392041514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.15260206&lt;dd&gt;Longitude: 49.726841&lt;dd&gt;Azimuth: 137.05658\u00b0&lt;dd&gt;Altitude: 62.453904\u00b0&lt;dd&gt;Slant Range: 608.18663km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.15260205585850375, 49.726841392041514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5809764858579264, 49.84678037888468], [-0.49512441619479214, 49.82293203052818], [-0.40936084328508127, 49.799013831019266], [-0.3236858629576851, 49.77502590696966], [-0.23809956954024755, 49.75096838506068], [-0.15260205585850375, 49.726841392041514], [-0.06719341323925708, 49.70264505472652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: -0.067193413&lt;dd&gt;Longitude: 49.702645&lt;dd&gt;Azimuth: 136.43428\u00b0&lt;dd&gt;Altitude: 61.892985\u00b0&lt;dd&gt;Slant Range: 611.02462km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.06719341323925708, 49.70264505472652]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.49512441619479214, 49.82293203052818], [-0.40936084328508127, 49.799013831019266], [-0.3236858629576851, 49.77502590696966], [-0.23809956954024755, 49.75096838506068], [-0.15260205585850375, 49.726841392041514], [-0.06719341323925708, 49.70264505472652], [0.018126268480918944, 49.67837949999389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: 0.018126268&lt;dd&gt;Longitude: 49.678379&lt;dd&gt;Azimuth: 135.8401\u00b0&lt;dd&gt;Altitude: 61.334303\u00b0&lt;dd&gt;Slant Range: 613.92943km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.018126268480918944, 49.67837949999389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.40936084328508127, 49.799013831019266], [-0.3236858629576851, 49.77502590696966], [-0.23809956954024755, 49.75096838506068], [-0.15260205585850375, 49.726841392041514], [-0.06719341323925708, 49.70264505472652], [0.018126268480918944, 49.67837949999389], [0.10335690094883604, 49.654044854780956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: 0.1033569&lt;dd&gt;Longitude: 49.654045&lt;dd&gt;Azimuth: 135.2723\u00b0&lt;dd&gt;Altitude: 60.778133\u00b0&lt;dd&gt;Slant Range: 616.90012km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.10335690094883604, 49.654044854780956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3236858629576851, 49.77502590696966], [-0.23809956954024755, 49.75096838506068], [-0.15260205585850375, 49.726841392041514], [-0.06719341323925708, 49.70264505472652], [0.018126268480918944, 49.67837949999389], [0.10335690094883604, 49.654044854780956], [0.18849839729901674, 49.629641246084944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: 0.1884984&lt;dd&gt;Longitude: 49.629641&lt;dd&gt;Azimuth: 134.72928\u00b0&lt;dd&gt;Altitude: 60.224722\u00b0&lt;dd&gt;Slant Range: 619.93574km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.18849839729901674, 49.629641246084944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.23809956954024755, 49.75096838506068], [-0.15260205585850375, 49.726841392041514], [-0.06719341323925708, 49.70264505472652], [0.018126268480918944, 49.67837949999389], [0.10335690094883604, 49.654044854780956], [0.18849839729901674, 49.629641246084944], [0.27355067214003076, 49.60516880095825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4726&lt;dd&gt;Latitude: 0.27355067&lt;dd&gt;Longitude: 49.605169&lt;dd&gt;Azimuth: 134.20955\u00b0&lt;dd&gt;Altitude: 59.674298\u00b0&lt;dd&gt;Slant Range: 623.03534km&quot;, &quot;name&quot;: &quot;STARLINK-4726&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.27355067214003076, 49.60516880095825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -3.1548228&lt;dd&gt;Longitude: 52.380781&lt;dd&gt;Azimuth: 339.88467\u00b0&lt;dd&gt;Altitude: 77.686377\u00b0&lt;dd&gt;Slant Range: 556.86145km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154], [-3.0584802965482853, 52.39397507357131]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -3.0584803&lt;dd&gt;Longitude: 52.393975&lt;dd&gt;Azimuth: 343.39609\u00b0&lt;dd&gt;Altitude: 77.765202\u00b0&lt;dd&gt;Slant Range: 556.71263km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0584802965482853, 52.39397507357131]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154], [-3.0584802965482853, 52.39397507357131], [-2.962078170614461, 52.4070840452318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.9620782&lt;dd&gt;Longitude: 52.407084&lt;dd&gt;Azimuth: 346.94075\u00b0&lt;dd&gt;Altitude: 77.79892\u00b0&lt;dd&gt;Slant Range: 556.65166km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.962078170614461, 52.4070840452318]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154], [-3.0584802965482853, 52.39397507357131], [-2.962078170614461, 52.4070840452318], [-2.86561670044495, 52.42010749359751]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.8656167&lt;dd&gt;Longitude: 52.420107&lt;dd&gt;Azimuth: 350.49189\u00b0&lt;dd&gt;Altitude: 77.787119\u00b0&lt;dd&gt;Slant Range: 556.67858km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.86561670044495, 52.42010749359751]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154], [-3.0584802965482853, 52.39397507357131], [-2.962078170614461, 52.4070840452318], [-2.86561670044495, 52.42010749359751], [-2.7690962123680722, 52.43304532887888]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.7690962&lt;dd&gt;Longitude: 52.433045&lt;dd&gt;Azimuth: 354.02246\u00b0&lt;dd&gt;Altitude: 77.729947\u00b0&lt;dd&gt;Slant Range: 556.79338km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7690962123680722, 52.43304532887888]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154], [-3.0584802965482853, 52.39397507357131], [-2.962078170614461, 52.4070840452318], [-2.86561670044495, 52.42010749359751], [-2.7690962123680722, 52.43304532887888], [-2.6725170342629605, 52.445897461755074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.672517&lt;dd&gt;Longitude: 52.445897&lt;dd&gt;Azimuth: 357.50635\u00b0&lt;dd&gt;Altitude: 77.628103\u00b0&lt;dd&gt;Slant Range: 556.99599km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6725170342629605, 52.445897461755074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.154822753486244, 52.380780668871154], [-3.0584802965482853, 52.39397507357131], [-2.962078170614461, 52.4070840452318], [-2.86561670044495, 52.42010749359751], [-2.7690962123680722, 52.43304532887888], [-2.6725170342629605, 52.445897461755074], [-2.5758794955664053, 52.45866380337673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.5758795&lt;dd&gt;Longitude: 52.458664&lt;dd&gt;Azimuth: 0.91947877\u00b0&lt;dd&gt;Altitude: 77.482802\u00b0&lt;dd&gt;Slant Range: 557.28633km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5758794955664053, 52.45866380337673]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0584802965482853, 52.39397507357131], [-2.962078170614461, 52.4070840452318], [-2.86561670044495, 52.42010749359751], [-2.7690962123680722, 52.43304532887888], [-2.6725170342629605, 52.445897461755074], [-2.5758794955664053, 52.45866380337673], [-2.479183927251227, 52.47134426536871]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.4791839&lt;dd&gt;Longitude: 52.471344&lt;dd&gt;Azimuth: 4.2407167\u00b0&lt;dd&gt;Altitude: 77.295707\u00b0&lt;dd&gt;Slant Range: 557.66425km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.479183927251227, 52.47134426536871]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.962078170614461, 52.4070840452318], [-2.86561670044495, 52.42010749359751], [-2.7690962123680722, 52.43304532887888], [-2.6725170342629605, 52.445897461755074], [-2.5758794955664053, 52.45866380337673], [-2.479183927251227, 52.47134426536871], [-2.38243066184658, 52.48393875983263]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.3824307&lt;dd&gt;Longitude: 52.483939&lt;dd&gt;Azimuth: 7.4524946\u00b0&lt;dd&gt;Altitude: 77.068854\u00b0&lt;dd&gt;Slant Range: 558.12959km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.38243066184658, 52.48393875983263]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.86561670044495, 52.42010749359751], [-2.7690962123680722, 52.43304532887888], [-2.6725170342629605, 52.445897461755074], [-2.5758794955664053, 52.45866380337673], [-2.479183927251227, 52.47134426536871], [-2.38243066184658, 52.48393875983263], [-2.28562003339765, 52.496447199350534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.28562&lt;dd&gt;Longitude: 52.496447&lt;dd&gt;Azimuth: 10.5411\u00b0&lt;dd&gt;Altitude: 76.80456\u00b0&lt;dd&gt;Slant Range: 558.68211km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.28562003339765, 52.496447199350534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7690962123680722, 52.43304532887888], [-2.6725170342629605, 52.445897461755074], [-2.5758794955664053, 52.45866380337673], [-2.479183927251227, 52.47134426536871], [-2.38243066184658, 52.48393875983263], [-2.28562003339765, 52.496447199350534], [-2.188752377499926, 52.50886949698632]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.1887524&lt;dd&gt;Longitude: 52.508869&lt;dd&gt;Azimuth: 13.496686\u00b0&lt;dd&gt;Altitude: 76.505332\u00b0&lt;dd&gt;Slant Range: 559.32156km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.188752377499926, 52.50886949698632]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6725170342629605, 52.445897461755074], [-2.5758794955664053, 52.45866380337673], [-2.479183927251227, 52.47134426536871], [-2.38243066184658, 52.48393875983263], [-2.28562003339765, 52.496447199350534], [-2.188752377499926, 52.50886949698632], [-2.0918280312515187, 52.52120556629016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -2.091828&lt;dd&gt;Longitude: 52.521206&lt;dd&gt;Azimuth: 16.313042\u00b0&lt;dd&gt;Altitude: 76.173782\u00b0&lt;dd&gt;Slant Range: 560.04764km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0918280312515187, 52.52120556629016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5758794955664053, 52.45866380337673], [-2.479183927251227, 52.47134426536871], [-2.38243066184658, 52.48393875983263], [-2.28562003339765, 52.496447199350534], [-2.188752377499926, 52.50886949698632], [-2.0918280312515187, 52.52120556629016], [-1.994847333282599, 52.53345532129981]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.9948473&lt;dd&gt;Longitude: 52.533455&lt;dd&gt;Azimuth: 18.987201\u00b0&lt;dd&gt;Altitude: 75.812555\u00b0&lt;dd&gt;Slant Range: 560.86001km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.994847333282599, 52.53345532129981]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.479183927251227, 52.47134426536871], [-2.38243066184658, 52.48393875983263], [-2.28562003339765, 52.496447199350534], [-2.188752377499926, 52.50886949698632], [-2.0918280312515187, 52.52120556629016], [-1.994847333282599, 52.53345532129981], [-1.8978106237314296, 52.54561867654437]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.8978106&lt;dd&gt;Longitude: 52.545619&lt;dd&gt;Azimuth: 21.518952\u00b0&lt;dd&gt;Altitude: 75.424266\u00b0&lt;dd&gt;Slant Range: 561.7583km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8978106237314296, 52.54561867654437]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.38243066184658, 52.48393875983263], [-2.28562003339765, 52.496447199350534], [-2.188752377499926, 52.50886949698632], [-2.0918280312515187, 52.52120556629016], [-1.994847333282599, 52.53345532129981], [-1.8978106237314296, 52.54561867654437], [-1.8007182442346459, 52.55769554704667]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.8007182&lt;dd&gt;Longitude: 52.557696&lt;dd&gt;Azimuth: 23.910321\u00b0&lt;dd&gt;Altitude: 75.011451\u00b0&lt;dd&gt;Slant Range: 562.7421km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8007182442346459, 52.55769554704667]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.28562003339765, 52.496447199350534], [-2.188752377499926, 52.50886949698632], [-2.0918280312515187, 52.52120556629016], [-1.994847333282599, 52.53345532129981], [-1.8978106237314296, 52.54561867654437], [-1.8007182442346459, 52.55769554704667], [-1.7035705379383226, 52.569685848325875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.7035705&lt;dd&gt;Longitude: 52.569686&lt;dd&gt;Azimuth: 26.165065\u00b0&lt;dd&gt;Altitude: 74.576539\u00b0&lt;dd&gt;Slant Range: 563.81095km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7035705379383226, 52.569685848325875]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.188752377499926, 52.50886949698632], [-2.0918280312515187, 52.52120556629016], [-1.994847333282599, 52.53345532129981], [-1.8978106237314296, 52.54561867654437], [-1.8007182442346459, 52.55769554704667], [-1.7035705379383226, 52.569685848325875], [-1.6063678494732438, 52.58158949640051]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.6063678&lt;dd&gt;Longitude: 52.581589&lt;dd&gt;Azimuth: 28.288212\u00b0&lt;dd&gt;Altitude: 74.121822\u00b0&lt;dd&gt;Slant Range: 564.96438km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6063678494732438, 52.58158949640051]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0918280312515187, 52.52120556629016], [-1.994847333282599, 52.53345532129981], [-1.8978106237314296, 52.54561867654437], [-1.8007182442346459, 52.55769554704667], [-1.7035705379383226, 52.569685848325875], [-1.6063678494732438, 52.58158949640051], [-1.509110524962102, 52.593406407791214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.5091105&lt;dd&gt;Longitude: 52.593406&lt;dd&gt;Azimuth: 30.285662\u00b0&lt;dd&gt;Altitude: 73.649445\u00b0&lt;dd&gt;Slant Range: 566.20186km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.509110524962102, 52.593406407791214]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.994847333282599, 52.53345532129981], [-1.8978106237314296, 52.54561867654437], [-1.8007182442346459, 52.55769554704667], [-1.7035705379383226, 52.569685848325875], [-1.6063678494732438, 52.58158949640051], [-1.509110524962102, 52.593406407791214], [-1.4117989120041308, 52.60513649952303]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.4117989&lt;dd&gt;Longitude: 52.605136&lt;dd&gt;Azimuth: 32.163858\u00b0&lt;dd&gt;Altitude: 73.161403\u00b0&lt;dd&gt;Slant Range: 567.52284km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4117989120041308, 52.60513649952303]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8978106237314296, 52.54561867654437], [-1.8007182442346459, 52.55769554704667], [-1.7035705379383226, 52.569685848325875], [-1.6063678494732438, 52.58158949640051], [-1.509110524962102, 52.593406407791214], [-1.4117989120041308, 52.60513649952303], [-1.314433359675257, 52.61677968912864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.3144334&lt;dd&gt;Longitude: 52.61678&lt;dd&gt;Azimuth: 33.92952\u00b0&lt;dd&gt;Altitude: 72.659536\u00b0&lt;dd&gt;Slant Range: 568.92673km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.314433359675257, 52.61677968912864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8007182442346459, 52.55769554704667], [-1.7035705379383226, 52.569685848325875], [-1.6063678494732438, 52.58158949640051], [-1.509110524962102, 52.593406407791214], [-1.4117989120041308, 52.60513649952303], [-1.314433359675257, 52.61677968912864], [-1.2170142185134194, 52.62833589465087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.2170142&lt;dd&gt;Longitude: 52.628336&lt;dd&gt;Azimuth: 35.589439\u00b0&lt;dd&gt;Altitude: 72.145536\u00b0&lt;dd&gt;Slant Range: 570.41294km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2170142185134194, 52.62833589465087]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7035705379383226, 52.569685848325875], [-1.6063678494732438, 52.58158949640051], [-1.509110524962102, 52.593406407791214], [-1.4117989120041308, 52.60513649952303], [-1.314433359675257, 52.61677968912864], [-1.2170142185134194, 52.62833589465087], [-1.11954184052353, 52.63980503464515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.1195418&lt;dd&gt;Longitude: 52.639805&lt;dd&gt;Azimuth: 37.150324\u00b0&lt;dd&gt;Altitude: 71.620951\u00b0&lt;dd&gt;Slant Range: 571.9808km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.11954184052353, 52.63980503464515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6063678494732438, 52.58158949640051], [-1.509110524962102, 52.593406407791214], [-1.4117989120041308, 52.60513649952303], [-1.314433359675257, 52.61677968912864], [-1.2170142185134194, 52.62833589465087], [-1.11954184052353, 52.63980503464515], [-1.0220165791542701, 52.651187028182605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -1.0220166&lt;dd&gt;Longitude: 52.651187&lt;dd&gt;Azimuth: 38.618697\u00b0&lt;dd&gt;Altitude: 71.0872\u00b0&lt;dd&gt;Slant Range: 573.62966km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0220165791542701, 52.651187028182605]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.509110524962102, 52.593406407791214], [-1.4117989120041308, 52.60513649952303], [-1.314433359675257, 52.61677968912864], [-1.2170142185134194, 52.62833589465087], [-1.11954184052353, 52.63980503464515], [-1.0220165791542701, 52.651187028182605], [-0.9244387893079352, 52.662481794852454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.92443879&lt;dd&gt;Longitude: 52.662482&lt;dd&gt;Azimuth: 40.000809\u00b0&lt;dd&gt;Altitude: 70.545574\u00b0&lt;dd&gt;Slant Range: 575.3588km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9244387893079352, 52.662481794852454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4117989120041308, 52.60513649952303], [-1.314433359675257, 52.61677968912864], [-1.2170142185134194, 52.62833589465087], [-1.11954184052353, 52.63980503464515], [-1.0220165791542701, 52.651187028182605], [-0.9244387893079352, 52.662481794852454], [-0.8268088273249917, 52.67368925476475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.82680883&lt;dd&gt;Longitude: 52.673689&lt;dd&gt;Azimuth: 41.302602\u00b0&lt;dd&gt;Altitude: 69.997249\u00b0&lt;dd&gt;Slant Range: 577.16752km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8268088273249917, 52.67368925476475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.314433359675257, 52.61677968912864], [-1.2170142185134194, 52.62833589465087], [-1.11954184052353, 52.63980503464515], [-1.0220165791542701, 52.651187028182605], [-0.9244387893079352, 52.662481794852454], [-0.8268088273249917, 52.67368925476475], [-0.7291270509750692, 52.68480932855295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.72912705&lt;dd&gt;Longitude: 52.684809&lt;dd&gt;Azimuth: 42.529674\u00b0&lt;dd&gt;Altitude: 69.443298\u00b0&lt;dd&gt;Slant Range: 579.05505km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7291270509750692, 52.68480932855295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2170142185134194, 52.62833589465087], [-1.11954184052353, 52.63980503464515], [-1.0220165791542701, 52.651187028182605], [-0.9244387893079352, 52.662481794852454], [-0.8268088273249917, 52.67368925476475], [-0.7291270509750692, 52.68480932855295], [-0.631393819454518, 52.69584193737653]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.63139382&lt;dd&gt;Longitude: 52.695842&lt;dd&gt;Azimuth: 43.687272\u00b0&lt;dd&gt;Altitude: 68.884696\u00b0&lt;dd&gt;Slant Range: 581.02064km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.631393819454518, 52.69584193737653]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.11954184052353, 52.63980503464515], [-1.0220165791542701, 52.651187028182605], [-0.9244387893079352, 52.662481794852454], [-0.8268088273249917, 52.67368925476475], [-0.7291270509750692, 52.68480932855295], [-0.631393819454518, 52.69584193737653], [-0.5336094933796401, 52.70678700292385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.53360949&lt;dd&gt;Longitude: 52.706787&lt;dd&gt;Azimuth: 44.780289\u00b0&lt;dd&gt;Altitude: 68.322332\u00b0&lt;dd&gt;Slant Range: 583.06348km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5336094933796401, 52.70678700292385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0220165791542701, 52.651187028182605], [-0.9244387893079352, 52.662481794852454], [-0.8268088273249917, 52.67368925476475], [-0.7291270509750692, 52.68480932855295], [-0.631393819454518, 52.69584193737653], [-0.5336094933796401, 52.70678700292385], [-0.43577443476819216, 52.7176444474145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.43577443&lt;dd&gt;Longitude: 52.717644&lt;dd&gt;Azimuth: 45.813275\u00b0&lt;dd&gt;Altitude: 67.757013\u00b0&lt;dd&gt;Slant Range: 585.18276km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.43577443476819216, 52.7176444474145]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9244387893079352, 52.662481794852454], [-0.8268088273249917, 52.67368925476475], [-0.7291270509750692, 52.68480932855295], [-0.631393819454518, 52.69584193737653], [-0.5336094933796401, 52.70678700292385], [-0.43577443476819216, 52.7176444474145], [-0.33788900705264147, 52.72841419360205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.33788901&lt;dd&gt;Longitude: 52.728414&lt;dd&gt;Azimuth: 46.790446\u00b0&lt;dd&gt;Altitude: 67.189476\u00b0&lt;dd&gt;Slant Range: 587.37767km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.33788900705264147, 52.72841419360205]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8268088273249917, 52.67368925476475], [-0.7291270509750692, 52.68480932855295], [-0.631393819454518, 52.69584193737653], [-0.5336094933796401, 52.70678700292385], [-0.43577443476819216, 52.7176444474145], [-0.33788900705264147, 52.72841419360205], [-0.23995357505110831, 52.739096164776484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.23995358&lt;dd&gt;Longitude: 52.739096&lt;dd&gt;Azimuth: 47.715704\u00b0&lt;dd&gt;Altitude: 66.62039\u00b0&lt;dd&gt;Slant Range: 589.64734km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.23995357505110831, 52.739096164776484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7291270509750692, 52.68480932855295], [-0.631393819454518, 52.69584193737653], [-0.5336094933796401, 52.70678700292385], [-0.43577443476819216, 52.7176444474145], [-0.33788900705264147, 52.72841419360205], [-0.23995357505110831, 52.739096164776484], [-0.14196850497527955, 52.749690284767034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.1419685&lt;dd&gt;Longitude: 52.74969&lt;dd&gt;Azimuth: 48.592652\u00b0&lt;dd&gt;Altitude: 66.050368\u00b0&lt;dd&gt;Slant Range: 591.99092km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.14196850497527955, 52.749690284767034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.631393819454518, 52.69584193737653], [-0.5336094933796401, 52.70678700292385], [-0.43577443476819216, 52.7176444474145], [-0.33788900705264147, 52.72841419360205], [-0.23995357505110831, 52.739096164776484], [-0.14196850497527955, 52.749690284767034], [-0.04393416440962027, 52.76019647794416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: -0.043934164&lt;dd&gt;Longitude: 52.760196&lt;dd&gt;Azimuth: 49.424617\u00b0&lt;dd&gt;Altitude: 65.479965\u00b0&lt;dd&gt;Slant Range: 594.40752km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.04393416440962027, 52.76019647794416]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5336094933796401, 52.70678700292385], [-0.43577443476819216, 52.7176444474145], [-0.33788900705264147, 52.72841419360205], [-0.23995357505110831, 52.739096164776484], [-0.14196850497527955, 52.749690284767034], [-0.04393416440962027, 52.76019647794416], [0.05414907768185793, 52.77061466922312]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.054149078&lt;dd&gt;Longitude: 52.770615&lt;dd&gt;Azimuth: 50.214666\u00b0&lt;dd&gt;Altitude: 64.90969\u00b0&lt;dd&gt;Slant Range: 596.89627km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.05414907768185793, 52.77061466922312]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.43577443476819216, 52.7176444474145], [-0.33788900705264147, 52.72841419360205], [-0.23995357505110831, 52.739096164776484], [-0.14196850497527955, 52.749690284767034], [-0.04393416440962027, 52.76019647794416], [0.05414907768185793, 52.77061466922312], [0.15228085097702115, 52.78094478406534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.15228085&lt;dd&gt;Longitude: 52.780945&lt;dd&gt;Azimuth: 50.965629\u00b0&lt;dd&gt;Altitude: 64.340006\u00b0&lt;dd&gt;Slant Range: 599.45626km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.15228085097702115, 52.78094478406534]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.33788900705264147, 52.72841419360205], [-0.23995357505110831, 52.739096164776484], [-0.14196850497527955, 52.749690284767034], [-0.04393416440962027, 52.76019647794416], [0.05414907768185793, 52.77061466922312], [0.15228085097702115, 52.78094478406534], [0.25046078379390846, 52.79118674848173]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.25046078&lt;dd&gt;Longitude: 52.791187&lt;dd&gt;Azimuth: 51.680111\u00b0&lt;dd&gt;Altitude: 63.771335\u00b0&lt;dd&gt;Slant Range: 602.08657km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.25046078379390846, 52.79118674848173]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.23995357505110831, 52.739096164776484], [-0.14196850497527955, 52.749690284767034], [-0.04393416440962027, 52.76019647794416], [0.05414907768185793, 52.77061466922312], [0.15228085097702115, 52.78094478406534], [0.25046078379390846, 52.79118674848173], [0.34868850310658367, 52.80134048903485]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.3486885&lt;dd&gt;Longitude: 52.80134&lt;dd&gt;Azimuth: 52.360518\u00b0&lt;dd&gt;Altitude: 63.204063\u00b0&lt;dd&gt;Slant Range: 604.78628km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.34868850310658367, 52.80134048903485]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.14196850497527955, 52.749690284767034], [-0.04393416440962027, 52.76019647794416], [0.05414907768185793, 52.77061466922312], [0.15228085097702115, 52.78094478406534], [0.25046078379390846, 52.79118674848173], [0.34868850310658367, 52.80134048903485], [0.44696363454510996, 52.81140593284158]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.44696363&lt;dd&gt;Longitude: 52.811406&lt;dd&gt;Azimuth: 53.009066\u00b0&lt;dd&gt;Altitude: 62.638542\u00b0&lt;dd&gt;Slant Range: 607.55448km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.44696363454510996, 52.81140593284158]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.04393416440962027, 52.76019647794416], [0.05414907768185793, 52.77061466922312], [0.15228085097702115, 52.78094478406534], [0.25046078379390846, 52.79118674848173], [0.34868850310658367, 52.80134048903485], [0.44696363454510996, 52.81140593284158], [0.5452858024135901, 52.82138300757539]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.5452858&lt;dd&gt;Longitude: 52.821383&lt;dd&gt;Azimuth: 53.627801\u00b0&lt;dd&gt;Altitude: 62.075092\u00b0&lt;dd&gt;Slant Range: 610.39022km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5452858024135901, 52.82138300757539]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.05414907768185793, 52.77061466922312], [0.15228085097702115, 52.78094478406534], [0.25046078379390846, 52.79118674848173], [0.34868850310658367, 52.80134048903485], [0.44696363454510996, 52.81140593284158], [0.5452858024135901, 52.82138300757539], [0.643654629693067, 52.83127164146905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.64365463&lt;dd&gt;Longitude: 52.831272&lt;dd&gt;Azimuth: 54.218611\u00b0&lt;dd&gt;Altitude: 61.514006\u00b0&lt;dd&gt;Slant Range: 613.29255km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.643654629693067, 52.83127164146905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.15228085097702115, 52.78094478406534], [0.25046078379390846, 52.79118674848173], [0.34868850310658367, 52.80134048903485], [0.44696363454510996, 52.81140593284158], [0.5452858024135901, 52.82138300757539], [0.643654629693067, 52.83127164146905], [0.7420697380403021, 52.841071763316755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.74206974&lt;dd&gt;Longitude: 52.841072&lt;dd&gt;Azimuth: 54.783242\u00b0&lt;dd&gt;Altitude: 60.95555\u00b0&lt;dd&gt;Slant Range: 616.26055km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7420697380403021, 52.841071763316755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.25046078379390846, 52.79118674848173], [0.34868850310658367, 52.80134048903485], [0.44696363454510996, 52.81140593284158], [0.5452858024135901, 52.82138300757539], [0.643654629693067, 52.83127164146905], [0.7420697380403021, 52.841071763316755], [0.840530747821388, 52.85078330247697]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.84053075&lt;dd&gt;Longitude: 52.850783&lt;dd&gt;Azimuth: 55.323304\u00b0&lt;dd&gt;Altitude: 60.399968\u00b0&lt;dd&gt;Slant Range: 619.29326km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.840530747821388, 52.85078330247697]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.34868850310658367, 52.80134048903485], [0.44696363454510996, 52.81140593284158], [0.5452858024135901, 52.82138300757539], [0.643654629693067, 52.83127164146905], [0.7420697380403021, 52.841071763316755], [0.840530747821388, 52.85078330247697], [0.9390372780923851, 52.86040618887438]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 0.93903728&lt;dd&gt;Longitude: 52.860406&lt;dd&gt;Azimuth: 55.840289\u00b0&lt;dd&gt;Altitude: 59.847479\u00b0&lt;dd&gt;Slant Range: 622.38972km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9390372780923851, 52.86040618887438]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.44696363454510996, 52.81140593284158], [0.5452858024135901, 52.82138300757539], [0.643654629693067, 52.83127164146905], [0.7420697380403021, 52.841071763316755], [0.840530747821388, 52.85078330247697], [0.9390372780923851, 52.86040618887438], [1.0375889466277173, 52.869940353002676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.0375889&lt;dd&gt;Longitude: 52.86994&lt;dd&gt;Azimuth: 56.335579\u00b0&lt;dd&gt;Altitude: 59.298284\u00b0&lt;dd&gt;Slant Range: 625.549km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0375889466277173, 52.869940353002676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5452858024135901, 52.82138300757539], [0.643654629693067, 52.83127164146905], [0.7420697380403021, 52.841071763316755], [0.840530747821388, 52.85078330247697], [0.9390372780923851, 52.86040618887438], [1.0375889466277173, 52.869940353002676], [1.136185369921597, 52.87938572592682]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.1361854&lt;dd&gt;Longitude: 52.879386&lt;dd&gt;Azimuth: 56.810451\u00b0&lt;dd&gt;Altitude: 58.752565\u00b0&lt;dd&gt;Slant Range: 628.77014km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.136185369921597, 52.87938572592682]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.643654629693067, 52.83127164146905], [0.7420697380403021, 52.841071763316755], [0.840530747821388, 52.85078330247697], [0.9390372780923851, 52.86040618887438], [1.0375889466277173, 52.869940353002676], [1.136185369921597, 52.87938572592682], [1.2348261631953534, 52.888742239285335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.2348262&lt;dd&gt;Longitude: 52.888742&lt;dd&gt;Azimuth: 57.266093\u00b0&lt;dd&gt;Altitude: 58.210487\u00b0&lt;dd&gt;Slant Range: 632.05218km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2348261631953534, 52.888742239285335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7420697380403021, 52.841071763316755], [0.840530747821388, 52.85078330247697], [0.9390372780923851, 52.86040618887438], [1.0375889466277173, 52.869940353002676], [1.136185369921597, 52.87938572592682], [1.2348261631953534, 52.888742239285335], [1.333510940407737, 52.898009825292895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.3335109&lt;dd&gt;Longitude: 52.89801&lt;dd&gt;Azimuth: 57.703605\u00b0&lt;dd&gt;Altitude: 57.672197\u00b0&lt;dd&gt;Slant Range: 635.39419km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.333510940407737, 52.898009825292895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.840530747821388, 52.85078330247697], [0.9390372780923851, 52.86040618887438], [1.0375889466277173, 52.869940353002676], [1.136185369921597, 52.87938572592682], [1.2348261631953534, 52.888742239285335], [1.333510940407737, 52.898009825292895], [1.4322393142709247, 52.90718841674224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.4322393&lt;dd&gt;Longitude: 52.907188&lt;dd&gt;Azimuth: 58.12401\u00b0&lt;dd&gt;Altitude: 57.13783\u00b0&lt;dd&gt;Slant Range: 638.79522km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4322393142709247, 52.90718841674224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9390372780923851, 52.86040618887438], [1.0375889466277173, 52.869940353002676], [1.136185369921597, 52.87938572592682], [1.2348261631953534, 52.888742239285335], [1.333510940407737, 52.898009825292895], [1.4322393142709247, 52.90718841674224], [1.5310108962451758, 52.91627794700692]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.5310109&lt;dd&gt;Longitude: 52.916278&lt;dd&gt;Azimuth: 58.528258\u00b0&lt;dd&gt;Altitude: 56.607506\u00b0&lt;dd&gt;Slant Range: 642.25433km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5310108962451758, 52.91627794700692]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0375889466277173, 52.869940353002676], [1.136185369921597, 52.87938572592682], [1.2348261631953534, 52.888742239285335], [1.333510940407737, 52.898009825292895], [1.4322393142709247, 52.90718841674224], [1.5310108962451758, 52.91627794700692], [1.6298252965643794, 52.92527835004337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.6298253&lt;dd&gt;Longitude: 52.925278&lt;dd&gt;Azimuth: 58.917234\u00b0&lt;dd&gt;Altitude: 56.081332\u00b0&lt;dd&gt;Slant Range: 645.77057km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6298252965643794, 52.92527835004337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.136185369921597, 52.87938572592682], [1.2348261631953534, 52.888742239285335], [1.333510940407737, 52.898009825292895], [1.4322393142709247, 52.90718841674224], [1.5310108962451758, 52.91627794700692], [1.6298252965643794, 52.92527835004337], [1.7286821242273758, 52.93418956039339]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.7286821&lt;dd&gt;Longitude: 52.93419&lt;dd&gt;Azimuth: 59.291763\u00b0&lt;dd&gt;Altitude: 55.559403\u00b0&lt;dd&gt;Slant Range: 649.34302km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7286821242273758, 52.93418956039339]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2348261631953534, 52.888742239285335], [1.333510940407737, 52.898009825292895], [1.4322393142709247, 52.90718841674224], [1.5310108962451758, 52.91627794700692], [1.6298252965643794, 52.92527835004337], [1.7286821242273758, 52.93418956039339], [1.8275809870303754, 52.94301151318627]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.827581&lt;dd&gt;Longitude: 52.943012&lt;dd&gt;Azimuth: 59.652613\u00b0&lt;dd&gt;Altitude: 55.041805\u00b0&lt;dd&gt;Slant Range: 652.97075km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8275809870303754, 52.94301151318627]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.333510940407737, 52.898009825292895], [1.4322393142709247, 52.90718841674224], [1.5310108962451758, 52.91627794700692], [1.6298252965643794, 52.92527835004337], [1.7286821242273758, 52.93418956039339], [1.8275809870303754, 52.94301151318627], [1.9265214915523254, 52.95174414414098]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 1.9265215&lt;dd&gt;Longitude: 52.951744&lt;dd&gt;Azimuth: 60.0005\u00b0&lt;dd&gt;Altitude: 54.528612\u00b0&lt;dd&gt;Slant Range: 656.65283km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9265214915523254, 52.95174414414098]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4322393142709247, 52.90718841674224], [1.5310108962451758, 52.91627794700692], [1.6298252965643794, 52.92527835004337], [1.7286821242273758, 52.93418956039339], [1.8275809870303754, 52.94301151318627], [1.9265214915523254, 52.95174414414098], [2.0255032431831044, 52.96038738956874]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.0255032&lt;dd&gt;Longitude: 52.960387&lt;dd&gt;Azimuth: 60.336095\u00b0&lt;dd&gt;Altitude: 54.019888\u00b0&lt;dd&gt;Slant Range: 660.38837km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0255032431831044, 52.96038738956874]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5310108962451758, 52.91627794700692], [1.6298252965643794, 52.92527835004337], [1.7286821242273758, 52.93418956039339], [1.8275809870303754, 52.94301151318627], [1.9265214915523254, 52.95174414414098], [2.0255032431831044, 52.96038738956874], [2.1245258461180256, 52.96894118637474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.1245258&lt;dd&gt;Longitude: 52.968941&lt;dd&gt;Azimuth: 60.660022\u00b0&lt;dd&gt;Altitude: 53.51569\u00b0&lt;dd&gt;Slant Range: 664.17644km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1245258461180256, 52.96894118637474]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6298252965643794, 52.92527835004337], [1.7286821242273758, 52.93418956039339], [1.8275809870303754, 52.94301151318627], [1.9265214915523254, 52.95174414414098], [2.0255032431831044, 52.96038738956874], [2.1245258461180256, 52.96894118637474], [2.223588903386715, 52.977405472060994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.2235889&lt;dd&gt;Longitude: 52.977405&lt;dd&gt;Azimuth: 60.972869\u00b0&lt;dd&gt;Altitude: 53.016066\u00b0&lt;dd&gt;Slant Range: 668.01616km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.223588903386715, 52.977405472060994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7286821242273758, 52.93418956039339], [1.8275809870303754, 52.94301151318627], [1.9265214915523254, 52.95174414414098], [2.0255032431831044, 52.96038738956874], [2.1245258461180256, 52.96894118637474], [2.223588903386715, 52.977405472060994], [2.3226920168375935, 52.98578018472781]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.322692&lt;dd&gt;Longitude: 52.98578&lt;dd&gt;Azimuth: 61.275183\u00b0&lt;dd&gt;Altitude: 52.521056\u00b0&lt;dd&gt;Slant Range: 671.90663km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3226920168375935, 52.98578018472781]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8275809870303754, 52.94301151318627], [1.9265214915523254, 52.95174414414098], [2.0255032431831044, 52.96038738956874], [2.1245258461180256, 52.96894118637474], [2.223588903386715, 52.977405472060994], [2.3226920168375935, 52.98578018472781], [2.42183478717436, 52.99406526307656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.4218348&lt;dd&gt;Longitude: 52.994065&lt;dd&gt;Azimuth: 61.567477\u00b0&lt;dd&gt;Altitude: 52.030693\u00b0&lt;dd&gt;Slant Range: 675.84697km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.42183478717436, 52.99406526307656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9265214915523254, 52.95174414414098], [2.0255032431831044, 52.96038738956874], [2.1245258461180256, 52.96894118637474], [2.223588903386715, 52.977405472060994], [2.3226920168375935, 52.98578018472781], [2.42183478717436, 52.99406526307656], [2.521016813944062, 53.002260646411564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.5210168&lt;dd&gt;Longitude: 53.002261&lt;dd&gt;Azimuth: 61.850235\u00b0&lt;dd&gt;Altitude: 51.545004\u00b0&lt;dd&gt;Slant Range: 679.8363km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.521016813944062, 53.002260646411564]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0255032431831044, 52.96038738956874], [2.1245258461180256, 52.96894118637474], [2.223588903386715, 52.977405472060994], [2.3226920168375935, 52.98578018472781], [2.42183478717436, 52.99406526307656], [2.521016813944062, 53.002260646411564], [2.620237695562715, 53.010366274642266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.6202377&lt;dd&gt;Longitude: 53.010366&lt;dd&gt;Azimuth: 62.123908\u00b0&lt;dd&gt;Altitude: 51.064009\u00b0&lt;dd&gt;Slant Range: 683.87378km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.620237695562715, 53.010366274642266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1245258461180256, 52.96894118637474], [2.223588903386715, 52.977405472060994], [2.3226920168375935, 52.98578018472781], [2.42183478717436, 52.99406526307656], [2.521016813944062, 53.002260646411564], [2.620237695562715, 53.010366274642266], [2.7194970293128873, 53.018382088285286]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.719497&lt;dd&gt;Longitude: 53.018382&lt;dd&gt;Azimuth: 62.388921\u00b0&lt;dd&gt;Altitude: 50.587723\u00b0&lt;dd&gt;Slant Range: 687.95854km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7194970293128873, 53.018382088285286]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.223588903386715, 52.977405472060994], [2.3226920168375935, 52.98578018472781], [2.42183478717436, 52.99406526307656], [2.521016813944062, 53.002260646411564], [2.620237695562715, 53.010366274642266], [2.7194970293128873, 53.018382088285286], [2.818794411365378, 53.02630802846674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.8187944&lt;dd&gt;Longitude: 53.026308&lt;dd&gt;Azimuth: 62.645675\u00b0&lt;dd&gt;Altitude: 50.116156\u00b0&lt;dd&gt;Slant Range: 692.08975km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.818794411365378, 53.02630802846674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3226920168375935, 52.98578018472781], [2.42183478717436, 52.99406526307656], [2.521016813944062, 53.002260646411564], [2.620237695562715, 53.010366274642266], [2.7194970293128873, 53.018382088285286], [2.818794411365378, 53.02630802846674], [2.91812943678344, 53.03414403692401]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 2.9181294&lt;dd&gt;Longitude: 53.034144&lt;dd&gt;Azimuth: 62.894545\u00b0&lt;dd&gt;Altitude: 49.649311\u00b0&lt;dd&gt;Slant Range: 696.26656km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.91812943678344, 53.03414403692401]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.42183478717436, 52.99406526307656], [2.521016813944062, 53.002260646411564], [2.620237695562715, 53.010366274642266], [2.7194970293128873, 53.018382088285286], [2.818794411365378, 53.02630802846674], [2.91812943678344, 53.03414403692401], [3.0175016995292445, 53.04189005600813]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.0175017&lt;dd&gt;Longitude: 53.04189&lt;dd&gt;Azimuth: 63.135886\u00b0&lt;dd&gt;Altitude: 49.187189\u00b0&lt;dd&gt;Slant Range: 700.48817km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0175016995292445, 53.04189005600813]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.521016813944062, 53.002260646411564], [2.620237695562715, 53.010366274642266], [2.7194970293128873, 53.018382088285286], [2.818794411365378, 53.02630802846674], [2.91812943678344, 53.03414403692401], [3.0175016995292445, 53.04189005600813], [3.116910792486347, 53.049546028685526]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.1169108&lt;dd&gt;Longitude: 53.049546&lt;dd&gt;Azimuth: 63.370032\u00b0&lt;dd&gt;Altitude: 48.729786\u00b0&lt;dd&gt;Slant Range: 704.75376km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.116910792486347, 53.049546028685526]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.620237695562715, 53.010366274642266], [2.7194970293128873, 53.018382088285286], [2.818794411365378, 53.02630802846674], [2.91812943678344, 53.03414403692401], [3.0175016995292445, 53.04189005600813], [3.116910792486347, 53.049546028685526], [3.216356307457373, 53.05711189854027]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.2163563&lt;dd&gt;Longitude: 53.057112&lt;dd&gt;Azimuth: 63.597296\u00b0&lt;dd&gt;Altitude: 48.277093\u00b0&lt;dd&gt;Slant Range: 709.06253km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.216356307457373, 53.05711189854027]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7194970293128873, 53.018382088285286], [2.818794411365378, 53.02630802846674], [2.91812943678344, 53.03414403692401], [3.0175016995292445, 53.04189005600813], [3.116910792486347, 53.049546028685526], [3.216356307457373, 53.05711189854027], [3.315837835180377, 53.064587609776076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.3158378&lt;dd&gt;Longitude: 53.064588&lt;dd&gt;Azimuth: 63.817977\u00b0&lt;dd&gt;Altitude: 47.829097\u00b0&lt;dd&gt;Slant Range: 713.4137km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.315837835180377, 53.064587609776076]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.818794411365378, 53.02630802846674], [2.91812943678344, 53.03414403692401], [3.0175016995292445, 53.04189005600813], [3.116910792486347, 53.049546028685526], [3.216356307457373, 53.05711189854027], [3.315837835180377, 53.064587609776076], [3.4153549653412365, 53.07197310721811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.415355&lt;dd&gt;Longitude: 53.071973&lt;dd&gt;Azimuth: 64.032355\u00b0&lt;dd&gt;Altitude: 47.385785\u00b0&lt;dd&gt;Slant Range: 717.80648km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4153549653412365, 53.07197310721811]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.91812943678344, 53.03414403692401], [3.0175016995292445, 53.04189005600813], [3.116910792486347, 53.049546028685526], [3.216356307457373, 53.05711189854027], [3.315837835180377, 53.064587609776076], [3.4153549653412365, 53.07197310721811], [3.5149072865839037, 53.07926833631517]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.5149073&lt;dd&gt;Longitude: 53.079268&lt;dd&gt;Azimuth: 64.240695\u00b0&lt;dd&gt;Altitude: 46.947137\u00b0&lt;dd&gt;Slant Range: 722.24013km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5149072865839037, 53.07926833631517]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0175016995292445, 53.04189005600813], [3.116910792486347, 53.049546028685526], [3.216356307457373, 53.05711189854027], [3.315837835180377, 53.064587609776076], [3.4153549653412365, 53.07197310721811], [3.5149072865839037, 53.07926833631517], [3.6144943865133845, 53.0864732431415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.6144944&lt;dd&gt;Longitude: 53.086473&lt;dd&gt;Azimuth: 64.443249\u00b0&lt;dd&gt;Altitude: 46.513131\u00b0&lt;dd&gt;Slant Range: 726.71387km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.6144943865133845, 53.0864732431415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.116910792486347, 53.049546028685526], [3.216356307457373, 53.05711189854027], [3.315837835180377, 53.064587609776076], [3.4153549653412365, 53.07197310721811], [3.5149072865839037, 53.07926833631517], [3.6144943865133845, 53.0864732431415], [3.714115851723318, 53.093587774398635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.7141159&lt;dd&gt;Longitude: 53.093588&lt;dd&gt;Azimuth: 64.640253\u00b0&lt;dd&gt;Altitude: 46.083745\u00b0&lt;dd&gt;Slant Range: 731.22698km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.714115851723318, 53.093587774398635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.216356307457373, 53.05711189854027], [3.315837835180377, 53.064587609776076], [3.4153549653412365, 53.07197310721811], [3.5149072865839037, 53.07926833631517], [3.6144943865133845, 53.0864732431415], [3.714115851723318, 53.093587774398635], [3.813771267782417, 53.100611877417755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.8137713&lt;dd&gt;Longitude: 53.100612&lt;dd&gt;Azimuth: 64.831933\u00b0&lt;dd&gt;Altitude: 45.65895\u00b0&lt;dd&gt;Slant Range: 735.77871km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.813771267782417, 53.100611877417755]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.315837835180377, 53.064587609776076], [3.4153549653412365, 53.07197310721811], [3.5149072865839037, 53.07926833631517], [3.6144943865133845, 53.0864732431415], [3.714115851723318, 53.093587774398635], [3.813771267782417, 53.100611877417755], [3.9134602192738295, 53.10754550016097]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 3.9134602&lt;dd&gt;Longitude: 53.107546&lt;dd&gt;Azimuth: 65.018502\u00b0&lt;dd&gt;Altitude: 45.23872\u00b0&lt;dd&gt;Slant Range: 740.36836km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9134602192738295, 53.10754550016097]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4153549653412365, 53.07197310721811], [3.5149072865839037, 53.07926833631517], [3.6144943865133845, 53.0864732431415], [3.714115851723318, 53.093587774398635], [3.813771267782417, 53.100611877417755], [3.9134602192738295, 53.10754550016097], [4.013182289781601, 53.11438859122353]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.0131823&lt;dd&gt;Longitude: 53.114389&lt;dd&gt;Azimuth: 65.200161\u00b0&lt;dd&gt;Altitude: 44.823022\u00b0&lt;dd&gt;Slant Range: 744.99522km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.013182289781601, 53.11438859122353]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5149072865839037, 53.07926833631517], [3.6144943865133845, 53.0864732431415], [3.714115851723318, 53.093587774398635], [3.813771267782417, 53.100611877417755], [3.9134602192738295, 53.10754550016097], [4.013182289781601, 53.11438859122353], [4.112937061919658, 53.12114109983572]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.1129371&lt;dd&gt;Longitude: 53.121141&lt;dd&gt;Azimuth: 65.377104\u00b0&lt;dd&gt;Altitude: 44.411824\u00b0&lt;dd&gt;Slant Range: 749.6586km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.112937061919658, 53.12114109983572]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.6144943865133845, 53.0864732431415], [3.714115851723318, 53.093587774398635], [3.813771267782417, 53.100611877417755], [3.9134602192738295, 53.10754550016097], [4.013182289781601, 53.11438859122353], [4.112937061919658, 53.12114109983572], [4.21272411732995, 53.12780297586451]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.2127241&lt;dd&gt;Longitude: 53.127803&lt;dd&gt;Azimuth: 65.549511\u00b0&lt;dd&gt;Altitude: 44.005091\u00b0&lt;dd&gt;Slant Range: 754.3578km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.21272411732995, 53.12780297586451]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.714115851723318, 53.093587774398635], [3.813771267782417, 53.100611877417755], [3.9134602192738295, 53.10754550016097], [4.013182289781601, 53.11438859122353], [4.112937061919658, 53.12114109983572], [4.21272411732995, 53.12780297586451], [4.312543036703745, 53.13437416981543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.312543&lt;dd&gt;Longitude: 53.134374&lt;dd&gt;Azimuth: 65.717555\u00b0&lt;dd&gt;Altitude: 43.602789\u00b0&lt;dd&gt;Slant Range: 759.09217km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.312543036703745, 53.13437416981543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.813771267782417, 53.100611877417755], [3.9134602192738295, 53.10754550016097], [4.013182289781601, 53.11438859122353], [4.112937061919658, 53.12114109983572], [4.21272411732995, 53.12780297586451], [4.312543036703745, 53.13437416981543], [4.412393399786464, 53.14085463283456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.4123934&lt;dd&gt;Longitude: 53.140855&lt;dd&gt;Azimuth: 65.881402\u00b0&lt;dd&gt;Altitude: 43.204878\u00b0&lt;dd&gt;Slant Range: 763.86104km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.412393399786464, 53.14085463283456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9134602192738295, 53.10754550016097], [4.013182289781601, 53.11438859122353], [4.112937061919658, 53.12114109983572], [4.21272411732995, 53.12780297586451], [4.312543036703745, 53.13437416981543], [4.412393399786464, 53.14085463283456], [4.5122747853914245, 53.14724431670971]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.5122748&lt;dd&gt;Longitude: 53.147244&lt;dd&gt;Azimuth: 66.041208\u00b0&lt;dd&gt;Altitude: 42.811322\u00b0&lt;dd&gt;Slant Range: 768.66376km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.5122747853914245, 53.14724431670971]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.013182289781601, 53.11438859122353], [4.112937061919658, 53.12114109983572], [4.21272411732995, 53.12780297586451], [4.312543036703745, 53.13437416981543], [4.412393399786464, 53.14085463283456], [4.5122747853914245, 53.14724431670971], [4.612186771411489, 53.153543173873054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.6121868&lt;dd&gt;Longitude: 53.153543&lt;dd&gt;Azimuth: 66.197121\u00b0&lt;dd&gt;Altitude: 42.422079\u00b0&lt;dd&gt;Slant Range: 773.4997km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.612186771411489, 53.153543173873054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.112937061919658, 53.12114109983572], [4.21272411732995, 53.12780297586451], [4.312543036703745, 53.13437416981543], [4.412393399786464, 53.14085463283456], [4.5122747853914245, 53.14724431670971], [4.612186771411489, 53.153543173873054], [4.712128934834005, 53.159751157401956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.7121289&lt;dd&gt;Longitude: 53.159751&lt;dd&gt;Azimuth: 66.349283\u00b0&lt;dd&gt;Altitude: 42.037108\u00b0&lt;dd&gt;Slant Range: 778.36823km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.712128934834005, 53.159751157401956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.21272411732995, 53.12780297586451], [4.312543036703745, 53.13437416981543], [4.412393399786464, 53.14085463283456], [4.5122747853914245, 53.14724431670971], [4.612186771411489, 53.153543173873054], [4.712128934834005, 53.159751157401956], [4.8121008517440345, 53.16586822102129]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.8121009&lt;dd&gt;Longitude: 53.165868&lt;dd&gt;Azimuth: 66.49783\u00b0&lt;dd&gt;Altitude: 41.656369\u00b0&lt;dd&gt;Slant Range: 783.26874km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.8121008517440345, 53.16586822102129]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.312543036703745, 53.13437416981543], [4.412393399786464, 53.14085463283456], [4.5122747853914245, 53.14724431670971], [4.612186771411489, 53.153543173873054], [4.712128934834005, 53.159751157401956], [4.8121008517440345, 53.16586822102129], [4.912102097341758, 53.17189431910487]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 4.9121021&lt;dd&gt;Longitude: 53.171894&lt;dd&gt;Azimuth: 66.64289\u00b0&lt;dd&gt;Altitude: 41.279819\u00b0&lt;dd&gt;Slant Range: 788.20063km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.912102097341758, 53.17189431910487]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.412393399786464, 53.14085463283456], [4.5122747853914245, 53.14724431670971], [4.612186771411489, 53.153543173873054], [4.712128934834005, 53.159751157401956], [4.8121008517440345, 53.16586822102129], [4.912102097341758, 53.17189431910487], [5.012132245955883, 53.17782940667717]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.0121322&lt;dd&gt;Longitude: 53.177829&lt;dd&gt;Azimuth: 66.784585\u00b0&lt;dd&gt;Altitude: 40.907413\u00b0&lt;dd&gt;Slant Range: 793.16331km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.012132245955883, 53.17782940667717]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.5122747853914245, 53.14724431670971], [4.612186771411489, 53.153543173873054], [4.712128934834005, 53.159751157401956], [4.8121008517440345, 53.16586822102129], [4.912102097341758, 53.17189431910487], [5.012132245955883, 53.17782940667717], [5.112190871053239, 53.18367343941489]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.1121909&lt;dd&gt;Longitude: 53.183673&lt;dd&gt;Azimuth: 66.923034\u00b0&lt;dd&gt;Altitude: 40.539109\u00b0&lt;dd&gt;Slant Range: 798.1562km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.112190871053239, 53.18367343941489]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.612186771411489, 53.153543173873054], [4.712128934834005, 53.159751157401956], [4.8121008517440345, 53.16586822102129], [4.912102097341758, 53.17189431910487], [5.012132245955883, 53.17782940667717], [5.112190871053239, 53.18367343941489], [5.212277545245519, 53.18942637364868]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.2122775&lt;dd&gt;Longitude: 53.189426&lt;dd&gt;Azimuth: 67.058348\u00b0&lt;dd&gt;Altitude: 40.174862\u00b0&lt;dd&gt;Slant Range: 803.17872km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.212277545245519, 53.18942637364868]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.712128934834005, 53.159751157401956], [4.8121008517440345, 53.16586822102129], [4.912102097341758, 53.17189431910487], [5.012132245955883, 53.17782940667717], [5.112190871053239, 53.18367343941489], [5.212277545245519, 53.18942637364868], [5.3123918403138335, 53.19508816636458]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.3123918&lt;dd&gt;Longitude: 53.195088&lt;dd&gt;Azimuth: 67.190633\u00b0&lt;dd&gt;Altitude: 39.814626\u00b0&lt;dd&gt;Slant Range: 808.23033km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.3123918403138335, 53.19508816636458]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.8121008517440345, 53.16586822102129], [4.912102097341758, 53.17189431910487], [5.012132245955883, 53.17782940667717], [5.112190871053239, 53.18367343941489], [5.212277545245519, 53.18942637364868], [5.3123918403138335, 53.19508816636458], [5.412533327209064, 53.20065877520588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.4125333&lt;dd&gt;Longitude: 53.200659&lt;dd&gt;Azimuth: 67.319992\u00b0&lt;dd&gt;Altitude: 39.458357\u00b0&lt;dd&gt;Slant Range: 813.31046km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.412533327209064, 53.20065877520588]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.912102097341758, 53.17189431910487], [5.012132245955883, 53.17782940667717], [5.112190871053239, 53.18367343941489], [5.212277545245519, 53.18942637364868], [5.3123918403138335, 53.19508816636458], [5.412533327209064, 53.20065877520588], [5.512701576063419, 53.20613815847428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.5127016&lt;dd&gt;Longitude: 53.206138&lt;dd&gt;Azimuth: 67.446522\u00b0&lt;dd&gt;Altitude: 39.106009\u00b0&lt;dd&gt;Slant Range: 818.4186km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.512701576063419, 53.20613815847428]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.012132245955883, 53.17782940667717], [5.112190871053239, 53.18367343941489], [5.212277545245519, 53.18942637364868], [5.3123918403138335, 53.19508816636458], [5.412533327209064, 53.20065877520588], [5.512701576063419, 53.20613815847428], [5.612896156218574, 53.21152627513175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.6128962&lt;dd&gt;Longitude: 53.211526&lt;dd&gt;Azimuth: 67.570317\u00b0&lt;dd&gt;Altitude: 38.757536\u00b0&lt;dd&gt;Slant Range: 823.5542km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.612896156218574, 53.21152627513175]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.112190871053239, 53.18367343941489], [5.212277545245519, 53.18942637364868], [5.3123918403138335, 53.19508816636458], [5.412533327209064, 53.20065877520588], [5.512701576063419, 53.20613815847428], [5.612896156218574, 53.21152627513175], [5.713116636214604, 53.216823084801796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.7131166&lt;dd&gt;Longitude: 53.216823&lt;dd&gt;Azimuth: 67.691467\u00b0&lt;dd&gt;Altitude: 38.412893\u00b0&lt;dd&gt;Slant Range: 828.71675km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.713116636214604, 53.216823084801796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.212277545245519, 53.18942637364868], [5.3123918403138335, 53.19508816636458], [5.412533327209064, 53.20065877520588], [5.512701576063419, 53.20613815847428], [5.612896156218574, 53.21152627513175], [5.713116636214604, 53.216823084801796], [5.813362583824023, 53.222028547771174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.8133626&lt;dd&gt;Longitude: 53.222029&lt;dd&gt;Azimuth: 67.810056\u00b0&lt;dd&gt;Altitude: 38.072032\u00b0&lt;dd&gt;Slant Range: 833.90575km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.813362583824023, 53.222028547771174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.3123918403138335, 53.19508816636458], [5.412533327209064, 53.20065877520588], [5.512701576063419, 53.20613815847428], [5.612896156218574, 53.21152627513175], [5.713116636214604, 53.216823084801796], [5.813362583824023, 53.222028547771174], [5.913633566044388, 53.22714262499104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 5.9136336&lt;dd&gt;Longitude: 53.227143&lt;dd&gt;Azimuth: 67.926167\u00b0&lt;dd&gt;Altitude: 37.734908\u00b0&lt;dd&gt;Slant Range: 839.1207km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.913633566044388, 53.22714262499104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.412533327209064, 53.20065877520588], [5.512701576063419, 53.20613815847428], [5.612896156218574, 53.21152627513175], [5.713116636214604, 53.216823084801796], [5.813362583824023, 53.222028547771174], [5.913633566044388, 53.22714262499104], [6.013929149132338, 53.2321652780788]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 6.0139291&lt;dd&gt;Longitude: 53.232165&lt;dd&gt;Azimuth: 68.039878\u00b0&lt;dd&gt;Altitude: 37.401475\u00b0&lt;dd&gt;Slant Range: 844.36111km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.013929149132338, 53.2321652780788]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.512701576063419, 53.20613815847428], [5.612896156218574, 53.21152627513175], [5.713116636214604, 53.216823084801796], [5.813362583824023, 53.222028547771174], [5.913633566044388, 53.22714262499104], [6.013929149132338, 53.2321652780788], [6.114248898589244, 53.237096469319034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4749&lt;dd&gt;Latitude: 6.1142489&lt;dd&gt;Longitude: 53.237096&lt;dd&gt;Azimuth: 68.151265\u00b0&lt;dd&gt;Altitude: 37.071687\u00b0&lt;dd&gt;Slant Range: 849.62651km&quot;, &quot;name&quot;: &quot;STARLINK-4749&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.114248898589244, 53.237096469319034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -10.428818&lt;dd&gt;Longitude: 53.21557&lt;dd&gt;Azimuth: 293.1982\u00b0&lt;dd&gt;Altitude: 28.80409\u00b0&lt;dd&gt;Slant Range: 683.15084km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935], [-10.324149040553307, 53.221048259083545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -10.324149&lt;dd&gt;Longitude: 53.221048&lt;dd&gt;Azimuth: 293.4672\u00b0&lt;dd&gt;Altitude: 29.127712\u00b0&lt;dd&gt;Slant Range: 677.46592km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.324149040553307, 53.221048259083545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935], [-10.324149040553307, 53.221048259083545], [-10.219452196344593, 53.22642704943061]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -10.219452&lt;dd&gt;Longitude: 53.226427&lt;dd&gt;Azimuth: 293.74239\u00b0&lt;dd&gt;Altitude: 29.455684\u00b0&lt;dd&gt;Slant Range: 671.80971km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.219452196344593, 53.22642704943061]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935], [-10.324149040553307, 53.221048259083545], [-10.219452196344593, 53.22642704943061], [-10.1147284233746, 53.23170649425249]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -10.114728&lt;dd&gt;Longitude: 53.231706&lt;dd&gt;Azimuth: 294.02399\u00b0&lt;dd&gt;Altitude: 29.788064\u00b0&lt;dd&gt;Slant Range: 666.18295km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.1147284233746, 53.23170649425249]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935], [-10.324149040553307, 53.221048259083545], [-10.219452196344593, 53.22642704943061], [-10.1147284233746, 53.23170649425249], [-10.009978213548678, 53.23688655056856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -10.009978&lt;dd&gt;Longitude: 53.236887&lt;dd&gt;Azimuth: 294.31222\u00b0&lt;dd&gt;Altitude: 30.12491\u00b0&lt;dd&gt;Slant Range: 660.58639km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.009978213548678, 53.23688655056856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935], [-10.324149040553307, 53.221048259083545], [-10.219452196344593, 53.22642704943061], [-10.1147284233746, 53.23170649425249], [-10.009978213548678, 53.23688655056856], [-9.90520205962482, 53.24196717618778]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.9052021&lt;dd&gt;Longitude: 53.241967&lt;dd&gt;Azimuth: 294.6073\u00b0&lt;dd&gt;Altitude: 30.466279\u00b0&lt;dd&gt;Slant Range: 655.02082km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.90520205962482, 53.24196717618778]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.428818464987675, 53.215570166978935], [-10.324149040553307, 53.221048259083545], [-10.219452196344593, 53.22642704943061], [-10.1147284233746, 53.23170649425249], [-10.009978213548678, 53.23688655056856], [-9.90520205962482, 53.24196717618778], [-9.800400455223153, 53.2469483297096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.8004005&lt;dd&gt;Longitude: 53.246948&lt;dd&gt;Azimuth: 294.90947\u00b0&lt;dd&gt;Altitude: 30.812226\u00b0&lt;dd&gt;Slant Range: 649.48704km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.800400455223153, 53.2469483297096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.324149040553307, 53.221048259083545], [-10.219452196344593, 53.22642704943061], [-10.1147284233746, 53.23170649425249], [-10.009978213548678, 53.23688655056856], [-9.90520205962482, 53.24196717618778], [-9.800400455223153, 53.2469483297096], [-9.695573894785431, 53.25182997052609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.6955739&lt;dd&gt;Longitude: 53.25183&lt;dd&gt;Azimuth: 295.21896\u00b0&lt;dd&gt;Altitude: 31.162805\u00b0&lt;dd&gt;Slant Range: 643.98588km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.695573894785431, 53.25182997052609]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.219452196344593, 53.22642704943061], [-10.1147284233746, 53.23170649425249], [-10.009978213548678, 53.23688655056856], [-9.90520205962482, 53.24196717618778], [-9.800400455223153, 53.2469483297096], [-9.695573894785431, 53.25182997052609], [-9.590722873585698, 53.25661205882343]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.5907229&lt;dd&gt;Longitude: 53.256612&lt;dd&gt;Azimuth: 295.53605\u00b0&lt;dd&gt;Altitude: 31.518066\u00b0&lt;dd&gt;Slant Range: 638.51818km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.590722873585698, 53.25661205882343]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.1147284233746, 53.23170649425249], [-10.009978213548678, 53.23688655056856], [-9.90520205962482, 53.24196717618778], [-9.800400455223153, 53.2469483297096], [-9.695573894785431, 53.25182997052609], [-9.590722873585698, 53.25661205882343], [-9.485847887687124, 53.26129455558348]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.4858479&lt;dd&gt;Longitude: 53.261295&lt;dd&gt;Azimuth: 295.86099\u00b0&lt;dd&gt;Altitude: 31.87806\u00b0&lt;dd&gt;Slant Range: 633.08482km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.485847887687124, 53.26129455558348]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.009978213548678, 53.23688655056856], [-9.90520205962482, 53.24196717618778], [-9.800400455223153, 53.2469483297096], [-9.695573894785431, 53.25182997052609], [-9.590722873585698, 53.25661205882343], [-9.485847887687124, 53.26129455558348], [-9.380949433954665, 53.26587742258543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.3809494&lt;dd&gt;Longitude: 53.265877&lt;dd&gt;Azimuth: 296.19406\u00b0&lt;dd&gt;Altitude: 32.242832\u00b0&lt;dd&gt;Slant Range: 627.6867km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.380949433954665, 53.26587742258543]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.90520205962482, 53.24196717618778], [-9.800400455223153, 53.2469483297096], [-9.695573894785431, 53.25182997052609], [-9.590722873585698, 53.25661205882343], [-9.485847887687124, 53.26129455558348], [-9.380949433954665, 53.26587742258543], [-9.276028010010455, 53.270360622407324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.276028&lt;dd&gt;Longitude: 53.270361&lt;dd&gt;Azimuth: 296.53556\u00b0&lt;dd&gt;Altitude: 32.612425\u00b0&lt;dd&gt;Slant Range: 622.32474km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.276028010010455, 53.270360622407324]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.800400455223153, 53.2469483297096], [-9.695573894785431, 53.25182997052609], [-9.590722873585698, 53.25661205882343], [-9.485847887687124, 53.26129455558348], [-9.380949433954665, 53.26587742258543], [-9.276028010010455, 53.270360622407324], [-9.17108411424527, 53.27474411842732]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.1710841&lt;dd&gt;Longitude: 53.274744&lt;dd&gt;Azimuth: 296.88578\u00b0&lt;dd&gt;Altitude: 32.986881\u00b0&lt;dd&gt;Slant Range: 616.99989km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.17108411424527, 53.27474411842732]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.695573894785431, 53.25182997052609], [-9.590722873585698, 53.25661205882343], [-9.485847887687124, 53.26129455558348], [-9.380949433954665, 53.26587742258543], [-9.276028010010455, 53.270360622407324], [-9.17108411424527, 53.27474411842732], [-9.066118245783917, 53.279027874825715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -9.0661182&lt;dd&gt;Longitude: 53.279028&lt;dd&gt;Azimuth: 297.24505\u00b0&lt;dd&gt;Altitude: 33.366236\u00b0&lt;dd&gt;Slant Range: 611.71312km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.066118245783917, 53.279027874825715]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.590722873585698, 53.25661205882343], [-9.485847887687124, 53.26129455558348], [-9.380949433954665, 53.26587742258543], [-9.276028010010455, 53.270360622407324], [-9.17108411424527, 53.27474411842732], [-9.066118245783917, 53.279027874825715], [-8.961130904472775, 53.283211856585815]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.9611309&lt;dd&gt;Longitude: 53.283212&lt;dd&gt;Azimuth: 297.61369\u00b0&lt;dd&gt;Altitude: 33.750522\u00b0&lt;dd&gt;Slant Range: 606.46545km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.961130904472775, 53.283211856585815]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.485847887687124, 53.26129455558348], [-9.380949433954665, 53.26587742258543], [-9.276028010010455, 53.270360622407324], [-9.17108411424527, 53.27474411842732], [-9.066118245783917, 53.279027874825715], [-8.961130904472775, 53.283211856585815], [-8.856122590873111, 53.28729602949572]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.8561226&lt;dd&gt;Longitude: 53.287296&lt;dd&gt;Azimuth: 297.99205\u00b0&lt;dd&gt;Altitude: 34.139766\u00b0&lt;dd&gt;Slant Range: 601.25789km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.856122590873111, 53.28729602949572]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.380949433954665, 53.26587742258543], [-9.276028010010455, 53.270360622407324], [-9.17108411424527, 53.27474411842732], [-9.066118245783917, 53.279027874825715], [-8.961130904472775, 53.283211856585815], [-8.856122590873111, 53.28729602949572], [-8.751093806232381, 53.29128036014947]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.7510938&lt;dd&gt;Longitude: 53.29128&lt;dd&gt;Azimuth: 298.38049\u00b0&lt;dd&gt;Altitude: 34.533991\u00b0&lt;dd&gt;Slant Range: 596.09151km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.751093806232381, 53.29128036014947]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.276028010010455, 53.270360622407324], [-9.17108411424527, 53.27474411842732], [-9.066118245783917, 53.279027874825715], [-8.961130904472775, 53.283211856585815], [-8.856122590873111, 53.28729602949572], [-8.751093806232381, 53.29128036014947], [-8.646045052478039, 53.29516481594864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.6460451&lt;dd&gt;Longitude: 53.295165&lt;dd&gt;Azimuth: 298.77939\u00b0&lt;dd&gt;Altitude: 34.933213\u00b0&lt;dd&gt;Slant Range: 590.96739km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.646045052478039, 53.29516481594864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.17108411424527, 53.27474411842732], [-9.066118245783917, 53.279027874825715], [-8.961130904472775, 53.283211856585815], [-8.856122590873111, 53.28729602949572], [-8.751093806232381, 53.29128036014947], [-8.646045052478039, 53.29516481594864], [-8.540976832196758, 53.298949365103354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.5409768&lt;dd&gt;Longitude: 53.298949&lt;dd&gt;Azimuth: 299.18914\u00b0&lt;dd&gt;Altitude: 35.337444\u00b0&lt;dd&gt;Slant Range: 585.88665km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.540976832196758, 53.298949365103354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.066118245783917, 53.279027874825715], [-8.961130904472775, 53.283211856585815], [-8.856122590873111, 53.28729602949572], [-8.751093806232381, 53.29128036014947], [-8.646045052478039, 53.29516481594864], [-8.540976832196758, 53.298949365103354], [-8.435889648616103, 53.30263397663403]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.4358896&lt;dd&gt;Longitude: 53.302634&lt;dd&gt;Azimuth: 299.61015\u00b0&lt;dd&gt;Altitude: 35.746686\u00b0&lt;dd&gt;Slant Range: 580.85043km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.435889648616103, 53.30263397663403]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.961130904472775, 53.283211856585815], [-8.856122590873111, 53.28729602949572], [-8.751093806232381, 53.29128036014947], [-8.646045052478039, 53.29516481594864], [-8.540976832196758, 53.298949365103354], [-8.435889648616103, 53.30263397663403], [-8.330784005594786, 53.306218620372015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.330784&lt;dd&gt;Longitude: 53.306219&lt;dd&gt;Azimuth: 300.04285\u00b0&lt;dd&gt;Altitude: 36.160936\u00b0&lt;dd&gt;Slant Range: 575.85991km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.330784005594786, 53.306218620372015]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.856122590873111, 53.28729602949572], [-8.751093806232381, 53.29128036014947], [-8.646045052478039, 53.29516481594864], [-8.540976832196758, 53.298949365103354], [-8.435889648616103, 53.30263397663403], [-8.330784005594786, 53.306218620372015], [-8.225660407602978, 53.30970326696138]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.2256604&lt;dd&gt;Longitude: 53.309703&lt;dd&gt;Azimuth: 300.48769\u00b0&lt;dd&gt;Altitude: 36.58018\u00b0&lt;dd&gt;Slant Range: 570.91629km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.225660407602978, 53.30970326696138]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.751093806232381, 53.29128036014947], [-8.646045052478039, 53.29516481594864], [-8.540976832196758, 53.298949365103354], [-8.435889648616103, 53.30263397663403], [-8.330784005594786, 53.306218620372015], [-8.225660407602978, 53.30970326696138], [-8.120519359699255, 53.31308788785982]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.1205194&lt;dd&gt;Longitude: 53.313088&lt;dd&gt;Azimuth: 300.94514\u00b0&lt;dd&gt;Altitude: 37.004397\u00b0&lt;dd&gt;Slant Range: 566.0208km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.120519359699255, 53.31308788785982]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.646045052478039, 53.29516481594864], [-8.540976832196758, 53.298949365103354], [-8.435889648616103, 53.30263397663403], [-8.330784005594786, 53.306218620372015], [-8.225660407602978, 53.30970326696138], [-8.120519359699255, 53.31308788785982], [-8.01536136752733, 53.31637245533986]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -8.0153614&lt;dd&gt;Longitude: 53.316372&lt;dd&gt;Azimuth: 301.41569\u00b0&lt;dd&gt;Altitude: 37.433556\u00b0&lt;dd&gt;Slant Range: 561.17472km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.01536136752733, 53.31637245533986]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.540976832196758, 53.298949365103354], [-8.435889648616103, 53.30263397663403], [-8.330784005594786, 53.306218620372015], [-8.225660407602978, 53.30970326696138], [-8.120519359699255, 53.31308788785982], [-8.01536136752733, 53.31637245533986], [-7.910186937292889, 53.31955694249001]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.9101869&lt;dd&gt;Longitude: 53.319557&lt;dd&gt;Azimuth: 301.89985\u00b0&lt;dd&gt;Altitude: 37.867614\u00b0&lt;dd&gt;Slant Range: 556.37933km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.910186937292889, 53.31955694249001]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.435889648616103, 53.30263397663403], [-8.330784005594786, 53.306218620372015], [-8.225660407602978, 53.30970326696138], [-8.120519359699255, 53.31308788785982], [-8.01536136752733, 53.31637245533986], [-7.910186937292889, 53.31955694249001], [-7.804996575742286, 53.32264132321584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.8049966&lt;dd&gt;Longitude: 53.322641&lt;dd&gt;Azimuth: 302.39815\u00b0&lt;dd&gt;Altitude: 38.306517\u00b0&lt;dd&gt;Slant Range: 551.63596km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.804996575742286, 53.32264132321584]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.330784005594786, 53.306218620372015], [-8.225660407602978, 53.30970326696138], [-8.120519359699255, 53.31308788785982], [-8.01536136752733, 53.31637245533986], [-7.910186937292889, 53.31955694249001], [-7.804996575742286, 53.32264132321584], [-7.6997907901549585, 53.325625572241016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.6997908&lt;dd&gt;Longitude: 53.325626&lt;dd&gt;Azimuth: 302.91116\u00b0&lt;dd&gt;Altitude: 38.750196\u00b0&lt;dd&gt;Slant Range: 546.94599km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.6997907901549585, 53.325625572241016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225660407602978, 53.30970326696138], [-8.120519359699255, 53.31308788785982], [-8.01536136752733, 53.31637245533986], [-7.910186937292889, 53.31955694249001], [-7.804996575742286, 53.32264132321584], [-7.6997907901549585, 53.325625572241016], [-7.594570088322034, 53.328509665108456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.5945701&lt;dd&gt;Longitude: 53.32851&lt;dd&gt;Azimuth: 303.43944\u00b0&lt;dd&gt;Altitude: 39.198572\u00b0&lt;dd&gt;Slant Range: 542.31078km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.594570088322034, 53.328509665108456]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.120519359699255, 53.31308788785982], [-8.01536136752733, 53.31637245533986], [-7.910186937292889, 53.31955694249001], [-7.804996575742286, 53.32264132321584], [-7.6997907901549585, 53.325625572241016], [-7.594570088322034, 53.328509665108456], [-7.489334978526049, 53.33129357818111]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.489335&lt;dd&gt;Longitude: 53.331294&lt;dd&gt;Azimuth: 303.98362\u00b0&lt;dd&gt;Altitude: 39.651549\u00b0&lt;dd&gt;Slant Range: 537.73178km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.489334978526049, 53.33129357818111]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.01536136752733, 53.31637245533986], [-7.910186937292889, 53.31955694249001], [-7.804996575742286, 53.32264132321584], [-7.6997907901549585, 53.325625572241016], [-7.594570088322034, 53.328509665108456], [-7.489334978526049, 53.33129357818111], [-7.384085969535704, 53.333977288643226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.384086&lt;dd&gt;Longitude: 53.333977&lt;dd&gt;Azimuth: 304.54432\u00b0&lt;dd&gt;Altitude: 40.109012\u00b0&lt;dd&gt;Slant Range: 533.21042km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.384085969535704, 53.333977288643226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.910186937292889, 53.31955694249001], [-7.804996575742286, 53.32264132321584], [-7.6997907901549585, 53.325625572241016], [-7.594570088322034, 53.328509665108456], [-7.489334978526049, 53.33129357818111], [-7.384085969535704, 53.333977288643226], [-7.2788235705773445, 53.33656077450089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.2788236&lt;dd&gt;Longitude: 53.336561&lt;dd&gt;Azimuth: 305.1222\u00b0&lt;dd&gt;Altitude: 40.570833\u00b0&lt;dd&gt;Slant Range: 528.7482km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.2788235705773445, 53.33656077450089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.804996575742286, 53.32264132321584], [-7.6997907901549585, 53.325625572241016], [-7.594570088322034, 53.328509665108456], [-7.489334978526049, 53.33129357818111], [-7.384085969535704, 53.333977288643226], [-7.2788235705773445, 53.33656077450089], [-7.173548291327405, 53.339044014583294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.1735483&lt;dd&gt;Longitude: 53.339044&lt;dd&gt;Azimuth: 305.71795\u00b0&lt;dd&gt;Altitude: 41.036863\u00b0&lt;dd&gt;Slant Range: 524.34663km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.173548291327405, 53.339044014583294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6997907901549585, 53.325625572241016], [-7.594570088322034, 53.328509665108456], [-7.489334978526049, 53.33129357818111], [-7.384085969535704, 53.333977288643226], [-7.2788235705773445, 53.33656077450089], [-7.173548291327405, 53.339044014583294], [-7.068260641881717, 53.34142698854337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -7.0682606&lt;dd&gt;Longitude: 53.341427&lt;dd&gt;Azimuth: 306.33229\u00b0&lt;dd&gt;Altitude: 41.506932\u00b0&lt;dd&gt;Slant Range: 520.00726km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.068260641881717, 53.34142698854337]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.594570088322034, 53.328509665108456], [-7.489334978526049, 53.33129357818111], [-7.384085969535704, 53.333977288643226], [-7.2788235705773445, 53.33656077450089], [-7.173548291327405, 53.339044014583294], [-7.068260641881717, 53.34142698854337], [-6.96296113276002, 53.34370967685879]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.9629611&lt;dd&gt;Longitude: 53.34371&lt;dd&gt;Azimuth: 306.96596\u00b0&lt;dd&gt;Altitude: 41.98085\u00b0&lt;dd&gt;Slant Range: 515.73165km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.96296113276002, 53.34370967685879]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.489334978526049, 53.33129357818111], [-7.384085969535704, 53.333977288643226], [-7.2788235705773445, 53.33656077450089], [-7.173548291327405, 53.339044014583294], [-7.068260641881717, 53.34142698854337], [-6.96296113276002, 53.34370967685879], [-6.857650274870992, 53.34589206083251]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.8576503&lt;dd&gt;Longitude: 53.345892&lt;dd&gt;Azimuth: 307.61973\u00b0&lt;dd&gt;Altitude: 42.458402\u00b0&lt;dd&gt;Slant Range: 511.52143km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.857650274870992, 53.34589206083251]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.384085969535704, 53.333977288643226], [-7.2788235705773445, 53.33656077450089], [-7.173548291327405, 53.339044014583294], [-7.068260641881717, 53.34142698854337], [-6.96296113276002, 53.34370967685879], [-6.857650274870992, 53.34589206083251], [-6.752328579501217, 53.34797412259389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.7523286&lt;dd&gt;Longitude: 53.347974&lt;dd&gt;Azimuth: 308.29442\u00b0&lt;dd&gt;Altitude: 42.939348\u00b0&lt;dd&gt;Slant Range: 507.37821km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.752328579501217, 53.34797412259389]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.2788235705773445, 53.33656077450089], [-7.173548291327405, 53.339044014583294], [-7.068260641881717, 53.34142698854337], [-6.96296113276002, 53.34370967685879], [-6.857650274870992, 53.34589206083251], [-6.752328579501217, 53.34797412259389], [-6.646996558300216, 53.34995584509908]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.6469966&lt;dd&gt;Longitude: 53.349956&lt;dd&gt;Azimuth: 308.99084\u00b0&lt;dd&gt;Altitude: 43.423423\u00b0&lt;dd&gt;Slant Range: 503.30365km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.646996558300216, 53.34995584509908]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.173548291327405, 53.339044014583294], [-7.068260641881717, 53.34142698854337], [-6.96296113276002, 53.34370967685879], [-6.857650274870992, 53.34589206083251], [-6.752328579501217, 53.34797412259389], [-6.646996558300216, 53.34995584509908], [-6.541654723264776, 53.351837212131976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.5416547&lt;dd&gt;Longitude: 53.351837&lt;dd&gt;Azimuth: 309.70986\u00b0&lt;dd&gt;Altitude: 43.910331\u00b0&lt;dd&gt;Slant Range: 499.29945km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.541654723264776, 53.351837212131976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.068260641881717, 53.34142698854337], [-6.96296113276002, 53.34370967685879], [-6.857650274870992, 53.34589206083251], [-6.752328579501217, 53.34797412259389], [-6.646996558300216, 53.34995584509908], [-6.541654723264776, 53.351837212131976], [-6.436303586712819, 53.35361820830476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.4363036&lt;dd&gt;Longitude: 53.353618&lt;dd&gt;Azimuth: 310.45238\u00b0&lt;dd&gt;Altitude: 44.39975\u00b0&lt;dd&gt;Slant Range: 495.36732km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.436303586712819, 53.35361820830476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.96296113276002, 53.34370967685879], [-6.857650274870992, 53.34589206083251], [-6.752328579501217, 53.34797412259389], [-6.646996558300216, 53.34995584509908], [-6.541654723264776, 53.351837212131976], [-6.436303586712819, 53.35361820830476], [-6.330943661274367, 53.355298819058476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.3309437&lt;dd&gt;Longitude: 53.355299&lt;dd&gt;Azimuth: 311.21931\u00b0&lt;dd&gt;Altitude: 44.891321\u00b0&lt;dd&gt;Slant Range: 491.50898km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.330943661274367, 53.355298819058476]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.857650274870992, 53.34589206083251], [-6.752328579501217, 53.34797412259389], [-6.646996558300216, 53.34995584509908], [-6.541654723264776, 53.351837212131976], [-6.436303586712819, 53.35361820830476], [-6.330943661274367, 53.355298819058476], [-6.225575459883071, 53.35687903066381]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.2255755&lt;dd&gt;Longitude: 53.356879&lt;dd&gt;Azimuth: 312.01161\u00b0&lt;dd&gt;Altitude: 45.384656\u00b0&lt;dd&gt;Slant Range: 487.7262km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.225575459883071, 53.35687903066381]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.752328579501217, 53.34797412259389], [-6.646996558300216, 53.34995584509908], [-6.541654723264776, 53.351837212131976], [-6.436303586712819, 53.35361820830476], [-6.330943661274367, 53.355298819058476], [-6.225575459883071, 53.35687903066381], [-6.120199495732524, 53.35835883022148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.1201995&lt;dd&gt;Longitude: 53.358359&lt;dd&gt;Azimuth: 312.83023\u00b0&lt;dd&gt;Altitude: 45.879326\u00b0&lt;dd&gt;Slant Range: 484.02074km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.120199495732524, 53.35835883022148]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.646996558300216, 53.34995584509908], [-6.541654723264776, 53.351837212131976], [-6.436303586712819, 53.35361820830476], [-6.330943661274367, 53.355298819058476], [-6.225575459883071, 53.35687903066381], [-6.120199495732524, 53.35835883022148], [-6.014816282290353, 53.35973820566289]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -6.0148163&lt;dd&gt;Longitude: 53.359738&lt;dd&gt;Azimuth: 313.67618\u00b0&lt;dd&gt;Altitude: 46.37487\u00b0&lt;dd&gt;Slant Range: 480.39442km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.014816282290353, 53.35973820566289]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.541654723264776, 53.351837212131976], [-6.436303586712819, 53.35361820830476], [-6.330943661274367, 53.355298819058476], [-6.225575459883071, 53.35687903066381], [-6.120199495732524, 53.35835883022148], [-6.014816282290353, 53.35973820566289], [-5.909426333256493, 53.36101714575054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.9094263&lt;dd&gt;Longitude: 53.361017&lt;dd&gt;Azimuth: 314.55048\u00b0&lt;dd&gt;Altitude: 46.870784\u00b0&lt;dd&gt;Slant Range: 476.84902km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.909426333256493, 53.36101714575054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.436303586712819, 53.35361820830476], [-6.330943661274367, 53.355298819058476], [-6.225575459883071, 53.35687903066381], [-6.120199495732524, 53.35835883022148], [-6.014816282290353, 53.35973820566289], [-5.909426333256493, 53.36101714575054], [-5.804030162560976, 53.3621956400785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.8040302&lt;dd&gt;Longitude: 53.362196&lt;dd&gt;Azimuth: 315.45416\u00b0&lt;dd&gt;Altitude: 47.366523\u00b0&lt;dd&gt;Slant Range: 473.38639km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.804030162560976, 53.3621956400785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.330943661274367, 53.355298819058476], [-6.225575459883071, 53.35687903066381], [-6.120199495732524, 53.35835883022148], [-6.014816282290353, 53.35973820566289], [-5.909426333256493, 53.36101714575054], [-5.804030162560976, 53.3621956400785], [-5.698628284341992, 53.3632736790729]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.6986283&lt;dd&gt;Longitude: 53.363274&lt;dd&gt;Azimuth: 316.38826\u00b0&lt;dd&gt;Altitude: 47.861502\u00b0&lt;dd&gt;Slant Range: 470.00834km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.698628284341992, 53.3632736790729]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.225575459883071, 53.35687903066381], [-6.120199495732524, 53.35835883022148], [-6.014816282290353, 53.35973820566289], [-5.909426333256493, 53.36101714575054], [-5.804030162560976, 53.3621956400785], [-5.698628284341992, 53.3632736790729], [-5.593221212929939, 53.36425125399226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.5932212&lt;dd&gt;Longitude: 53.364251&lt;dd&gt;Azimuth: 317.35384\u00b0&lt;dd&gt;Altitude: 48.355087\u00b0&lt;dd&gt;Slant Range: 466.71672km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.593221212929939, 53.36425125399226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.120199495732524, 53.35835883022148], [-6.014816282290353, 53.35973820566289], [-5.909426333256493, 53.36101714575054], [-5.804030162560976, 53.3621956400785], [-5.698628284341992, 53.3632736790729], [-5.593221212929939, 53.36425125399226], [-5.487809462821827, 53.36512835692786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.4878095&lt;dd&gt;Longitude: 53.365128&lt;dd&gt;Azimuth: 318.35195\u00b0&lt;dd&gt;Altitude: 48.846603\u00b0&lt;dd&gt;Slant Range: 463.51338km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.487809462821827, 53.36512835692786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.014816282290353, 53.35973820566289], [-5.909426333256493, 53.36101714575054], [-5.804030162560976, 53.3621956400785], [-5.698628284341992, 53.3632736790729], [-5.593221212929939, 53.36425125399226], [-5.487809462821827, 53.36512835692786], [-5.382393548681832, 53.36590498080414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.3823935&lt;dd&gt;Longitude: 53.365905&lt;dd&gt;Azimuth: 319.38365\u00b0&lt;dd&gt;Altitude: 49.335324\u00b0&lt;dd&gt;Slant Range: 460.40016km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.382393548681832, 53.36590498080414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.909426333256493, 53.36101714575054], [-5.804030162560976, 53.3621956400785], [-5.698628284341992, 53.3632736790729], [-5.593221212929939, 53.36425125399226], [-5.487809462821827, 53.36512835692786], [-5.382393548681832, 53.36590498080414], [-5.276973985301508, 53.36658111937884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.276974&lt;dd&gt;Longitude: 53.366581&lt;dd&gt;Azimuth: 320.44997\u00b0&lt;dd&gt;Altitude: 49.820479\u00b0&lt;dd&gt;Slant Range: 457.37891km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.276973985301508, 53.36658111937884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.804030162560976, 53.3621956400785], [-5.698628284341992, 53.3632736790729], [-5.593221212929939, 53.36425125399226], [-5.487809462821827, 53.36512835692786], [-5.382393548681832, 53.36590498080414], [-5.276973985301508, 53.36658111937884], [-5.171551287611386, 53.367156767243436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.1715513&lt;dd&gt;Longitude: 53.367157&lt;dd&gt;Azimuth: 321.55192\u00b0&lt;dd&gt;Altitude: 50.301244\u00b0&lt;dd&gt;Slant Range: 454.45146km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.171551287611386, 53.367156767243436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.698628284341992, 53.3632736790729], [-5.593221212929939, 53.36425125399226], [-5.487809462821827, 53.36512835692786], [-5.382393548681832, 53.36590498080414], [-5.276973985301508, 53.36658111937884], [-5.171551287611386, 53.367156767243436], [-5.066125970627644, 53.367631919823246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -5.066126&lt;dd&gt;Longitude: 53.367632&lt;dd&gt;Azimuth: 322.69048\u00b0&lt;dd&gt;Altitude: 50.776751\u00b0&lt;dd&gt;Slant Range: 451.61965km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.066125970627644, 53.367631919823246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.593221212929939, 53.36425125399226], [-5.487809462821827, 53.36512835692786], [-5.382393548681832, 53.36590498080414], [-5.276973985301508, 53.36658111937884], [-5.171551287611386, 53.367156767243436], [-5.066125970627644, 53.367631919823246], [-4.9606985494695826, 53.36800657337757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.9606985&lt;dd&gt;Longitude: 53.368007&lt;dd&gt;Azimuth: 323.86657\u00b0&lt;dd&gt;Altitude: 51.246078\u00b0&lt;dd&gt;Slant Range: 448.88528km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.9606985494695826, 53.36800657337757]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.487809462821827, 53.36512835692786], [-5.382393548681832, 53.36590498080414], [-5.276973985301508, 53.36658111937884], [-5.171551287611386, 53.367156767243436], [-5.066125970627644, 53.367631919823246], [-4.9606985494695826, 53.36800657337757], [-4.855269539318819, 53.368280725000126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.8552695&lt;dd&gt;Longitude: 53.368281&lt;dd&gt;Azimuth: 325.08106\u00b0&lt;dd&gt;Altitude: 51.70826\u00b0&lt;dd&gt;Slant Range: 446.25014km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.855269539318819, 53.368280725000126]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.382393548681832, 53.36590498080414], [-5.276973985301508, 53.36658111937884], [-5.171551287611386, 53.367156767243436], [-5.066125970627644, 53.367631919823246], [-4.9606985494695826, 53.36800657337757], [-4.855269539318819, 53.368280725000126], [-4.749839455415823, 53.368454372618764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.7498395&lt;dd&gt;Longitude: 53.368454&lt;dd&gt;Azimuth: 326.33474\u00b0&lt;dd&gt;Altitude: 52.162279\u00b0&lt;dd&gt;Slant Range: 443.71602km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.749839455415823, 53.368454372618764]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.276973985301508, 53.36658111937884], [-5.171551287611386, 53.367156767243436], [-5.066125970627644, 53.367631919823246], [-4.9606985494695826, 53.36800657337757], [-4.855269539318819, 53.368280725000126], [-4.749839455415823, 53.368454372618764], [-4.644408813029943, 53.36852751499585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.6444088&lt;dd&gt;Longitude: 53.368528&lt;dd&gt;Azimuth: 327.62828\u00b0&lt;dd&gt;Altitude: 52.607077\u00b0&lt;dd&gt;Slant Range: 441.28465km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.644408813029943, 53.36852751499585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.171551287611386, 53.367156767243436], [-5.066125970627644, 53.367631919823246], [-4.9606985494695826, 53.36800657337757], [-4.855269539318819, 53.368280725000126], [-4.749839455415823, 53.368454372618764], [-4.644408813029943, 53.36852751499585], [-4.53897812746068, 53.368500151728284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.5389781&lt;dd&gt;Longitude: 53.3685&lt;dd&gt;Azimuth: 328.96226\u00b0&lt;dd&gt;Altitude: 53.041549\u00b0&lt;dd&gt;Slant Range: 438.95775km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.53897812746068, 53.368500151728284]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.066125970627644, 53.367631919823246], [-4.9606985494695826, 53.36800657337757], [-4.855269539318819, 53.368280725000126], [-4.749839455415823, 53.368454372618764], [-4.644408813029943, 53.36852751499585], [-4.53897812746068, 53.368500151728284], [-4.433547913994482, 53.36837228324739]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.4335479&lt;dd&gt;Longitude: 53.368372&lt;dd&gt;Azimuth: 330.3371\u00b0&lt;dd&gt;Altitude: 53.464555\u00b0&lt;dd&gt;Slant Range: 436.73698km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.433547913994482, 53.36837228324739]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.9606985494695826, 53.36800657337757], [-4.855269539318819, 53.368280725000126], [-4.749839455415823, 53.368454372618764], [-4.644408813029943, 53.36852751499585], [-4.53897812746068, 53.368500151728284], [-4.433547913994482, 53.36837228324739], [-4.328118687916395, 53.36814391081899]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.3281187&lt;dd&gt;Longitude: 53.368144&lt;dd&gt;Azimuth: 331.75309\u00b0&lt;dd&gt;Altitude: 53.874918\u00b0&lt;dd&gt;Slant Range: 434.62398km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.328118687916395, 53.36814391081899]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.855269539318819, 53.368280725000126], [-4.749839455415823, 53.368454372618764], [-4.644408813029943, 53.36852751499585], [-4.53897812746068, 53.368500151728284], [-4.433547913994482, 53.36837228324739], [-4.328118687916395, 53.36814391081899], [-4.22269096447058, 53.36781503654335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.222691&lt;dd&gt;Longitude: 53.367815&lt;dd&gt;Azimuth: 333.2103\u00b0&lt;dd&gt;Altitude: 54.271431\u00b0&lt;dd&gt;Slant Range: 432.62033km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.22269096447058, 53.36781503654335]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.749839455415823, 53.368454372618764], [-4.644408813029943, 53.36852751499585], [-4.53897812746068, 53.368500151728284], [-4.433547913994482, 53.36837228324739], [-4.328118687916395, 53.36814391081899], [-4.22269096447058, 53.36781503654335], [-4.117265258855191, 53.3673856633551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.1172653&lt;dd&gt;Longitude: 53.367386&lt;dd&gt;Azimuth: 334.70862\u00b0&lt;dd&gt;Altitude: 54.652867\u00b0&lt;dd&gt;Slant Range: 430.72755km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.117265258855191, 53.3673856633551]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.644408813029943, 53.36852751499585], [-4.53897812746068, 53.368500151728284], [-4.433547913994482, 53.36837228324739], [-4.328118687916395, 53.36814391081899], [-4.22269096447058, 53.36781503654335], [-4.117265258855191, 53.3673856633551], [-4.011842086197216, 53.366855795023106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -4.0118421&lt;dd&gt;Longitude: 53.366856&lt;dd&gt;Azimuth: 336.2477\u00b0&lt;dd&gt;Altitude: 55.017982\u00b0&lt;dd&gt;Slant Range: 428.94712km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.011842086197216, 53.366855795023106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.53897812746068, 53.368500151728284], [-4.433547913994482, 53.36837228324739], [-4.328118687916395, 53.36814391081899], [-4.22269096447058, 53.36781503654335], [-4.117265258855191, 53.3673856633551], [-4.011842086197216, 53.366855795023106], [-3.9064219615430336, 53.366225436150266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.906422&lt;dd&gt;Longitude: 53.366225&lt;dd&gt;Azimuth: 337.82694\u00b0&lt;dd&gt;Altitude: 55.365526\u00b0&lt;dd&gt;Slant Range: 427.28044km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9064219615430336, 53.366225436150266]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.433547913994482, 53.36837228324739], [-4.328118687916395, 53.36814391081899], [-4.22269096447058, 53.36781503654335], [-4.117265258855191, 53.3673856633551], [-4.011842086197216, 53.366855795023106], [-3.9064219615430336, 53.366225436150266], [-3.801005399836406, 53.36549459217342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.8010054&lt;dd&gt;Longitude: 53.365495&lt;dd&gt;Azimuth: 339.44545\u00b0&lt;dd&gt;Altitude: 55.694252\u00b0&lt;dd&gt;Slant Range: 425.72886km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.801005399836406, 53.36549459217342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.328118687916395, 53.36814391081899], [-4.22269096447058, 53.36781503654335], [-4.117265258855191, 53.3673856633551], [-4.011842086197216, 53.366855795023106], [-3.9064219615430336, 53.366225436150266], [-3.801005399836406, 53.36549459217342], [-3.6955929158995473, 53.36466326936311]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.6955929&lt;dd&gt;Longitude: 53.364663&lt;dd&gt;Azimuth: 341.10207\u00b0&lt;dd&gt;Altitude: 56.002927\u00b0&lt;dd&gt;Slant Range: 424.29362km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6955929158995473, 53.36466326936311]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.22269096447058, 53.36781503654335], [-4.117265258855191, 53.3673856633551], [-4.011842086197216, 53.366855795023106], [-3.9064219615430336, 53.366225436150266], [-3.801005399836406, 53.36549459217342], [-3.6955929158995473, 53.36466326936311], [-3.5901850244206797, 53.363731474823176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.590185&lt;dd&gt;Longitude: 53.363731&lt;dd&gt;Azimuth: 342.79533\u00b0&lt;dd&gt;Altitude: 56.290346\u00b0&lt;dd&gt;Slant Range: 422.97593km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.5901850244206797, 53.363731474823176]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.117265258855191, 53.3673856633551], [-4.011842086197216, 53.366855795023106], [-3.9064219615430336, 53.366225436150266], [-3.801005399836406, 53.36549459217342], [-3.6955929158995473, 53.36466326936311], [-3.5901850244206797, 53.363731474823176], [-3.4847822399379056, 53.36269921649074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.4847822&lt;dd&gt;Longitude: 53.362699&lt;dd&gt;Azimuth: 344.52341\u00b0&lt;dd&gt;Altitude: 56.555339\u00b0&lt;dd&gt;Slant Range: 421.77688km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4847822399379056, 53.36269921649074]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.011842086197216, 53.366855795023106], [-3.9064219615430336, 53.366225436150266], [-3.801005399836406, 53.36549459217342], [-3.6955929158995473, 53.36466326936311], [-3.5901850244206797, 53.363731474823176], [-3.4847822399379056, 53.36269921649074], [-3.3793850768147253, 53.36156650313567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.3793851&lt;dd&gt;Longitude: 53.361567&lt;dd&gt;Azimuth: 346.28419\u00b0&lt;dd&gt;Altitude: 56.796789\u00b0&lt;dd&gt;Slant Range: 420.69749km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3793850768147253, 53.36156650313567]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9064219615430336, 53.366225436150266], [-3.801005399836406, 53.36549459217342], [-3.6955929158995473, 53.36466326936311], [-3.5901850244206797, 53.363731474823176], [-3.4847822399379056, 53.36269921649074], [-3.3793850768147253, 53.36156650313567], [-3.273994049226912, 53.36033334436021]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.273994&lt;dd&gt;Longitude: 53.360333&lt;dd&gt;Azimuth: 348.07522\u00b0&lt;dd&gt;Altitude: 57.013644\u00b0&lt;dd&gt;Slant Range: 419.73869km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.273994049226912, 53.36033334436021]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.801005399836406, 53.36549459217342], [-3.6955929158995473, 53.36466326936311], [-3.5901850244206797, 53.363731474823176], [-3.4847822399379056, 53.36269921649074], [-3.3793850768147253, 53.36156650313567], [-3.273994049226912, 53.36033334436021], [-3.1686096711501426, 53.358999750598784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.1686097&lt;dd&gt;Longitude: 53.359&lt;dd&gt;Azimuth: 349.89373\u00b0&lt;dd&gt;Altitude: 57.204931\u00b0&lt;dd&gt;Slant Range: 418.9013km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.1686096711501426, 53.358999750598784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6955929158995473, 53.36466326936311], [-3.5901850244206797, 53.363731474823176], [-3.4847822399379056, 53.36269921649074], [-3.3793850768147253, 53.36156650313567], [-3.273994049226912, 53.36033334436021], [-3.1686096711501426, 53.358999750598784], [-3.06323245632766, 53.357565733117355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -3.0632325&lt;dd&gt;Longitude: 53.357566&lt;dd&gt;Azimuth: 351.73664\u00b0&lt;dd&gt;Altitude: 57.369765\u00b0&lt;dd&gt;Slant Range: 418.18605km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.06323245632766, 53.357565733117355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.5901850244206797, 53.363731474823176], [-3.4847822399379056, 53.36269921649074], [-3.3793850768147253, 53.36156650313567], [-3.273994049226912, 53.36033334436021], [-3.1686096711501426, 53.358999750598784], [-3.06323245632766, 53.357565733117355], [-2.9578629182815934, 53.356031304013115]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.9578629&lt;dd&gt;Longitude: 53.356031&lt;dd&gt;Azimuth: 353.60059\u00b0&lt;dd&gt;Altitude: 57.507369\u00b0&lt;dd&gt;Slant Range: 417.59357km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9578629182815934, 53.356031304013115]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4847822399379056, 53.36269921649074], [-3.3793850768147253, 53.36156650313567], [-3.273994049226912, 53.36033334436021], [-3.1686096711501426, 53.358999750598784], [-3.06323245632766, 53.357565733117355], [-2.9578629182815934, 53.356031304013115], [-2.8525015702617162, 53.35439647621398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.8525016&lt;dd&gt;Longitude: 53.354396&lt;dd&gt;Azimuth: 355.48195\u00b0&lt;dd&gt;Altitude: 57.61708\u00b0&lt;dd&gt;Slant Range: 417.12439km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8525015702617162, 53.35439647621398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3793850768147253, 53.36156650313567], [-3.273994049226912, 53.36033334436021], [-3.1686096711501426, 53.358999750598784], [-3.06323245632766, 53.357565733117355], [-2.9578629182815934, 53.356031304013115], [-2.8525015702617162, 53.35439647621398], [-2.7471489252515258, 53.35266126347786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.7471489&lt;dd&gt;Longitude: 53.352661&lt;dd&gt;Azimuth: 357.3769\u00b0&lt;dd&gt;Altitude: 57.69836\u00b0&lt;dd&gt;Slant Range: 416.77893km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7471489252515258, 53.35266126347786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.273994049226912, 53.36033334436021], [-3.1686096711501426, 53.358999750598784], [-3.06323245632766, 53.357565733117355], [-2.9578629182815934, 53.356031304013115], [-2.8525015702617162, 53.35439647621398], [-2.7471489252515258, 53.35266126347786], [-2.641805495943307, 53.35082568039246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.6418055&lt;dd&gt;Longitude: 53.350826&lt;dd&gt;Azimuth: 359.28143\u00b0&lt;dd&gt;Altitude: 57.750807\u00b0&lt;dd&gt;Slant Range: 416.55748km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.641805495943307, 53.35082568039246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.1686096711501426, 53.358999750598784], [-3.06323245632766, 53.357565733117355], [-2.9578629182815934, 53.356031304013115], [-2.8525015702617162, 53.35439647621398], [-2.7471489252515258, 53.35266126347786], [-2.641805495943307, 53.35082568039246], [-2.5364717947246485, 53.348889742374354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.5364718&lt;dd&gt;Longitude: 53.34889&lt;dd&gt;Azimuth: 1.1914092\u00b0&lt;dd&gt;Altitude: 57.774159\u00b0&lt;dd&gt;Slant Range: 416.46025km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5364717947246485, 53.348889742374354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.06323245632766, 53.357565733117355], [-2.9578629182815934, 53.356031304013115], [-2.8525015702617162, 53.35439647621398], [-2.7471489252515258, 53.35266126347786], [-2.641805495943307, 53.35082568039246], [-2.5364717947246485, 53.348889742374354], [-2.4311483336542685, 53.34685346566853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.4311483&lt;dd&gt;Longitude: 53.346853&lt;dd&gt;Azimuth: 3.1026325\u00b0&lt;dd&gt;Altitude: 57.7683\u00b0&lt;dd&gt;Slant Range: 416.48733km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.4311483336542685, 53.34685346566853]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9578629182815934, 53.356031304013115], [-2.8525015702617162, 53.35439647621398], [-2.7471489252515258, 53.35266126347786], [-2.641805495943307, 53.35082568039246], [-2.5364717947246485, 53.348889742374354], [-2.4311483336542685, 53.34685346566853], [-2.32583562445418, 53.34471686734768]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.3258356&lt;dd&gt;Longitude: 53.344717&lt;dd&gt;Azimuth: 5.010881\u00b0&lt;dd&gt;Altitude: 57.733258\u00b0&lt;dd&gt;Slant Range: 416.63869km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.32583562445418, 53.34471686734768]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8525015702617162, 53.35439647621398], [-2.7471489252515258, 53.35266126347786], [-2.641805495943307, 53.35082568039246], [-2.5364717947246485, 53.348889742374354], [-2.4311483336542685, 53.34685346566853], [-2.32583562445418, 53.34471686734768], [-2.2205341784857455, 53.34247996531156]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.2205342&lt;dd&gt;Longitude: 53.34248&lt;dd&gt;Azimuth: 6.9119741\u00b0&lt;dd&gt;Altitude: 57.669213\u00b0&lt;dd&gt;Slant Range: 416.91419km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2205341784857455, 53.34247996531156]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7471489252515258, 53.35266126347786], [-2.641805495943307, 53.35082568039246], [-2.5364717947246485, 53.348889742374354], [-2.4311483336542685, 53.34685346566853], [-2.32583562445418, 53.34471686734768], [-2.2205341784857455, 53.34247996531156], [-2.115244506738077, 53.34014277828611]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.1152445&lt;dd&gt;Longitude: 53.340143&lt;dd&gt;Azimuth: 8.8018253\u00b0&lt;dd&gt;Altitude: 57.576484\u00b0&lt;dd&gt;Slant Range: 417.3136km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.115244506738077, 53.34014277828611]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.641805495943307, 53.35082568039246], [-2.5364717947246485, 53.348889742374354], [-2.4311483336542685, 53.34685346566853], [-2.32583562445418, 53.34471686734768], [-2.2205341784857455, 53.34247996531156], [-2.115244506738077, 53.34014277828611], [-2.009967119802512, 53.337705325822895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -2.0099671&lt;dd&gt;Longitude: 53.337705&lt;dd&gt;Azimuth: 10.676493\u00b0&lt;dd&gt;Altitude: 57.455531\u00b0&lt;dd&gt;Slant Range: 417.83655km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.009967119802512, 53.337705325822895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5364717947246485, 53.348889742374354], [-2.4311483336542685, 53.34685346566853], [-2.32583562445418, 53.34471686734768], [-2.2205341784857455, 53.34247996531156], [-2.115244506738077, 53.34014277828611], [-2.009967119802512, 53.337705325822895], [-1.9047025278687482, 53.33516762829817]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.9047025&lt;dd&gt;Longitude: 53.335168&lt;dd&gt;Azimuth: 12.532229\u00b0&lt;dd&gt;Altitude: 57.306943\u00b0&lt;dd&gt;Slant Range: 418.48257km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9047025278687482, 53.33516762829817]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.4311483336542685, 53.34685346566853], [-2.32583562445418, 53.34471686734768], [-2.2205341784857455, 53.34247996531156], [-2.115244506738077, 53.34014277828611], [-2.009967119802512, 53.337705325822895], [-1.9047025278687482, 53.33516762829817], [-1.799451240698508, 53.3325297069121]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.7994512&lt;dd&gt;Longitude: 53.33253&lt;dd&gt;Azimuth: 14.365516\u00b0&lt;dd&gt;Altitude: 57.131434\u00b0&lt;dd&gt;Slant Range: 419.25111km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.799451240698508, 53.3325297069121]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.32583562445418, 53.34471686734768], [-2.2205341784857455, 53.34247996531156], [-2.115244506738077, 53.34014277828611], [-2.009967119802512, 53.337705325822895], [-1.9047025278687482, 53.33516762829817], [-1.799451240698508, 53.3325297069121], [-1.6942137676093298, 53.329791583687836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.6942138&lt;dd&gt;Longitude: 53.329792&lt;dd&gt;Azimuth: 16.173106\u00b0&lt;dd&gt;Altitude: 56.929825\u00b0&lt;dd&gt;Slant Range: 420.14148km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6942137676093298, 53.329791583687836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.2205341784857455, 53.34247996531156], [-2.115244506738077, 53.34014277828611], [-2.009967119802512, 53.337705325822895], [-1.9047025278687482, 53.33516762829817], [-1.799451240698508, 53.3325297069121], [-1.6942137676093298, 53.329791583687836], [-1.5889906174606767, 53.32695328147077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.5889906&lt;dd&gt;Longitude: 53.326953&lt;dd&gt;Azimuth: 17.952043\u00b0&lt;dd&gt;Altitude: 56.70304\u00b0&lt;dd&gt;Slant Range: 421.15292km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5889906174606767, 53.32695328147077]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.115244506738077, 53.34014277828611], [-2.009967119802512, 53.337705325822895], [-1.9047025278687482, 53.33516762829817], [-1.799451240698508, 53.3325297069121], [-1.6942137676093298, 53.329791583687836], [-1.5889906174606767, 53.32695328147077], [-1.4837822986385913, 53.324014823927385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.4837823&lt;dd&gt;Longitude: 53.324015&lt;dd&gt;Azimuth: 19.699684\u00b0&lt;dd&gt;Altitude: 56.452085\u00b0&lt;dd&gt;Slant Range: 422.28455km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4837822986385913, 53.324014823927385]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.009967119802512, 53.337705325822895], [-1.9047025278687482, 53.33516762829817], [-1.799451240698508, 53.3325297069121], [-1.6942137676093298, 53.329791583687836], [-1.5889906174606767, 53.32695328147077], [-1.4837822986385913, 53.324014823927385], [-1.3785893190332816, 53.32097623554462]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.3785893&lt;dd&gt;Longitude: 53.320976&lt;dd&gt;Azimuth: 21.41371\u00b0&lt;dd&gt;Altitude: 56.178042\u00b0&lt;dd&gt;Slant Range: 423.5354km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3785893190332816, 53.32097623554462]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9047025278687482, 53.33516762829817], [-1.799451240698508, 53.3325297069121], [-1.6942137676093298, 53.329791583687836], [-1.5889906174606767, 53.32695328147077], [-1.4837822986385913, 53.324014823927385], [-1.3785893190332816, 53.32097623554462], [-1.2734121860260152, 53.317837541628386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.2734122&lt;dd&gt;Longitude: 53.317838&lt;dd&gt;Azimuth: 23.092129\u00b0&lt;dd&gt;Altitude: 55.882051\u00b0&lt;dd&gt;Slant Range: 424.90443km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2734121860260152, 53.317837541628386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.799451240698508, 53.3325297069121], [-1.6942137676093298, 53.329791583687836], [-1.5889906174606767, 53.32695328147077], [-1.4837822986385913, 53.324014823927385], [-1.3785893190332816, 53.32097623554462], [-1.2734121860260152, 53.317837541628386], [-1.1682514064793754, 53.314598768303114]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.1682514&lt;dd&gt;Longitude: 53.314599&lt;dd&gt;Azimuth: 24.733273\u00b0&lt;dd&gt;Altitude: 55.565297\u00b0&lt;dd&gt;Slant Range: 426.39048km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1682514064793754, 53.314598768303114]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6942137676093298, 53.329791583687836], [-1.5889906174606767, 53.32695328147077], [-1.4837822986385913, 53.324014823927385], [-1.3785893190332816, 53.32097623554462], [-1.2734121860260152, 53.317837541628386], [-1.1682514064793754, 53.314598768303114], [-1.0631074867019432, 53.31125994251021]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -1.0631075&lt;dd&gt;Longitude: 53.31126&lt;dd&gt;Azimuth: 26.335792\u00b0&lt;dd&gt;Altitude: 55.228999\u00b0&lt;dd&gt;Slant Range: 427.99235km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0631074867019432, 53.31125994251021]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5889906174606767, 53.32695328147077], [-1.4837822986385913, 53.324014823927385], [-1.3785893190332816, 53.32097623554462], [-1.2734121860260152, 53.317837541628386], [-1.1682514064793754, 53.314598768303114], [-1.0631074867019432, 53.31125994251021], [-0.9579809324544815, 53.30782109200731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.95798093&lt;dd&gt;Longitude: 53.307821&lt;dd&gt;Azimuth: 27.898638\u00b0&lt;dd&gt;Altitude: 54.874397\u00b0&lt;dd&gt;Slant Range: 429.70874km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9579809324544815, 53.30782109200731]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4837822986385913, 53.324014823927385], [-1.3785893190332816, 53.32097623554462], [-1.2734121860260152, 53.317837541628386], [-1.1682514064793754, 53.314598768303114], [-1.0631074867019432, 53.31125994251021], [-0.9579809324544815, 53.30782109200731], [-0.8528722489144898, 53.30428224536683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.85287225&lt;dd&gt;Longitude: 53.304282&lt;dd&gt;Azimuth: 29.421049\u00b0&lt;dd&gt;Altitude: 54.502741\u00b0&lt;dd&gt;Slant Range: 431.53827km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8528722489144898, 53.30428224536683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3785893190332816, 53.32097623554462], [-1.2734121860260152, 53.317837541628386], [-1.1682514064793754, 53.314598768303114], [-1.0631074867019432, 53.31125994251021], [-0.9579809324544815, 53.30782109200731], [-0.8528722489144898, 53.30428224536683], [-0.7477819406755178, 53.30064343197519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.74778194&lt;dd&gt;Longitude: 53.300643&lt;dd&gt;Azimuth: 30.902529\u00b0&lt;dd&gt;Altitude: 54.115277\u00b0&lt;dd&gt;Slant Range: 433.4795km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7477819406755178, 53.30064343197519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2734121860260152, 53.317837541628386], [-1.1682514064793754, 53.314598768303114], [-1.0631074867019432, 53.31125994251021], [-0.9579809324544815, 53.30782109200731], [-0.8528722489144898, 53.30428224536683], [-0.7477819406755178, 53.30064343197519], [-0.6427105117142409, 53.29690468203123]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.64271051&lt;dd&gt;Longitude: 53.296905&lt;dd&gt;Azimuth: 32.342825\u00b0&lt;dd&gt;Altitude: 53.713246\u00b0&lt;dd&gt;Slant Range: 435.53096km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6427105117142409, 53.29690468203123]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1682514064793754, 53.314598768303114], [-1.0631074867019432, 53.31125994251021], [-0.9579809324544815, 53.30782109200731], [-0.8528722489144898, 53.30428224536683], [-0.7477819406755178, 53.30064343197519], [-0.6427105117142409, 53.29690468203123], [-0.5376584653966927, 53.293066026545354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.53765847&lt;dd&gt;Longitude: 53.293066&lt;dd&gt;Azimuth: 33.741907\u00b0&lt;dd&gt;Altitude: 53.297866\u00b0&lt;dd&gt;Slant Range: 437.69107km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5376584653966927, 53.293066026545354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0631074867019432, 53.31125994251021], [-0.9579809324544815, 53.30782109200731], [-0.8528722489144898, 53.30428224536683], [-0.7477819406755178, 53.30064343197519], [-0.6427105117142409, 53.29690468203123], [-0.5376584653966927, 53.293066026545354], [-0.43262630443053224, 53.28912749733793]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.4326263&lt;dd&gt;Longitude: 53.289127&lt;dd&gt;Azimuth: 35.09994\u00b0&lt;dd&gt;Altitude: 52.870332\u00b0&lt;dd&gt;Slant Range: 439.95825km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.43262630443053224, 53.28912749733793]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9579809324544815, 53.30782109200731], [-0.8528722489144898, 53.30428224536683], [-0.7477819406755178, 53.30064343197519], [-0.6427105117142409, 53.29690468203123], [-0.5376584653966927, 53.293066026545354], [-0.43262630443053224, 53.28912749733793], [-0.3276145308829059, 53.28508912703838]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.32761453&lt;dd&gt;Longitude: 53.285089&lt;dd&gt;Azimuth: 36.417262\u00b0&lt;dd&gt;Altitude: 52.431806\u00b0&lt;dd&gt;Slant Range: 442.33083km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3276145308829059, 53.28508912703838]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8528722489144898, 53.30428224536683], [-0.7477819406755178, 53.30064343197519], [-0.6427105117142409, 53.29690468203123], [-0.5376584653966927, 53.293066026545354], [-0.43262630443053224, 53.28912749733793], [-0.3276145308829059, 53.28508912703838], [-0.22262364613586832, 53.28095094908348]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.22262365&lt;dd&gt;Longitude: 53.280951&lt;dd&gt;Azimuth: 37.694366\u00b0&lt;dd&gt;Altitude: 51.983415\u00b0&lt;dd&gt;Slant Range: 444.80714km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.22262364613586832, 53.28095094908348]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7477819406755178, 53.30064343197519], [-0.6427105117142409, 53.29690468203123], [-0.5376584653966927, 53.293066026545354], [-0.43262630443053224, 53.28912749733793], [-0.3276145308829059, 53.28508912703838], [-0.22262364613586832, 53.28095094908348], [-0.11765415089551741, 53.27671299771628]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.11765415&lt;dd&gt;Longitude: 53.276713&lt;dd&gt;Azimuth: 38.93187\u00b0&lt;dd&gt;Altitude: 51.526244\u00b0&lt;dd&gt;Slant Range: 447.38544km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.11765415089551741, 53.27671299771628]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6427105117142409, 53.29690468203123], [-0.5376584653966927, 53.293066026545354], [-0.43262630443053224, 53.28912749733793], [-0.3276145308829059, 53.28508912703838], [-0.22262364613586832, 53.28095094908348], [-0.11765415089551741, 53.27671299771628], [-0.012706545148127872, 53.272375307984596]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: -0.012706545&lt;dd&gt;Longitude: 53.272375&lt;dd&gt;Azimuth: 40.130502\u00b0&lt;dd&gt;Altitude: 51.061335\u00b0&lt;dd&gt;Slant Range: 450.06397km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.012706545148127872, 53.272375307984596]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5376584653966927, 53.293066026545354], [-0.43262630443053224, 53.28912749733793], [-0.3276145308829059, 53.28508912703838], [-0.22262364613586832, 53.28095094908348], [-0.11765415089551741, 53.27671299771628], [-0.012706545148127872, 53.272375307984596], [0.0922186718272283, 53.26793791573973]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.092218672&lt;dd&gt;Longitude: 53.267938&lt;dd&gt;Azimuth: 41.291083\u00b0&lt;dd&gt;Altitude: 50.589683\u00b0&lt;dd&gt;Slant Range: 452.84097km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.0922186718272283, 53.26793791573973]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.43262630443053224, 53.28912749733793], [-0.3276145308829059, 53.28508912703838], [-0.22262364613586832, 53.28095094908348], [-0.11765415089551741, 53.27671299771628], [-0.012706545148127872, 53.272375307984596], [0.0922186718272283, 53.26793791573973], [0.19712100149901124, 53.26340085763481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.197121&lt;dd&gt;Longitude: 53.263401&lt;dd&gt;Azimuth: 42.414502\u00b0&lt;dd&gt;Altitude: 50.112236\u00b0&lt;dd&gt;Slant Range: 455.71462km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.19712100149901124, 53.26340085763481]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3276145308829059, 53.28508912703838], [-0.22262364613586832, 53.28095094908348], [-0.11765415089551741, 53.27671299771628], [-0.012706545148127872, 53.272375307984596], [0.0922186718272283, 53.26793791573973], [0.19712100149901124, 53.26340085763481], [0.3019999460826534, 53.258764171123545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.30199995&lt;dd&gt;Longitude: 53.258764&lt;dd&gt;Azimuth: 43.501709\u00b0&lt;dd&gt;Altitude: 49.629894\u00b0&lt;dd&gt;Slant Range: 458.6831km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.3019999460826534, 53.258764171123545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.22262364613586832, 53.28095094908348], [-0.11765415089551741, 53.27671299771628], [-0.012706545148127872, 53.272375307984596], [0.0922186718272283, 53.26793791573973], [0.19712100149901124, 53.26340085763481], [0.3019999460826534, 53.258764171123545], [0.40685500856407025, 53.25402789445854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.40685501&lt;dd&gt;Longitude: 53.254028&lt;dd&gt;Azimuth: 44.553695\u00b0&lt;dd&gt;Altitude: 49.143507\u00b0&lt;dd&gt;Slant Range: 461.74458km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.40685500856407025, 53.25402789445854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.11765415089551741, 53.27671299771628], [-0.012706545148127872, 53.272375307984596], [0.0922186718272283, 53.26793791573973], [0.19712100149901124, 53.26340085763481], [0.3019999460826534, 53.258764171123545], [0.40685500856407025, 53.25402789445854], [0.5116856927089984, 53.24919206668989]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.51168569&lt;dd&gt;Longitude: 53.249192&lt;dd&gt;Azimuth: 45.571483\u00b0&lt;dd&gt;Altitude: 48.653875\u00b0&lt;dd&gt;Slant Range: 464.89722km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5116856927089984, 53.24919206668989]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.012706545148127872, 53.272375307984596], [0.0922186718272283, 53.26793791573973], [0.19712100149901124, 53.26340085763481], [0.3019999460826534, 53.258764171123545], [0.40685500856407025, 53.25402789445854], [0.5116856927089984, 53.24919206668989], [0.6164915030929946, 53.24425672766356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.6164915&lt;dd&gt;Longitude: 53.244257&lt;dd&gt;Azimuth: 46.556115\u00b0&lt;dd&gt;Altitude: 48.161752\u00b0&lt;dd&gt;Slant Range: 468.13918km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6164915030929946, 53.24425672766356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.0922186718272283, 53.26793791573973], [0.19712100149901124, 53.26340085763481], [0.3019999460826534, 53.258764171123545], [0.40685500856407025, 53.25402789445854], [0.5116856927089984, 53.24919206668989], [0.6164915030929946, 53.24425672766356], [0.7212719450969319, 53.23922191801977]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.72127195&lt;dd&gt;Longitude: 53.239222&lt;dd&gt;Azimuth: 47.508646\u00b0&lt;dd&gt;Altitude: 47.667841\u00b0&lt;dd&gt;Slant Range: 471.4686km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7212719450969319, 53.23922191801977]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.19712100149901124, 53.26340085763481], [0.3019999460826534, 53.258764171123545], [0.40685500856407025, 53.25402789445854], [0.5116856927089984, 53.24919206668989], [0.6164915030929946, 53.24425672766356], [0.7212719450969319, 53.23922191801977], [0.8260265249409938, 53.23408767919134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.82602652&lt;dd&gt;Longitude: 53.234088&lt;dd&gt;Azimuth: 48.430131\u00b0&lt;dd&gt;Altitude: 47.172801\u00b0&lt;dd&gt;Slant Range: 474.88365km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8260265249409938, 53.23408767919134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.3019999460826534, 53.258764171123545], [0.40685500856407025, 53.25402789445854], [0.5116856927089984, 53.24919206668989], [0.6164915030929946, 53.24425672766356], [0.7212719450969319, 53.23922191801977], [0.8260265249409938, 53.23408767919134], [0.9307547496833252, 53.22885405340226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 0.93075475&lt;dd&gt;Longitude: 53.228854&lt;dd&gt;Azimuth: 49.321622\u00b0&lt;dd&gt;Altitude: 46.677245\u00b0&lt;dd&gt;Slant Range: 478.38249km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9307547496833252, 53.22885405340226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.40685500856407025, 53.25402789445854], [0.5116856927089984, 53.24919206668989], [0.6164915030929946, 53.24425672766356], [0.7212719450969319, 53.23922191801977], [0.8260265249409938, 53.23408767919134], [0.9307547496833252, 53.22885405340226], [1.0354561272543066, 53.22352108366553]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.0354561&lt;dd&gt;Longitude: 53.223521&lt;dd&gt;Azimuth: 50.18416\u00b0&lt;dd&gt;Altitude: 46.181741\u00b0&lt;dd&gt;Slant Range: 481.96328km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0354561272543066, 53.22352108366553]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5116856927089984, 53.24919206668989], [0.6164915030929946, 53.24425672766356], [0.7212719450969319, 53.23922191801977], [0.8260265249409938, 53.23408767919134], [0.9307547496833252, 53.22885405340226], [1.0354561272543066, 53.22352108366553], [1.1401301664515917, 53.218088813782046]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.1401302&lt;dd&gt;Longitude: 53.218089&lt;dd&gt;Azimuth: 51.018773\u00b0&lt;dd&gt;Altitude: 45.686817\u00b0&lt;dd&gt;Slant Range: 485.62421km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1401301664515917, 53.218088813782046]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6164915030929946, 53.24425672766356], [0.7212719450969319, 53.23922191801977], [0.8260265249409938, 53.23408767919134], [0.9307547496833252, 53.22885405340226], [1.0354561272543066, 53.22352108366553], [1.1401301664515917, 53.218088813782046], [1.2447763769729574, 53.21255728833826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.2447764&lt;dd&gt;Longitude: 53.212557&lt;dd&gt;Azimuth: 51.82647\u00b0&lt;dd&gt;Altitude: 45.192958\u00b0&lt;dd&gt;Slant Range: 489.36348km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2447763769729574, 53.21255728833826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7212719450969319, 53.23922191801977], [0.8260265249409938, 53.23408767919134], [0.9307547496833252, 53.22885405340226], [1.0354561272543066, 53.22352108366553], [1.1401301664515917, 53.218088813782046], [1.2447763769729574, 53.21255728833826], [1.3493942694227141, 53.20692655270493]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.3493943&lt;dd&gt;Longitude: 53.206927&lt;dd&gt;Azimuth: 52.608235\u00b0&lt;dd&gt;Altitude: 44.700613\u00b0&lt;dd&gt;Slant Range: 493.1793km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3493942694227141, 53.20692655270493]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8260265249409938, 53.23408767919134], [0.9307547496833252, 53.22885405340226], [1.0354561272543066, 53.22352108366553], [1.1401301664515917, 53.218088813782046], [1.2447763769729574, 53.21255728833826], [1.3493942694227141, 53.20692655270493], [1.4539833553266177, 53.20119665303487]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.4539834&lt;dd&gt;Longitude: 53.201197&lt;dd&gt;Azimuth: 53.365032\u00b0&lt;dd&gt;Altitude: 44.210193\u00b0&lt;dd&gt;Slant Range: 497.0699km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4539833553266177, 53.20119665303487]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9307547496833252, 53.22885405340226], [1.0354561272543066, 53.22352108366553], [1.1401301664515917, 53.218088813782046], [1.2447763769729574, 53.21255728833826], [1.3493942694227141, 53.20692655270493], [1.4539833553266177, 53.20119665303487], [1.558543147146779, 53.195367636261444]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.5585431&lt;dd&gt;Longitude: 53.195368&lt;dd&gt;Azimuth: 54.097795\u00b0&lt;dd&gt;Altitude: 43.722073\u00b0&lt;dd&gt;Slant Range: 501.03354km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.558543147146779, 53.195367636261444]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0354561272543066, 53.22352108366553], [1.1401301664515917, 53.218088813782046], [1.2447763769729574, 53.21255728833826], [1.3493942694227141, 53.20692655270493], [1.4539833553266177, 53.20119665303487], [1.558543147146779, 53.195367636261444], [1.6630731583026561, 53.18943955009647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.6630732&lt;dd&gt;Longitude: 53.18944&lt;dd&gt;Azimuth: 54.807434\u00b0&lt;dd&gt;Altitude: 43.236596\u00b0&lt;dd&gt;Slant Range: 505.06848km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6630731583026561, 53.18943955009647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1401301664515917, 53.218088813782046], [1.2447763769729574, 53.21255728833826], [1.3493942694227141, 53.20692655270493], [1.4539833553266177, 53.20119665303487], [1.558543147146779, 53.195367636261444], [1.6630731583026561, 53.18943955009647], [1.7675729031806464, 53.18341244302857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.7675729&lt;dd&gt;Longitude: 53.183412&lt;dd&gt;Azimuth: 55.494828\u00b0&lt;dd&gt;Altitude: 42.754075\u00b0&lt;dd&gt;Slant Range: 509.17305km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7675729031806464, 53.18341244302857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2447763769729574, 53.21255728833826], [1.3493942694227141, 53.20692655270493], [1.4539833553266177, 53.20119665303487], [1.558543147146779, 53.195367636261444], [1.6630731583026561, 53.18943955009647], [1.7675729031806464, 53.18341244302857], [1.8720418971456898, 53.17728636432085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.8720419&lt;dd&gt;Longitude: 53.177286&lt;dd&gt;Azimuth: 56.160826\u00b0&lt;dd&gt;Altitude: 42.274792\u00b0&lt;dd&gt;Slant Range: 513.34554km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8720418971456898, 53.17728636432085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3493942694227141, 53.20692655270493], [1.4539833553266177, 53.20119665303487], [1.558543147146779, 53.195367636261444], [1.6630731583026561, 53.18943955009647], [1.7675729031806464, 53.18341244302857], [1.8720418971456898, 53.17728636432085], [1.9764796565666356, 53.171061364009475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 1.9764797&lt;dd&gt;Longitude: 53.171061&lt;dd&gt;Azimuth: 56.806249\u00b0&lt;dd&gt;Altitude: 41.799001\u00b0&lt;dd&gt;Slant Range: 517.58433km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9764796565666356, 53.171061364009475]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4539833553266177, 53.20119665303487], [1.558543147146779, 53.195367636261444], [1.6630731583026561, 53.18943955009647], [1.7675729031806464, 53.18341244302857], [1.8720418971456898, 53.17728636432085], [1.9764796565666356, 53.171061364009475], [2.0808856988213336, 53.16473749290119]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4752&lt;dd&gt;Latitude: 2.0808857&lt;dd&gt;Longitude: 53.164737&lt;dd&gt;Azimuth: 57.431889\u00b0&lt;dd&gt;Altitude: 41.326931\u00b0&lt;dd&gt;Slant Range: 521.88778km&quot;, &quot;name&quot;: &quot;STARLINK-4752&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0808856988213336, 53.16473749290119]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.9949312&lt;dd&gt;Longitude: 53.197358&lt;dd&gt;Azimuth: 320.80999\u00b0&lt;dd&gt;Altitude: 62.416195\u00b0&lt;dd&gt;Slant Range: 591.65614km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672], [-4.894429700812917, 53.20292514710208]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.8944297&lt;dd&gt;Longitude: 53.202925&lt;dd&gt;Azimuth: 322.06871\u00b0&lt;dd&gt;Altitude: 62.785379\u00b0&lt;dd&gt;Slant Range: 589.87064km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.894429700812917, 53.20292514710208]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672], [-4.894429700812917, 53.20292514710208], [-4.793901333959654, 53.20840018496825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.7939013&lt;dd&gt;Longitude: 53.2084&lt;dd&gt;Azimuth: 323.3665\u00b0&lt;dd&gt;Altitude: 63.144869\u00b0&lt;dd&gt;Slant Range: 588.1631km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.793901333959654, 53.20840018496825]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672], [-4.894429700812917, 53.20292514710208], [-4.793901333959654, 53.20840018496825], [-4.693346531751429, 53.21378332871649]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.6933465&lt;dd&gt;Longitude: 53.213783&lt;dd&gt;Azimuth: 324.70384\u00b0&lt;dd&gt;Altitude: 63.493907\u00b0&lt;dd&gt;Slant Range: 586.5342km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.693346531751429, 53.21378332871649]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672], [-4.894429700812917, 53.20292514710208], [-4.793901333959654, 53.20840018496825], [-4.693346531751429, 53.21378332871649], [-4.592765730230049, 53.219074537638804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.5927657&lt;dd&gt;Longitude: 53.219075&lt;dd&gt;Azimuth: 326.08106\u00b0&lt;dd&gt;Altitude: 63.83172\u00b0&lt;dd&gt;Slant Range: 584.9846km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.592765730230049, 53.219074537638804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672], [-4.894429700812917, 53.20292514710208], [-4.793901333959654, 53.20840018496825], [-4.693346531751429, 53.21378332871649], [-4.592765730230049, 53.219074537638804], [-4.492159366215695, 53.22427377169975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.4921594&lt;dd&gt;Longitude: 53.224274&lt;dd&gt;Azimuth: 327.49832\u00b0&lt;dd&gt;Altitude: 64.157516\u00b0&lt;dd&gt;Slant Range: 583.51494km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.492159366215695, 53.22427377169975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.994931197076432, 53.19735825649672], [-4.894429700812917, 53.20292514710208], [-4.793901333959654, 53.20840018496825], [-4.693346531751429, 53.21378332871649], [-4.592765730230049, 53.219074537638804], [-4.492159366215695, 53.22427377169975], [-4.3915278773082385, 53.22938099153781]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.3915279&lt;dd&gt;Longitude: 53.229381&lt;dd&gt;Azimuth: 328.95562\u00b0&lt;dd&gt;Altitude: 64.470494\u00b0&lt;dd&gt;Slant Range: 582.12581km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.3915278773082385, 53.22938099153781]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.894429700812917, 53.20292514710208], [-4.793901333959654, 53.20840018496825], [-4.693346531751429, 53.21378332871649], [-4.592765730230049, 53.219074537638804], [-4.492159366215695, 53.22427377169975], [-4.3915278773082385, 53.22938099153781], [-4.290871701859512, 53.23439615846679]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.2908717&lt;dd&gt;Longitude: 53.234396&lt;dd&gt;Azimuth: 330.45272\u00b0&lt;dd&gt;Altitude: 64.769845\u00b0&lt;dd&gt;Slant Range: 580.81781km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.290871701859512, 53.23439615846679]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.793901333959654, 53.20840018496825], [-4.693346531751429, 53.21378332871649], [-4.592765730230049, 53.219074537638804], [-4.492159366215695, 53.22427377169975], [-4.3915278773082385, 53.22938099153781], [-4.290871701859512, 53.23439615846679], [-4.190191278981678, 53.23931923447734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.1901913&lt;dd&gt;Longitude: 53.239319&lt;dd&gt;Azimuth: 331.98917\u00b0&lt;dd&gt;Altitude: 65.054757\u00b0&lt;dd&gt;Slant Range: 579.59148km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.190191278981678, 53.23931923447734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.693346531751429, 53.21378332871649], [-4.592765730230049, 53.219074537638804], [-4.492159366215695, 53.22427377169975], [-4.3915278773082385, 53.22938099153781], [-4.290871701859512, 53.23439615846679], [-4.190191278981678, 53.23931923447734], [-4.089487048507639, 53.2441501822384]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -4.089487&lt;dd&gt;Longitude: 53.24415&lt;dd&gt;Azimuth: 333.56427\u00b0&lt;dd&gt;Altitude: 65.32442\u00b0&lt;dd&gt;Slant Range: 578.44733km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.089487048507639, 53.2441501822384]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.592765730230049, 53.219074537638804], [-4.492159366215695, 53.22427377169975], [-4.3915278773082385, 53.22938099153781], [-4.290871701859512, 53.23439615846679], [-4.190191278981678, 53.23931923447734], [-4.089487048507639, 53.2441501822384], [-3.988759451008847, 53.24888896509836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.9887595&lt;dd&gt;Longitude: 53.248889&lt;dd&gt;Azimuth: 335.17705\u00b0&lt;dd&gt;Altitude: 65.578034\u00b0&lt;dd&gt;Slant Range: 577.38588km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.988759451008847, 53.24888896509836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.492159366215695, 53.22427377169975], [-4.3915278773082385, 53.22938099153781], [-4.290871701859512, 53.23439615846679], [-4.190191278981678, 53.23931923447734], [-4.089487048507639, 53.2441501822384], [-3.988759451008847, 53.24888896509836], [-3.8880089277500387, 53.25353554708676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.8880089&lt;dd&gt;Longitude: 53.253536&lt;dd&gt;Azimuth: 336.82626\u00b0&lt;dd&gt;Altitude: 65.814813\u00b0&lt;dd&gt;Slant Range: 576.40755km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8880089277500387, 53.25353554708676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.3915278773082385, 53.22938099153781], [-4.290871701859512, 53.23439615846679], [-4.190191278981678, 53.23931923447734], [-4.089487048507639, 53.2441501822384], [-3.988759451008847, 53.24888896509836], [-3.8880089277500387, 53.25353554708676], [-3.787235920705342, 53.25808989291524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.7872359&lt;dd&gt;Longitude: 53.25809&lt;dd&gt;Azimuth: 338.51035\u00b0&lt;dd&gt;Altitude: 66.033996\u00b0&lt;dd&gt;Slant Range: 575.5128km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.787235920705342, 53.25808989291524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.290871701859512, 53.23439615846679], [-4.190191278981678, 53.23931923447734], [-4.089487048507639, 53.2441501822384], [-3.988759451008847, 53.24888896509836], [-3.8880089277500387, 53.25353554708676], [-3.787235920705342, 53.25808989291524], [-3.6864408725303637, 53.26255196797922]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.6864409&lt;dd&gt;Longitude: 53.262552&lt;dd&gt;Azimuth: 340.22745\u00b0&lt;dd&gt;Altitude: 66.234848\u00b0&lt;dd&gt;Slant Range: 574.702km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6864408725303637, 53.26255196797922]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.190191278981678, 53.23931923447734], [-4.089487048507639, 53.2441501822384], [-3.988759451008847, 53.24888896509836], [-3.8880089277500387, 53.25353554708676], [-3.787235920705342, 53.25808989291524], [-3.6864408725303637, 53.26255196797922], [-3.5856242265438927, 53.26692173835901]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.5856242&lt;dd&gt;Longitude: 53.266922&lt;dd&gt;Azimuth: 341.9754\u00b0&lt;dd&gt;Altitude: 66.416676\u00b0&lt;dd&gt;Slant Range: 573.97551km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.5856242265438927, 53.26692173835901]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.089487048507639, 53.2441501822384], [-3.988759451008847, 53.24888896509836], [-3.8880089277500387, 53.25353554708676], [-3.787235920705342, 53.25808989291524], [-3.6864408725303637, 53.26255196797922], [-3.5856242265438927, 53.26692173835901], [-3.4847864267329407, 53.271199170821006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.4847864&lt;dd&gt;Longitude: 53.271199&lt;dd&gt;Azimuth: 343.75173\u00b0&lt;dd&gt;Altitude: 66.578829\u00b0&lt;dd&gt;Slant Range: 573.33365km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4847864267329407, 53.271199170821006]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.988759451008847, 53.24888896509836], [-3.8880089277500387, 53.25353554708676], [-3.787235920705342, 53.25808989291524], [-3.6864408725303637, 53.26255196797922], [-3.5856242265438927, 53.26692173835901], [-3.4847864267329407, 53.271199170821006], [-3.383927917722667, 53.27538423281902]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.3839279&lt;dd&gt;Longitude: 53.275384&lt;dd&gt;Azimuth: 345.55366\u00b0&lt;dd&gt;Altitude: 66.720711\u00b0&lt;dd&gt;Slant Range: 572.77672km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.383927917722667, 53.27538423281902]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8880089277500387, 53.25353554708676], [-3.787235920705342, 53.25808989291524], [-3.6864408725303637, 53.26255196797922], [-3.5856242265438927, 53.26692173835901], [-3.4847864267329407, 53.271199170821006], [-3.383927917722667, 53.27538423281902], [-3.2830491447731442, 53.27947689249565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.2830491&lt;dd&gt;Longitude: 53.279477&lt;dd&gt;Azimuth: 347.37815\u00b0&lt;dd&gt;Altitude: 66.841787\u00b0&lt;dd&gt;Slant Range: 572.30495km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.2830491447731442, 53.27947689249565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.787235920705342, 53.25808989291524], [-3.6864408725303637, 53.26255196797922], [-3.5856242265438927, 53.26692173835901], [-3.4847864267329407, 53.271199170821006], [-3.383927917722667, 53.27538423281902], [-3.2830491447731442, 53.27947689249565], [-3.182150553762669, 53.283477118683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.1821506&lt;dd&gt;Longitude: 53.283477&lt;dd&gt;Azimuth: 349.22189\u00b0&lt;dd&gt;Altitude: 66.941591\u00b0&lt;dd&gt;Slant Range: 571.91856km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.182150553762669, 53.283477118683]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6864408725303637, 53.26255196797922], [-3.5856242265438927, 53.26692173835901], [-3.4847864267329407, 53.271199170821006], [-3.383927917722667, 53.27538423281902], [-3.2830491447731442, 53.27947689249565], [-3.182150553762669, 53.283477118683], [-3.081232591173208, 53.28738488090453]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -3.0812326&lt;dd&gt;Longitude: 53.287385&lt;dd&gt;Azimuth: 351.08132\u00b0&lt;dd&gt;Altitude: 67.019731\u00b0&lt;dd&gt;Slant Range: 571.61772km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.081232591173208, 53.28738488090453]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.5856242265438927, 53.26692173835901], [-3.4847864267329407, 53.271199170821006], [-3.383927917722667, 53.27538423281902], [-3.2830491447731442, 53.27947689249565], [-3.182150553762669, 53.283477118683], [-3.081232591173208, 53.28738488090453], [-2.9802957040803966, 53.29120014937545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.9802957&lt;dd&gt;Longitude: 53.2912&lt;dd&gt;Azimuth: 352.95273\u00b0&lt;dd&gt;Altitude: 67.075894\u00b0&lt;dd&gt;Slant Range: 571.40256km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9802957040803966, 53.29120014937545]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4847864267329407, 53.271199170821006], [-3.383927917722667, 53.27538423281902], [-3.2830491447731442, 53.27947689249565], [-3.182150553762669, 53.283477118683], [-3.081232591173208, 53.28738488090453], [-2.9802957040803966, 53.29120014937545], [-2.8793403401410465, 53.29492289500445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.8793403&lt;dd&gt;Longitude: 53.294923&lt;dd&gt;Azimuth: 354.83223\u00b0&lt;dd&gt;Altitude: 67.109855\u00b0&lt;dd&gt;Slant Range: 571.2732km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8793403401410465, 53.29492289500445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.383927917722667, 53.27538423281902], [-3.2830491447731442, 53.27947689249565], [-3.182150553762669, 53.283477118683], [-3.081232591173208, 53.28738488090453], [-2.9802957040803966, 53.29120014937545], [-2.8793403401410465, 53.29492289500445], [-2.7783669475700683, 53.29855308939445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.7783669&lt;dd&gt;Longitude: 53.298553&lt;dd&gt;Azimuth: 356.71584\u00b0&lt;dd&gt;Altitude: 67.121475\u00b0&lt;dd&gt;Slant Range: 571.22967km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7783669475700683, 53.29855308939445]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.2830491447731442, 53.27947689249565], [-3.182150553762669, 53.283477118683], [-3.081232591173208, 53.28738488090453], [-2.9802957040803966, 53.29120014937545], [-2.8793403401410465, 53.29492289500445], [-2.7783669475700683, 53.29855308939445], [-2.6773759751416417, 53.30209070484376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.677376&lt;dd&gt;Longitude: 53.302091&lt;dd&gt;Azimuth: 358.59951\u00b0&lt;dd&gt;Altitude: 67.110707\u00b0&lt;dd&gt;Slant Range: 571.27201km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6773759751416417, 53.30209070484376]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.182150553762669, 53.283477118683], [-3.081232591173208, 53.28738488090453], [-2.9802957040803966, 53.29120014937545], [-2.8793403401410465, 53.29492289500445], [-2.7783669475700683, 53.29855308939445], [-2.6773759751416417, 53.30209070484376], [-2.576367872167815, 53.305535714347165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.5763679&lt;dd&gt;Longitude: 53.305536&lt;dd&gt;Azimuth: 0.47921912\u00b0&lt;dd&gt;Altitude: 67.077596\u00b0&lt;dd&gt;Slant Range: 571.40019km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.576367872167815, 53.305535714347165]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.081232591173208, 53.28738488090453], [-2.9802957040803966, 53.29120014937545], [-2.8793403401410465, 53.29492289500445], [-2.7783669475700683, 53.29855308939445], [-2.6773759751416417, 53.30209070484376], [-2.576367872167815, 53.305535714347165], [-2.47534308848202, 53.308888091596785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.4753431&lt;dd&gt;Longitude: 53.308888&lt;dd&gt;Azimuth: 2.3509734\u00b0&lt;dd&gt;Altitude: 67.022277\u00b0&lt;dd&gt;Slant Range: 571.61415km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.47534308848202, 53.308888091596785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.9802957040803966, 53.29120014937545], [-2.8793403401410465, 53.29492289500445], [-2.7783669475700683, 53.29855308939445], [-2.6773759751416417, 53.30209070484376], [-2.576367872167815, 53.305535714347165], [-2.47534308848202, 53.308888091596785], [-2.3743020744326566, 53.312147810983234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.3743021&lt;dd&gt;Longitude: 53.312148&lt;dd&gt;Azimuth: 4.2108883\u00b0&lt;dd&gt;Altitude: 66.944973\u00b0&lt;dd&gt;Slant Range: 571.9138km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3743020744326566, 53.312147810983234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8793403401410465, 53.29492289500445], [-2.7783669475700683, 53.29855308939445], [-2.6773759751416417, 53.30209070484376], [-2.576367872167815, 53.305535714347165], [-2.47534308848202, 53.308888091596785], [-2.3743020744326566, 53.312147810983234], [-2.2732452808664565, 53.31531484759656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.2732453&lt;dd&gt;Longitude: 53.315315&lt;dd&gt;Azimuth: 6.0552263\u00b0&lt;dd&gt;Altitude: 66.845992\u00b0&lt;dd&gt;Slant Range: 572.29901km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.2732452808664565, 53.31531484759656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7783669475700683, 53.29855308939445], [-2.6773759751416417, 53.30209070484376], [-2.576367872167815, 53.305535714347165], [-2.47534308848202, 53.308888091596785], [-2.3743020744326566, 53.312147810983234], [-2.2732452808664565, 53.31531484759656], [-2.172173159109013, 53.318389177227054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.1721732&lt;dd&gt;Longitude: 53.318389&lt;dd&gt;Azimuth: 7.8804404\u00b0&lt;dd&gt;Altitude: 66.725726\u00b0&lt;dd&gt;Slant Range: 572.7696km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.172173159109013, 53.318389177227054]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6773759751416417, 53.30209070484376], [-2.576367872167815, 53.305535714347165], [-2.47534308848202, 53.308888091596785], [-2.3743020744326566, 53.312147810983234], [-2.2732452808664565, 53.31531484759656], [-2.172173159109013, 53.318389177227054], [-2.0710861609679667, 53.32137077636626]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -2.0710862&lt;dd&gt;Longitude: 53.321371&lt;dd&gt;Azimuth: 9.6832112\u00b0&lt;dd&gt;Altitude: 66.584637\u00b0&lt;dd&gt;Slant Range: 573.32535km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0710861609679667, 53.32137077636626]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.576367872167815, 53.305535714347165], [-2.47534308848202, 53.308888091596785], [-2.3743020744326566, 53.312147810983234], [-2.2732452808664565, 53.31531484759656], [-2.172173159109013, 53.318389177227054], [-2.0710861609679667, 53.32137077636626], [-1.9699847386970737, 53.324259622207904]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.9699847&lt;dd&gt;Longitude: 53.32426&lt;dd&gt;Azimuth: 11.460477\u00b0&lt;dd&gt;Altitude: 66.423259\u00b0&lt;dd&gt;Slant Range: 573.96603km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9699847386970737, 53.324259622207904]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.47534308848202, 53.308888091596785], [-2.3743020744326566, 53.312147810983234], [-2.2732452808664565, 53.31531484759656], [-2.172173159109013, 53.318389177227054], [-2.0710861609679667, 53.32137077636626], [-1.9699847386970737, 53.324259622207904], [-1.8688693450031293, 53.327055692648635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.8688693&lt;dd&gt;Longitude: 53.327056&lt;dd&gt;Azimuth: 13.209456\u00b0&lt;dd&gt;Altitude: 66.242186\u00b0&lt;dd&gt;Slant Range: 574.69135km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8688693450031293, 53.327055692648635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3743020744326566, 53.312147810983234], [-2.2732452808664565, 53.31531484759656], [-2.172173159109013, 53.318389177227054], [-2.0710861609679667, 53.32137077636626], [-1.9699847386970737, 53.324259622207904], [-1.8688693450031293, 53.327055692648635], [-1.7677404330113113, 53.329758966288914]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.7677404&lt;dd&gt;Longitude: 53.329759&lt;dd&gt;Azimuth: 14.927665\u00b0&lt;dd&gt;Altitude: 66.042066\u00b0&lt;dd&gt;Slant Range: 575.50098km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7677404330113113, 53.329758966288914]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.2732452808664565, 53.31531484759656], [-2.172173159109013, 53.318389177227054], [-2.0710861609679667, 53.32137077636626], [-1.9699847386970737, 53.324259622207904], [-1.8688693450031293, 53.327055692648635], [-1.7677404330113113, 53.329758966288914], [-1.6665984562758418, 53.332369422433885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.6665985&lt;dd&gt;Longitude: 53.332369&lt;dd&gt;Azimuth: 16.612926\u00b0&lt;dd&gt;Altitude: 65.823593\u00b0&lt;dd&gt;Slant Range: 576.39457km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.6665984562758418, 53.332369422433885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.172173159109013, 53.318389177227054], [-2.0710861609679667, 53.32137077636626], [-1.9699847386970737, 53.324259622207904], [-1.8688693450031293, 53.327055692648635], [-1.7677404330113113, 53.329758966288914], [-1.6665984562758418, 53.332369422433885], [-1.5654438687454844, 53.33488704109397]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.5654439&lt;dd&gt;Longitude: 53.334887&lt;dd&gt;Azimuth: 18.263373\u00b0&lt;dd&gt;Altitude: 65.587499\u00b0&lt;dd&gt;Slant Range: 577.37172km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5654438687454844, 53.33488704109397]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0710861609679667, 53.32137077636626], [-1.9699847386970737, 53.324259622207904], [-1.8688693450031293, 53.327055692648635], [-1.7677404330113113, 53.329758966288914], [-1.6665984562758418, 53.332369422433885], [-1.5654438687454844, 53.33488704109397], [-1.4642771247591675, 53.33731180298593]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.4642771&lt;dd&gt;Longitude: 53.337312&lt;dd&gt;Azimuth: 19.877442\u00b0&lt;dd&gt;Altitude: 65.334545\u00b0&lt;dd&gt;Slant Range: 578.43203km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4642771247591675, 53.33731180298593]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9699847386970737, 53.324259622207904], [-1.8688693450031293, 53.327055692648635], [-1.7677404330113113, 53.329758966288914], [-1.6665984562758418, 53.332369422433885], [-1.5654438687454844, 53.33488704109397], [-1.4642771247591675, 53.33731180298593], [-1.3630986790307176, 53.339643689533254]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.3630987&lt;dd&gt;Longitude: 53.339644&lt;dd&gt;Azimuth: 21.45387\u00b0&lt;dd&gt;Altitude: 65.065517\u00b0&lt;dd&gt;Slant Range: 579.57502km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3630986790307176, 53.339643689533254]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8688693450031293, 53.327055692648635], [-1.7677404330113113, 53.329758966288914], [-1.6665984562758418, 53.332369422433885], [-1.5654438687454844, 53.33488704109397], [-1.4642771247591675, 53.33731180298593], [-1.3630986790307176, 53.339643689533254], [-1.2619089866373339, 53.34188268286706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.261909&lt;dd&gt;Longitude: 53.341883&lt;dd&gt;Azimuth: 22.991677\u00b0&lt;dd&gt;Altitude: 64.781213\u00b0&lt;dd&gt;Slant Range: 580.8002km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2619089866373339, 53.34188268286706]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7677404330113113, 53.329758966288914], [-1.6665984562758418, 53.332369422433885], [-1.5654438687454844, 53.33488704109397], [-1.4642771247591675, 53.33731180298593], [-1.3630986790307176, 53.339643689533254], [-1.2619089866373339, 53.34188268286706], [-1.160708502997705, 53.34402876582677]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.1607085&lt;dd&gt;Longitude: 53.344029&lt;dd&gt;Azimuth: 24.490152\u00b0&lt;dd&gt;Altitude: 64.482445\u00b0&lt;dd&gt;Slant Range: 582.10706km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.160708502997705, 53.34402876582677]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.6665984562758418, 53.332369422433885], [-1.5654438687454844, 53.33488704109397], [-1.4642771247591675, 53.33731180298593], [-1.3630986790307176, 53.339643689533254], [-1.2619089866373339, 53.34188268286706], [-1.160708502997705, 53.34402876582677], [-1.059497683863994, 53.34608192196069]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -1.0594977&lt;dd&gt;Longitude: 53.346082&lt;dd&gt;Azimuth: 25.948833\u00b0&lt;dd&gt;Altitude: 64.170022\u00b0&lt;dd&gt;Slant Range: 583.49505km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.059497683863994, 53.34608192196069]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5654438687454844, 53.33488704109397], [-1.4642771247591675, 53.33731180298593], [-1.3630986790307176, 53.339643689533254], [-1.2619089866373339, 53.34188268286706], [-1.160708502997705, 53.34402876582677], [-1.059497683863994, 53.34608192196069], [-0.9582769853187353, 53.34804213552663]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.95827699&lt;dd&gt;Longitude: 53.348042&lt;dd&gt;Azimuth: 27.36749\u00b0&lt;dd&gt;Altitude: 63.844756\u00b0&lt;dd&gt;Slant Range: 584.96359km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9582769853187353, 53.34804213552663]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4642771247591675, 53.33731180298593], [-1.3630986790307176, 53.339643689533254], [-1.2619089866373339, 53.34188268286706], [-1.160708502997705, 53.34402876582677], [-1.059497683863994, 53.34608192196069], [-0.9582769853187353, 53.34804213552663], [-0.8570468637311959, 53.34990939149262]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.85704686&lt;dd&gt;Longitude: 53.349909&lt;dd&gt;Azimuth: 28.746097\u00b0&lt;dd&gt;Altitude: 63.507448\u00b0&lt;dd&gt;Slant Range: 586.51206km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8570468637311959, 53.34990939149262]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3630986790307176, 53.339643689533254], [-1.2619089866373339, 53.34188268286706], [-1.160708502997705, 53.34402876582677], [-1.059497683863994, 53.34608192196069], [-0.9582769853187353, 53.34804213552663], [-0.8570468637311959, 53.34990939149262], [-0.7558077757776814, 53.35168367553725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.75580778&lt;dd&gt;Longitude: 53.351684&lt;dd&gt;Azimuth: 30.084816\u00b0&lt;dd&gt;Altitude: 63.158888\u00b0&lt;dd&gt;Slant Range: 588.13985km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7558077757776814, 53.35168367553725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2619089866373339, 53.34188268286706], [-1.160708502997705, 53.34402876582677], [-1.059497683863994, 53.34608192196069], [-0.9582769853187353, 53.34804213552663], [-0.8570468637311959, 53.34990939149262], [-0.7558077757776814, 53.35168367553725], [-0.6545601784033939, 53.35336497405049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.65456018&lt;dd&gt;Longitude: 53.353365&lt;dd&gt;Azimuth: 31.383972\u00b0&lt;dd&gt;Altitude: 62.799853\u00b0&lt;dd&gt;Slant Range: 589.84628km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6545601784033939, 53.35336497405049]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.160708502997705, 53.34402876582677], [-1.059497683863994, 53.34608192196069], [-0.9582769853187353, 53.34804213552663], [-0.8570468637311959, 53.34990939149262], [-0.7558077757776814, 53.35168367553725], [-0.6545601784033939, 53.35336497405049], [-0.5533045288164021, 53.35495327413397]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.55330453&lt;dd&gt;Longitude: 53.354953&lt;dd&gt;Azimuth: 32.644034\u00b0&lt;dd&gt;Altitude: 62.431099\u00b0&lt;dd&gt;Slant Range: 591.63068km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5533045288164021, 53.35495327413397]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.059497683863994, 53.34608192196069], [-0.9582769853187353, 53.34804213552663], [-0.8570468637311959, 53.34990939149262], [-0.7558077757776814, 53.35168367553725], [-0.6545601784033939, 53.35336497405049], [-0.5533045288164021, 53.35495327413397], [-0.45204128447776887, 53.35644856360161]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.45204128&lt;dd&gt;Longitude: 53.356449&lt;dd&gt;Azimuth: 33.865591\u00b0&lt;dd&gt;Altitude: 62.053363\u00b0&lt;dd&gt;Slant Range: 593.49233km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.45204128447776887, 53.35644856360161]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9582769853187353, 53.34804213552663], [-0.8570468637311959, 53.34990939149262], [-0.7558077757776814, 53.35168367553725], [-0.6545601784033939, 53.35336497405049], [-0.5533045288164021, 53.35495327413397], [-0.45204128447776887, 53.35644856360161], [-0.3507709030832562, 53.357850830980034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.3507709&lt;dd&gt;Longitude: 53.357851&lt;dd&gt;Azimuth: 35.049338\u00b0&lt;dd&gt;Altitude: 61.66736\u00b0&lt;dd&gt;Slant Range: 595.43053km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3507709030832562, 53.357850830980034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8570468637311959, 53.34990939149262], [-0.7558077757776814, 53.35168367553725], [-0.6545601784033939, 53.35336497405049], [-0.5533045288164021, 53.35495327413397], [-0.45204128447776887, 53.35644856360161], [-0.3507709030832562, 53.357850830980034], [-0.24949384254187623, 53.359160065509016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.24949384&lt;dd&gt;Longitude: 53.35916&lt;dd&gt;Azimuth: 36.196055\u00b0&lt;dd&gt;Altitude: 61.273778\u00b0&lt;dd&gt;Slant Range: 597.44451km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.24949384254187623, 53.359160065509016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7558077757776814, 53.35168367553725], [-0.6545601784033939, 53.35336497405049], [-0.5533045288164021, 53.35495327413397], [-0.45204128447776887, 53.35644856360161], [-0.3507709030832562, 53.357850830980034], [-0.24949384254187623, 53.359160065509016], [-0.1482105609816413, 53.36037625714185]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.14821056&lt;dd&gt;Longitude: 53.360376&lt;dd&gt;Azimuth: 37.30659\u00b0&lt;dd&gt;Altitude: 60.873281\u00b0&lt;dd&gt;Slant Range: 599.53351km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.1482105609816413, 53.36037625714185]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6545601784033939, 53.35336497405049], [-0.5533045288164021, 53.35495327413397], [-0.45204128447776887, 53.35644856360161], [-0.3507709030832562, 53.357850830980034], [-0.24949384254187623, 53.359160065509016], [-0.1482105609816413, 53.36037625714185], [-0.046921516709005504, 53.36149939654578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: -0.046921517&lt;dd&gt;Longitude: 53.361499&lt;dd&gt;Azimuth: 38.381849\u00b0&lt;dd&gt;Altitude: 60.46651\u00b0&lt;dd&gt;Slant Range: 601.69675km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.046921516709005504, 53.36149939654578]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5533045288164021, 53.35495327413397], [-0.45204128447776887, 53.35644856360161], [-0.3507709030832562, 53.357850830980034], [-0.24949384254187623, 53.359160065509016], [-0.1482105609816413, 53.36037625714185], [-0.046921516709005504, 53.36149939654578], [0.05437283177563943, 53.362529475102356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.054372832&lt;dd&gt;Longitude: 53.362529&lt;dd&gt;Azimuth: 39.422779\u00b0&lt;dd&gt;Altitude: 60.054074\u00b0&lt;dd&gt;Slant Range: 603.93342km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.05437283177563943, 53.362529475102356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.45204128447776887, 53.35644856360161], [-0.3507709030832562, 53.357850830980034], [-0.24949384254187623, 53.359160065509016], [-0.1482105609816413, 53.36037625714185], [-0.046921516709005504, 53.36149939654578], [0.05437283177563943, 53.362529475102356], [0.1556720258219578, 53.36346648490771]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.15567203&lt;dd&gt;Longitude: 53.363466&lt;dd&gt;Azimuth: 40.430355\u00b0&lt;dd&gt;Altitude: 59.636558\u00b0&lt;dd&gt;Slant Range: 606.24272km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.1556720258219578, 53.36346648490771]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3507709030832562, 53.357850830980034], [-0.24949384254187623, 53.359160065509016], [-0.1482105609816413, 53.36037625714185], [-0.046921516709005504, 53.36149939654578], [0.05437283177563943, 53.362529475102356], [0.1556720258219578, 53.36346648490771], [0.25697560662053526, 53.364310418772895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.25697561&lt;dd&gt;Longitude: 53.36431&lt;dd&gt;Azimuth: 41.405575\u00b0&lt;dd&gt;Altitude: 59.214521\u00b0&lt;dd&gt;Slant Range: 608.62381km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.25697560662053526, 53.364310418772895]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.24949384254187623, 53.359160065509016], [-0.1482105609816413, 53.36037625714185], [-0.046921516709005504, 53.36149939654578], [0.05437283177563943, 53.362529475102356], [0.1556720258219578, 53.36346648490771], [0.25697560662053526, 53.364310418772895], [0.358283115230944, 53.365061270224196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.35828312&lt;dd&gt;Longitude: 53.365061&lt;dd&gt;Azimuth: 42.349448\u00b0&lt;dd&gt;Altitude: 58.788493\u00b0&lt;dd&gt;Slant Range: 611.07585km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.358283115230944, 53.365061270224196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.1482105609816413, 53.36037625714185], [-0.046921516709005504, 53.36149939654578], [0.05437283177563943, 53.362529475102356], [0.1556720258219578, 53.36346648490771], [0.25697560662053526, 53.364310418772895], [0.358283115230944, 53.365061270224196], [0.45959409258576317, 53.36571903350325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.45959409&lt;dd&gt;Longitude: 53.365719&lt;dd&gt;Azimuth: 43.262984\u00b0&lt;dd&gt;Altitude: 58.35898\u00b0&lt;dd&gt;Slant Range: 613.59799km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.45959409258576317, 53.36571903350325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.046921516709005504, 53.36149939654578], [0.05437283177563943, 53.362529475102356], [0.1556720258219578, 53.36346648490771], [0.25697560662053526, 53.364310418772895], [0.358283115230944, 53.365061270224196], [0.45959409258576317, 53.36571903350325], [0.560908079519, 53.3662837035674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.56090808&lt;dd&gt;Longitude: 53.366284&lt;dd&gt;Azimuth: 44.147193\u00b0&lt;dd&gt;Altitude: 57.926461\u00b0&lt;dd&gt;Slant Range: 616.18936km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.560908079519, 53.3662837035674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.05437283177563943, 53.362529475102356], [0.1556720258219578, 53.36346648490771], [0.25697560662053526, 53.364310418772895], [0.358283115230944, 53.365061270224196], [0.45959409258576317, 53.36571903350325], [0.560908079519, 53.3662837035674], [0.6622246167587111, 53.36675527608982]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.66222462&lt;dd&gt;Longitude: 53.366755&lt;dd&gt;Azimuth: 45.003075\u00b0&lt;dd&gt;Altitude: 57.49139\u00b0&lt;dd&gt;Slant Range: 618.84909km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6622246167587111, 53.36675527608982]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.1556720258219578, 53.36346648490771], [0.25697560662053526, 53.364310418772895], [0.358283115230944, 53.365061270224196], [0.45959409258576317, 53.36571903350325], [0.560908079519, 53.3662837035674], [0.6622246167587111, 53.36675527608982], [0.7635432449692404, 53.367133747459725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.76354324&lt;dd&gt;Longitude: 53.367134&lt;dd&gt;Azimuth: 45.831616\u00b0&lt;dd&gt;Altitude: 57.054197\u00b0&lt;dd&gt;Slant Range: 621.5763km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7635432449692404, 53.367133747459725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.25697560662053526, 53.364310418772895], [0.358283115230944, 53.365061270224196], [0.45959409258576317, 53.36571903350325], [0.560908079519, 53.3662837035674], [0.6622246167587111, 53.36675527608982], [0.7635432449692404, 53.367133747459725], [0.864863504736003, 53.36741911478243]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.8648635&lt;dd&gt;Longitude: 53.367419&lt;dd&gt;Azimuth: 46.633787\u00b0&lt;dd&gt;Altitude: 56.615288\u00b0&lt;dd&gt;Slant Range: 624.37011km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.864863504736003, 53.36741911478243]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.358283115230944, 53.365061270224196], [0.45959409258576317, 53.36571903350325], [0.560908079519, 53.3662837035674], [0.6622246167587111, 53.36675527608982], [0.7635432449692404, 53.367133747459725], [0.864863504736003, 53.36741911478243], [0.9661849366027869, 53.367611375879484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 0.96618494&lt;dd&gt;Longitude: 53.367611&lt;dd&gt;Azimuth: 47.410537\u00b0&lt;dd&gt;Altitude: 56.175045\u00b0&lt;dd&gt;Slant Range: 627.22962km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.9661849366027869, 53.367611375879484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.45959409258576317, 53.36571903350325], [0.560908079519, 53.3662837035674], [0.6622246167587111, 53.36675527608982], [0.7635432449692404, 53.367133747459725], [0.864863504736003, 53.36741911478243], [0.9661849366027869, 53.367611375879484], [1.067507081071804, 53.36771052928885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.0675071&lt;dd&gt;Longitude: 53.367711&lt;dd&gt;Azimuth: 48.162794\u00b0&lt;dd&gt;Altitude: 55.733831\u00b0&lt;dd&gt;Slant Range: 630.15392km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.067507081071804, 53.36771052928885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.560908079519, 53.3662837035674], [0.6622246167587111, 53.36675527608982], [0.7635432449692404, 53.367133747459725], [0.864863504736003, 53.36741911478243], [0.9661849366027869, 53.367611375879484], [1.067507081071804, 53.36771052928885], [1.1688294786276074, 53.36771657426483]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.1688295&lt;dd&gt;Longitude: 53.367717&lt;dd&gt;Azimuth: 48.891461\u00b0&lt;dd&gt;Altitude: 55.291984\u00b0&lt;dd&gt;Slant Range: 633.14213km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1688294786276074, 53.36771657426483]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6622246167587111, 53.36675527608982], [0.7635432449692404, 53.367133747459725], [0.864863504736003, 53.36741911478243], [0.9661849366027869, 53.367611375879484], [1.067507081071804, 53.36771052928885], [1.1688294786276074, 53.36771657426483], [1.2701516697438864, 53.36762951077816]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.2701517&lt;dd&gt;Longitude: 53.36763&lt;dd&gt;Azimuth: 49.597415\u00b0&lt;dd&gt;Altitude: 54.849823\u00b0&lt;dd&gt;Slant Range: 636.19334km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2701516697438864, 53.36762951077816]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7635432449692404, 53.367133747459725], [0.864863504736003, 53.36741911478243], [0.9661849366027869, 53.367611375879484], [1.067507081071804, 53.36771052928885], [1.1688294786276074, 53.36771657426483], [1.2701516697438864, 53.36762951077816], [1.3714731948999777, 53.36744933951601]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.3714732&lt;dd&gt;Longitude: 53.367449&lt;dd&gt;Azimuth: 50.281505\u00b0&lt;dd&gt;Altitude: 54.407649\u00b0&lt;dd&gt;Slant Range: 639.30664km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3714731948999777, 53.36744933951601]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.864863504736003, 53.36741911478243], [0.9661849366027869, 53.367611375879484], [1.067507081071804, 53.36771052928885], [1.1688294786276074, 53.36771657426483], [1.2701516697438864, 53.36762951077816], [1.3714731948999777, 53.36744933951601], [1.4727935946003068, 53.367176061881985]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.4727936&lt;dd&gt;Longitude: 53.367176&lt;dd&gt;Azimuth: 50.944556\u00b0&lt;dd&gt;Altitude: 53.965742\u00b0&lt;dd&gt;Slant Range: 642.48113km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4727935946003068, 53.367176061881985]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.9661849366027869, 53.367611375879484], [1.067507081071804, 53.36771052928885], [1.1688294786276074, 53.36771657426483], [1.2701516697438864, 53.36762951077816], [1.3714731948999777, 53.36744933951601], [1.4727935946003068, 53.367176061881985], [1.5741124093811814, 53.36680967999589]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.5741124&lt;dd&gt;Longitude: 53.36681&lt;dd&gt;Azimuth: 51.587362\u00b0&lt;dd&gt;Altitude: 53.524366\u00b0&lt;dd&gt;Slant Range: 645.71589km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5741124093811814, 53.36680967999589]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.067507081071804, 53.36771052928885], [1.1688294786276074, 53.36771657426483], [1.2701516697438864, 53.36762951077816], [1.3714731948999777, 53.36744933951601], [1.4727935946003068, 53.367176061881985], [1.5741124093811814, 53.36680967999589], [1.6754291798248613, 53.36635019669401]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.6754292&lt;dd&gt;Longitude: 53.36635&lt;dd&gt;Azimuth: 52.21069\u00b0&lt;dd&gt;Altitude: 53.083765\u00b0&lt;dd&gt;Slant Range: 649.01003km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6754291798248613, 53.36635019669401]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1688294786276074, 53.36771657426483], [1.2701516697438864, 53.36762951077816], [1.3714731948999777, 53.36744933951601], [1.4727935946003068, 53.367176061881985], [1.5741124093811814, 53.36680967999589], [1.6754291798248613, 53.36635019669401], [1.7767434465818233, 53.36579761552861]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.7767434&lt;dd&gt;Longitude: 53.365798&lt;dd&gt;Azimuth: 52.815279\u00b0&lt;dd&gt;Altitude: 52.644171\u00b0&lt;dd&gt;Slant Range: 652.36264km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7767434465818233, 53.36579761552861]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2701516697438864, 53.36762951077816], [1.3714731948999777, 53.36744933951601], [1.4727935946003068, 53.367176061881985], [1.5741124093811814, 53.36680967999589], [1.6754291798248613, 53.36635019669401], [1.7767434465818233, 53.36579761552861], [1.8780547503796912, 53.36515194076802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.8780548&lt;dd&gt;Longitude: 53.365152&lt;dd&gt;Azimuth: 53.401841\u00b0&lt;dd&gt;Altitude: 52.205798\u00b0&lt;dd&gt;Slant Range: 655.77283km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8780547503796912, 53.36515194076802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3714731948999777, 53.36744933951601], [1.4727935946003068, 53.367176061881985], [1.5741124093811814, 53.36680967999589], [1.6754291798248613, 53.36635019669401], [1.7767434465818233, 53.36579761552861], [1.8780547503796912, 53.36515194076802], [1.9793626320329312, 53.36441317739656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 1.9793626&lt;dd&gt;Longitude: 53.364413&lt;dd&gt;Azimuth: 53.971061\u00b0&lt;dd&gt;Altitude: 51.768844\u00b0&lt;dd&gt;Slant Range: 659.23968km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9793626320329312, 53.36441317739656]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4727935946003068, 53.367176061881985], [1.5741124093811814, 53.36680967999589], [1.6754291798248613, 53.36635019669401], [1.7767434465818233, 53.36579761552861], [1.8780547503796912, 53.36515194076802], [1.9793626320329312, 53.36441317739656], [2.0806666324733336, 53.36358133111398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.0806666&lt;dd&gt;Longitude: 53.363581&lt;dd&gt;Azimuth: 54.523596\u00b0&lt;dd&gt;Altitude: 51.333495\u00b0&lt;dd&gt;Slant Range: 662.76232km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0806666324733336, 53.36358133111398]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5741124093811814, 53.36680967999589], [1.6754291798248613, 53.36635019669401], [1.7767434465818233, 53.36579761552861], [1.8780547503796912, 53.36515194076802], [1.9793626320329312, 53.36441317739656], [2.0806666324733336, 53.36358133111398], [2.1819662927350008, 53.3626564083357]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.1819663&lt;dd&gt;Longitude: 53.362656&lt;dd&gt;Azimuth: 55.060078\u00b0&lt;dd&gt;Altitude: 50.899925\u00b0&lt;dd&gt;Slant Range: 666.33985km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.1819662927350008, 53.3626564083357]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6754291798248613, 53.36635019669401], [1.7767434465818233, 53.36579761552861], [1.8780547503796912, 53.36515194076802], [1.9793626320329312, 53.36441317739656], [2.0806666324733336, 53.36358133111398], [2.1819662927350008, 53.3626564083357], [2.2832611540032257, 53.36163841619227]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.2832612&lt;dd&gt;Longitude: 53.361638&lt;dd&gt;Azimuth: 55.581114\u00b0&lt;dd&gt;Altitude: 50.468291\u00b0&lt;dd&gt;Slant Range: 669.97139km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2832611540032257, 53.36163841619227]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7767434465818233, 53.36579761552861], [1.8780547503796912, 53.36515194076802], [1.9793626320329312, 53.36441317739656], [2.0806666324733336, 53.36358133111398], [2.1819662927350008, 53.3626564083357], [2.2832611540032257, 53.36163841619227], [2.3845507576023808, 53.36052736252913]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.3845508&lt;dd&gt;Longitude: 53.360527&lt;dd&gt;Azimuth: 56.087286\u00b0&lt;dd&gt;Altitude: 50.038743\u00b0&lt;dd&gt;Slant Range: 673.65606km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.3845507576023808, 53.36052736252913]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8780547503796912, 53.36515194076802], [1.9793626320329312, 53.36441317739656], [2.0806666324733336, 53.36358133111398], [2.1819662927350008, 53.3626564083357], [2.2832611540032257, 53.36163841619227], [2.3845507576023808, 53.36052736252913], [2.4858346450240596, 53.35932325590647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.4858346&lt;dd&gt;Longitude: 53.359323&lt;dd&gt;Azimuth: 56.579151\u00b0&lt;dd&gt;Altitude: 49.611416\u00b0&lt;dd&gt;Slant Range: 677.39299km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.4858346450240596, 53.35932325590647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9793626320329312, 53.36441317739656], [2.0806666324733336, 53.36358133111398], [2.1819662927350008, 53.3626564083357], [2.2832611540032257, 53.36163841619227], [2.3845507576023808, 53.36052736252913], [2.4858346450240596, 53.35932325590647], [2.58711235793298, 53.35802610559872]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.5871124&lt;dd&gt;Longitude: 53.358026&lt;dd&gt;Azimuth: 57.057245\u00b0&lt;dd&gt;Altitude: 49.186436\u00b0&lt;dd&gt;Slant Range: 681.18132km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.58711235793298, 53.35802610559872]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0806666324733336, 53.36358133111398], [2.1819662927350008, 53.3626564083357], [2.2832611540032257, 53.36163841619227], [2.3845507576023808, 53.36052736252913], [2.4858346450240596, 53.35932325590647], [2.58711235793298, 53.35802610559872], [2.688383438189704, 53.35663592159426]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.6883834&lt;dd&gt;Longitude: 53.356636&lt;dd&gt;Azimuth: 57.52208\u00b0&lt;dd&gt;Altitude: 48.763918\u00b0&lt;dd&gt;Slant Range: 685.02019km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.688383438189704, 53.35663592159426]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.1819662927350008, 53.3626564083357], [2.2832611540032257, 53.36163841619227], [2.3845507576023808, 53.36052736252913], [2.4858346450240596, 53.35932325590647], [2.58711235793298, 53.35802610559872], [2.688383438189704, 53.35663592159426], [2.7896474278551957, 53.35515271459514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.7896474&lt;dd&gt;Longitude: 53.355153&lt;dd&gt;Azimuth: 57.974148\u00b0&lt;dd&gt;Altitude: 48.343969\u00b0&lt;dd&gt;Slant Range: 688.90874km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7896474278551957, 53.35515271459514]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.2832611540032257, 53.36163841619227], [2.3845507576023808, 53.36052736252913], [2.4858346450240596, 53.35932325590647], [2.58711235793298, 53.35802610559872], [2.688383438189704, 53.35663592159426], [2.7896474278551957, 53.35515271459514], [2.890903869212574, 53.353576496016586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.8909039&lt;dd&gt;Longitude: 53.353576&lt;dd&gt;Azimuth: 58.41392\u00b0&lt;dd&gt;Altitude: 47.926686\u00b0&lt;dd&gt;Slant Range: 692.84615km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.890903869212574, 53.353576496016586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.3845507576023808, 53.36052736252913], [2.4858346450240596, 53.35932325590647], [2.58711235793298, 53.35802610559872], [2.688383438189704, 53.35663592159426], [2.7896474278551957, 53.35515271459514], [2.890903869212574, 53.353576496016586], [2.9921523047755354, 53.35190727798648]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 2.9921523&lt;dd&gt;Longitude: 53.351907&lt;dd&gt;Azimuth: 58.841846\u00b0&lt;dd&gt;Altitude: 47.512156\u00b0&lt;dd&gt;Slant Range: 696.83157km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.9921523047755354, 53.35190727798648]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.4858346450240596, 53.35932325590647], [2.58711235793298, 53.35802610559872], [2.688383438189704, 53.35663592159426], [2.7896474278551957, 53.35515271459514], [2.890903869212574, 53.353576496016586], [2.9921523047755354, 53.35190727798648], [3.093392277311635, 53.35014507334509]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.0933923&lt;dd&gt;Longitude: 53.350145&lt;dd&gt;Azimuth: 59.258358\u00b0&lt;dd&gt;Altitude: 47.10046\u00b0&lt;dd&gt;Slant Range: 700.86418km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.093392277311635, 53.35014507334509]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.58711235793298, 53.35802610559872], [2.688383438189704, 53.35663592159426], [2.7896474278551957, 53.35515271459514], [2.890903869212574, 53.353576496016586], [2.9921523047755354, 53.35190727798648], [3.093392277311635, 53.35014507334509], [3.194623329842492, 53.34828989564441]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.1946233&lt;dd&gt;Longitude: 53.34829&lt;dd&gt;Azimuth: 59.663871\u00b0&lt;dd&gt;Altitude: 46.69167\u00b0&lt;dd&gt;Slant Range: 704.94317km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.194623329842492, 53.34828989564441]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.688383438189704, 53.35663592159426], [2.7896474278551957, 53.35515271459514], [2.890903869212574, 53.353576496016586], [2.9921523047755354, 53.35190727798648], [3.093392277311635, 53.35014507334509], [3.194623329842492, 53.34828989564441], [3.295845005667424, 53.34634175914785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.295845&lt;dd&gt;Longitude: 53.346342&lt;dd&gt;Azimuth: 60.058781\u00b0&lt;dd&gt;Altitude: 46.285852\u00b0&lt;dd&gt;Slant Range: 709.06774km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.295845005667424, 53.34634175914785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7896474278551957, 53.35515271459514], [2.890903869212574, 53.353576496016586], [2.9921523047755354, 53.35190727798648], [3.093392277311635, 53.35014507334509], [3.194623329842492, 53.34828989564441], [3.295845005667424, 53.34634175914785], [3.3970568483787944, 53.3443006788294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.3970568&lt;dd&gt;Longitude: 53.344301&lt;dd&gt;Azimuth: 60.443467\u00b0&lt;dd&gt;Altitude: 45.883065\u00b0&lt;dd&gt;Slant Range: 713.23708km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.3970568483787944, 53.3443006788294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.890903869212574, 53.353576496016586], [2.9921523047755354, 53.35190727798648], [3.093392277311635, 53.35014507334509], [3.194623329842492, 53.34828989564441], [3.295845005667424, 53.34634175914785], [3.3970568483787944, 53.3443006788294], [3.4982584018698963, 53.34216667037338]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.4982584&lt;dd&gt;Longitude: 53.342167&lt;dd&gt;Azimuth: 60.818292\u00b0&lt;dd&gt;Altitude: 45.483361\u00b0&lt;dd&gt;Slant Range: 717.45042km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4982584018698963, 53.34216667037338]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.9921523047755354, 53.35190727798648], [3.093392277311635, 53.35014507334509], [3.194623329842492, 53.34828989564441], [3.295845005667424, 53.34634175914785], [3.3970568483787944, 53.3443006788294], [3.4982584018698963, 53.34216667037338], [3.599449210350426, 53.339939750173585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.5994492&lt;dd&gt;Longitude: 53.33994&lt;dd&gt;Azimuth: 61.183606\u00b0&lt;dd&gt;Altitude: 45.086786\u00b0&lt;dd&gt;Slant Range: 721.70697km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.599449210350426, 53.339939750173585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.093392277311635, 53.35014507334509], [3.194623329842492, 53.34828989564441], [3.295845005667424, 53.34634175914785], [3.3970568483787944, 53.3443006788294], [3.4982584018698963, 53.34216667037338], [3.599449210350426, 53.339939750173585], [3.700628818364825, 53.337619935332945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.7006288&lt;dd&gt;Longitude: 53.33762&lt;dd&gt;Azimuth: 61.539742\u00b0&lt;dd&gt;Altitude: 44.693381\u00b0&lt;dd&gt;Slant Range: 726.00598km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.700628818364825, 53.337619935332945]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.194623329842492, 53.34828989564441], [3.295845005667424, 53.34634175914785], [3.3970568483787944, 53.3443006788294], [3.4982584018698963, 53.34216667037338], [3.599449210350426, 53.339939750173585], [3.700628818364825, 53.337619935332945], [3.8017967708013662, 53.33520724366251]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.8017968&lt;dd&gt;Longitude: 53.335207&lt;dd&gt;Azimuth: 61.887019\u00b0&lt;dd&gt;Altitude: 44.30318\u00b0&lt;dd&gt;Slant Range: 730.34669km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.8017967708013662, 53.33520724366251]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.295845005667424, 53.34634175914785], [3.3970568483787944, 53.3443006788294], [3.4982584018698963, 53.34216667037338], [3.599449210350426, 53.339939750173585], [3.700628818364825, 53.337619935332945], [3.8017967708013662, 53.33520724366251], [3.9029526129046728, 53.332701693681116]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 3.9029526&lt;dd&gt;Longitude: 53.332702&lt;dd&gt;Azimuth: 62.225744\u00b0&lt;dd&gt;Altitude: 43.916216\u00b0&lt;dd&gt;Slant Range: 734.72835km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.9029526129046728, 53.332701693681116]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.3970568483787944, 53.3443006788294], [3.4982584018698963, 53.34216667037338], [3.599449210350426, 53.339939750173585], [3.700628818364825, 53.337619935332945], [3.8017967708013662, 53.33520724366251], [3.9029526129046728, 53.332701693681116], [4.004095890299736, 53.33010330461454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.0040959&lt;dd&gt;Longitude: 53.330103&lt;dd&gt;Azimuth: 62.556211\u00b0&lt;dd&gt;Altitude: 43.532513\u00b0&lt;dd&gt;Slant Range: 739.15023km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.004095890299736, 53.33010330461454]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4982584018698963, 53.34216667037338], [3.599449210350426, 53.339939750173585], [3.700628818364825, 53.337619935332945], [3.8017967708013662, 53.33520724366251], [3.9029526129046728, 53.332701693681116], [4.004095890299736, 53.33010330461454], [4.105226148991305, 53.327412096394774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.1052261&lt;dd&gt;Longitude: 53.327412&lt;dd&gt;Azimuth: 62.878701\u00b0&lt;dd&gt;Altitude: 43.152092\u00b0&lt;dd&gt;Slant Range: 743.61161km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.105226148991305, 53.327412096394774]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.599449210350426, 53.339939750173585], [3.700628818364825, 53.337619935332945], [3.8017967708013662, 53.33520724366251], [3.9029526129046728, 53.332701693681116], [4.004095890299736, 53.33010330461454], [4.105226148991305, 53.327412096394774], [4.20634293539091, 53.324628089659235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.2063429&lt;dd&gt;Longitude: 53.324628&lt;dd&gt;Azimuth: 63.193485\u00b0&lt;dd&gt;Altitude: 42.774971\u00b0&lt;dd&gt;Slant Range: 748.11178km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.20634293539091, 53.324628089659235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.700628818364825, 53.337619935332945], [3.8017967708013662, 53.33520724366251], [3.9029526129046728, 53.332701693681116], [4.004095890299736, 53.33010330461454], [4.105226148991305, 53.327412096394774], [4.20634293539091, 53.324628089659235], [4.307445796319328, 53.3217513057501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.3074458&lt;dd&gt;Longitude: 53.321751&lt;dd&gt;Azimuth: 63.50082\u00b0&lt;dd&gt;Altitude: 42.401163\u00b0&lt;dd&gt;Slant Range: 752.65003km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.307445796319328, 53.3217513057501]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.8017967708013662, 53.33520724366251], [3.9029526129046728, 53.332701693681116], [4.004095890299736, 53.33010330461454], [4.105226148991305, 53.327412096394774], [4.20634293539091, 53.324628089659235], [4.307445796319328, 53.3217513057501], [4.408534279034067, 53.31878176671341]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.4085343&lt;dd&gt;Longitude: 53.318782&lt;dd&gt;Azimuth: 63.800955\u00b0&lt;dd&gt;Altitude: 42.030677\u00b0&lt;dd&gt;Slant Range: 757.22568km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.408534279034067, 53.31878176671341]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.9029526129046728, 53.332701693681116], [4.004095890299736, 53.33010330461454], [4.105226148991305, 53.327412096394774], [4.20634293539091, 53.324628089659235], [4.307445796319328, 53.3217513057501], [4.408534279034067, 53.31878176671341], [4.509607931219463, 53.31571949529829]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.5096079&lt;dd&gt;Longitude: 53.315719&lt;dd&gt;Azimuth: 64.094129\u00b0&lt;dd&gt;Altitude: 41.663521\u00b0&lt;dd&gt;Slant Range: 761.83805km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.509607931219463, 53.31571949529829]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.004095890299736, 53.33010330461454], [4.105226148991305, 53.327412096394774], [4.20634293539091, 53.324628089659235], [4.307445796319328, 53.3217513057501], [4.408534279034067, 53.31878176671341], [4.509607931219463, 53.31571949529829], [4.610666301036504, 53.312564514956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.6106663&lt;dd&gt;Longitude: 53.312565&lt;dd&gt;Azimuth: 64.380569\u00b0&lt;dd&gt;Altitude: 41.299698\u00b0&lt;dd&gt;Slant Range: 766.48647km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.610666301036504, 53.312564514956]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.105226148991305, 53.327412096394774], [4.20634293539091, 53.324628089659235], [4.307445796319328, 53.3217513057501], [4.408534279034067, 53.31878176671341], [4.509607931219463, 53.31571949529829], [4.610666301036504, 53.312564514956], [4.7117089370984, 53.30931684983925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.7117089&lt;dd&gt;Longitude: 53.309317&lt;dd&gt;Azimuth: 64.660495\u00b0&lt;dd&gt;Altitude: 40.939207\u00b0&lt;dd&gt;Slant Range: 771.17028km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.7117089370984, 53.30931684983925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.20634293539091, 53.324628089659235], [4.307445796319328, 53.3217513057501], [4.408534279034067, 53.31878176671341], [4.509607931219463, 53.31571949529829], [4.610666301036504, 53.312564514956], [4.7117089370984, 53.30931684983925], [4.81273538851247, 53.30597652480105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.8127354&lt;dd&gt;Longitude: 53.305977&lt;dd&gt;Azimuth: 64.934117\u00b0&lt;dd&gt;Altitude: 40.582047\u00b0&lt;dd&gt;Slant Range: 775.88884km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.81273538851247, 53.30597652480105]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.307445796319328, 53.3217513057501], [4.408534279034067, 53.31878176671341], [4.509607931219463, 53.31571949529829], [4.610666301036504, 53.312564514956], [4.7117089370984, 53.30931684983925], [4.81273538851247, 53.30597652480105], [4.913745204871714, 53.30254356539392]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 4.9137452&lt;dd&gt;Longitude: 53.302544&lt;dd&gt;Azimuth: 65.201638\u00b0&lt;dd&gt;Altitude: 40.228212\u00b0&lt;dd&gt;Slant Range: 780.64151km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.913745204871714, 53.30254356539392]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.408534279034067, 53.31878176671341], [4.509607931219463, 53.31571949529829], [4.610666301036504, 53.312564514956], [4.7117089370984, 53.30931684983925], [4.81273538851247, 53.30597652480105], [4.913745204871714, 53.30254356539392], [5.014737936293643, 53.29901799786892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.0147379&lt;dd&gt;Longitude: 53.299018&lt;dd&gt;Azimuth: 65.463251\u00b0&lt;dd&gt;Altitude: 39.877694\u00b0&lt;dd&gt;Slant Range: 785.42766km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.014737936293643, 53.29901799786892]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.509607931219463, 53.31571949529829], [4.610666301036504, 53.312564514956], [4.7117089370984, 53.30931684983925], [4.81273538851247, 53.30597652480105], [4.913745204871714, 53.30254356539392], [5.014737936293643, 53.29901799786892], [5.1157131334061345, 53.29539984917464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.1157131&lt;dd&gt;Longitude: 53.2954&lt;dd&gt;Azimuth: 65.719143\u00b0&lt;dd&gt;Altitude: 39.530486\u00b0&lt;dd&gt;Slant Range: 790.24669km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.1157131334061345, 53.29539984917464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.610666301036504, 53.312564514956], [4.7117089370984, 53.30931684983925], [4.81273538851247, 53.30597652480105], [4.913745204871714, 53.30254356539392], [5.014737936293643, 53.29901799786892], [5.1157131334061345, 53.29539984917464], [5.216670347384171, 53.29168914695615]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.2166703&lt;dd&gt;Longitude: 53.291689&lt;dd&gt;Azimuth: 65.969493\u00b0&lt;dd&gt;Altitude: 39.186574\u00b0&lt;dd&gt;Slant Range: 795.09799km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.216670347384171, 53.29168914695615]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.7117089370984, 53.30931684983925], [4.81273538851247, 53.30597652480105], [4.913745204871714, 53.30254356539392], [5.014737936293643, 53.29901799786892], [5.1157131334061345, 53.29539984917464], [5.216670347384171, 53.29168914695615], [5.317609129948799, 53.287885919554085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.3176091&lt;dd&gt;Longitude: 53.287886&lt;dd&gt;Azimuth: 66.214473\u00b0&lt;dd&gt;Altitude: 38.845945\u00b0&lt;dd&gt;Slant Range: 799.98097km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.317609129948799, 53.287885919554085]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.81273538851247, 53.30597652480105], [4.913745204871714, 53.30254356539392], [5.014737936293643, 53.29901799786892], [5.1157131334061345, 53.29539984917464], [5.216670347384171, 53.29168914695615], [5.317609129948799, 53.287885919554085], [5.418529033385549, 53.28399019600343]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.418529&lt;dd&gt;Longitude: 53.28399&lt;dd&gt;Azimuth: 66.454248\u00b0&lt;dd&gt;Altitude: 38.508585\u00b0&lt;dd&gt;Slant Range: 804.89504km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.418529033385549, 53.28399019600343]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.913745204871714, 53.30254356539392], [5.014737936293643, 53.29901799786892], [5.1157131334061345, 53.29539984917464], [5.216670347384171, 53.29168914695615], [5.317609129948799, 53.287885919554085], [5.418529033385549, 53.28399019600343], [5.519429610555021, 53.2800020060325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.5194296&lt;dd&gt;Longitude: 53.280002&lt;dd&gt;Azimuth: 66.688978\u00b0&lt;dd&gt;Altitude: 38.174475\u00b0&lt;dd&gt;Slant Range: 809.83963km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.519429610555021, 53.2800020060325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.014737936293643, 53.29901799786892], [5.1157131334061345, 53.29539984917464], [5.216670347384171, 53.29168914695615], [5.317609129948799, 53.287885919554085], [5.418529033385549, 53.28399019600343], [5.519429610555021, 53.2800020060325], [5.620310414916524, 53.27592138006196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.6203104&lt;dd&gt;Longitude: 53.275921&lt;dd&gt;Azimuth: 66.918816\u00b0&lt;dd&gt;Altitude: 37.843599\u00b0&lt;dd&gt;Slant Range: 814.81419km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.620310414916524, 53.27592138006196]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.1157131334061345, 53.29539984917464], [5.216670347384171, 53.29168914695615], [5.317609129948799, 53.287885919554085], [5.418529033385549, 53.28399019600343], [5.519429610555021, 53.2800020060325], [5.620310414916524, 53.27592138006196], [5.721171000523977, 53.27174834920336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.721171&lt;dd&gt;Longitude: 53.271748&lt;dd&gt;Azimuth: 67.143909\u00b0&lt;dd&gt;Altitude: 37.515936\u00b0&lt;dd&gt;Slant Range: 819.81816km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.721171000523977, 53.27174834920336]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.216670347384171, 53.29168914695615], [5.317609129948799, 53.287885919554085], [5.418529033385549, 53.28399019600343], [5.519429610555021, 53.2800020060325], [5.620310414916524, 53.27592138006196], [5.721171000523977, 53.27174834920336], [5.82201092205657, 53.26748294525832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.8220109&lt;dd&gt;Longitude: 53.267483&lt;dd&gt;Azimuth: 67.364398\u00b0&lt;dd&gt;Altitude: 37.191464\u00b0&lt;dd&gt;Slant Range: 824.851km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.82201092205657, 53.26748294525832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.317609129948799, 53.287885919554085], [5.418529033385549, 53.28399019600343], [5.519429610555021, 53.2800020060325], [5.620310414916524, 53.27592138006196], [5.721171000523977, 53.27174834920336], [5.82201092205657, 53.26748294525832], [5.922829734814875, 53.26312520071725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 5.9228297&lt;dd&gt;Longitude: 53.263125&lt;dd&gt;Azimuth: 67.58042\u00b0&lt;dd&gt;Altitude: 36.870163\u00b0&lt;dd&gt;Slant Range: 829.91218km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.922829734814875, 53.26312520071725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.418529033385549, 53.28399019600343], [5.519429610555021, 53.2800020060325], [5.620310414916524, 53.27592138006196], [5.721171000523977, 53.27174834920336], [5.82201092205657, 53.26748294525832], [5.922829734814875, 53.26312520071725], [6.023626994753966, 53.25867514875782]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.023627&lt;dd&gt;Longitude: 53.258675&lt;dd&gt;Azimuth: 67.792107\u00b0&lt;dd&gt;Altitude: 36.552008\u00b0&lt;dd&gt;Slant Range: 835.00118km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.023626994753966, 53.25867514875782]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.519429610555021, 53.2800020060325], [5.620310414916524, 53.27592138006196], [5.721171000523977, 53.27174834920336], [5.82201092205657, 53.26748294525832], [5.922829734814875, 53.26312520071725], [6.023626994753966, 53.25867514875782], [6.124402258474242, 53.254132823244305]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.1244023&lt;dd&gt;Longitude: 53.254133&lt;dd&gt;Azimuth: 67.999583\u00b0&lt;dd&gt;Altitude: 36.236976\u00b0&lt;dd&gt;Slant Range: 840.11749km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.124402258474242, 53.254132823244305]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.620310414916524, 53.27592138006196], [5.721171000523977, 53.27174834920336], [5.82201092205657, 53.26748294525832], [5.922829734814875, 53.26312520071725], [6.023626994753966, 53.25867514875782], [6.124402258474242, 53.254132823244305], [6.225155083252974, 53.24949825872581]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.2251551&lt;dd&gt;Longitude: 53.249498&lt;dd&gt;Azimuth: 68.202972\u00b0&lt;dd&gt;Altitude: 35.925042\u00b0&lt;dd&gt;Slant Range: 845.2606km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.225155083252974, 53.24949825872581]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.721171000523977, 53.27174834920336], [5.82201092205657, 53.26748294525832], [5.922829734814875, 53.26312520071725], [6.023626994753966, 53.25867514875782], [6.124402258474242, 53.254132823244305], [6.225155083252974, 53.24949825872581], [6.325885027051866, 53.24477149043519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.325885&lt;dd&gt;Longitude: 53.244771&lt;dd&gt;Azimuth: 68.40239\u00b0&lt;dd&gt;Altitude: 35.616179\u00b0&lt;dd&gt;Slant Range: 850.43003km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.325885027051866, 53.24477149043519]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.82201092205657, 53.26748294525832], [5.922829734814875, 53.26312520071725], [6.023626994753966, 53.25867514875782], [6.124402258474242, 53.254132823244305], [6.225155083252974, 53.24949825872581], [6.325885027051866, 53.24477149043519], [6.426591648520736, 53.23995255428785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.4265916&lt;dd&gt;Longitude: 53.239953&lt;dd&gt;Azimuth: 68.597951\u00b0&lt;dd&gt;Altitude: 35.310361\u00b0&lt;dd&gt;Slant Range: 855.62529km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.426591648520736, 53.23995255428785]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[5.922829734814875, 53.26312520071725], [6.023626994753966, 53.25867514875782], [6.124402258474242, 53.254132823244305], [6.225155083252974, 53.24949825872581], [6.325885027051866, 53.24477149043519], [6.426591648520736, 53.23995255428785], [6.527274507021138, 53.23504148688016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.5272745&lt;dd&gt;Longitude: 53.235041&lt;dd&gt;Azimuth: 68.789764\u00b0&lt;dd&gt;Altitude: 35.007562\u00b0&lt;dd&gt;Slant Range: 860.84591km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.527274507021138, 53.23504148688016]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[6.023626994753966, 53.25867514875782], [6.124402258474242, 53.254132823244305], [6.225155083252974, 53.24949825872581], [6.325885027051866, 53.24477149043519], [6.426591648520736, 53.23995255428785], [6.527274507021138, 53.23504148688016], [6.6279331626383655, 53.23003832548824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.6279332&lt;dd&gt;Longitude: 53.230038&lt;dd&gt;Azimuth: 68.977933\u00b0&lt;dd&gt;Altitude: 34.707752\u00b0&lt;dd&gt;Slant Range: 866.09142km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.6279331626383655, 53.23003832548824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[6.124402258474242, 53.254132823244305], [6.225155083252974, 53.24949825872581], [6.325885027051866, 53.24477149043519], [6.426591648520736, 53.23995255428785], [6.527274507021138, 53.23504148688016], [6.6279331626383655, 53.23003832548824], [6.72856717618863, 53.224943108066725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.7285672&lt;dd&gt;Longitude: 53.224943&lt;dd&gt;Azimuth: 69.16256\u00b0&lt;dd&gt;Altitude: 34.410905\u00b0&lt;dd&gt;Slant Range: 871.36137km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.72856717618863, 53.224943108066725]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[6.225155083252974, 53.24949825872581], [6.325885027051866, 53.24477149043519], [6.426591648520736, 53.23995255428785], [6.527274507021138, 53.23504148688016], [6.6279331626383655, 53.23003832548824], [6.72856717618863, 53.224943108066725], [6.82917610923374, 53.21975587324689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.8291761&lt;dd&gt;Longitude: 53.219756&lt;dd&gt;Azimuth: 69.343742\u00b0&lt;dd&gt;Altitude: 34.11699\u00b0&lt;dd&gt;Slant Range: 876.65531km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.82917610923374, 53.21975587324689]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[6.325885027051866, 53.24477149043519], [6.426591648520736, 53.23995255428785], [6.527274507021138, 53.23504148688016], [6.6279331626383655, 53.23003832548824], [6.72856717618863, 53.224943108066725], [6.82917610923374, 53.21975587324689], [6.929759524098686, 53.21447666033587]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4794&lt;dd&gt;Latitude: 6.9297595&lt;dd&gt;Longitude: 53.214477&lt;dd&gt;Azimuth: 69.521575\u00b0&lt;dd&gt;Altitude: 33.82598\u00b0&lt;dd&gt;Slant Range: 881.97281km&quot;, &quot;name&quot;: &quot;STARLINK-4794&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[6.929759524098686, 53.21447666033587]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.990431&lt;dd&gt;Longitude: 52.996097&lt;dd&gt;Azimuth: 288.6153\u00b0&lt;dd&gt;Altitude: 30.70289\u00b0&lt;dd&gt;Slant Range: 825.3576km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921], [-11.889268747658031, 53.004451254176665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.889269&lt;dd&gt;Longitude: 53.004451&lt;dd&gt;Azimuth: 288.81055\u00b0&lt;dd&gt;Altitude: 30.992418\u00b0&lt;dd&gt;Slant Range: 819.79849km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.889268747658031, 53.004451254176665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921], [-11.889268747658031, 53.004451254176665], [-11.788065820673168, 53.012712360953955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.788066&lt;dd&gt;Longitude: 53.012712&lt;dd&gt;Azimuth: 289.00959\u00b0&lt;dd&gt;Altitude: 31.285156\u00b0&lt;dd&gt;Slant Range: 814.26271km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.788065820673168, 53.012712360953955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921], [-11.889268747658031, 53.004451254176665], [-11.788065820673168, 53.012712360953955], [-11.686822937205616, 53.020880177207744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.686823&lt;dd&gt;Longitude: 53.02088&lt;dd&gt;Azimuth: 289.21256\u00b0&lt;dd&gt;Altitude: 31.581144\u00b0&lt;dd&gt;Slant Range: 808.75074km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.686822937205616, 53.020880177207744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921], [-11.889268747658031, 53.004451254176665], [-11.788065820673168, 53.012712360953955], [-11.686822937205616, 53.020880177207744], [-11.585540524767977, 53.02895464058146]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.585541&lt;dd&gt;Longitude: 53.028955&lt;dd&gt;Azimuth: 289.41955\u00b0&lt;dd&gt;Altitude: 31.880421\u00b0&lt;dd&gt;Slant Range: 803.26309km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.585540524767977, 53.02895464058146]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921], [-11.889268747658031, 53.004451254176665], [-11.788065820673168, 53.012712360953955], [-11.686822937205616, 53.020880177207744], [-11.585540524767977, 53.02895464058146], [-11.484219012073781, 53.036935689378396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.484219&lt;dd&gt;Longitude: 53.036936&lt;dd&gt;Azimuth: 289.63069\u00b0&lt;dd&gt;Altitude: 32.183024\u00b0&lt;dd&gt;Slant Range: 797.80026km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.484219012073781, 53.036935689378396]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.990431291853897, 52.99609691988921], [-11.889268747658031, 53.004451254176665], [-11.788065820673168, 53.012712360953955], [-11.686822937205616, 53.020880177207744], [-11.585540524767977, 53.02895464058146], [-11.484219012073781, 53.036935689378396], [-11.382858829006496, 53.044823262563824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.382859&lt;dd&gt;Longitude: 53.044823&lt;dd&gt;Azimuth: 289.8461\u00b0&lt;dd&gt;Altitude: 32.488992\u00b0&lt;dd&gt;Slant Range: 792.36277km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.382858829006496, 53.044823262563824]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.889268747658031, 53.004451254176665], [-11.788065820673168, 53.012712360953955], [-11.686822937205616, 53.020880177207744], [-11.585540524767977, 53.02895464058146], [-11.484219012073781, 53.036935689378396], [-11.382858829006496, 53.044823262563824], [-11.281460406632473, 53.05261729976698]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.28146&lt;dd&gt;Longitude: 53.052617&lt;dd&gt;Azimuth: 290.06591\u00b0&lt;dd&gt;Altitude: 32.798362\u00b0&lt;dd&gt;Slant Range: 786.95115km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.281460406632473, 53.05261729976698]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.788065820673168, 53.012712360953955], [-11.686822937205616, 53.020880177207744], [-11.585540524767977, 53.02895464058146], [-11.484219012073781, 53.036935689378396], [-11.382858829006496, 53.044823262563824], [-11.281460406632473, 53.05261729976698], [-11.180024177171587, 53.060317741283356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.180024&lt;dd&gt;Longitude: 53.060318&lt;dd&gt;Azimuth: 290.29025\u00b0&lt;dd&gt;Altitude: 33.11117\u00b0&lt;dd&gt;Slant Range: 781.56594km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.180024177171587, 53.060317741283356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.686822937205616, 53.020880177207744], [-11.585540524767977, 53.02895464058146], [-11.484219012073781, 53.036935689378396], [-11.382858829006496, 53.044823262563824], [-11.281460406632473, 53.05261729976698], [-11.180024177171587, 53.060317741283356], [-11.078550573997619, 53.06792452807733]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -11.078551&lt;dd&gt;Longitude: 53.067925&lt;dd&gt;Azimuth: 290.51926\u00b0&lt;dd&gt;Altitude: 33.427453\u00b0&lt;dd&gt;Slant Range: 776.20771km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-11.078550573997619, 53.06792452807733]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.585540524767977, 53.02895464058146], [-11.484219012073781, 53.036935689378396], [-11.382858829006496, 53.044823262563824], [-11.281460406632473, 53.05261729976698], [-11.180024177171587, 53.060317741283356], [-11.078550573997619, 53.06792452807733], [-10.977040031613447, 53.07543760178371]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.97704&lt;dd&gt;Longitude: 53.075438&lt;dd&gt;Azimuth: 290.75308\u00b0&lt;dd&gt;Altitude: 33.747246\u00b0&lt;dd&gt;Slant Range: 770.87702km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.977040031613447, 53.07543760178371]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.484219012073781, 53.036935689378396], [-11.382858829006496, 53.044823262563824], [-11.281460406632473, 53.05261729976698], [-11.180024177171587, 53.060317741283356], [-11.078550573997619, 53.06792452807733], [-10.977040031613447, 53.07543760178371], [-10.87549298565318, 53.08285690471037]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.875493&lt;dd&gt;Longitude: 53.082857&lt;dd&gt;Azimuth: 290.99187\u00b0&lt;dd&gt;Altitude: 34.070583\u00b0&lt;dd&gt;Slant Range: 765.57445km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.87549298565318, 53.08285690471037]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.382858829006496, 53.044823262563824], [-11.281460406632473, 53.05261729976698], [-11.180024177171587, 53.060317741283356], [-11.078550573997619, 53.06792452807733], [-10.977040031613447, 53.07543760178371], [-10.87549298565318, 53.08285690471037], [-10.77390987286049, 53.09018237984023]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.77391&lt;dd&gt;Longitude: 53.090182&lt;dd&gt;Azimuth: 291.23576\u00b0&lt;dd&gt;Altitude: 34.397498\u00b0&lt;dd&gt;Slant Range: 760.3006km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.77390987286049, 53.09018237984023]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.281460406632473, 53.05261729976698], [-11.180024177171587, 53.060317741283356], [-11.078550573997619, 53.06792452807733], [-10.977040031613447, 53.07543760178371], [-10.87549298565318, 53.08285690471037], [-10.77390987286049, 53.09018237984023], [-10.672291131077577, 53.09741397083342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.672291&lt;dd&gt;Longitude: 53.097414&lt;dd&gt;Azimuth: 291.48493\u00b0&lt;dd&gt;Altitude: 34.728023\u00b0&lt;dd&gt;Slant Range: 755.05607km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.672291131077577, 53.09741397083342]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.180024177171587, 53.060317741283356], [-11.078550573997619, 53.06792452807733], [-10.977040031613447, 53.07543760178371], [-10.87549298565318, 53.08285690471037], [-10.77390987286049, 53.09018237984023], [-10.672291131077577, 53.09741397083342], [-10.570637199241807, 53.10455162202915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.570637&lt;dd&gt;Longitude: 53.104552&lt;dd&gt;Azimuth: 291.73954\u00b0&lt;dd&gt;Altitude: 35.062189\u00b0&lt;dd&gt;Slant Range: 749.84149km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.570637199241807, 53.10455162202915]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-11.078550573997619, 53.06792452807733], [-10.977040031613447, 53.07543760178371], [-10.87549298565318, 53.08285690471037], [-10.77390987286049, 53.09018237984023], [-10.672291131077577, 53.09741397083342], [-10.570637199241807, 53.10455162202915], [-10.468948517363296, 53.11159527844826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.468949&lt;dd&gt;Longitude: 53.111595&lt;dd&gt;Azimuth: 291.99977\u00b0&lt;dd&gt;Altitude: 35.400026\u00b0&lt;dd&gt;Slant Range: 744.65748km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.468948517363296, 53.11159527844826]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.977040031613447, 53.07543760178371], [-10.87549298565318, 53.08285690471037], [-10.77390987286049, 53.09018237984023], [-10.672291131077577, 53.09741397083342], [-10.570637199241807, 53.10455162202915], [-10.468948517363296, 53.11159527844826], [-10.367225526514325, 53.118544885794726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.367226&lt;dd&gt;Longitude: 53.118545&lt;dd&gt;Azimuth: 292.26578\u00b0&lt;dd&gt;Altitude: 35.741561\u00b0&lt;dd&gt;Slant Range: 739.50471km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.367225526514325, 53.118544885794726]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.87549298565318, 53.08285690471037], [-10.77390987286049, 53.09018237984023], [-10.672291131077577, 53.09741397083342], [-10.570637199241807, 53.10455162202915], [-10.468948517363296, 53.11159527844826], [-10.367225526514325, 53.118544885794726], [-10.265468668822653, 53.12540039045813]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.265469&lt;dd&gt;Longitude: 53.1254&lt;dd&gt;Azimuth: 292.53778\u00b0&lt;dd&gt;Altitude: 36.086822\u00b0&lt;dd&gt;Slant Range: 734.38383km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.265468668822653, 53.12540039045813]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.77390987286049, 53.09018237984023], [-10.672291131077577, 53.09741397083342], [-10.570637199241807, 53.10455162202915], [-10.468948517363296, 53.11159527844826], [-10.367225526514325, 53.118544885794726], [-10.265468668822653, 53.12540039045813], [-10.163678387453867, 53.13216173951542]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.163678&lt;dd&gt;Longitude: 53.132162&lt;dd&gt;Azimuth: 292.81596\u00b0&lt;dd&gt;Altitude: 36.435832\u00b0&lt;dd&gt;Slant Range: 729.29553km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.163678387453867, 53.13216173951542]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.672291131077577, 53.09741397083342], [-10.570637199241807, 53.10455162202915], [-10.468948517363296, 53.11159527844826], [-10.367225526514325, 53.118544885794726], [-10.265468668822653, 53.12540039045813], [-10.163678387453867, 53.13216173951542], [-10.061855126603524, 53.1388288807329]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -10.061855&lt;dd&gt;Longitude: 53.138829&lt;dd&gt;Azimuth: 293.10052\u00b0&lt;dd&gt;Altitude: 36.788614\u00b0&lt;dd&gt;Slant Range: 724.24048km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.061855126603524, 53.1388288807329]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.570637199241807, 53.10455162202915], [-10.468948517363296, 53.11159527844826], [-10.367225526514325, 53.118544885794726], [-10.265468668822653, 53.12540039045813], [-10.163678387453867, 53.13216173951542], [-10.061855126603524, 53.1388288807329], [-9.959999331476709, 53.14540176256839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.9599993&lt;dd&gt;Longitude: 53.145402&lt;dd&gt;Azimuth: 293.39167\u00b0&lt;dd&gt;Altitude: 37.145188\u00b0&lt;dd&gt;Slant Range: 719.21941km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.959999331476709, 53.14540176256839]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.468948517363296, 53.11159527844826], [-10.367225526514325, 53.118544885794726], [-10.265468668822653, 53.12540039045813], [-10.163678387453867, 53.13216173951542], [-10.061855126603524, 53.1388288807329], [-9.959999331476709, 53.14540176256839], [-9.858111448286978, 53.15188033417289]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.8581114&lt;dd&gt;Longitude: 53.15188&lt;dd&gt;Azimuth: 293.68963\u00b0&lt;dd&gt;Altitude: 37.505571\u00b0&lt;dd&gt;Slant Range: 714.23303km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.858111448286978, 53.15188033417289]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.367225526514325, 53.118544885794726], [-10.265468668822653, 53.12540039045813], [-10.163678387453867, 53.13216173951542], [-10.061855126603524, 53.1388288807329], [-9.959999331476709, 53.14540176256839], [-9.858111448286978, 53.15188033417289], [-9.75619192423271, 53.15826454539275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.7561919&lt;dd&gt;Longitude: 53.158265&lt;dd&gt;Azimuth: 293.99463\u00b0&lt;dd&gt;Altitude: 37.869779\u00b0&lt;dd&gt;Slant Range: 709.28207km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.75619192423271, 53.15826454539275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.265468668822653, 53.12540039045813], [-10.163678387453867, 53.13216173951542], [-10.061855126603524, 53.1388288807329], [-9.959999331476709, 53.14540176256839], [-9.858111448286978, 53.15188033417289], [-9.75619192423271, 53.15826454539275], [-9.654241207486956, 53.16455434677132]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.6542412&lt;dd&gt;Longitude: 53.164554&lt;dd&gt;Azimuth: 294.30692\u00b0&lt;dd&gt;Altitude: 38.237823\u00b0&lt;dd&gt;Slant Range: 704.36731km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.654241207486956, 53.16455434677132]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.163678387453867, 53.13216173951542], [-10.061855126603524, 53.1388288807329], [-9.959999331476709, 53.14540176256839], [-9.858111448286978, 53.15188033417289], [-9.75619192423271, 53.15826454539275], [-9.654241207486956, 53.16455434677132], [-9.552259747193226, 53.17074968955089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.5522597&lt;dd&gt;Longitude: 53.17075&lt;dd&gt;Azimuth: 294.62673\u00b0&lt;dd&gt;Altitude: 38.609711\u00b0&lt;dd&gt;Slant Range: 699.48949km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.552259747193226, 53.17074968955089]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.061855126603524, 53.1388288807329], [-9.959999331476709, 53.14540176256839], [-9.858111448286978, 53.15188033417289], [-9.75619192423271, 53.15826454539275], [-9.654241207486956, 53.16455434677132], [-9.552259747193226, 53.17074968955089], [-9.450247993440664, 53.17685052567484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.450248&lt;dd&gt;Longitude: 53.176851&lt;dd&gt;Azimuth: 294.95433\u00b0&lt;dd&gt;Altitude: 38.98545\u00b0&lt;dd&gt;Slant Range: 694.64941km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.450247993440664, 53.17685052567484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.959999331476709, 53.14540176256839], [-9.858111448286978, 53.15188033417289], [-9.75619192423271, 53.15826454539275], [-9.654241207486956, 53.16455434677132], [-9.552259747193226, 53.17074968955089], [-9.450247993440664, 53.17685052567484], [-9.348206397259661, 53.182856807788816]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.3482064&lt;dd&gt;Longitude: 53.182857&lt;dd&gt;Azimuth: 295.28999\u00b0&lt;dd&gt;Altitude: 39.365041\u00b0&lt;dd&gt;Slant Range: 689.84787km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.348206397259661, 53.182856807788816]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.858111448286978, 53.15188033417289], [-9.75619192423271, 53.15826454539275], [-9.654241207486956, 53.16455434677132], [-9.552259747193226, 53.17074968955089], [-9.450247993440664, 53.17685052567484], [-9.348206397259661, 53.182856807788816], [-9.246135410599578, 53.18876848924316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.2461354&lt;dd&gt;Longitude: 53.188768&lt;dd&gt;Azimuth: 295.63399\u00b0&lt;dd&gt;Altitude: 39.74848\u00b0&lt;dd&gt;Slant Range: 685.08567km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.246135410599578, 53.18876848924316]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.75619192423271, 53.15826454539275], [-9.654241207486956, 53.16455434677132], [-9.552259747193226, 53.17074968955089], [-9.450247993440664, 53.17685052567484], [-9.348206397259661, 53.182856807788816], [-9.246135410599578, 53.18876848924316], [-9.144035486332324, 53.19458552409429]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.1440355&lt;dd&gt;Longitude: 53.194586&lt;dd&gt;Azimuth: 295.98662\u00b0&lt;dd&gt;Altitude: 40.135761\u00b0&lt;dd&gt;Slant Range: 680.36366km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.144035486332324, 53.19458552409429]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.654241207486956, 53.16455434677132], [-9.552259747193226, 53.17074968955089], [-9.450247993440664, 53.17685052567484], [-9.348206397259661, 53.182856807788816], [-9.246135410599578, 53.18876848924316], [-9.144035486332324, 53.19458552409429], [-9.041907078216385, 53.20030786710663]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -9.0419071&lt;dd&gt;Longitude: 53.200308&lt;dd&gt;Azimuth: 296.34819\u00b0&lt;dd&gt;Altitude: 40.526872\u00b0&lt;dd&gt;Slant Range: 675.68268km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.041907078216385, 53.20030786710663]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.552259747193226, 53.17074968955089], [-9.450247993440664, 53.17685052567484], [-9.348206397259661, 53.182856807788816], [-9.246135410599578, 53.18876848924316], [-9.144035486332324, 53.19458552409429], [-9.041907078216385, 53.20030786710663], [-8.939750640903428, 53.205935473754096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-4790&lt;dd&gt;Latitude: -8.9397506&lt;dd&gt;Longitude: 53.205935&lt;dd&gt;Azimuth: 296.71903\u00b0&lt;dd&gt;Altitude: 40.921797\u00b0&lt;dd&gt;Slant Range: 671.0436km&quot;, &quot;name&quot;: &quot;STARLINK-4790&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.939750640903428, 53.205935473754096]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 1.7397466&lt;dd&gt;Longitude: 49.384067&lt;dd&gt;Azimuth: 125.11052\u00b0&lt;dd&gt;Altitude: 51.838981\u00b0&lt;dd&gt;Slant Range: 676.18755km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174], [1.824015560368354, 49.40915150211262]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 1.8240156&lt;dd&gt;Longitude: 49.409152&lt;dd&gt;Azimuth: 124.22599\u00b0&lt;dd&gt;Altitude: 51.605801\u00b0&lt;dd&gt;Slant Range: 678.11173km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.824015560368354, 49.40915150211262]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174], [1.824015560368354, 49.40915150211262], [1.9083744098282782, 49.434167988940104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 1.9083744&lt;dd&gt;Longitude: 49.434168&lt;dd&gt;Azimuth: 123.35569\u00b0&lt;dd&gt;Altitude: 51.367022\u00b0&lt;dd&gt;Slant Range: 680.10285km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9083744098282782, 49.434167988940104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174], [1.824015560368354, 49.40915150211262], [1.9083744098282782, 49.434167988940104], [1.992823096541509, 49.45911661209028]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 1.9928231&lt;dd&gt;Longitude: 49.459117&lt;dd&gt;Azimuth: 122.4997\u00b0&lt;dd&gt;Altitude: 51.122916\u00b0&lt;dd&gt;Slant Range: 682.16034km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.992823096541509, 49.45911661209028]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174], [1.824015560368354, 49.40915150211262], [1.9083744098282782, 49.434167988940104], [1.992823096541509, 49.45911661209028], [2.0773615464540724, 49.48399724416693]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.0773615&lt;dd&gt;Longitude: 49.483997&lt;dd&gt;Azimuth: 121.65802\u00b0&lt;dd&gt;Altitude: 50.873755\u00b0&lt;dd&gt;Slant Range: 684.28358km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0773615464540724, 49.48399724416693]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174], [1.824015560368354, 49.40915150211262], [1.9083744098282782, 49.434167988940104], [1.992823096541509, 49.45911661209028], [2.0773615464540724, 49.48399724416693], [2.161989684078327, 49.508809757812415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.1619897&lt;dd&gt;Longitude: 49.50881&lt;dd&gt;Azimuth: 120.83066\u00b0&lt;dd&gt;Altitude: 50.619807\u00b0&lt;dd&gt;Slant Range: 686.47197km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.161989684078327, 49.508809757812415]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7397466207764969, 49.384067279040174], [1.824015560368354, 49.40915150211262], [1.9083744098282782, 49.434167988940104], [1.992823096541509, 49.45911661209028], [2.0773615464540724, 49.48399724416693], [2.161989684078327, 49.508809757812415], [2.246707432476095, 49.53355402570983]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.2467074&lt;dd&gt;Longitude: 49.533554&lt;dd&gt;Azimuth: 120.0176\u00b0&lt;dd&gt;Altitude: 50.361336\u00b0&lt;dd&gt;Slant Range: 688.72488km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.246707432476095, 49.53355402570983]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.824015560368354, 49.40915150211262], [1.9083744098282782, 49.434167988940104], [1.992823096541509, 49.45911661209028], [2.0773615464540724, 49.48399724416693], [2.161989684078327, 49.508809757812415], [2.246707432476095, 49.53355402570983], [2.331514713268434, 49.55822992058459]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.3315147&lt;dd&gt;Longitude: 49.55823&lt;dd&gt;Azimuth: 119.21879\u00b0&lt;dd&gt;Altitude: 50.098602\u00b0&lt;dd&gt;Slant Range: 691.04168km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.331514713268434, 49.55822992058459]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9083744098282782, 49.434167988940104], [1.992823096541509, 49.45911661209028], [2.0773615464540724, 49.48399724416693], [2.161989684078327, 49.508809757812415], [2.246707432476095, 49.53355402570983], [2.331514713268434, 49.55822992058459], [2.416411446612327, 49.5828373152084]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.4164114&lt;dd&gt;Longitude: 49.582837&lt;dd&gt;Azimuth: 118.43418\u00b0&lt;dd&gt;Altitude: 49.831862\u00b0&lt;dd&gt;Slant Range: 693.42173km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.416411446612327, 49.5828373152084]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.992823096541509, 49.45911661209028], [2.0773615464540724, 49.48399724416693], [2.161989684078327, 49.508809757812415], [2.246707432476095, 49.53355402570983], [2.331514713268434, 49.55822992058459], [2.416411446612327, 49.5828373152084], [2.5013975512160536, 49.6073760823992]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.5013976&lt;dd&gt;Longitude: 49.607376&lt;dd&gt;Azimuth: 117.66366\u00b0&lt;dd&gt;Altitude: 49.561366\u00b0&lt;dd&gt;Slant Range: 695.86437km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.5013975512160536, 49.6073760823992]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.0773615464540724, 49.48399724416693], [2.161989684078327, 49.508809757812415], [2.246707432476095, 49.53355402570983], [2.331514713268434, 49.55822992058459], [2.416411446612327, 49.5828373152084], [2.5013975512160536, 49.6073760823992], [2.586472944314024, 49.63184609502606]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.5864729&lt;dd&gt;Longitude: 49.631846&lt;dd&gt;Azimuth: 116.90715\u00b0&lt;dd&gt;Altitude: 49.28736\u00b0&lt;dd&gt;Slant Range: 698.36894km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.586472944314024, 49.63184609502606]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.161989684078327, 49.508809757812415], [2.246707432476095, 49.53355402570983], [2.331514713268434, 49.55822992058459], [2.416411446612327, 49.5828373152084], [2.5013975512160536, 49.6073760823992], [2.586472944314024, 49.63184609502606], [2.671637541681053, 49.65624722600872]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.6716375&lt;dd&gt;Longitude: 49.656247&lt;dd&gt;Azimuth: 116.16452\u00b0&lt;dd&gt;Altitude: 49.010085\u00b0&lt;dd&gt;Slant Range: 700.93478km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.671637541681053, 49.65624722600872]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.246707432476095, 49.53355402570983], [2.331514713268434, 49.55822992058459], [2.416411446612327, 49.5828373152084], [2.5013975512160536, 49.6073760823992], [2.586472944314024, 49.63184609502606], [2.671637541681053, 49.65624722600872], [2.7568912576124136, 49.68057934832213]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.7568913&lt;dd&gt;Longitude: 49.680579&lt;dd&gt;Azimuth: 115.43564\u00b0&lt;dd&gt;Altitude: 48.729774\u00b0&lt;dd&gt;Slant Range: 703.56122km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.7568912576124136, 49.68057934832213]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.331514713268434, 49.55822992058459], [2.416411446612327, 49.5828373152084], [2.5013975512160536, 49.6073760823992], [2.586472944314024, 49.63184609502606], [2.671637541681053, 49.65624722600872], [2.7568912576124136, 49.68057934832213], [2.8422340049236823, 49.7048423349976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.842234&lt;dd&gt;Longitude: 49.704842&lt;dd&gt;Azimuth: 114.72036\u00b0&lt;dd&gt;Altitude: 48.446655\u00b0&lt;dd&gt;Slant Range: 706.24757km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.8422340049236823, 49.7048423349976]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.416411446612327, 49.5828373152084], [2.5013975512160536, 49.6073760823992], [2.586472944314024, 49.63184609502606], [2.671637541681053, 49.65624722600872], [2.7568912576124136, 49.68057934832213], [2.8422340049236823, 49.7048423349976], [2.927665694956032, 49.72903605912576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 2.9276657&lt;dd&gt;Longitude: 49.729036&lt;dd&gt;Azimuth: 114.01853\u00b0&lt;dd&gt;Altitude: 48.160952\u00b0&lt;dd&gt;Slant Range: 708.99315km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.927665694956032, 49.72903605912576]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.5013975512160536, 49.6073760823992], [2.586472944314024, 49.63184609502606], [2.671637541681053, 49.65624722600872], [2.7568912576124136, 49.68057934832213], [2.8422340049236823, 49.7048423349976], [2.927665694956032, 49.72903605912576], [3.013186237550737, 49.753160393857655]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.0131862&lt;dd&gt;Longitude: 49.75316&lt;dd&gt;Azimuth: 113.32997\u00b0&lt;dd&gt;Altitude: 47.87288\u00b0&lt;dd&gt;Slant Range: 711.79727km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.013186237550737, 49.753160393857655]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.586472944314024, 49.63184609502606], [2.671637541681053, 49.65624722600872], [2.7568912576124136, 49.68057934832213], [2.8422340049236823, 49.7048423349976], [2.927665694956032, 49.72903605912576], [3.013186237550737, 49.753160393857655], [3.0987955410672394, 49.77721521240929]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.0987955&lt;dd&gt;Longitude: 49.777215&lt;dd&gt;Azimuth: 112.65452\u00b0&lt;dd&gt;Altitude: 47.582649\u00b0&lt;dd&gt;Slant Range: 714.65925km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.0987955410672394, 49.77721521240929]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.671637541681053, 49.65624722600872], [2.7568912576124136, 49.68057934832213], [2.8422340049236823, 49.7048423349976], [2.927665694956032, 49.72903605912576], [3.013186237550737, 49.753160393857655], [3.0987955410672394, 49.77721521240929], [3.184493512358236, 49.801200388061524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.1844935&lt;dd&gt;Longitude: 49.8012&lt;dd&gt;Azimuth: 111.99199\u00b0&lt;dd&gt;Altitude: 47.290461\u00b0&lt;dd&gt;Slant Range: 717.57838km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.184493512358236, 49.801200388061524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.7568912576124136, 49.68057934832213], [2.8422340049236823, 49.7048423349976], [2.927665694956032, 49.72903605912576], [3.013186237550737, 49.753160393857655], [3.0987955410672394, 49.77721521240929], [3.184493512358236, 49.801200388061524], [3.270280056781718, 49.82511579416426]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.2702801&lt;dd&gt;Longitude: 49.825116&lt;dd&gt;Azimuth: 111.34218\u00b0&lt;dd&gt;Altitude: 46.996512\u00b0&lt;dd&gt;Slant Range: 720.55396km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.270280056781718, 49.82511579416426]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.8422340049236823, 49.7048423349976], [2.927665694956032, 49.72903605912576], [3.013186237550737, 49.753160393857655], [3.0987955410672394, 49.77721521240929], [3.184493512358236, 49.801200388061524], [3.270280056781718, 49.82511579416426], [3.356155078183537, 49.84896130413803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.3561551&lt;dd&gt;Longitude: 49.848961&lt;dd&gt;Azimuth: 110.70489\u00b0&lt;dd&gt;Altitude: 46.700992\u00b0&lt;dd&gt;Slant Range: 723.58531km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.356155078183537, 49.84896130413803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[2.927665694956032, 49.72903605912576], [3.013186237550737, 49.753160393857655], [3.0987955410672394, 49.77721521240929], [3.184493512358236, 49.801200388061524], [3.270280056781718, 49.82511579416426], [3.356155078183537, 49.84896130413803], [3.4421184789041774, 49.87273679147677]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.4421185&lt;dd&gt;Longitude: 49.872737&lt;dd&gt;Azimuth: 110.07993\u00b0&lt;dd&gt;Altitude: 46.404085\u00b0&lt;dd&gt;Slant Range: 726.6717km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.4421184789041774, 49.87273679147677]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.013186237550737, 49.753160393857655], [3.0987955410672394, 49.77721521240929], [3.184493512358236, 49.801200388061524], [3.270280056781718, 49.82511579416426], [3.356155078183537, 49.84896130413803], [3.4421184789041774, 49.87273679147677], [3.5281701597587016, 49.89644212974903]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.5281702&lt;dd&gt;Longitude: 49.896442&lt;dd&gt;Azimuth: 109.46709\u00b0&lt;dd&gt;Altitude: 46.105967\u00b0&lt;dd&gt;Slant Range: 729.81246km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.5281701597587016, 49.89644212974903]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.0987955410672394, 49.77721521240929], [3.184493512358236, 49.801200388061524], [3.270280056781718, 49.82511579416426], [3.356155078183537, 49.84896130413803], [3.4421184789041774, 49.87273679147677], [3.5281701597587016, 49.89644212974903], [3.614310020055533, 49.92007719260273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.61431&lt;dd&gt;Longitude: 49.920077&lt;dd&gt;Azimuth: 108.86615\u00b0&lt;dd&gt;Altitude: 45.806807\u00b0&lt;dd&gt;Slant Range: 733.00686km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.614310020055533, 49.92007719260273]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.184493512358236, 49.801200388061524], [3.270280056781718, 49.82511579416426], [3.356155078183537, 49.84896130413803], [3.4421184789041774, 49.87273679147677], [3.5281701597587016, 49.89644212974903], [3.614310020055533, 49.92007719260273], [3.7005379575656137, 49.94364185376477]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.700538&lt;dd&gt;Longitude: 49.943642&lt;dd&gt;Azimuth: 108.2769\u00b0&lt;dd&gt;Altitude: 45.50677\u00b0&lt;dd&gt;Slant Range: 736.25421km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.7005379575656137, 49.94364185376477]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.270280056781718, 49.82511579416426], [3.356155078183537, 49.84896130413803], [3.4421184789041774, 49.87273679147677], [3.5281701597587016, 49.89644212974903], [3.614310020055533, 49.92007719260273], [3.7005379575656137, 49.94364185376477], [3.786853868537646, 49.96713598704639]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.7868539&lt;dd&gt;Longitude: 49.967136&lt;dd&gt;Azimuth: 107.69914\u00b0&lt;dd&gt;Altitude: 45.206011\u00b0&lt;dd&gt;Slant Range: 739.55381km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.786853868537646, 49.96713598704639]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.356155078183537, 49.84896130413803], [3.4421184789041774, 49.87273679147677], [3.5281701597587016, 49.89644212974903], [3.614310020055533, 49.92007719260273], [3.7005379575656137, 49.94364185376477], [3.786853868537646, 49.96713598704639], [3.873257647684025, 49.99055946634269]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.8732576&lt;dd&gt;Longitude: 49.990559&lt;dd&gt;Azimuth: 107.13264\u00b0&lt;dd&gt;Altitude: 44.904682\u00b0&lt;dd&gt;Slant Range: 742.90496km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.873257647684025, 49.99055946634269]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.4421184789041774, 49.87273679147677], [3.5281701597587016, 49.89644212974903], [3.614310020055533, 49.92007719260273], [3.7005379575656137, 49.94364185376477], [3.786853868537646, 49.96713598704639], [3.873257647684025, 49.99055946634269], [3.959749188181724, 50.01391216563723]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 3.9597492&lt;dd&gt;Longitude: 50.013912&lt;dd&gt;Azimuth: 106.57719\u00b0&lt;dd&gt;Altitude: 44.602928\u00b0&lt;dd&gt;Slant Range: 746.30696km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.959749188181724, 50.01391216563723]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.5281701597587016, 49.89644212974903], [3.614310020055533, 49.92007719260273], [3.7005379575656137, 49.94364185376477], [3.786853868537646, 49.96713598704639], [3.873257647684025, 49.99055946634269], [3.959749188181724, 50.01391216563723], [4.046328381659907, 50.037193959003645]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.0463284&lt;dd&gt;Longitude: 50.037194&lt;dd&gt;Azimuth: 106.03257\u00b0&lt;dd&gt;Altitude: 44.300885\u00b0&lt;dd&gt;Slant Range: 749.75911km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.046328381659907, 50.037193959003645]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.614310020055533, 49.92007719260273], [3.7005379575656137, 49.94364185376477], [3.786853868537646, 49.96713598704639], [3.873257647684025, 49.99055946634269], [3.959749188181724, 50.01391216563723], [4.046328381659907, 50.037193959003645], [4.132995118211658, 50.06040472060821]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.1329951&lt;dd&gt;Longitude: 50.060405&lt;dd&gt;Azimuth: 105.49856\u00b0&lt;dd&gt;Altitude: 43.998687\u00b0&lt;dd&gt;Slant Range: 753.26072km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.132995118211658, 50.06040472060821]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.7005379575656137, 49.94364185376477], [3.786853868537646, 49.96713598704639], [3.873257647684025, 49.99055946634269], [3.959749188181724, 50.01391216563723], [4.046328381659907, 50.037193959003645], [4.132995118211658, 50.06040472060821], [4.219749286365685, 50.08354432471224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.2197493&lt;dd&gt;Longitude: 50.083544&lt;dd&gt;Azimuth: 104.97495\u00b0&lt;dd&gt;Altitude: 43.69646\u00b0&lt;dd&gt;Slant Range: 756.8111km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.219749286365685, 50.08354432471224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.786853868537646, 49.96713598704639], [3.873257647684025, 49.99055946634269], [3.959749188181724, 50.01391216563723], [4.046328381659907, 50.037193959003645], [4.132995118211658, 50.06040472060821], [4.219749286365685, 50.08354432471224], [4.306590773107237, 50.106612645675014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.3065908&lt;dd&gt;Longitude: 50.106613&lt;dd&gt;Azimuth: 104.46154\u00b0&lt;dd&gt;Altitude: 43.394325\u00b0&lt;dd&gt;Slant Range: 760.40957km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.306590773107237, 50.106612645675014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.873257647684025, 49.99055946634269], [3.959749188181724, 50.01391216563723], [4.046328381659907, 50.037193959003645], [4.132995118211658, 50.06040472060821], [4.219749286365685, 50.08354432471224], [4.306590773107237, 50.106612645675014], [4.393519463852428, 50.12960955795535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.3935195&lt;dd&gt;Longitude: 50.12961&lt;dd&gt;Azimuth: 103.95809\u00b0&lt;dd&gt;Altitude: 43.092395\u00b0&lt;dd&gt;Slant Range: 764.05543km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.393519463852428, 50.12960955795535]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.959749188181724, 50.01391216563723], [4.046328381659907, 50.037193959003645], [4.132995118211658, 50.06040472060821], [4.219749286365685, 50.08354432471224], [4.306590773107237, 50.106612645675014], [4.393519463852428, 50.12960955795535], [4.480535242468217, 50.152534936115664]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.4805352&lt;dd&gt;Longitude: 50.152535&lt;dd&gt;Azimuth: 103.46441\u00b0&lt;dd&gt;Altitude: 42.790782\u00b0&lt;dd&gt;Slant Range: 767.74802km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.480535242468217, 50.152534936115664]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.046328381659907, 50.037193959003645], [4.132995118211658, 50.06040472060821], [4.219749286365685, 50.08354432471224], [4.306590773107237, 50.106612645675014], [4.393519463852428, 50.12960955795535], [4.480535242468217, 50.152534936115664], [4.567637991236523, 50.17538865482239]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.567638&lt;dd&gt;Longitude: 50.175389&lt;dd&gt;Azimuth: 102.98029\u00b0&lt;dd&gt;Altitude: 42.489588\u00b0&lt;dd&gt;Slant Range: 771.48665km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.567637991236523, 50.17538865482239]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.132995118211658, 50.06040472060821], [4.219749286365685, 50.08354432471224], [4.306590773107237, 50.106612645675014], [4.393519463852428, 50.12960955795535], [4.480535242468217, 50.152534936115664], [4.567637991236523, 50.17538865482239], [4.654827590882323, 50.19817058885069]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.6548276&lt;dd&gt;Longitude: 50.198171&lt;dd&gt;Azimuth: 102.50552\u00b0&lt;dd&gt;Altitude: 42.188914\u00b0&lt;dd&gt;Slant Range: 775.27065km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.654827590882323, 50.19817058885069]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.219749286365685, 50.08354432471224], [4.306590773107237, 50.106612645675014], [4.393519463852428, 50.12960955795535], [4.480535242468217, 50.152534936115664], [4.567637991236523, 50.17538865482239], [4.654827590882323, 50.19817058885069], [4.742103920546115, 50.22088061308533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.7421039&lt;dd&gt;Longitude: 50.220881&lt;dd&gt;Azimuth: 102.0399\u00b0&lt;dd&gt;Altitude: 41.888852\u00b0&lt;dd&gt;Slant Range: 779.09936km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.742103920546115, 50.22088061308533]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.306590773107237, 50.106612645675014], [4.393519463852428, 50.12960955795535], [4.480535242468217, 50.152534936115664], [4.567637991236523, 50.17538865482239], [4.654827590882323, 50.19817058885069], [4.742103920546115, 50.22088061308533], [4.829466857797053, 50.24351860252459]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.8294669&lt;dd&gt;Longitude: 50.243519&lt;dd&gt;Azimuth: 101.58322\u00b0&lt;dd&gt;Altitude: 41.589492\u00b0&lt;dd&gt;Slant Range: 782.97212km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.829466857797053, 50.24351860252459]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.393519463852428, 50.12960955795535], [4.480535242468217, 50.152534936115664], [4.567637991236523, 50.17538865482239], [4.654827590882323, 50.19817058885069], [4.742103920546115, 50.22088061308533], [4.829466857797053, 50.24351860252459], [4.916916278610146, 50.266084432280934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 4.9169163&lt;dd&gt;Longitude: 50.266084&lt;dd&gt;Azimuth: 101.1353\u00b0&lt;dd&gt;Altitude: 41.290918\u00b0&lt;dd&gt;Slant Range: 786.88827km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[4.916916278610146, 50.266084432280934]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.480535242468217, 50.152534936115664], [4.567637991236523, 50.17538865482239], [4.654827590882323, 50.19817058885069], [4.742103920546115, 50.22088061308533], [4.829466857797053, 50.24351860252459], [4.916916278610146, 50.266084432280934], [5.00445205738712, 50.288577977586414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 5.0044521&lt;dd&gt;Longitude: 50.288578&lt;dd&gt;Azimuth: 100.69593\u00b0&lt;dd&gt;Altitude: 40.993209\u00b0&lt;dd&gt;Slant Range: 790.84717km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.00445205738712, 50.288577977586414]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[4.567637991236523, 50.17538865482239], [4.654827590882323, 50.19817058885069], [4.742103920546115, 50.22088061308533], [4.829466857797053, 50.24351860252459], [4.916916278610146, 50.266084432280934], [5.00445205738712, 50.288577977586414], [5.0920740669306985, 50.310999113792114]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5024&lt;dd&gt;Latitude: 5.0920741&lt;dd&gt;Longitude: 50.310999&lt;dd&gt;Azimuth: 100.26493\u00b0&lt;dd&gt;Altitude: 40.696442\u00b0&lt;dd&gt;Slant Range: 794.84817km&quot;, &quot;name&quot;: &quot;STARLINK-5024&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[5.0920740669306985, 50.310999113792114]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -8.225665&lt;dd&gt;Longitude: 49.189896&lt;dd&gt;Azimuth: 239.96335\u00b0&lt;dd&gt;Altitude: 42.445764\u00b0&lt;dd&gt;Slant Range: 689.16647km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767], [-8.14093256160896, 49.215835761165565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -8.1409326&lt;dd&gt;Longitude: 49.215836&lt;dd&gt;Azimuth: 239.8281\u00b0&lt;dd&gt;Altitude: 42.886713\u00b0&lt;dd&gt;Slant Range: 684.22608km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.14093256160896, 49.215835761165565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767], [-8.14093256160896, 49.215835761165565], [-8.056107325718603, 49.24170743537262]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -8.0561073&lt;dd&gt;Longitude: 49.241707&lt;dd&gt;Azimuth: 239.68881\u00b0&lt;dd&gt;Altitude: 43.333426\u00b0&lt;dd&gt;Slant Range: 679.32319km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.056107325718603, 49.24170743537262]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767], [-8.14093256160896, 49.215835761165565], [-8.056107325718603, 49.24170743537262], [-7.971189315537799, 49.26751044936154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.9711893&lt;dd&gt;Longitude: 49.26751&lt;dd&gt;Azimuth: 239.5453\u00b0&lt;dd&gt;Altitude: 43.785975\u00b0&lt;dd&gt;Slant Range: 674.45865km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.971189315537799, 49.26751044936154]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767], [-8.14093256160896, 49.215835761165565], [-8.056107325718603, 49.24170743537262], [-7.971189315537799, 49.26751044936154], [-7.886178596734468, 49.29324467037472]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.8861786&lt;dd&gt;Longitude: 49.293245&lt;dd&gt;Azimuth: 239.39738\u00b0&lt;dd&gt;Altitude: 44.244427\u00b0&lt;dd&gt;Slant Range: 669.63329km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.886178596734468, 49.29324467037472]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767], [-8.14093256160896, 49.215835761165565], [-8.056107325718603, 49.24170743537262], [-7.971189315537799, 49.26751044936154], [-7.886178596734468, 49.29324467037472], [-7.801075236445361, 49.3189099656776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.8010752&lt;dd&gt;Longitude: 49.31891&lt;dd&gt;Azimuth: 239.24485\u00b0&lt;dd&gt;Altitude: 44.70885\u00b0&lt;dd&gt;Slant Range: 664.84797km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.801075236445361, 49.3189099656776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.225664959017719, 49.18989555951767], [-8.14093256160896, 49.215835761165565], [-8.056107325718603, 49.24170743537262], [-7.971189315537799, 49.26751044936154], [-7.886178596734468, 49.29324467037472], [-7.801075236445361, 49.3189099656776], [-7.715879303293922, 49.34450620256082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.7158793&lt;dd&gt;Longitude: 49.344506&lt;dd&gt;Azimuth: 239.0875\u00b0&lt;dd&gt;Altitude: 45.179307\u00b0&lt;dd&gt;Slant Range: 660.10357km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.715879303293922, 49.34450620256082]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.14093256160896, 49.215835761165565], [-8.056107325718603, 49.24170743537262], [-7.971189315537799, 49.26751044936154], [-7.886178596734468, 49.29324467037472], [-7.801075236445361, 49.3189099656776], [-7.715879303293922, 49.34450620256082], [-7.630590867381663, 49.37003324834168]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.6305909&lt;dd&gt;Longitude: 49.370033&lt;dd&gt;Azimuth: 238.92511\u00b0&lt;dd&gt;Altitude: 45.655863\u00b0&lt;dd&gt;Slant Range: 655.40098km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.630590867381663, 49.37003324834168]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.056107325718603, 49.24170743537262], [-7.971189315537799, 49.26751044936154], [-7.886178596734468, 49.29324467037472], [-7.801075236445361, 49.3189099656776], [-7.715879303293922, 49.34450620256082], [-7.630590867381663, 49.37003324834168], [-7.545210000312132, 49.395490970368144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.54521&lt;dd&gt;Longitude: 49.395491&lt;dd&gt;Azimuth: 238.75743\u00b0&lt;dd&gt;Altitude: 46.138577\u00b0&lt;dd&gt;Slant Range: 650.74111km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.545210000312132, 49.395490970368144]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.971189315537799, 49.26751044936154], [-7.886178596734468, 49.29324467037472], [-7.801075236445361, 49.3189099656776], [-7.715879303293922, 49.34450620256082], [-7.630590867381663, 49.37003324834168], [-7.545210000312132, 49.395490970368144], [-7.4597367751756956, 49.42087923601889]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.4597368&lt;dd&gt;Longitude: 49.420879&lt;dd&gt;Azimuth: 238.58421\u00b0&lt;dd&gt;Altitude: 46.627509\u00b0&lt;dd&gt;Slant Range: 646.12489km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.4597367751756956, 49.42087923601889]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.886178596734468, 49.29324467037472], [-7.801075236445361, 49.3189099656776], [-7.715879303293922, 49.34450620256082], [-7.630590867381663, 49.37003324834168], [-7.545210000312132, 49.395490970368144], [-7.4597367751756956, 49.42087923601889], [-7.374171266576133, 49.446197912708136]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.3741713&lt;dd&gt;Longitude: 49.446198&lt;dd&gt;Azimuth: 238.40519\u00b0&lt;dd&gt;Altitude: 47.122714\u00b0&lt;dd&gt;Slant Range: 641.55327km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.374171266576133, 49.446197912708136]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.801075236445361, 49.3189099656776], [-7.715879303293922, 49.34450620256082], [-7.630590867381663, 49.37003324834168], [-7.545210000312132, 49.395490970368144], [-7.4597367751756956, 49.42087923601889], [-7.374171266576133, 49.446197912708136], [-7.288513550613787, 49.47144686788608]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.2885136&lt;dd&gt;Longitude: 49.471447&lt;dd&gt;Azimuth: 238.22006\u00b0&lt;dd&gt;Altitude: 47.624244\u00b0&lt;dd&gt;Slant Range: 637.02721km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.288513550613787, 49.47144686788608]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.715879303293922, 49.34450620256082], [-7.630590867381663, 49.37003324834168], [-7.545210000312132, 49.395490970368144], [-7.4597367751756956, 49.42087923601889], [-7.374171266576133, 49.446197912708136], [-7.288513550613787, 49.47144686788608], [-7.202763704912078, 49.49662596904178]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.2027637&lt;dd&gt;Longitude: 49.496626&lt;dd&gt;Azimuth: 238.02853\u00b0&lt;dd&gt;Altitude: 48.132147\u00b0&lt;dd&gt;Slant Range: 632.5477km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.202763704912078, 49.49662596904178]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.630590867381663, 49.37003324834168], [-7.545210000312132, 49.395490970368144], [-7.4597367751756956, 49.42087923601889], [-7.374171266576133, 49.446197912708136], [-7.288513550613787, 49.47144686788608], [-7.202763704912078, 49.49662596904178], [-7.116921808611274, 49.52173508370641]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.1169218&lt;dd&gt;Longitude: 49.521735&lt;dd&gt;Azimuth: 237.83026\u00b0&lt;dd&gt;Altitude: 48.64647\u00b0&lt;dd&gt;Slant Range: 628.11574km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.116921808611274, 49.52173508370641]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.545210000312132, 49.395490970368144], [-7.4597367751756956, 49.42087923601889], [-7.374171266576133, 49.446197912708136], [-7.288513550613787, 49.47144686788608], [-7.202763704912078, 49.49662596904178], [-7.116921808611274, 49.52173508370641], [-7.030987942370241, 49.5467740794544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -7.0309879&lt;dd&gt;Longitude: 49.546774&lt;dd&gt;Azimuth: 237.62491\u00b0&lt;dd&gt;Altitude: 49.167254\u00b0&lt;dd&gt;Slant Range: 623.73234km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.030987942370241, 49.5467740794544]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.4597367751756956, 49.42087923601889], [-7.374171266576133, 49.446197912708136], [-7.288513550613787, 49.47144686788608], [-7.202763704912078, 49.49662596904178], [-7.116921808611274, 49.52173508370641], [-7.030987942370241, 49.5467740794544], [-6.944962188386241, 49.57174282390637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.9449622&lt;dd&gt;Longitude: 49.571743&lt;dd&gt;Azimuth: 237.4121\u00b0&lt;dd&gt;Altitude: 49.694534\u00b0&lt;dd&gt;Slant Range: 619.39855km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.944962188386241, 49.57174282390637]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.374171266576133, 49.446197912708136], [-7.288513550613787, 49.47144686788608], [-7.202763704912078, 49.49662596904178], [-7.116921808611274, 49.52173508370641], [-7.030987942370241, 49.5467740794544], [-6.944962188386241, 49.57174282390637], [-6.858844630382645, 49.59664118473233]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.8588446&lt;dd&gt;Longitude: 49.596641&lt;dd&gt;Azimuth: 237.19143\u00b0&lt;dd&gt;Altitude: 50.228341\u00b0&lt;dd&gt;Slant Range: 615.11541km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.858844630382645, 49.59664118473233]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.288513550613787, 49.47144686788608], [-7.202763704912078, 49.49662596904178], [-7.116921808611274, 49.52173508370641], [-7.030987942370241, 49.5467740794544], [-6.944962188386241, 49.57174282390637], [-6.858844630382645, 49.59664118473233], [-6.772635353632082, 49.62146902965223]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.7726354&lt;dd&gt;Longitude: 49.621469&lt;dd&gt;Azimuth: 236.96247\u00b0&lt;dd&gt;Altitude: 50.768702\u00b0&lt;dd&gt;Slant Range: 610.884km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.772635353632082, 49.62146902965223]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.202763704912078, 49.49662596904178], [-7.116921808611274, 49.52173508370641], [-7.030987942370241, 49.5467740794544], [-6.944962188386241, 49.57174282390637], [-6.858844630382645, 49.59664118473233], [-6.772635353632082, 49.62146902965223], [-6.686334444944866, 49.646226226440355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.6863344&lt;dd&gt;Longitude: 49.646226&lt;dd&gt;Azimuth: 236.72475\u00b0&lt;dd&gt;Altitude: 51.315637\u00b0&lt;dd&gt;Slant Range: 606.7054km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.686334444944866, 49.646226226440355]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.116921808611274, 49.52173508370641], [-7.030987942370241, 49.5467740794544], [-6.944962188386241, 49.57174282390637], [-6.858844630382645, 49.59664118473233], [-6.772635353632082, 49.62146902965223], [-6.686334444944866, 49.646226226440355], [-6.599941992687774, 49.67091264292662]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.599942&lt;dd&gt;Longitude: 49.670913&lt;dd&gt;Azimuth: 236.47778\u00b0&lt;dd&gt;Altitude: 51.869158\u00b0&lt;dd&gt;Slant Range: 602.58072km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.599941992687774, 49.67091264292662]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.030987942370241, 49.5467740794544], [-6.944962188386241, 49.57174282390637], [-6.858844630382645, 49.59664118473233], [-6.772635353632082, 49.62146902965223], [-6.686334444944866, 49.646226226440355], [-6.599941992687774, 49.67091264292662], [-6.513458086778469, 49.69552814699944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.5134581&lt;dd&gt;Longitude: 49.695528&lt;dd&gt;Azimuth: 236.22103\u00b0&lt;dd&gt;Altitude: 52.429271\u00b0&lt;dd&gt;Slant Range: 598.51108km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.513458086778469, 49.69552814699944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.944962188386241, 49.57174282390637], [-6.858844630382645, 49.59664118473233], [-6.772635353632082, 49.62146902965223], [-6.686334444944866, 49.646226226440355], [-6.599941992687774, 49.67091264292662], [-6.513458086778469, 49.69552814699944], [-6.426882818702809, 49.72007260660776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.4268828&lt;dd&gt;Longitude: 49.720073&lt;dd&gt;Azimuth: 235.95392\u00b0&lt;dd&gt;Altitude: 52.995974\u00b0&lt;dd&gt;Slant Range: 594.4976km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.426882818702809, 49.72007260660776]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.858844630382645, 49.59664118473233], [-6.772635353632082, 49.62146902965223], [-6.686334444944866, 49.646226226440355], [-6.599941992687774, 49.67091264292662], [-6.513458086778469, 49.69552814699944], [-6.426882818702809, 49.72007260660776], [-6.340216281500286, 49.744545889765014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.3402163&lt;dd&gt;Longitude: 49.744546&lt;dd&gt;Azimuth: 235.67583\u00b0&lt;dd&gt;Altitude: 53.569258\u00b0&lt;dd&gt;Slant Range: 590.54145km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.340216281500286, 49.744545889765014]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.772635353632082, 49.62146902965223], [-6.686334444944866, 49.646226226440355], [-6.599941992687774, 49.67091264292662], [-6.513458086778469, 49.69552814699944], [-6.426882818702809, 49.72007260660776], [-6.340216281500286, 49.744545889765014], [-6.253458569794898, 49.76894786454885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.2534586&lt;dd&gt;Longitude: 49.768948&lt;dd&gt;Azimuth: 235.3861\u00b0&lt;dd&gt;Altitude: 54.149101\u00b0&lt;dd&gt;Slant Range: 586.64378km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.253458569794898, 49.76894786454885]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.686334444944866, 49.646226226440355], [-6.599941992687774, 49.67091264292662], [-6.513458086778469, 49.69552814699944], [-6.426882818702809, 49.72007260660776], [-6.340216281500286, 49.744545889765014], [-6.253458569794898, 49.76894786454885], [-6.166609779780254, 49.79327839910684]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.1666098&lt;dd&gt;Longitude: 49.793278&lt;dd&gt;Azimuth: 235.08399\u00b0&lt;dd&gt;Altitude: 54.735476\u00b0&lt;dd&gt;Slant Range: 582.80577km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.166609779780254, 49.79327839910684]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.599941992687774, 49.67091264292662], [-6.513458086778469, 49.69552814699944], [-6.426882818702809, 49.72007260660776], [-6.340216281500286, 49.744545889765014], [-6.253458569794898, 49.76894786454885], [-6.166609779780254, 49.79327839910684], [-6.0796700092313145, 49.8175373616566]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -6.07967&lt;dd&gt;Longitude: 49.817537&lt;dd&gt;Azimuth: 234.76873\u00b0&lt;dd&gt;Altitude: 55.32834\u00b0&lt;dd&gt;Slant Range: 579.02861km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.0796700092313145, 49.8175373616566]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.513458086778469, 49.69552814699944], [-6.426882818702809, 49.72007260660776], [-6.340216281500286, 49.744545889765014], [-6.253458569794898, 49.76894786454885], [-6.166609779780254, 49.79327839910684], [-6.0796700092313145, 49.8175373616566], [-5.99263935750797, 49.8417246204896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.9926394&lt;dd&gt;Longitude: 49.841725&lt;dd&gt;Azimuth: 234.43947\u00b0&lt;dd&gt;Altitude: 55.927641\u00b0&lt;dd&gt;Slant Range: 575.31351km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.99263935750797, 49.8417246204896]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.426882818702809, 49.72007260660776], [-6.340216281500286, 49.744545889765014], [-6.253458569794898, 49.76894786454885], [-6.166609779780254, 49.79327839910684], [-6.0796700092313145, 49.8175373616566], [-5.99263935750797, 49.8417246204896], [-5.905517925567541, 49.86584004397294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.9055179&lt;dd&gt;Longitude: 49.86584&lt;dd&gt;Azimuth: 234.09528\u00b0&lt;dd&gt;Altitude: 56.533315\u00b0&lt;dd&gt;Slant Range: 571.66167km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.905517925567541, 49.86584004397294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.340216281500286, 49.744545889765014], [-6.253458569794898, 49.76894786454885], [-6.166609779780254, 49.79327839910684], [-6.0796700092313145, 49.8175373616566], [-5.99263935750797, 49.8417246204896], [-5.905517925567541, 49.86584004397294], [-5.818305815951721, 49.889883500552635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.8183058&lt;dd&gt;Longitude: 49.889884&lt;dd&gt;Azimuth: 233.73517\u00b0&lt;dd&gt;Altitude: 57.145282\u00b0&lt;dd&gt;Slant Range: 568.07433km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.818305815951721, 49.889883500552635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.253458569794898, 49.76894786454885], [-6.166609779780254, 49.79327839910684], [-6.0796700092313145, 49.8175373616566], [-5.99263935750797, 49.8417246204896], [-5.905517925567541, 49.86584004397294], [-5.818305815951721, 49.889883500552635], [-5.731003132815431, 49.91385485875585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.7310031&lt;dd&gt;Longitude: 49.913855&lt;dd&gt;Azimuth: 233.35805\u00b0&lt;dd&gt;Altitude: 57.763448\u00b0&lt;dd&gt;Slant Range: 564.55272km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.731003132815431, 49.91385485875585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.166609779780254, 49.79327839910684], [-6.0796700092313145, 49.8175373616566], [-5.99263935750797, 49.8417246204896], [-5.905517925567541, 49.86584004397294], [-5.818305815951721, 49.889883500552635], [-5.731003132815431, 49.91385485875585], [-5.643609981909621, 49.937753987193325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.64361&lt;dd&gt;Longitude: 49.937754&lt;dd&gt;Azimuth: 232.96272\u00b0&lt;dd&gt;Altitude: 58.387701\u00b0&lt;dd&gt;Slant Range: 561.09807km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.643609981909621, 49.937753987193325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.0796700092313145, 49.8175373616566], [-5.99263935750797, 49.8417246204896], [-5.905517925567541, 49.86584004397294], [-5.818305815951721, 49.889883500552635], [-5.731003132815431, 49.91385485875585], [-5.643609981909621, 49.937753987193325], [-5.556126470604498, 49.961580754561766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.5561265&lt;dd&gt;Longitude: 49.961581&lt;dd&gt;Azimuth: 232.54789\u00b0&lt;dd&gt;Altitude: 59.017912\u00b0&lt;dd&gt;Slant Range: 557.71164km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.556126470604498, 49.961580754561766]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.99263935750797, 49.8417246204896], [-5.905517925567541, 49.86584004397294], [-5.818305815951721, 49.889883500552635], [-5.731003132815431, 49.91385485875585], [-5.643609981909621, 49.937753987193325], [-5.556126470604498, 49.961580754561766], [-5.468552707871492, 49.985335029647565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.4685527&lt;dd&gt;Longitude: 49.985335&lt;dd&gt;Azimuth: 232.11214\u00b0&lt;dd&gt;Altitude: 59.653934\u00b0&lt;dd&gt;Slant Range: 554.39468km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.468552707871492, 49.985335029647565]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.905517925567541, 49.86584004397294], [-5.818305815951721, 49.889883500552635], [-5.731003132815431, 49.91385485875585], [-5.643609981909621, 49.937753987193325], [-5.556126470604498, 49.961580754561766], [-5.468552707871492, 49.985335029647565], [-5.38088880431734, 50.00901668132807]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.3808888&lt;dd&gt;Longitude: 50.009017&lt;dd&gt;Azimuth: 231.65391\u00b0&lt;dd&gt;Altitude: 60.295597\u00b0&lt;dd&gt;Slant Range: 551.14845km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.38088880431734, 50.00901668132807]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.818305815951721, 49.889883500552635], [-5.731003132815431, 49.91385485875585], [-5.643609981909621, 49.937753987193325], [-5.556126470604498, 49.961580754561766], [-5.468552707871492, 49.985335029647565], [-5.38088880431734, 50.00901668132807], [-5.293134872161555, 50.032625578574994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.2931349&lt;dd&gt;Longitude: 50.032626&lt;dd&gt;Azimuth: 231.1715\u00b0&lt;dd&gt;Altitude: 60.942706\u00b0&lt;dd&gt;Slant Range: 547.97421km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.293134872161555, 50.032625578574994]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.731003132815431, 49.91385485875585], [-5.643609981909621, 49.937753987193325], [-5.556126470604498, 49.961580754561766], [-5.468552707871492, 49.985335029647565], [-5.38088880431734, 50.00901668132807], [-5.293134872161555, 50.032625578574994], [-5.20529102525924, 50.056161590456796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.205291&lt;dd&gt;Longitude: 50.056162&lt;dd&gt;Azimuth: 230.66301\u00b0&lt;dd&gt;Altitude: 61.595044\u00b0&lt;dd&gt;Slant Range: 544.87321km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.20529102525924, 50.056161590456796]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.643609981909621, 49.937753987193325], [-5.556126470604498, 49.961580754561766], [-5.468552707871492, 49.985335029647565], [-5.38088880431734, 50.00901668132807], [-5.293134872161555, 50.032625578574994], [-5.20529102525924, 50.056161590456796], [-5.117357379094123, 50.07962458614129]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.1173574&lt;dd&gt;Longitude: 50.079625&lt;dd&gt;Azimuth: 230.1264\u00b0&lt;dd&gt;Altitude: 62.252363\u00b0&lt;dd&gt;Slant Range: 541.84673km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.117357379094123, 50.07962458614129]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.556126470604498, 49.961580754561766], [-5.468552707871492, 49.985335029647565], [-5.38088880431734, 50.00901668132807], [-5.293134872161555, 50.032625578574994], [-5.20529102525924, 50.056161590456796], [-5.117357379094123, 50.07962458614129], [-5.0293340507926745, 50.10301443489871]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -5.0293341&lt;dd&gt;Longitude: 50.103014&lt;dd&gt;Azimuth: 229.55936\u00b0&lt;dd&gt;Altitude: 62.914386\u00b0&lt;dd&gt;Slant Range: 538.89601km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.0293340507926745, 50.10301443489871]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.468552707871492, 49.985335029647565], [-5.38088880431734, 50.00901668132807], [-5.293134872161555, 50.032625578574994], [-5.20529102525924, 50.056161590456796], [-5.117357379094123, 50.07962458614129], [-5.0293340507926745, 50.10301443489871], [-4.941221159117163, 50.12633100610388]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.9412212&lt;dd&gt;Longitude: 50.126331&lt;dd&gt;Azimuth: 228.95939\u00b0&lt;dd&gt;Altitude: 63.580801\u00b0&lt;dd&gt;Slant Range: 536.02232km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.941221159117163, 50.12633100610388]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.38088880431734, 50.00901668132807], [-5.293134872161555, 50.032625578574994], [-5.20529102525924, 50.056161590456796], [-5.117357379094123, 50.07962458614129], [-5.0293340507926745, 50.10301443489871], [-4.941221159117163, 50.12633100610388], [-4.853018824479723, 50.149574169238804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.8530188&lt;dd&gt;Longitude: 50.149574&lt;dd&gt;Azimuth: 228.32367\u00b0&lt;dd&gt;Altitude: 64.251257\u00b0&lt;dd&gt;Slant Range: 533.2269km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.853018824479723, 50.149574169238804]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.293134872161555, 50.032625578574994], [-5.20529102525924, 50.056161590456796], [-5.117357379094123, 50.07962458614129], [-5.0293340507926745, 50.10301443489871], [-4.941221159117163, 50.12633100610388], [-4.853018824479723, 50.149574169238804], [-4.764727168950147, 50.17274379389607]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.7647272&lt;dd&gt;Longitude: 50.172744&lt;dd&gt;Azimuth: 227.64912\u00b0&lt;dd&gt;Altitude: 64.925364\u00b0&lt;dd&gt;Slant Range: 530.511km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.764727168950147, 50.17274379389607]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.20529102525924, 50.056161590456796], [-5.117357379094123, 50.07962458614129], [-5.0293340507926745, 50.10301443489871], [-4.941221159117163, 50.12633100610388], [-4.853018824479723, 50.149574169238804], [-4.764727168950147, 50.17274379389607], [-4.676346316240459, 50.19583974978111]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.6763463&lt;dd&gt;Longitude: 50.19584&lt;dd&gt;Azimuth: 226.93229\u00b0&lt;dd&gt;Altitude: 65.602683\u00b0&lt;dd&gt;Slant Range: 527.87584km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.676346316240459, 50.19583974978111]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.117357379094123, 50.07962458614129], [-5.0293340507926745, 50.10301443489871], [-4.941221159117163, 50.12633100610388], [-4.853018824479723, 50.149574169238804], [-4.764727168950147, 50.17274379389607], [-4.676346316240459, 50.19583974978111], [-4.587876391733799, 50.21886190671464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.5878764&lt;dd&gt;Longitude: 50.218862&lt;dd&gt;Azimuth: 226.16934\u00b0&lt;dd&gt;Altitude: 66.282722\u00b0&lt;dd&gt;Slant Range: 525.32263km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.587876391733799, 50.21886190671464]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.0293340507926745, 50.10301443489871], [-4.941221159117163, 50.12633100610388], [-4.853018824479723, 50.149574169238804], [-4.764727168950147, 50.17274379389607], [-4.676346316240459, 50.19583974978111], [-4.587876391733799, 50.21886190671464], [-4.499317522470961, 50.24181013463592]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.4993175&lt;dd&gt;Longitude: 50.24181&lt;dd&gt;Azimuth: 225.35599\u00b0&lt;dd&gt;Altitude: 66.964933\u00b0&lt;dd&gt;Slant Range: 522.8526km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.499317522470961, 50.24181013463592]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.941221159117163, 50.12633100610388], [-4.853018824479723, 50.149574169238804], [-4.764727168950147, 50.17274379389607], [-4.676346316240459, 50.19583974978111], [-4.587876391733799, 50.21886190671464], [-4.499317522470961, 50.24181013463592], [-4.410669837161613, 50.26468430360513]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.4106698&lt;dd&gt;Longitude: 50.264684&lt;dd&gt;Azimuth: 224.48748\u00b0&lt;dd&gt;Altitude: 67.648699\u00b0&lt;dd&gt;Slant Range: 520.46691km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.410669837161613, 50.26468430360513]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.853018824479723, 50.149574169238804], [-4.764727168950147, 50.17274379389607], [-4.676346316240459, 50.19583974978111], [-4.587876391733799, 50.21886190671464], [-4.499317522470961, 50.24181013463592], [-4.410669837161613, 50.26468430360513], [-4.321933466188932, 50.287484283806364]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.3219335&lt;dd&gt;Longitude: 50.287484&lt;dd&gt;Azimuth: 223.55845\u00b0&lt;dd&gt;Altitude: 68.333331\u00b0&lt;dd&gt;Slant Range: 518.16674km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.321933466188932, 50.287484283806364]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.764727168950147, 50.17274379389607], [-4.676346316240459, 50.19583974978111], [-4.587876391733799, 50.21886190671464], [-4.499317522470961, 50.24181013463592], [-4.410669837161613, 50.26468430360513], [-4.321933466188932, 50.287484283806364], [-4.233108541614714, 50.3102099455502]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.2331085&lt;dd&gt;Longitude: 50.31021&lt;dd&gt;Azimuth: 222.56292\u00b0&lt;dd&gt;Altitude: 69.018052\u00b0&lt;dd&gt;Slant Range: 515.95324km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.233108541614714, 50.3102099455502]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.676346316240459, 50.19583974978111], [-4.587876391733799, 50.21886190671464], [-4.499317522470961, 50.24181013463592], [-4.410669837161613, 50.26468430360513], [-4.321933466188932, 50.287484283806364], [-4.233108541614714, 50.3102099455502], [-4.144195197173444, 50.33286115927626]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.1441952&lt;dd&gt;Longitude: 50.332861&lt;dd&gt;Azimuth: 221.4942\u00b0&lt;dd&gt;Altitude: 69.70199\u00b0&lt;dd&gt;Slant Range: 513.82752km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.144195197173444, 50.33286115927626]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.587876391733799, 50.21886190671464], [-4.499317522470961, 50.24181013463592], [-4.410669837161613, 50.26468430360513], [-4.321933466188932, 50.287484283806364], [-4.233108541614714, 50.3102099455502], [-4.144195197173444, 50.33286115927626], [-4.055193568291233, 50.35543779555685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -4.0551936&lt;dd&gt;Longitude: 50.355438&lt;dd&gt;Azimuth: 220.34477\u00b0&lt;dd&gt;Altitude: 70.384161\u00b0&lt;dd&gt;Slant Range: 511.79068km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.055193568291233, 50.35543779555685]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.499317522470961, 50.24181013463592], [-4.410669837161613, 50.26468430360513], [-4.321933466188932, 50.287484283806364], [-4.233108541614714, 50.3102099455502], [-4.144195197173444, 50.33286115927626], [-4.055193568291233, 50.35543779555685], [-3.966103792076145, 50.37793972509854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.9661038&lt;dd&gt;Longitude: 50.37794&lt;dd&gt;Azimuth: 219.1062\u00b0&lt;dd&gt;Altitude: 71.063456\u00b0&lt;dd&gt;Slant Range: 509.8438km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.966103792076145, 50.37793972509854]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.410669837161613, 50.26468430360513], [-4.321933466188932, 50.287484283806364], [-4.233108541614714, 50.3102099455502], [-4.144195197173444, 50.33286115927626], [-4.055193568291233, 50.35543779555685], [-3.966103792076145, 50.37793972509854], [-3.876926007337535, 50.400366818745944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.876926&lt;dd&gt;Longitude: 50.400367&lt;dd&gt;Azimuth: 217.76904\u00b0&lt;dd&gt;Altitude: 71.738616\u00b0&lt;dd&gt;Slant Range: 507.9879km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.876926007337535, 50.400366818745944]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.321933466188932, 50.287484283806364], [-4.233108541614714, 50.3102099455502], [-4.144195197173444, 50.33286115927626], [-4.055193568291233, 50.35543779555685], [-3.966103792076145, 50.37793972509854], [-3.876926007337535, 50.400366818745944], [-3.7876603545683403, 50.42271894748405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.7876604&lt;dd&gt;Longitude: 50.422719&lt;dd&gt;Azimuth: 216.32272\u00b0&lt;dd&gt;Altitude: 72.408216\u00b0&lt;dd&gt;Slant Range: 506.22399km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.7876603545683403, 50.42271894748405]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.233108541614714, 50.3102099455502], [-4.144195197173444, 50.33286115927626], [-4.055193568291233, 50.35543779555685], [-3.966103792076145, 50.37793972509854], [-3.876926007337535, 50.400366818745944], [-3.7876603545683403, 50.42271894748405], [-3.6983069759696847, 50.44499598244134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.698307&lt;dd&gt;Longitude: 50.444996&lt;dd&gt;Azimuth: 214.75545\u00b0&lt;dd&gt;Altitude: 73.070636\u00b0&lt;dd&gt;Slant Range: 504.55304km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6983069759696847, 50.44499598244134]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.144195197173444, 50.33286115927626], [-4.055193568291233, 50.35543779555685], [-3.966103792076145, 50.37793972509854], [-3.876926007337535, 50.400366818745944], [-3.7876603545683403, 50.42271894748405], [-3.6983069759696847, 50.44499598244134], [-3.6088660154431946, 50.46719779489174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.608866&lt;dd&gt;Longitude: 50.467198&lt;dd&gt;Azimuth: 213.05409\u00b0&lt;dd&gt;Altitude: 73.724029\u00b0&lt;dd&gt;Slant Range: 502.97597km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.6088660154431946, 50.46719779489174]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.055193568291233, 50.35543779555685], [-3.966103792076145, 50.37793972509854], [-3.876926007337535, 50.400366818745944], [-3.7876603545683403, 50.42271894748405], [-3.6983069759696847, 50.44499598244134], [-3.6088660154431946, 50.46719779489174], [-3.519337618599091, 50.48932425625916]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.5193376&lt;dd&gt;Longitude: 50.489324&lt;dd&gt;Azimuth: 211.20415\u00b0&lt;dd&gt;Altitude: 74.366291\u00b0&lt;dd&gt;Slant Range: 501.49367km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.519337618599091, 50.48932425625916]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.966103792076145, 50.37793972509854], [-3.876926007337535, 50.400366818745944], [-3.7876603545683403, 50.42271894748405], [-3.6983069759696847, 50.44499598244134], [-3.6088660154431946, 50.46719779489174], [-3.519337618599091, 50.48932425625916], [-3.4297219327522455, 50.51137523811856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.4297219&lt;dd&gt;Longitude: 50.511375&lt;dd&gt;Azimuth: 209.18973\u00b0&lt;dd&gt;Altitude: 74.99502\u00b0&lt;dd&gt;Slant Range: 500.10698km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.4297219327522455, 50.51137523811856]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.876926007337535, 50.400366818745944], [-3.7876603545683403, 50.42271894748405], [-3.6983069759696847, 50.44499598244134], [-3.6088660154431946, 50.46719779489174], [-3.519337618599091, 50.48932425625916], [-3.4297219327522455, 50.51137523811856], [-3.340019106940141, 50.53335061220002]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.3400191&lt;dd&gt;Longitude: 50.533351&lt;dd&gt;Azimuth: 206.99366\u00b0&lt;dd&gt;Altitude: 75.607477\u00b0&lt;dd&gt;Slant Range: 498.81671km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.340019106940141, 50.53335061220002]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.7876603545683403, 50.42271894748405], [-3.6983069759696847, 50.44499598244134], [-3.6088660154431946, 50.46719779489174], [-3.519337618599091, 50.48932425625916], [-3.4297219327522455, 50.51137523811856], [-3.340019106940141, 50.53335061220002], [-3.250229291909671, 50.55525025039055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.2502293&lt;dd&gt;Longitude: 50.55525&lt;dd&gt;Azimuth: 204.59765\u00b0&lt;dd&gt;Altitude: 76.200539\u00b0&lt;dd&gt;Slant Range: 497.62361km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.250229291909671, 50.55525025039055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6983069759696847, 50.44499598244134], [-3.6088660154431946, 50.46719779489174], [-3.519337618599091, 50.48932425625916], [-3.4297219327522455, 50.51137523811856], [-3.340019106940141, 50.53335061220002], [-3.250229291909671, 50.55525025039055], [-3.160352640134719, 50.57707402473832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.1603526&lt;dd&gt;Longitude: 50.577074&lt;dd&gt;Azimuth: 201.98282\u00b0&lt;dd&gt;Altitude: 76.770661\u00b0&lt;dd&gt;Slant Range: 496.52837km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.160352640134719, 50.57707402473832]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.6088660154431946, 50.46719779489174], [-3.519337618599091, 50.48932425625916], [-3.4297219327522455, 50.51137523811856], [-3.340019106940141, 50.53335061220002], [-3.250229291909671, 50.55525025039055], [-3.160352640134719, 50.57707402473832], [-3.0703893058088556, 50.59882180745434]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -3.0703893&lt;dd&gt;Longitude: 50.598822&lt;dd&gt;Azimuth: 199.13031\u00b0&lt;dd&gt;Altitude: 77.313839\u00b0&lt;dd&gt;Slant Range: 495.53165km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0703893058088556, 50.59882180745434]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.519337618599091, 50.48932425625916], [-3.4297219327522455, 50.51137523811856], [-3.340019106940141, 50.53335061220002], [-3.250229291909671, 50.55525025039055], [-3.160352640134719, 50.57707402473832], [-3.0703893058088556, 50.59882180745434], [-2.980339444857807, 50.620493470915925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.9803394&lt;dd&gt;Longitude: 50.620493&lt;dd&gt;Azimuth: 196.02247\u00b0&lt;dd&gt;Altitude: 77.82559\u00b0&lt;dd&gt;Slant Range: 494.63404km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.980339444857807, 50.620493470915925]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.4297219327522455, 50.51137523811856], [-3.340019106940141, 50.53335061220002], [-3.250229291909671, 50.55525025039055], [-3.160352640134719, 50.57707402473832], [-3.0703893058088556, 50.59882180745434], [-2.980339444857807, 50.620493470915925], [-2.8902032149343153, 50.64208888766949]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.8902032&lt;dd&gt;Longitude: 50.642089&lt;dd&gt;Azimuth: 192.64439\u00b0&lt;dd&gt;Altitude: 78.300958\u00b0&lt;dd&gt;Slant Range: 493.83608km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8902032149343153, 50.64208888766949]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.340019106940141, 50.53335061220002], [-3.250229291909671, 50.55525025039055], [-3.160352640134719, 50.57707402473832], [-3.0703893058088556, 50.59882180745434], [-2.980339444857807, 50.620493470915925], [-2.8902032149343153, 50.64208888766949], [-2.7999807754255683, 50.66360793043327]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.7999808&lt;dd&gt;Longitude: 50.663608&lt;dd&gt;Azimuth: 188.98601\u00b0&lt;dd&gt;Altitude: 78.734559\u00b0&lt;dd&gt;Slant Range: 493.13827km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7999807754255683, 50.66360793043327]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.250229291909671, 50.55525025039055], [-3.160352640134719, 50.57707402473832], [-3.0703893058088556, 50.59882180745434], [-2.980339444857807, 50.620493470915925], [-2.8902032149343153, 50.64208888766949], [-2.7999807754255683, 50.66360793043327], [-2.709672287460247, 50.685050472100734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.7096723&lt;dd&gt;Longitude: 50.68505&lt;dd&gt;Azimuth: 185.04467\u00b0&lt;dd&gt;Altitude: 79.120689\u00b0&lt;dd&gt;Slant Range: 492.54102km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.709672287460247, 50.685050472100734]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.160352640134719, 50.57707402473832], [-3.0703893058088556, 50.59882180745434], [-2.980339444857807, 50.620493470915925], [-2.8902032149343153, 50.64208888766949], [-2.7999807754255683, 50.66360793043327], [-2.709672287460247, 50.685050472100734], [-2.6192779138984, 50.70641638574307]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.6192779&lt;dd&gt;Longitude: 50.706416&lt;dd&gt;Azimuth: 180.82795\u00b0&lt;dd&gt;Altitude: 79.453497\u00b0&lt;dd&gt;Slant Range: 492.0447km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6192779138984, 50.70641638574307]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0703893058088556, 50.59882180745434], [-2.980339444857807, 50.620493470915925], [-2.8902032149343153, 50.64208888766949], [-2.7999807754255683, 50.66360793043327], [-2.709672287460247, 50.685050472100734], [-2.6192779138984, 50.70641638574307], [-2.5287978193516194, 50.72770554461206]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.5287978&lt;dd&gt;Longitude: 50.727706&lt;dd&gt;Azimuth: 176.35638\u00b0&lt;dd&gt;Altitude: 79.727257\u00b0&lt;dd&gt;Slant Range: 491.64962km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5287978193516194, 50.72770554461206]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.980339444857807, 50.620493470915925], [-2.8902032149343153, 50.64208888766949], [-2.7999807754255683, 50.66360793043327], [-2.709672287460247, 50.685050472100734], [-2.6192779138984, 50.70641638574307], [-2.5287978193516194, 50.72770554461206], [-2.438232170175255, 50.748917822143646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.4382322&lt;dd&gt;Longitude: 50.748918&lt;dd&gt;Azimuth: 171.66527\u00b0&lt;dd&gt;Altitude: 79.936704\u00b0&lt;dd&gt;Slant Range: 491.35602km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.438232170175255, 50.748917822143646]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.8902032149343153, 50.64208888766949], [-2.7999807754255683, 50.66360793043327], [-2.709672287460247, 50.685050472100734], [-2.6192779138984, 50.70641638574307], [-2.5287978193516194, 50.72770554461206], [-2.438232170175255, 50.748917822143646], [-2.3475811344721307, 50.77005309196001]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.3475811&lt;dd&gt;Longitude: 50.770053&lt;dd&gt;Azimuth: 166.80504\u00b0&lt;dd&gt;Altitude: 80.077426\u00b0&lt;dd&gt;Slant Range: 491.16408km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.3475811344721307, 50.77005309196001]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.7999807754255683, 50.66360793043327], [-2.709672287460247, 50.685050472100734], [-2.6192779138984, 50.70641638574307], [-2.5287978193516194, 50.72770554461206], [-2.438232170175255, 50.748917822143646], [-2.3475811344721307, 50.77005309196001], [-2.256844882096258, 50.79111122787332]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.2568449&lt;dd&gt;Longitude: 50.791111&lt;dd&gt;Azimuth: 161.83933\u00b0&lt;dd&gt;Altitude: 80.146255\u00b0&lt;dd&gt;Slant Range: 491.07393km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.256844882096258, 50.79111122787332]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.709672287460247, 50.685050472100734], [-2.6192779138984, 50.70641638574307], [-2.5287978193516194, 50.72770554461206], [-2.438232170175255, 50.748917822143646], [-2.3475811344721307, 50.77005309196001], [-2.256844882096258, 50.79111122787332], [-2.166023584662352, 50.81209210388802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.1660236&lt;dd&gt;Longitude: 50.812092&lt;dd&gt;Azimuth: 156.84072\u00b0&lt;dd&gt;Altitude: 80.141579\u00b0&lt;dd&gt;Slant Range: 491.08561km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.166023584662352, 50.81209210388802]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.6192779138984, 50.70641638574307], [-2.5287978193516194, 50.72770554461206], [-2.438232170175255, 50.748917822143646], [-2.3475811344721307, 50.77005309196001], [-2.256844882096258, 50.79111122787332], [-2.166023584662352, 50.81209210388802], [-2.0751174155281746, 50.83299559420477]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -2.0751174&lt;dd&gt;Longitude: 50.832996&lt;dd&gt;Azimuth: 151.88473\u00b0&lt;dd&gt;Altitude: 80.063515\u00b0&lt;dd&gt;Slant Range: 491.19913km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.0751174155281746, 50.83299559420477]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.5287978193516194, 50.72770554461206], [-2.438232170175255, 50.748917822143646], [-2.3475811344721307, 50.77005309196001], [-2.256844882096258, 50.79111122787332], [-2.166023584662352, 50.81209210388802], [-2.0751174155281746, 50.83299559420477], [-1.9841265498330556, 50.85382157322207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.9841265&lt;dd&gt;Longitude: 50.853822&lt;dd&gt;Azimuth: 147.04308\u00b0&lt;dd&gt;Altitude: 79.913894\u00b0&lt;dd&gt;Slant Range: 491.41441km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.9841265498330556, 50.85382157322207]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.438232170175255, 50.748917822143646], [-2.3475811344721307, 50.77005309196001], [-2.256844882096258, 50.79111122787332], [-2.166023584662352, 50.81209210388802], [-2.0751174155281746, 50.83299559420477], [-1.9841265498330556, 50.85382157322207], [-1.8930511644587091, 50.874569915540384]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.8930512&lt;dd&gt;Longitude: 50.87457&lt;dd&gt;Azimuth: 142.3779\u00b0&lt;dd&gt;Altitude: 79.696068\u00b0&lt;dd&gt;Slant Range: 491.73131km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.8930511644587091, 50.874569915540384]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.3475811344721307, 50.77005309196001], [-2.256844882096258, 50.79111122787332], [-2.166023584662352, 50.81209210388802], [-2.0751174155281746, 50.83299559420477], [-1.9841265498330556, 50.85382157322207], [-1.8930511644587091, 50.874569915540384], [-1.801891438063202, 50.89524049596482]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.8018914&lt;dd&gt;Longitude: 50.89524&lt;dd&gt;Azimuth: 137.9377\u00b0&lt;dd&gt;Altitude: 79.414586\u00b0&lt;dd&gt;Slant Range: 492.14965km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.801891438063202, 50.89524049596482]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.256844882096258, 50.79111122787332], [-2.166023584662352, 50.81209210388802], [-2.0751174155281746, 50.83299559420477], [-1.9841265498330556, 50.85382157322207], [-1.8930511644587091, 50.874569915540384], [-1.801891438063202, 50.89524049596482], [-1.7106475510660175, 50.91583318950797]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.7106476&lt;dd&gt;Longitude: 50.915833&lt;dd&gt;Azimuth: 133.75582\u00b0&lt;dd&gt;Altitude: 79.074797\u00b0&lt;dd&gt;Slant Range: 492.66915km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.7106475510660175, 50.91583318950797]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.166023584662352, 50.81209210388802], [-2.0751174155281746, 50.83299559420477], [-1.9841265498330556, 50.85382157322207], [-1.8930511644587091, 50.874569915540384], [-1.801891438063202, 50.89524049596482], [-1.7106475510660175, 50.91583318950797], [-1.619319685661363, 50.9363478713931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.6193197&lt;dd&gt;Longitude: 50.936348&lt;dd&gt;Azimuth: 129.85098\u00b0&lt;dd&gt;Altitude: 78.682465\u00b0&lt;dd&gt;Slant Range: 493.28951km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.619319685661363, 50.9363478713931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.0751174155281746, 50.83299559420477], [-1.9841265498330556, 50.85382157322207], [-1.8930511644587091, 50.874569915540384], [-1.801891438063202, 50.89524049596482], [-1.7106475510660175, 50.91583318950797], [-1.619319685661363, 50.9363478713931], [-1.5279080258102056, 50.95678441705712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.527908&lt;dd&gt;Longitude: 50.956784&lt;dd&gt;Azimuth: 126.22927\u00b0&lt;dd&gt;Altitude: 78.243436\u00b0&lt;dd&gt;Slant Range: 494.01033km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.5279080258102056, 50.95678441705712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.9841265498330556, 50.85382157322207], [-1.8930511644587091, 50.874569915540384], [-1.801891438063202, 50.89524049596482], [-1.7106475510660175, 50.91583318950797], [-1.619319685661363, 50.9363478713931], [-1.5279080258102056, 50.95678441705712], [-1.4364127572530458, 50.977142702153515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.4364128&lt;dd&gt;Longitude: 50.977143&lt;dd&gt;Azimuth: 122.88693\u00b0&lt;dd&gt;Altitude: 77.763383\u00b0&lt;dd&gt;Slant Range: 494.83118km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.4364127572530458, 50.977142702153515]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.8930511644587091, 50.874569915540384], [-1.801891438063202, 50.89524049596482], [-1.7106475510660175, 50.91583318950797], [-1.619319685661363, 50.9363478713931], [-1.5279080258102056, 50.95678441705712], [-1.4364127572530458, 50.977142702153515], [-1.3448340675021822, 50.9974226025555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.3448341&lt;dd&gt;Longitude: 50.997423&lt;dd&gt;Azimuth: 119.81311\u00b0&lt;dd&gt;Altitude: 77.24764\u00b0&lt;dd&gt;Slant Range: 495.75156km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.3448340675021822, 50.9974226025555]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.801891438063202, 50.89524049596482], [-1.7106475510660175, 50.91583318950797], [-1.619319685661363, 50.9363478713931], [-1.5279080258102056, 50.95678441705712], [-1.4364127572530458, 50.977142702153515], [-1.3448340675021822, 50.9974226025555], [-1.2531721458540512, 51.01762399435906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.2531721&lt;dd&gt;Longitude: 51.017624&lt;dd&gt;Azimuth: 116.99245\u00b0&lt;dd&gt;Altitude: 76.701103\u00b0&lt;dd&gt;Slant Range: 496.77092km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.2531721458540512, 51.01762399435906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.7106475510660175, 50.91583318950797], [-1.619319685661363, 50.9363478713931], [-1.5279080258102056, 50.95678441705712], [-1.4364127572530458, 50.977142702153515], [-1.3448340675021822, 50.9974226025555], [-1.2531721458540512, 51.01762399435906], [-1.1614271833761503, 51.03774675388615]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.1614272&lt;dd&gt;Longitude: 51.037747&lt;dd&gt;Azimuth: 114.40707\u00b0&lt;dd&gt;Altitude: 76.128194\u00b0&lt;dd&gt;Slant Range: 497.88865km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.1614271833761503, 51.03774675388615]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.619319685661363, 50.9363478713931], [-1.5279080258102056, 50.95678441705712], [-1.4364127572530458, 50.977142702153515], [-1.3448340675021822, 50.9974226025555], [-1.2531721458540512, 51.01762399435906], [-1.1614271833761503, 51.03774675388615], [-1.0695993729268574, 51.057790757687386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -1.0695994&lt;dd&gt;Longitude: 51.057791&lt;dd&gt;Azimuth: 112.03805\u00b0&lt;dd&gt;Altitude: 75.532856\u00b0&lt;dd&gt;Slant Range: 499.10408km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-1.0695993729268574, 51.057790757687386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.5279080258102056, 50.95678441705712], [-1.4364127572530458, 50.977142702153515], [-1.3448340675021822, 50.9974226025555], [-1.2531721458540512, 51.01762399435906], [-1.1614271833761503, 51.03774675388615], [-1.0695993729268574, 51.057790757687386], [-0.9776889091479511, 51.0777558825453]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.97768891&lt;dd&gt;Longitude: 51.077756&lt;dd&gt;Azimuth: 109.86655\u00b0&lt;dd&gt;Altitude: 74.918576\u00b0&lt;dd&gt;Slant Range: 500.4165km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.9776889091479511, 51.0777558825453]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.4364127572530458, 50.977142702153515], [-1.3448340675021822, 50.9974226025555], [-1.2531721458540512, 51.01762399435906], [-1.1614271833761503, 51.03774675388615], [-1.0695993729268574, 51.057790757687386], [-0.9776889091479511, 51.0777558825453], [-0.8856959884630593, 51.09764200547768]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.88569599&lt;dd&gt;Longitude: 51.097642&lt;dd&gt;Azimuth: 107.87441\u00b0&lt;dd&gt;Altitude: 74.288425\u00b0&lt;dd&gt;Slant Range: 501.82515km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.8856959884630593, 51.09764200547768]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.3448340675021822, 50.9974226025555], [-1.2531721458540512, 51.01762399435906], [-1.1614271833761503, 51.03774675388615], [-1.0695993729268574, 51.057790757687386], [-0.9776889091479511, 51.0777558825453], [-0.8856959884630593, 51.09764200547768], [-0.7936208090840441, 51.11744900374041]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.79362081&lt;dd&gt;Longitude: 51.117449&lt;dd&gt;Azimuth: 106.04462\u00b0&lt;dd&gt;Altitude: 73.645095\u00b0&lt;dd&gt;Slant Range: 503.32922km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7936208090840441, 51.11744900374041]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.2531721458540512, 51.01762399435906], [-1.1614271833761503, 51.03774675388615], [-1.0695993729268574, 51.057790757687386], [-0.9776889091479511, 51.0777558825453], [-0.8856959884630593, 51.09764200547768], [-0.7936208090840441, 51.11744900374041], [-0.7014635710195778, 51.13717675483004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.70146357&lt;dd&gt;Longitude: 51.137177&lt;dd&gt;Azimuth: 104.36145\u00b0&lt;dd&gt;Altitude: 72.990948\u00b0&lt;dd&gt;Slant Range: 504.92785km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.7014635710195778, 51.13717675483004]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.1614271833761503, 51.03774675388615], [-1.0695993729268574, 51.057790757687386], [-0.9776889091479511, 51.0777558825453], [-0.8856959884630593, 51.09764200547768], [-0.7936208090840441, 51.11744900374041], [-0.7014635710195778, 51.13717675483004], [-0.6092244760580693, 51.15682513648779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.60922448&lt;dd&gt;Longitude: 51.156825&lt;dd&gt;Azimuth: 102.81058\u00b0&lt;dd&gt;Altitude: 72.328051\u00b0&lt;dd&gt;Slant Range: 506.62015km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.6092244760580693, 51.15682513648779]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-1.0695993729268574, 51.057790757687386], [-0.9776889091479511, 51.0777558825453], [-0.8856959884630593, 51.09764200547768], [-0.7936208090840441, 51.11744900374041], [-0.7014635710195778, 51.13717675483004], [-0.6092244760580693, 51.15682513648779], [-0.5169037277879941, 51.176394026702354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.51690373&lt;dd&gt;Longitude: 51.176394&lt;dd&gt;Azimuth: 101.37908\u00b0&lt;dd&gt;Altitude: 71.658217\u00b0&lt;dd&gt;Slant Range: 508.40518km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.5169037277879941, 51.176394026702354]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.9776889091479511, 51.0777558825453], [-0.8856959884630593, 51.09764200547768], [-0.7936208090840441, 51.11744900374041], [-0.7014635710195778, 51.13717675483004], [-0.6092244760580693, 51.15682513648779], [-0.5169037277879941, 51.176394026702354], [-0.4245015315927549, 51.19588330371268]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.42450153&lt;dd&gt;Longitude: 51.195883&lt;dd&gt;Azimuth: 100.05529\u00b0&lt;dd&gt;Altitude: 70.98304\u00b0&lt;dd&gt;Slant Range: 510.28196km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.4245015315927549, 51.19588330371268]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.8856959884630593, 51.09764200547768], [-0.7936208090840441, 51.11744900374041], [-0.7014635710195778, 51.13717675483004], [-0.6092244760580693, 51.15682513648779], [-0.5169037277879941, 51.176394026702354], [-0.4245015315927549, 51.19588330371268], [-0.3320180946428951, 51.21529284601131]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.33201809&lt;dd&gt;Longitude: 51.215293&lt;dd&gt;Azimuth: 98.828811\u00b0&lt;dd&gt;Altitude: 70.303922\u00b0&lt;dd&gt;Slant Range: 512.24949km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.3320180946428951, 51.21529284601131]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7936208090840441, 51.11744900374041], [-0.7014635710195778, 51.13717675483004], [-0.6092244760580693, 51.15682513648779], [-0.5169037277879941, 51.176394026702354], [-0.4245015315927549, 51.19588330371268], [-0.3320180946428951, 51.21529284601131], [-0.23945362591497898, 51.23462253234745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.23945363&lt;dd&gt;Longitude: 51.234623&lt;dd&gt;Azimuth: 97.690323\u00b0&lt;dd&gt;Altitude: 69.622098\u00b0&lt;dd&gt;Slant Range: 514.30671km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.23945362591497898, 51.23462253234745]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.7014635710195778, 51.13717675483004], [-0.6092244760580693, 51.15682513648779], [-0.5169037277879941, 51.176394026702354], [-0.4245015315927549, 51.19588330371268], [-0.3320180946428951, 51.21529284601131], [-0.23945362591497898, 51.23462253234745], [-0.14680833617556155, 51.253872241730356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.14680834&lt;dd&gt;Longitude: 51.253872&lt;dd&gt;Azimuth: 96.631525\u00b0&lt;dd&gt;Altitude: 68.93866\u00b0&lt;dd&gt;Slant Range: 516.45256km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.14680833617556155, 51.253872241730356]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.6092244760580693, 51.15682513648779], [-0.5169037277879941, 51.176394026702354], [-0.4245015315927549, 51.19588330371268], [-0.3320180946428951, 51.21529284601131], [-0.23945362591497898, 51.23462253234745], [-0.14680833617556155, 51.253872241730356], [-0.05408243799635332, 51.273041853431955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: -0.054082438&lt;dd&gt;Longitude: 51.273042&lt;dd&gt;Azimuth: 95.645012\u00b0&lt;dd&gt;Altitude: 68.254576\u00b0&lt;dd&gt;Slant Range: 518.68593km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-0.05408243799635332, 51.273041853431955]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.5169037277879941, 51.176394026702354], [-0.4245015315927549, 51.19588330371268], [-0.3320180946428951, 51.21529284601131], [-0.23945362591497898, 51.23462253234745], [-0.14680833617556155, 51.253872241730356], [-0.05408243799635332, 51.273041853431955], [0.03872385425585548, 51.29213124698997]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.038723854&lt;dd&gt;Longitude: 51.292131&lt;dd&gt;Azimuth: 94.72418\u00b0&lt;dd&gt;Altitude: 67.570703\u00b0&lt;dd&gt;Slant Range: 521.00569km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.03872385425585548, 51.29213124698997]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.4245015315927549, 51.19588330371268], [-0.3320180946428951, 51.21529284601131], [-0.23945362591497898, 51.23462253234745], [-0.14680833617556155, 51.253872241730356], [-0.05408243799635332, 51.273041853431955], [0.03872385425585548, 51.29213124698997], [0.1316103244078468, 51.311140302212166]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.13161032&lt;dd&gt;Longitude: 51.31114&lt;dd&gt;Azimuth: 93.863136\u00b0&lt;dd&gt;Altitude: 66.887804\u00b0&lt;dd&gt;Slant Range: 523.4107km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.1316103244078468, 51.311140302212166]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.3320180946428951, 51.21529284601131], [-0.23945362591497898, 51.23462253234745], [-0.14680833617556155, 51.253872241730356], [-0.05408243799635332, 51.273041853431955], [0.03872385425585548, 51.29213124698997], [0.1316103244078468, 51.311140302212166], [0.22457675449274794, 51.33006889917786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.22457675&lt;dd&gt;Longitude: 51.330069&lt;dd&gt;Azimuth: 93.056615\u00b0&lt;dd&gt;Altitude: 66.206559\u00b0&lt;dd&gt;Slant Range: 525.89977km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.22457675449274794, 51.33006889917786]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.23945362591497898, 51.23462253234745], [-0.14680833617556155, 51.253872241730356], [-0.05408243799635332, 51.273041853431955], [0.03872385425585548, 51.29213124698997], [0.1316103244078468, 51.311140302212166], [0.22457675449274794, 51.33006889917786], [0.31762292473372145, 51.34891691824224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.31762292&lt;dd&gt;Longitude: 51.348917&lt;dd&gt;Azimuth: 92.299909\u00b0&lt;dd&gt;Altitude: 65.527574\u00b0&lt;dd&gt;Slant Range: 528.47173km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.31762292473372145, 51.34891691824224]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.14680833617556155, 51.253872241730356], [-0.05408243799635332, 51.273041853431955], [0.03872385425585548, 51.29213124698997], [0.1316103244078468, 51.311140302212166], [0.22457675449274794, 51.33006889917786], [0.31762292473372145, 51.34891691824224], [0.4107486135564077, 51.367684240038884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.41074861&lt;dd&gt;Longitude: 51.367684&lt;dd&gt;Azimuth: 91.588802\u00b0&lt;dd&gt;Altitude: 64.851387\u00b0&lt;dd&gt;Slant Range: 531.12535km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.4107486135564077, 51.367684240038884]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-0.05408243799635332, 51.273041853431955], [0.03872385425585548, 51.29213124698997], [0.1316103244078468, 51.311140302212166], [0.22457675449274794, 51.33006889917786], [0.31762292473372145, 51.34891691824224], [0.4107486135564077, 51.367684240038884], [0.5039535975757191, 51.386370745483696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.5039536&lt;dd&gt;Longitude: 51.386371&lt;dd&gt;Azimuth: 90.919511\u00b0&lt;dd&gt;Altitude: 64.178483\u00b0&lt;dd&gt;Slant Range: 533.85943km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5039535975757191, 51.386370745483696]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.03872385425585548, 51.29213124698997], [0.1316103244078468, 51.311140302212166], [0.22457675449274794, 51.33006889917786], [0.31762292473372145, 51.34891691824224], [0.4107486135564077, 51.367684240038884], [0.5039535975757191, 51.386370745483696], [0.5972376516089185, 51.404976315776494]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.59723765&lt;dd&gt;Longitude: 51.404976&lt;dd&gt;Azimuth: 90.288638\u00b0&lt;dd&gt;Altitude: 63.509292\u00b0&lt;dd&gt;Slant Range: 536.67272km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.5972376516089185, 51.404976315776494]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.1316103244078468, 51.311140302212166], [0.22457675449274794, 51.33006889917786], [0.31762292473372145, 51.34891691824224], [0.4107486135564077, 51.367684240038884], [0.5039535975757191, 51.386370745483696], [0.5972376516089185, 51.404976315776494], [0.6906005486640421, 51.4235008324062]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.69060055&lt;dd&gt;Longitude: 51.423501&lt;dd&gt;Azimuth: 89.693124\u00b0&lt;dd&gt;Altitude: 62.844199\u00b0&lt;dd&gt;Slant Range: 539.56399km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.6906005486640421, 51.4235008324062]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.22457675449274794, 51.33006889917786], [0.31762292473372145, 51.34891691824224], [0.4107486135564077, 51.367684240038884], [0.5039535975757191, 51.386370745483696], [0.5972376516089185, 51.404976315776494], [0.6906005486640421, 51.4235008324062], [0.7840420599455733, 51.44194417715252]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.78404206&lt;dd&gt;Longitude: 51.441944&lt;dd&gt;Azimuth: 89.130212\u00b0&lt;dd&gt;Altitude: 62.183548\u00b0&lt;dd&gt;Slant Range: 542.53198km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.7840420599455733, 51.44194417715252]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.31762292473372145, 51.34891691824224], [0.4107486135564077, 51.367684240038884], [0.5039535975757191, 51.386370745483696], [0.5972376516089185, 51.404976315776494], [0.6906005486640421, 51.4235008324062], [0.7840420599455733, 51.44194417715252], [0.8775619548537308, 51.46030623208978]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.87756195&lt;dd&gt;Longitude: 51.460306&lt;dd&gt;Azimuth: 88.597409\u00b0&lt;dd&gt;Altitude: 61.527645\u00b0&lt;dd&gt;Slant Range: 545.57544km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.8775619548537308, 51.46030623208978]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.4107486135564077, 51.367684240038884], [0.5039535975757191, 51.386370745483696], [0.5972376516089185, 51.404976315776494], [0.6906005486640421, 51.4235008324062], [0.7840420599455733, 51.44194417715252], [0.8775619548537308, 51.46030623208978], [0.971160000979837, 51.478586879589784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 0.97116&lt;dd&gt;Longitude: 51.478587&lt;dd&gt;Azimuth: 88.092463\u00b0&lt;dd&gt;Altitude: 60.876763\u00b0&lt;dd&gt;Slant Range: 548.69311km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[0.971160000979837, 51.478586879589784]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5039535975757191, 51.386370745483696], [0.5972376516089185, 51.404976315776494], [0.6906005486640421, 51.4235008324062], [0.7840420599455733, 51.44194417715252], [0.8775619548537308, 51.46030623208978], [0.971160000979837, 51.478586879589784], [1.0648359641065221, 51.49678600232497]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.064836&lt;dd&gt;Longitude: 51.496786&lt;dd&gt;Azimuth: 87.613331\u00b0&lt;dd&gt;Altitude: 60.231143\u00b0&lt;dd&gt;Slant Range: 551.88373km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.0648359641065221, 51.49678600232497]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.5972376516089185, 51.404976315776494], [0.6906005486640421, 51.4235008324062], [0.7840420599455733, 51.44194417715252], [0.8775619548537308, 51.46030623208978], [0.971160000979837, 51.478586879589784], [1.0648359641065221, 51.49678600232497], [1.1585896082209042, 51.51490348327226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.1585896&lt;dd&gt;Longitude: 51.514903&lt;dd&gt;Azimuth: 87.158156\u00b0&lt;dd&gt;Altitude: 59.591001\u00b0&lt;dd&gt;Slant Range: 555.14603km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.1585896082209042, 51.51490348327226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.6906005486640421, 51.4235008324062], [0.7840420599455733, 51.44194417715252], [0.8775619548537308, 51.46030623208978], [0.971160000979837, 51.478586879589784], [1.0648359641065221, 51.49678600232497], [1.1585896082209042, 51.51490348327226], [1.2524206954932409, 51.532939205715294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.2524207&lt;dd&gt;Longitude: 51.532939&lt;dd&gt;Azimuth: 86.725251\u00b0&lt;dd&gt;Altitude: 58.956525\u00b0&lt;dd&gt;Slant Range: 558.47876km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.2524206954932409, 51.532939205715294]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.7840420599455733, 51.44194417715252], [0.8775619548537308, 51.46030623208978], [0.971160000979837, 51.478586879589784], [1.0648359641065221, 51.49678600232497], [1.1585896082209042, 51.51490348327226], [1.2524206954932409, 51.532939205715294], [1.3463289862932657, 51.550893053247975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.346329&lt;dd&gt;Longitude: 51.550893&lt;dd&gt;Azimuth: 86.313078\u00b0&lt;dd&gt;Altitude: 58.327882\u00b0&lt;dd&gt;Slant Range: 561.88066km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.3463289862932657, 51.550893053247975]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.8775619548537308, 51.46030623208978], [0.971160000979837, 51.478586879589784], [1.0648359641065221, 51.49678600232497], [1.1585896082209042, 51.51490348327226], [1.2524206954932409, 51.532939205715294], [1.3463289862932657, 51.550893053247975], [1.4403142391810269, 51.56876490977791]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.4403142&lt;dd&gt;Longitude: 51.568765&lt;dd&gt;Azimuth: 85.920234\u00b0&lt;dd&gt;Altitude: 57.705217\u00b0&lt;dd&gt;Slant Range: 565.35048km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.4403142391810269, 51.56876490977791]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[0.971160000979837, 51.478586879589784], [1.0648359641065221, 51.49678600232497], [1.1585896082209042, 51.51490348327226], [1.2524206954932409, 51.532939205715294], [1.3463289862932657, 51.550893053247975], [1.4403142391810269, 51.56876490977791], [1.5343762109166588, 51.5865546595295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.5343762&lt;dd&gt;Longitude: 51.586555&lt;dd&gt;Azimuth: 85.545434\u00b0&lt;dd&gt;Altitude: 57.088655\u00b0&lt;dd&gt;Slant Range: 568.88697km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.5343762109166588, 51.5865546595295]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.0648359641065221, 51.49678600232497], [1.1585896082209042, 51.51490348327226], [1.2524206954932409, 51.532939205715294], [1.3463289862932657, 51.550893053247975], [1.4403142391810269, 51.56876490977791], [1.5343762109166588, 51.5865546595295], [1.6285146564490083, 51.604262187046864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.6285147&lt;dd&gt;Longitude: 51.604262&lt;dd&gt;Azimuth: 85.187503\u00b0&lt;dd&gt;Altitude: 56.478304\u00b0&lt;dd&gt;Slant Range: 572.48888km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.6285146564490083, 51.604262187046864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.1585896082209042, 51.51490348327226], [1.2524206954932409, 51.532939205715294], [1.3463289862932657, 51.550893053247975], [1.4403142391810269, 51.56876490977791], [1.5343762109166588, 51.5865546595295], [1.6285146564490083, 51.604262187046864], [1.7227293289250487, 51.62188737719727]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.7227293&lt;dd&gt;Longitude: 51.621887&lt;dd&gt;Azimuth: 84.845363\u00b0&lt;dd&gt;Altitude: 55.874256\u00b0&lt;dd&gt;Slant Range: 576.155km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.7227293289250487, 51.62188737719727]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.2524206954932409, 51.532939205715294], [1.3463289862932657, 51.550893053247975], [1.4403142391810269, 51.56876490977791], [1.5343762109166588, 51.5865546595295], [1.6285146564490083, 51.604262187046864], [1.7227293289250487, 51.62188737719727], [1.8170199796914832, 51.63943011517433]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.81702&lt;dd&gt;Longitude: 51.63943&lt;dd&gt;Azimuth: 84.518023\u00b0&lt;dd&gt;Altitude: 55.276588\u00b0&lt;dd&gt;Slant Range: 579.88409km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.8170199796914832, 51.63943011517433]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.3463289862932657, 51.550893053247975], [1.4403142391810269, 51.56876490977791], [1.5343762109166588, 51.5865546595295], [1.6285146564490083, 51.604262187046864], [1.7227293289250487, 51.62188737719727], [1.8170199796914832, 51.63943011517433], [1.9113863582852793, 51.65689028650106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 1.9113864&lt;dd&gt;Longitude: 51.65689&lt;dd&gt;Azimuth: 84.204573\u00b0&lt;dd&gt;Altitude: 54.685362\u00b0&lt;dd&gt;Slant Range: 583.67494km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[1.9113863582852793, 51.65689028650106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.4403142391810269, 51.56876490977791], [1.5343762109166588, 51.5865546595295], [1.6285146564490083, 51.604262187046864], [1.7227293289250487, 51.62188737719727], [1.8170199796914832, 51.63943011517433], [1.9113863582852793, 51.65689028650106], [2.0058282124416835, 51.67426777703325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 2.0058282&lt;dd&gt;Longitude: 51.674268&lt;dd&gt;Azimuth: 83.904172\u00b0&lt;dd&gt;Altitude: 54.10063\u00b0&lt;dd&gt;Slant Range: 587.52636km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.0058282124416835, 51.67426777703325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.5343762109166588, 51.5865546595295], [1.6285146564490083, 51.604262187046864], [1.7227293289250487, 51.62188737719727], [1.8170199796914832, 51.63943011517433], [1.9113863582852793, 51.65689028650106], [2.0058282124416835, 51.67426777703325], [2.100345288094859, 51.691562472962325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 2.1003453&lt;dd&gt;Longitude: 51.691562&lt;dd&gt;Azimuth: 83.616046\u00b0&lt;dd&gt;Altitude: 53.522429\u00b0&lt;dd&gt;Slant Range: 591.43716km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.100345288094859, 51.691562472962325]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.6285146564490083, 51.604262187046864], [1.7227293289250487, 51.62188737719727], [1.8170199796914832, 51.63943011517433], [1.9113863582852793, 51.65689028650106], [2.0058282124416835, 51.67426777703325], [2.100345288094859, 51.691562472962325], [2.194937329382412, 51.7087742608193]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 2.1949373&lt;dd&gt;Longitude: 51.708774&lt;dd&gt;Azimuth: 83.33948\u00b0&lt;dd&gt;Altitude: 52.950787\u00b0&lt;dd&gt;Slant Range: 595.40616km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.194937329382412, 51.7087742608193]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.7227293289250487, 51.62188737719727], [1.8170199796914832, 51.63943011517433], [1.9113863582852793, 51.65689028650106], [2.0058282124416835, 51.67426777703325], [2.100345288094859, 51.691562472962325], [2.194937329382412, 51.7087742608193], [2.2896040786295933, 51.72590302747688]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 2.2896041&lt;dd&gt;Longitude: 51.725903&lt;dd&gt;Azimuth: 83.07381\u00b0&lt;dd&gt;Altitude: 52.385723\u00b0&lt;dd&gt;Slant Range: 599.4322km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.2896040786295933, 51.72590302747688]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.8170199796914832, 51.63943011517433], [1.9113863582852793, 51.65689028650106], [2.0058282124416835, 51.67426777703325], [2.100345288094859, 51.691562472962325], [2.194937329382412, 51.7087742608193], [2.2896040786295933, 51.72590302747688], [2.384345276375683, 51.74294866015373]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 2.3843453&lt;dd&gt;Longitude: 51.742949&lt;dd&gt;Azimuth: 82.818423\u00b0&lt;dd&gt;Altitude: 51.827244\u00b0&lt;dd&gt;Slant Range: 603.51414km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.384345276375683, 51.74294866015373]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[1.9113863582852793, 51.65689028650106], [2.0058282124416835, 51.67426777703325], [2.100345288094859, 51.691562472962325], [2.194937329382412, 51.7087742608193], [2.2896040786295933, 51.72590302747688], [2.384345276375683, 51.74294866015373], [2.479160661355798, 51.75991104641712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5040&lt;dd&gt;Latitude: 2.4791607&lt;dd&gt;Longitude: 51.759911&lt;dd&gt;Azimuth: 82.572749\u00b0&lt;dd&gt;Altitude: 51.275352\u00b0&lt;dd&gt;Slant Range: 607.65084km&quot;, &quot;name&quot;: &quot;STARLINK-5040&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[2.479160661355798, 51.75991104641712]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -10.178693&lt;dd&gt;Longitude: 48.634101&lt;dd&gt;Azimuth: 242.87213\u00b0&lt;dd&gt;Altitude: 33.359511\u00b0&lt;dd&gt;Slant Range: 804.79922km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833], [-10.095749860874697, 48.661488609230496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -10.09575&lt;dd&gt;Longitude: 48.661489&lt;dd&gt;Azimuth: 242.80146\u00b0&lt;dd&gt;Altitude: 33.688472\u00b0&lt;dd&gt;Slant Range: 799.14662km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.095749860874697, 48.661488609230496]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833], [-10.095749860874697, 48.661488609230496], [-10.012712337403137, 48.68881059270079]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -10.012712&lt;dd&gt;Longitude: 48.688811&lt;dd&gt;Azimuth: 242.72917\u00b0&lt;dd&gt;Altitude: 34.021625\u00b0&lt;dd&gt;Slant Range: 793.51667km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-10.012712337403137, 48.68881059270079]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833], [-10.095749860874697, 48.661488609230496], [-10.012712337403137, 48.68881059270079], [-9.929580655971503, 48.71606644361034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.9295807&lt;dd&gt;Longitude: 48.716066&lt;dd&gt;Azimuth: 242.65519\u00b0&lt;dd&gt;Altitude: 34.359041\u00b0&lt;dd&gt;Slant Range: 787.90984km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.929580655971503, 48.71606644361034]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833], [-10.095749860874697, 48.661488609230496], [-10.012712337403137, 48.68881059270079], [-9.929580655971503, 48.71606644361034], [-9.84635485302172, 48.7432560285058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.8463549&lt;dd&gt;Longitude: 48.743256&lt;dd&gt;Azimuth: 242.57948\u00b0&lt;dd&gt;Altitude: 34.700791\u00b0&lt;dd&gt;Slant Range: 782.32665km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.84635485302172, 48.7432560285058]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833], [-10.095749860874697, 48.661488609230496], [-10.012712337403137, 48.68881059270079], [-9.929580655971503, 48.71606644361034], [-9.84635485302172, 48.7432560285058], [-9.763034966355095, 48.7703792139111]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.763035&lt;dd&gt;Longitude: 48.770379&lt;dd&gt;Azimuth: 242.50196\u00b0&lt;dd&gt;Altitude: 35.046946\u00b0&lt;dd&gt;Slant Range: 776.76761km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.763034966355095, 48.7703792139111]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.178693191308355, 48.63410062662833], [-10.095749860874697, 48.661488609230496], [-10.012712337403137, 48.68881059270079], [-9.929580655971503, 48.71606644361034], [-9.84635485302172, 48.7432560285058], [-9.763034966355095, 48.7703792139111], [-9.67962103514748, 48.797435866330275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.679621&lt;dd&gt;Longitude: 48.797436&lt;dd&gt;Azimuth: 242.42258\u00b0&lt;dd&gt;Altitude: 35.397581\u00b0&lt;dd&gt;Slant Range: 771.23325km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.67962103514748, 48.797435866330275]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.095749860874697, 48.661488609230496], [-10.012712337403137, 48.68881059270079], [-9.929580655971503, 48.71606644361034], [-9.84635485302172, 48.7432560285058], [-9.763034966355095, 48.7703792139111], [-9.67962103514748, 48.797435866330275], [-9.59611309994215, 48.82442585224931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.5961131&lt;dd&gt;Longitude: 48.824426&lt;dd&gt;Azimuth: 242.34128\u00b0&lt;dd&gt;Altitude: 35.752767\u00b0&lt;dd&gt;Slant Range: 765.72412km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.59611309994215, 48.82442585224931]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-10.012712337403137, 48.68881059270079], [-9.929580655971503, 48.71606644361034], [-9.84635485302172, 48.7432560285058], [-9.763034966355095, 48.7703792139111], [-9.67962103514748, 48.797435866330275], [-9.59611309994215, 48.82442585224931], [-9.5125112026681, 48.85134903813738]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.5125112&lt;dd&gt;Longitude: 48.851349&lt;dd&gt;Azimuth: 242.25798\u00b0&lt;dd&gt;Altitude: 36.112581\u00b0&lt;dd&gt;Slant Range: 760.24076km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.5125112026681, 48.85134903813738]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.929580655971503, 48.71606644361034], [-9.84635485302172, 48.7432560285058], [-9.763034966355095, 48.7703792139111], [-9.67962103514748, 48.797435866330275], [-9.59611309994215, 48.82442585224931], [-9.5125112026681, 48.85134903813738], [-9.428815386647457, 48.87820529045042]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.4288154&lt;dd&gt;Longitude: 48.878205&lt;dd&gt;Azimuth: 242.17261\u00b0&lt;dd&gt;Altitude: 36.477097\u00b0&lt;dd&gt;Slant Range: 754.78374km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.428815386647457, 48.87820529045042]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.84635485302172, 48.7432560285058], [-9.763034966355095, 48.7703792139111], [-9.67962103514748, 48.797435866330275], [-9.59611309994215, 48.82442585224931], [-9.5125112026681, 48.85134903813738], [-9.428815386647457, 48.87820529045042], [-9.345025696584807, 48.90499447563169]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.3450257&lt;dd&gt;Longitude: 48.904994&lt;dd&gt;Azimuth: 242.08511\u00b0&lt;dd&gt;Altitude: 36.846392\u00b0&lt;dd&gt;Slant Range: 749.35365km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.345025696584807, 48.90499447563169]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.763034966355095, 48.7703792139111], [-9.67962103514748, 48.797435866330275], [-9.59611309994215, 48.82442585224931], [-9.5125112026681, 48.85134903813738], [-9.428815386647457, 48.87820529045042], [-9.345025696584807, 48.90499447563169], [-9.261142178593383, 48.93171646011507]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.2611422&lt;dd&gt;Longitude: 48.931716&lt;dd&gt;Azimuth: 241.99538\u00b0&lt;dd&gt;Altitude: 37.220541\u00b0&lt;dd&gt;Slant Range: 743.95108km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.261142178593383, 48.93171646011507]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.67962103514748, 48.797435866330275], [-9.59611309994215, 48.82442585224931], [-9.5125112026681, 48.85134903813738], [-9.428815386647457, 48.87820529045042], [-9.345025696584807, 48.90499447563169], [-9.261142178593383, 48.93171646011507], [-9.177164880187386, 48.95837111032643]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.1771649&lt;dd&gt;Longitude: 48.958371&lt;dd&gt;Azimuth: 241.90335\u00b0&lt;dd&gt;Altitude: 37.599623\u00b0&lt;dd&gt;Slant Range: 738.57664km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.177164880187386, 48.95837111032643]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.59611309994215, 48.82442585224931], [-9.5125112026681, 48.85134903813738], [-9.428815386647457, 48.87820529045042], [-9.345025696584807, 48.90499447563169], [-9.261142178593383, 48.93171646011507], [-9.177164880187386, 48.95837111032643], [-9.09309385029296, 48.98495829268601]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.0930939&lt;dd&gt;Longitude: 48.984958&lt;dd&gt;Azimuth: 241.80894\u00b0&lt;dd&gt;Altitude: 37.983715\u00b0&lt;dd&gt;Slant Range: 733.23096km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.09309385029296, 48.98495829268601]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.5125112026681, 48.85134903813738], [-9.428815386647457, 48.87820529045042], [-9.345025696584807, 48.90499447563169], [-9.261142178593383, 48.93171646011507], [-9.177164880187386, 48.95837111032643], [-9.09309385029296, 48.98495829268601], [-9.00892913925569, 49.01147787361063]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -9.0089291&lt;dd&gt;Longitude: 49.011478&lt;dd&gt;Azimuth: 241.71204\u00b0&lt;dd&gt;Altitude: 38.372895\u00b0&lt;dd&gt;Slant Range: 727.91467km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-9.00892913925569, 49.01147787361063]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.428815386647457, 48.87820529045042], [-9.345025696584807, 48.90499447563169], [-9.261142178593383, 48.93171646011507], [-9.177164880187386, 48.95837111032643], [-9.09309385029296, 48.98495829268601], [-9.00892913925569, 49.01147787361063], [-8.924670798844879, 49.037929719516235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.9246708&lt;dd&gt;Longitude: 49.03793&lt;dd&gt;Azimuth: 241.61258\u00b0&lt;dd&gt;Altitude: 38.767242\u00b0&lt;dd&gt;Slant Range: 722.62844km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.924670798844879, 49.037929719516235]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.345025696584807, 48.90499447563169], [-9.261142178593383, 48.93171646011507], [-9.177164880187386, 48.95837111032643], [-9.09309385029296, 48.98495829268601], [-9.00892913925569, 49.01147787361063], [-8.924670798844879, 49.037929719516235], [-8.840318882253065, 49.06431369681905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.8403189&lt;dd&gt;Longitude: 49.064314&lt;dd&gt;Azimuth: 241.51044\u00b0&lt;dd&gt;Altitude: 39.166836\u00b0&lt;dd&gt;Slant Range: 717.37292km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.840318882253065, 49.06431369681905]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.261142178593383, 48.93171646011507], [-9.177164880187386, 48.95837111032643], [-9.09309385029296, 48.98495829268601], [-9.00892913925569, 49.01147787361063], [-8.924670798844879, 49.037929719516235], [-8.840318882253065, 49.06431369681905], [-8.755873444115181, 49.090629671938984]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.7558734&lt;dd&gt;Longitude: 49.09063&lt;dd&gt;Azimuth: 241.40552\u00b0&lt;dd&gt;Altitude: 39.571755\u00b0&lt;dd&gt;Slant Range: 712.14881km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.755873444115181, 49.090629671938984]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.177164880187386, 48.95837111032643], [-9.09309385029296, 48.98495829268601], [-9.00892913925569, 49.01147787361063], [-8.924670798844879, 49.037929719516235], [-8.840318882253065, 49.06431369681905], [-8.755873444115181, 49.090629671938984], [-8.671334540501073, 49.11687751130056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.6713345&lt;dd&gt;Longitude: 49.116878&lt;dd&gt;Azimuth: 241.2977\u00b0&lt;dd&gt;Altitude: 39.982079\u00b0&lt;dd&gt;Slant Range: 706.95681km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.671334540501073, 49.11687751130056]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.09309385029296, 48.98495829268601], [-9.00892913925569, 49.01147787361063], [-8.924670798844879, 49.037929719516235], [-8.840318882253065, 49.06431369681905], [-8.755873444115181, 49.090629671938984], [-8.671334540501073, 49.11687751130056], [-8.586702228936542, 49.14305708133635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.5867022&lt;dd&gt;Longitude: 49.143057&lt;dd&gt;Azimuth: 241.18689\u00b0&lt;dd&gt;Altitude: 40.397888\u00b0&lt;dd&gt;Slant Range: 701.79764km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.586702228936542, 49.14305708133635]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-9.00892913925569, 49.01147787361063], [-8.924670798844879, 49.037929719516235], [-8.840318882253065, 49.06431369681905], [-8.755873444115181, 49.090629671938984], [-8.671334540501073, 49.11687751130056], [-8.586702228936542, 49.14305708133635], [-8.50197656838663, 49.16916824848862]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.5019766&lt;dd&gt;Longitude: 49.169168&lt;dd&gt;Azimuth: 241.07294\u00b0&lt;dd&gt;Altitude: 40.81926\u00b0&lt;dd&gt;Slant Range: 696.67203km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.50197656838663, 49.16916824848862]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.924670798844879, 49.037929719516235], [-8.840318882253065, 49.06431369681905], [-8.755873444115181, 49.090629671938984], [-8.671334540501073, 49.11687751130056], [-8.586702228936542, 49.14305708133635], [-8.50197656838663, 49.16916824848862], [-8.417157619287192, 49.19521087921106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.4171576&lt;dd&gt;Longitude: 49.195211&lt;dd&gt;Azimuth: 240.95573\u00b0&lt;dd&gt;Altitude: 41.246276\u00b0&lt;dd&gt;Slant Range: 691.58074km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.417157619287192, 49.19521087921106]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.840318882253065, 49.06431369681905], [-8.755873444115181, 49.090629671938984], [-8.671334540501073, 49.11687751130056], [-8.586702228936542, 49.14305708133635], [-8.50197656838663, 49.16916824848862], [-8.417157619287192, 49.19521087921106], [-8.332245443529585, 49.22118483997226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.3322454&lt;dd&gt;Longitude: 49.221185&lt;dd&gt;Azimuth: 240.83512\u00b0&lt;dd&gt;Altitude: 41.679015\u00b0&lt;dd&gt;Slant Range: 686.52453km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.332245443529585, 49.22118483997226]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.755873444115181, 49.090629671938984], [-8.671334540501073, 49.11687751130056], [-8.586702228936542, 49.14305708133635], [-8.50197656838663, 49.16916824848862], [-8.417157619287192, 49.19521087921106], [-8.332245443529585, 49.22118483997226], [-8.247240104482543, 49.24708999725686]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.2472401&lt;dd&gt;Longitude: 49.24709&lt;dd&gt;Azimuth: 240.71097\u00b0&lt;dd&gt;Altitude: 42.117555\u00b0&lt;dd&gt;Slant Range: 681.50419km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.247240104482543, 49.24708999725686]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.671334540501073, 49.11687751130056], [-8.586702228936542, 49.14305708133635], [-8.50197656838663, 49.16916824848862], [-8.417157619287192, 49.19521087921106], [-8.332245443529585, 49.22118483997226], [-8.247240104482543, 49.24708999725686], [-8.162141666981343, 49.2729262175684]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.1621417&lt;dd&gt;Longitude: 49.272926&lt;dd&gt;Azimuth: 240.58313\u00b0&lt;dd&gt;Altitude: 42.561973\u00b0&lt;dd&gt;Slant Range: 676.52052km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.162141666981343, 49.2729262175684]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.586702228936542, 49.14305708133635], [-8.50197656838663, 49.16916824848862], [-8.417157619287192, 49.19521087921106], [-8.332245443529585, 49.22118483997226], [-8.247240104482543, 49.24708999725686], [-8.162141666981343, 49.2729262175684], [-8.07695019735261, 49.29869336743149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -8.0769502&lt;dd&gt;Longitude: 49.298693&lt;dd&gt;Azimuth: 240.45142\u00b0&lt;dd&gt;Altitude: 43.012348\u00b0&lt;dd&gt;Slant Range: 671.57435km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-8.07695019735261, 49.29869336743149]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.50197656838663, 49.16916824848862], [-8.417157619287192, 49.19521087921106], [-8.332245443529585, 49.22118483997226], [-8.247240104482543, 49.24708999725686], [-8.162141666981343, 49.2729262175684], [-8.07695019735261, 49.29869336743149], [-7.991665763398725, 49.32439131339436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.9916658&lt;dd&gt;Longitude: 49.324391&lt;dd&gt;Azimuth: 240.31569\u00b0&lt;dd&gt;Altitude: 43.468756\u00b0&lt;dd&gt;Slant Range: 666.66652km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.991665763398725, 49.32439131339436]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.417157619287192, 49.19521087921106], [-8.332245443529585, 49.22118483997226], [-8.247240104482543, 49.24708999725686], [-8.162141666981343, 49.2729262175684], [-8.07695019735261, 49.29869336743149], [-7.991665763398725, 49.32439131339436], [-7.906288434425649, 49.350019922030334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.9062884&lt;dd&gt;Longitude: 49.35002&lt;dd&gt;Azimuth: 240.17574\u00b0&lt;dd&gt;Altitude: 43.931271\u00b0&lt;dd&gt;Slant Range: 661.79789km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.906288434425649, 49.350019922030334]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.332245443529585, 49.22118483997226], [-8.247240104482543, 49.24708999725686], [-8.162141666981343, 49.2729262175684], [-8.07695019735261, 49.29869336743149], [-7.991665763398725, 49.32439131339436], [-7.906288434425649, 49.350019922030334], [-7.82081828123037, 49.37557905994101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.8208183&lt;dd&gt;Longitude: 49.375579&lt;dd&gt;Azimuth: 240.03139\u00b0&lt;dd&gt;Altitude: 44.399968\u00b0&lt;dd&gt;Slant Range: 656.96932km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.82081828123037, 49.37557905994101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.247240104482543, 49.24708999725686], [-8.162141666981343, 49.2729262175684], [-8.07695019735261, 49.29869336743149], [-7.991665763398725, 49.32439131339436], [-7.906288434425649, 49.350019922030334], [-7.82081828123037, 49.37557905994101], [-7.7352553761176575, 49.40106859375857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.7352554&lt;dd&gt;Longitude: 49.401069&lt;dd&gt;Azimuth: 239.88243\u00b0&lt;dd&gt;Altitude: 44.874919\u00b0&lt;dd&gt;Slant Range: 652.18173km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.7352553761176575, 49.40106859375857]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.162141666981343, 49.2729262175684], [-8.07695019735261, 49.29869336743149], [-7.991665763398725, 49.32439131339436], [-7.906288434425649, 49.350019922030334], [-7.82081828123037, 49.37557905994101], [-7.7352553761176575, 49.40106859375857], [-7.6495997928988215, 49.42648839014763]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.6495998&lt;dd&gt;Longitude: 49.426488&lt;dd&gt;Azimuth: 239.72864\u00b0&lt;dd&gt;Altitude: 45.356195\u00b0&lt;dd&gt;Slant Range: 647.43601km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.6495997928988215, 49.42648839014763]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-8.07695019735261, 49.29869336743149], [-7.991665763398725, 49.32439131339436], [-7.906288434425649, 49.350019922030334], [-7.82081828123037, 49.37557905994101], [-7.7352553761176575, 49.40106859375857], [-7.6495997928988215, 49.42648839014763], [-7.563851606899601, 49.45183831580803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.5638516&lt;dd&gt;Longitude: 49.451838&lt;dd&gt;Azimuth: 239.56979\u00b0&lt;dd&gt;Altitude: 45.843863\u00b0&lt;dd&gt;Slant Range: 642.73311km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.563851606899601, 49.45183831580803]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.991665763398725, 49.32439131339436], [-7.906288434425649, 49.350019922030334], [-7.82081828123037, 49.37557905994101], [-7.7352553761176575, 49.40106859375857], [-7.6495997928988215, 49.42648839014763], [-7.563851606899601, 49.45183831580803], [-7.4780108949717645, 49.47711823747682]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.4780109&lt;dd&gt;Longitude: 49.477118&lt;dd&gt;Azimuth: 239.40564\u00b0&lt;dd&gt;Altitude: 46.337991\u00b0&lt;dd&gt;Slant Range: 638.07398km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.4780108949717645, 49.47711823747682]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.906288434425649, 49.350019922030334], [-7.82081828123037, 49.37557905994101], [-7.7352553761176575, 49.40106859375857], [-7.6495997928988215, 49.42648839014763], [-7.563851606899601, 49.45183831580803], [-7.4780108949717645, 49.47711823747682], [-7.392077735483008, 49.50232802193122]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.3920777&lt;dd&gt;Longitude: 49.502328&lt;dd&gt;Azimuth: 239.23592\u00b0&lt;dd&gt;Altitude: 46.838641\u00b0&lt;dd&gt;Slant Range: 633.45958km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.392077735483008, 49.50232802193122]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.82081828123037, 49.37557905994101], [-7.7352553761176575, 49.40106859375857], [-7.6495997928988215, 49.42648839014763], [-7.563851606899601, 49.45183831580803], [-7.4780108949717645, 49.47711823747682], [-7.392077735483008, 49.50232802193122], [-7.306052208339833, 49.52746753599065]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.3060522&lt;dd&gt;Longitude: 49.527468&lt;dd&gt;Azimuth: 239.06035\u00b0&lt;dd&gt;Altitude: 47.345874\u00b0&lt;dd&gt;Slant Range: 628.89091km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.306052208339833, 49.52746753599065]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.7352553761176575, 49.40106859375857], [-7.6495997928988215, 49.42648839014763], [-7.563851606899601, 49.45183831580803], [-7.4780108949717645, 49.47711823747682], [-7.392077735483008, 49.50232802193122], [-7.306052208339833, 49.52746753599065], [-7.219934394986091, 49.552536646518746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.2199344&lt;dd&gt;Longitude: 49.552537&lt;dd&gt;Azimuth: 238.87863\u00b0&lt;dd&gt;Altitude: 47.859748\u00b0&lt;dd&gt;Slant Range: 624.36898km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.219934394986091, 49.552536646518746]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.6495997928988215, 49.42648839014763], [-7.563851606899601, 49.45183831580803], [-7.4780108949717645, 49.47711823747682], [-7.392077735483008, 49.50232802193122], [-7.306052208339833, 49.52746753599065], [-7.219934394986091, 49.552536646518746], [-7.1337243784030395, 49.5775352204267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.1337244&lt;dd&gt;Longitude: 49.577535&lt;dd&gt;Azimuth: 238.69046\u00b0&lt;dd&gt;Altitude: 48.380315\u00b0&lt;dd&gt;Slant Range: 619.89482km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.1337243784030395, 49.5775352204267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.563851606899601, 49.45183831580803], [-7.4780108949717645, 49.47711823747682], [-7.392077735483008, 49.50232802193122], [-7.306052208339833, 49.52746753599065], [-7.219934394986091, 49.552536646518746], [-7.1337243784030395, 49.5775352204267], [-7.0474222431198985, 49.602463124675104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -7.0474222&lt;dd&gt;Longitude: 49.602463&lt;dd&gt;Azimuth: 238.49547\u00b0&lt;dd&gt;Altitude: 48.907627\u00b0&lt;dd&gt;Slant Range: 615.46946km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-7.0474222431198985, 49.602463124675104]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.4780108949717645, 49.47711823747682], [-7.392077735483008, 49.50232802193122], [-7.306052208339833, 49.52746753599065], [-7.219934394986091, 49.552536646518746], [-7.1337243784030395, 49.5775352204267], [-7.0474222431198985, 49.602463124675104], [-6.961028075223648, 49.62732022627658]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.9610281&lt;dd&gt;Longitude: 49.62732&lt;dd&gt;Azimuth: 238.29331\u00b0&lt;dd&gt;Altitude: 49.441727\u00b0&lt;dd&gt;Slant Range: 611.09398km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.961028075223648, 49.62732022627658]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.392077735483008, 49.50232802193122], [-7.306052208339833, 49.52746753599065], [-7.219934394986091, 49.552536646518746], [-7.1337243784030395, 49.5775352204267], [-7.0474222431198985, 49.602463124675104], [-6.961028075223648, 49.62732022627658], [-6.874541962347754, 49.652106392298045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.874542&lt;dd&gt;Longitude: 49.652106&lt;dd&gt;Azimuth: 238.0836\u00b0&lt;dd&gt;Altitude: 49.982656\u00b0&lt;dd&gt;Slant Range: 606.76946km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.874541962347754, 49.652106392298045]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.306052208339833, 49.52746753599065], [-7.219934394986091, 49.552536646518746], [-7.1337243784030395, 49.5775352204267], [-7.0474222431198985, 49.602463124675104], [-6.961028075223648, 49.62732022627658], [-6.874541962347754, 49.652106392298045], [-6.787963993706395, 49.67682148986366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.787964&lt;dd&gt;Longitude: 49.676821&lt;dd&gt;Azimuth: 237.8659\u00b0&lt;dd&gt;Altitude: 50.530449\u00b0&lt;dd&gt;Slant Range: 602.49701km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.787963993706395, 49.67682148986366]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.219934394986091, 49.552536646518746], [-7.1337243784030395, 49.5775352204267], [-7.0474222431198985, 49.602463124675104], [-6.961028075223648, 49.62732022627658], [-6.874541962347754, 49.652106392298045], [-6.787963993706395, 49.67682148986366], [-6.701294260065094, 49.70146538615658]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.7012943&lt;dd&gt;Longitude: 49.701465&lt;dd&gt;Azimuth: 237.63976\u00b0&lt;dd&gt;Altitude: 51.085135\u00b0&lt;dd&gt;Slant Range: 598.27773km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.701294260065094, 49.70146538615658]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.1337243784030395, 49.5775352204267], [-7.0474222431198985, 49.602463124675104], [-6.961028075223648, 49.62732022627658], [-6.874541962347754, 49.652106392298045], [-6.787963993706395, 49.67682148986366], [-6.701294260065094, 49.70146538615658], [-6.614532853773166, 49.72603794842227]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.6145329&lt;dd&gt;Longitude: 49.726038&lt;dd&gt;Azimuth: 237.40471\u00b0&lt;dd&gt;Altitude: 51.646735\u00b0&lt;dd&gt;Slant Range: 594.11278km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.614532853773166, 49.72603794842227]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-7.0474222431198985, 49.602463124675104], [-6.961028075223648, 49.62732022627658], [-6.874541962347754, 49.652106392298045], [-6.787963993706395, 49.67682148986366], [-6.701294260065094, 49.70146538615658], [-6.614532853773166, 49.72603794842227], [-6.527679868753406, 49.75053904397031]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.5276799&lt;dd&gt;Longitude: 49.750539&lt;dd&gt;Azimuth: 237.16022\u00b0&lt;dd&gt;Altitude: 52.215266\u00b0&lt;dd&gt;Slant Range: 590.0033km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.527679868753406, 49.75053904397031]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.961028075223648, 49.62732022627658], [-6.874541962347754, 49.652106392298045], [-6.787963993706395, 49.67682148986366], [-6.701294260065094, 49.70146538615658], [-6.614532853773166, 49.72603794842227], [-6.527679868753406, 49.75053904397031], [-6.440735400516755, 49.77496854017752]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.4407354&lt;dd&gt;Longitude: 49.774969&lt;dd&gt;Azimuth: 236.90572\u00b0&lt;dd&gt;Altitude: 52.790735\u00b0&lt;dd&gt;Slant Range: 585.95047km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.440735400516755, 49.77496854017752]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.874541962347754, 49.652106392298045], [-6.787963993706395, 49.67682148986366], [-6.701294260065094, 49.70146538615658], [-6.614532853773166, 49.72603794842227], [-6.527679868753406, 49.75053904397031], [-6.440735400516755, 49.77496854017752], [-6.353699546158343, 49.79932630448995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.3536995&lt;dd&gt;Longitude: 49.799326&lt;dd&gt;Azimuth: 236.64061\u00b0&lt;dd&gt;Altitude: 53.373141\u00b0&lt;dd&gt;Slant Range: 581.95547km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.353699546158343, 49.79932630448995]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.787963993706395, 49.67682148986366], [-6.701294260065094, 49.70146538615658], [-6.614532853773166, 49.72603794842227], [-6.527679868753406, 49.75053904397031], [-6.440735400516755, 49.77496854017752], [-6.353699546158343, 49.79932630448995], [-6.26657240437165, 49.82361220442596]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.2665724&lt;dd&gt;Longitude: 49.823612&lt;dd&gt;Azimuth: 236.36423\u00b0&lt;dd&gt;Altitude: 53.962475\u00b0&lt;dd&gt;Slant Range: 578.01951km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.26657240437165, 49.82361220442596]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.701294260065094, 49.70146538615658], [-6.614532853773166, 49.72603794842227], [-6.527679868753406, 49.75053904397031], [-6.440735400516755, 49.77496854017752], [-6.353699546158343, 49.79932630448995], [-6.26657240437165, 49.82361220442596], [-6.179354075444398, 49.84782610757836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.1793541&lt;dd&gt;Longitude: 49.847826&lt;dd&gt;Azimuth: 236.07587\u00b0&lt;dd&gt;Altitude: 54.558715\u00b0&lt;dd&gt;Slant Range: 574.14381km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.179354075444398, 49.84782610757836]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.614532853773166, 49.72603794842227], [-6.527679868753406, 49.75053904397031], [-6.440735400516755, 49.77496854017752], [-6.353699546158343, 49.79932630448995], [-6.26657240437165, 49.82361220442596], [-6.179354075444398, 49.84782610757836], [-6.092044661273748, 49.87196788161739]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.0920447&lt;dd&gt;Longitude: 49.871968&lt;dd&gt;Azimuth: 235.77476\u00b0&lt;dd&gt;Altitude: 55.161832\u00b0&lt;dd&gt;Slant Range: 570.3296km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.092044661273748, 49.87196788161739]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.527679868753406, 49.75053904397031], [-6.440735400516755, 49.77496854017752], [-6.353699546158343, 49.79932630448995], [-6.26657240437165, 49.82361220442596], [-6.179354075444398, 49.84782610757836], [-6.092044661273748, 49.87196788161739], [-6.004644265357443, 49.89603739429272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -6.0046443&lt;dd&gt;Longitude: 49.896037&lt;dd&gt;Azimuth: 235.46005\u00b0&lt;dd&gt;Altitude: 55.771783\u00b0&lt;dd&gt;Slant Range: 566.57813km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-6.004644265357443, 49.89603739429272]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.440735400516755, 49.77496854017752], [-6.353699546158343, 49.79932630448995], [-6.26657240437165, 49.82361220442596], [-6.179354075444398, 49.84782610757836], [-6.092044661273748, 49.87196788161739], [-6.004644265357443, 49.89603739429272], [-5.9171529928143665, 49.92003451343645]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.917153&lt;dd&gt;Longitude: 49.920035&lt;dd&gt;Azimuth: 235.13085\u00b0&lt;dd&gt;Altitude: 56.388512\u00b0&lt;dd&gt;Slant Range: 562.89065km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.9171529928143665, 49.92003451343645]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.353699546158343, 49.79932630448995], [-6.26657240437165, 49.82361220442596], [-6.179354075444398, 49.84782610757836], [-6.092044661273748, 49.87196788161739], [-6.004644265357443, 49.89603739429272], [-5.9171529928143665, 49.92003451343645], [-5.8295709503799396, 49.94395910696585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.829571&lt;dd&gt;Longitude: 49.943959&lt;dd&gt;Azimuth: 234.78615\u00b0&lt;dd&gt;Altitude: 57.01195\u00b0&lt;dd&gt;Slant Range: 559.26844km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.8295709503799396, 49.94395910696585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.26657240437165, 49.82361220442596], [-6.179354075444398, 49.84782610757836], [-6.092044661273748, 49.87196788161739], [-6.004644265357443, 49.89603739429272], [-5.9171529928143665, 49.92003451343645], [-5.8295709503799396, 49.94395910696585], [-5.7418982464108765, 49.967811042885586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.7418982&lt;dd&gt;Longitude: 49.967811&lt;dd&gt;Azimuth: 234.42487\u00b0&lt;dd&gt;Altitude: 57.642013\u00b0&lt;dd&gt;Slant Range: 555.71277km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.7418982464108765, 49.967811042885586]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.179354075444398, 49.84782610757836], [-6.092044661273748, 49.87196788161739], [-6.004644265357443, 49.89603739429272], [-5.9171529928143665, 49.92003451343645], [-5.8295709503799396, 49.94395910696585], [-5.7418982464108765, 49.967811042885586], [-5.654134990891114, 49.991590189290754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.654135&lt;dd&gt;Longitude: 49.99159&lt;dd&gt;Azimuth: 234.04583\u00b0&lt;dd&gt;Altitude: 58.278599\u00b0&lt;dd&gt;Slant Range: 552.22493km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.654134990891114, 49.991590189290754]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.092044661273748, 49.87196788161739], [-6.004644265357443, 49.89603739429272], [-5.9171529928143665, 49.92003451343645], [-5.8295709503799396, 49.94395910696585], [-5.7418982464108765, 49.967811042885586], [-5.654134990891114, 49.991590189290754], [-5.566281295442143, 50.015296414369246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.5662813&lt;dd&gt;Longitude: 50.015296&lt;dd&gt;Azimuth: 233.64773\u00b0&lt;dd&gt;Altitude: 58.92159\u00b0&lt;dd&gt;Slant Range: 548.80622km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.566281295442143, 50.015296414369246]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-6.004644265357443, 49.89603739429272], [-5.9171529928143665, 49.92003451343645], [-5.8295709503799396, 49.94395910696585], [-5.7418982464108765, 49.967811042885586], [-5.654134990891114, 49.991590189290754], [-5.566281295442143, 50.015296414369246], [-5.478337273314584, 50.0389295864044]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.4783373&lt;dd&gt;Longitude: 50.03893&lt;dd&gt;Azimuth: 233.22917\u00b0&lt;dd&gt;Altitude: 59.570847\u00b0&lt;dd&gt;Slant Range: 545.45795km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.478337273314584, 50.0389295864044]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.9171529928143665, 49.92003451343645], [-5.8295709503799396, 49.94395910696585], [-5.7418982464108765, 49.967811042885586], [-5.654134990891114, 49.991590189290754], [-5.566281295442143, 50.015296414369246], [-5.478337273314584, 50.0389295864044], [-5.390303039407782, 50.06248957377789]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.390303&lt;dd&gt;Longitude: 50.06249&lt;dd&gt;Azimuth: 232.78856\u00b0&lt;dd&gt;Altitude: 60.22621\u00b0&lt;dd&gt;Slant Range: 542.18142km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.390303039407782, 50.06248957377789]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.8295709503799396, 49.94395910696585], [-5.7418982464108765, 49.967811042885586], [-5.654134990891114, 49.991590189290754], [-5.566281295442143, 50.015296414369246], [-5.478337273314584, 50.0389295864044], [-5.390303039407782, 50.06248957377789], [-5.302178710268533, 50.08597624497202]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.3021787&lt;dd&gt;Longitude: 50.085976&lt;dd&gt;Azimuth: 232.32421\u00b0&lt;dd&gt;Altitude: 60.887496\u00b0&lt;dd&gt;Slant Range: 538.97795km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.302178710268533, 50.08597624497202]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.7418982464108765, 49.967811042885586], [-5.654134990891114, 49.991590189290754], [-5.566281295442143, 50.015296414369246], [-5.478337273314584, 50.0389295864044], [-5.390303039407782, 50.06248957377789], [-5.302178710268533, 50.08597624497202], [-5.2139644040857895, 50.109389468572864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.2139644&lt;dd&gt;Longitude: 50.109389&lt;dd&gt;Azimuth: 231.83421\u00b0&lt;dd&gt;Altitude: 61.554494\u00b0&lt;dd&gt;Slant Range: 535.84885km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.2139644040857895, 50.109389468572864]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.654134990891114, 49.991590189290754], [-5.566281295442143, 50.015296414369246], [-5.478337273314584, 50.0389295864044], [-5.390303039407782, 50.06248957377789], [-5.302178710268533, 50.08597624497202], [-5.2139644040857895, 50.109389468572864], [-5.125660240713921, 50.13272911327263]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.1256602&lt;dd&gt;Longitude: 50.132729&lt;dd&gt;Azimuth: 231.31648\u00b0&lt;dd&gt;Altitude: 62.226969\u00b0&lt;dd&gt;Slant Range: 532.79543km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.125660240713921, 50.13272911327263]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.566281295442143, 50.015296414369246], [-5.478337273314584, 50.0389295864044], [-5.390303039407782, 50.06248957377789], [-5.302178710268533, 50.08597624497202], [-5.2139644040857895, 50.109389468572864], [-5.125660240713921, 50.13272911327263], [-5.037266341659708, 50.15599504787264]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -5.0372663&lt;dd&gt;Longitude: 50.155995&lt;dd&gt;Azimuth: 230.7687\u00b0&lt;dd&gt;Altitude: 62.904651\u00b0&lt;dd&gt;Slant Range: 529.819km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-5.037266341659708, 50.15599504787264]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.478337273314584, 50.0389295864044], [-5.390303039407782, 50.06248957377789], [-5.302178710268533, 50.08597624497202], [-5.2139644040857895, 50.109389468572864], [-5.125660240713921, 50.13272911327263], [-5.037266341659708, 50.15599504787264], [-4.948782830099674, 50.17918714128585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.9487828&lt;dd&gt;Longitude: 50.179187&lt;dd&gt;Azimuth: 230.18831\u00b0&lt;dd&gt;Altitude: 63.587237\u00b0&lt;dd&gt;Slant Range: 526.92087km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.948782830099674, 50.17918714128585]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.390303039407782, 50.06248957377789], [-5.302178710268533, 50.08597624497202], [-5.2139644040857895, 50.109389468572864], [-5.125660240713921, 50.13272911327263], [-5.037266341659708, 50.15599504787264], [-4.948782830099674, 50.17918714128585], [-4.8602098308729555, 50.20230526253953]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.8602098&lt;dd&gt;Longitude: 50.202305&lt;dd&gt;Azimuth: 229.57244\u00b0&lt;dd&gt;Altitude: 64.274387\u00b0&lt;dd&gt;Slant Range: 524.10235km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.8602098308729555, 50.20230526253953]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.302178710268533, 50.08597624497202], [-5.2139644040857895, 50.109389468572864], [-5.125660240713921, 50.13272911327263], [-5.037266341659708, 50.15599504787264], [-4.948782830099674, 50.17918714128585], [-4.8602098308729555, 50.20230526253953], [-4.771547470501178, 50.225349280778225]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.7715475&lt;dd&gt;Longitude: 50.225349&lt;dd&gt;Azimuth: 228.91793\u00b0&lt;dd&gt;Altitude: 64.965717\u00b0&lt;dd&gt;Slant Range: 521.36473km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.771547470501178, 50.225349280778225]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.2139644040857895, 50.109389468572864], [-5.125660240713921, 50.13272911327263], [-5.037266341659708, 50.15599504787264], [-4.948782830099674, 50.17918714128585], [-4.8602098308729555, 50.20230526253953], [-4.771547470501178, 50.225349280778225], [-4.682795877170287, 50.24831906526647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.6827959&lt;dd&gt;Longitude: 50.248319&lt;dd&gt;Azimuth: 228.22123\u00b0&lt;dd&gt;Altitude: 65.660796\u00b0&lt;dd&gt;Slant Range: 518.70929km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.682795877170287, 50.24831906526647]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.125660240713921, 50.13272911327263], [-5.037266341659708, 50.15599504787264], [-4.948782830099674, 50.17918714128585], [-4.8602098308729555, 50.20230526253953], [-4.771547470501178, 50.225349280778225], [-4.682795877170287, 50.24831906526647], [-4.593955180759354, 50.27121448539101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.5939552&lt;dd&gt;Longitude: 50.271214&lt;dd&gt;Azimuth: 227.47837\u00b0&lt;dd&gt;Altitude: 66.35914\u00b0&lt;dd&gt;Slant Range: 516.13731km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.593955180759354, 50.27121448539101]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-5.037266341659708, 50.15599504787264], [-4.948782830099674, 50.17918714128585], [-4.8602098308729555, 50.20230526253953], [-4.771547470501178, 50.225349280778225], [-4.682795877170287, 50.24831906526647], [-4.593955180759354, 50.27121448539101], [-4.505025512822634, 50.2940354106648]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.5050255&lt;dd&gt;Longitude: 50.294035&lt;dd&gt;Azimuth: 226.6849\u00b0&lt;dd&gt;Altitude: 67.060205\u00b0&lt;dd&gt;Slant Range: 513.65003km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.505025512822634, 50.2940354106648]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.948782830099674, 50.17918714128585], [-4.8602098308729555, 50.20230526253953], [-4.771547470501178, 50.225349280778225], [-4.682795877170287, 50.24831906526647], [-4.593955180759354, 50.27121448539101], [-4.505025512822634, 50.2940354106648], [-4.416007006616335, 50.31678171072833]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.416007&lt;dd&gt;Longitude: 50.316782&lt;dd&gt;Azimuth: 225.83585\u00b0&lt;dd&gt;Altitude: 67.763379\u00b0&lt;dd&gt;Slant Range: 511.2487km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.416007006616335, 50.31678171072833]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.8602098308729555, 50.20230526253953], [-4.771547470501178, 50.225349280778225], [-4.682795877170287, 50.24831906526647], [-4.593955180759354, 50.27121448539101], [-4.505025512822634, 50.2940354106648], [-4.416007006616335, 50.31678171072833], [-4.326899797076049, 50.33945325535358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.3268998&lt;dd&gt;Longitude: 50.339453&lt;dd&gt;Azimuth: 224.92559\u00b0&lt;dd&gt;Altitude: 68.467975\u00b0&lt;dd&gt;Slant Range: 508.93454km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.326899797076049, 50.33945325535358]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.771547470501178, 50.225349280778225], [-4.682795877170287, 50.24831906526647], [-4.593955180759354, 50.27121448539101], [-4.505025512822634, 50.2940354106648], [-4.416007006616335, 50.31678171072833], [-4.326899797076049, 50.33945325535358], [-4.237704020845759, 50.3620499144462]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.237704&lt;dd&gt;Longitude: 50.36205&lt;dd&gt;Azimuth: 223.94781\u00b0&lt;dd&gt;Altitude: 69.173216\u00b0&lt;dd&gt;Slant Range: 506.70875km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.237704020845759, 50.3620499144462]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.682795877170287, 50.24831906526647], [-4.593955180759354, 50.27121448539101], [-4.505025512822634, 50.2940354106648], [-4.416007006616335, 50.31678171072833], [-4.326899797076049, 50.33945325535358], [-4.237704020845759, 50.3620499144462], [-4.148419816265598, 50.3845715580486]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.1484198&lt;dd&gt;Longitude: 50.384572&lt;dd&gt;Azimuth: 222.89537\u00b0&lt;dd&gt;Altitude: 69.878225\u00b0&lt;dd&gt;Slant Range: 504.57249km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.148419816265598, 50.3845715580486]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.593955180759354, 50.27121448539101], [-4.505025512822634, 50.2940354106648], [-4.416007006616335, 50.31678171072833], [-4.326899797076049, 50.33945325535358], [-4.237704020845759, 50.3620499144462], [-4.148419816265598, 50.3845715580486], [-4.059047323380606, 50.40701805634267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -4.0590473&lt;dd&gt;Longitude: 50.407018&lt;dd&gt;Azimuth: 221.76022\u00b0&lt;dd&gt;Altitude: 70.58201\u00b0&lt;dd&gt;Slant Range: 502.52692km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-4.059047323380606, 50.40701805634267]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.505025512822634, 50.2940354106648], [-4.416007006616335, 50.31678171072833], [-4.326899797076049, 50.33945325535358], [-4.237704020845759, 50.3620499144462], [-4.148419816265598, 50.3845715580486], [-4.059047323380606, 50.40701805634267], [-3.9695866839496072, 50.429389279652234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.9695867&lt;dd&gt;Longitude: 50.429389&lt;dd&gt;Azimuth: 220.53325\u00b0&lt;dd&gt;Altitude: 71.283443\u00b0&lt;dd&gt;Slant Range: 500.57313km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.9695866839496072, 50.429389279652234]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.416007006616335, 50.31678171072833], [-4.326899797076049, 50.33945325535358], [-4.237704020845759, 50.3620499144462], [-4.148419816265598, 50.3845715580486], [-4.059047323380606, 50.40701805634267], [-3.9695866839496072, 50.429389279652234], [-3.8800380414437576, 50.45168509844674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.880038&lt;dd&gt;Longitude: 50.451685&lt;dd&gt;Azimuth: 219.20416\u00b0&lt;dd&gt;Altitude: 71.981243\u00b0&lt;dd&gt;Slant Range: 498.71223km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.8800380414437576, 50.45168509844674]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.326899797076049, 50.33945325535358], [-4.237704020845759, 50.3620499144462], [-4.148419816265598, 50.3845715580486], [-4.059047323380606, 50.40701805634267], [-3.9695866839496072, 50.429389279652234], [-3.8800380414437576, 50.45168509844674], [-3.790401541043649, 50.4739053833435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.7904015&lt;dd&gt;Longitude: 50.473905&lt;dd&gt;Azimuth: 217.76132\u00b0&lt;dd&gt;Altitude: 72.673947\u00b0&lt;dd&gt;Slant Range: 496.94524km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.790401541043649, 50.4739053833435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.237704020845759, 50.3620499144462], [-4.148419816265598, 50.3845715580486], [-4.059047323380606, 50.40701805634267], [-3.9695866839496072, 50.429389279652234], [-3.8800380414437576, 50.45168509844674], [-3.790401541043649, 50.4739053833435], [-3.700677329658899, 50.49605000511083]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.7006773&lt;dd&gt;Longitude: 50.49605&lt;dd&gt;Azimuth: 216.19162\u00b0&lt;dd&gt;Altitude: 73.35988\u00b0&lt;dd&gt;Slant Range: 495.27318km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.700677329658899, 50.49605000511083]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.148419816265598, 50.3845715580486], [-4.059047323380606, 50.40701805634267], [-3.9695866839496072, 50.429389279652234], [-3.8800380414437576, 50.45168509844674], [-3.790401541043649, 50.4739053833435], [-3.700677329658899, 50.49605000511083], [-3.610865555917718, 50.51811883467055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.6108656&lt;dd&gt;Longitude: 50.518119&lt;dd&gt;Azimuth: 214.4803\u00b0&lt;dd&gt;Altitude: 74.037122\u00b0&lt;dd&gt;Slant Range: 493.69702km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.610865555917718, 50.51811883467055]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-4.059047323380606, 50.40701805634267], [-3.9695866839496072, 50.429389279652234], [-3.8800380414437576, 50.45168509844674], [-3.790401541043649, 50.4739053833435], [-3.700677329658899, 50.49605000511083], [-3.610865555917718, 50.51811883467055], [-3.5209663701795817, 50.540111743101484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.5209664&lt;dd&gt;Longitude: 50.540112&lt;dd&gt;Azimuth: 212.61086\u00b0&lt;dd&gt;Altitude: 74.703464\u00b0&lt;dd&gt;Slant Range: 492.21767km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.5209663701795817, 50.540111743101484]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.9695866839496072, 50.429389279652234], [-3.8800380414437576, 50.45168509844674], [-3.790401541043649, 50.4739053833435], [-3.700677329658899, 50.49605000511083], [-3.610865555917718, 50.51811883467055], [-3.5209663701795817, 50.540111743101484], [-3.430979924531567, 50.56202860164157]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.4309799&lt;dd&gt;Longitude: 50.562029&lt;dd&gt;Azimuth: 210.56495\u00b0&lt;dd&gt;Altitude: 75.356365\u00b0&lt;dd&gt;Slant Range: 490.83601km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.430979924531567, 50.56202860164157]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.8800380414437576, 50.45168509844674], [-3.790401541043649, 50.4739053833435], [-3.700677329658899, 50.49605000511083], [-3.610865555917718, 50.51811883467055], [-3.5209663701795817, 50.540111743101484], [-3.430979924531567, 50.56202860164157], [-3.3409063727984023, 50.583869281691676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.3409064&lt;dd&gt;Longitude: 50.583869&lt;dd&gt;Azimuth: 208.32247\u00b0&lt;dd&gt;Altitude: 75.992894\u00b0&lt;dd&gt;Slant Range: 489.55288km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.3409063727984023, 50.583869281691676]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.790401541043649, 50.4739053833435], [-3.700677329658899, 50.49605000511083], [-3.610865555917718, 50.51811883467055], [-3.5209663701795817, 50.540111743101484], [-3.430979924531567, 50.56202860164157], [-3.3409063727984023, 50.583869281691676], [-3.25074587054061, 50.60563365481782]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.2507459&lt;dd&gt;Longitude: 50.605634&lt;dd&gt;Azimuth: 205.86168\u00b0&lt;dd&gt;Altitude: 76.609677\u00b0&lt;dd&gt;Slant Range: 488.36904km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.25074587054061, 50.60563365481782]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.700677329658899, 50.49605000511083], [-3.610865555917718, 50.51811883467055], [-3.5209663701795817, 50.540111743101484], [-3.430979924531567, 50.56202860164157], [-3.3409063727984023, 50.583869281691676], [-3.25074587054061, 50.60563365481782], [-3.160498575058603, 50.62732159275386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.1604986&lt;dd&gt;Longitude: 50.627322&lt;dd&gt;Azimuth: 203.15967\u00b0&lt;dd&gt;Altitude: 77.202839\u00b0&lt;dd&gt;Slant Range: 487.28524km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.160498575058603, 50.62732159275386]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.610865555917718, 50.51811883467055], [-3.5209663701795817, 50.540111743101484], [-3.430979924531567, 50.56202860164157], [-3.3409063727984023, 50.583869281691676], [-3.25074587054061, 50.60563365481782], [-3.160498575058603, 50.62732159275386], [-3.0701646454003946, 50.64893296740546]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -3.0701646&lt;dd&gt;Longitude: 50.648933&lt;dd&gt;Azimuth: 200.19317\u00b0&lt;dd&gt;Altitude: 77.76795\u00b0&lt;dd&gt;Slant Range: 486.30212km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-3.0701646454003946, 50.64893296740546]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.5209663701795817, 50.540111743101484], [-3.430979924531567, 50.56202860164157], [-3.3409063727984023, 50.583869281691676], [-3.25074587054061, 50.60563365481782], [-3.160498575058603, 50.62732159275386], [-3.0701646454003946, 50.64893296740546], [-2.9797442423605807, 50.6704676508524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -2.9797442&lt;dd&gt;Longitude: 50.670468&lt;dd&gt;Azimuth: 196.93987\u00b0&lt;dd&gt;Altitude: 78.299991\u00b0&lt;dd&gt;Slant Range: 485.42031km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.9797442423605807, 50.6704676508524]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.430979924531567, 50.56202860164157], [-3.3409063727984023, 50.583869281691676], [-3.25074587054061, 50.60563365481782], [-3.160498575058603, 50.62732159275386], [-3.0701646454003946, 50.64893296740546], [-2.9797442423605807, 50.6704676508524], [-2.8892375284835707, 50.69192551535132]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -2.8892375&lt;dd&gt;Longitude: 50.691926&lt;dd&gt;Azimuth: 193.38041\u00b0&lt;dd&gt;Altitude: 78.793344\u00b0&lt;dd&gt;Slant Range: 484.64037km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.8892375284835707, 50.69192551535132]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.3409063727984023, 50.583869281691676], [-3.25074587054061, 50.60563365481782], [-3.160498575058603, 50.62732159275386], [-3.0701646454003946, 50.64893296740546], [-2.9797442423605807, 50.6704676508524], [-2.8892375284835707, 50.69192551535132], [-2.7986446680652426, 50.71330643333906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -2.7986447&lt;dd&gt;Longitude: 50.713306&lt;dd&gt;Azimuth: 189.50108\u00b0&lt;dd&gt;Altitude: 79.241843\u00b0&lt;dd&gt;Slant Range: 483.96277km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7986446680652426, 50.71330643333906]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.25074587054061, 50.60563365481782], [-3.160498575058603, 50.62732159275386], [-3.0701646454003946, 50.64893296740546], [-2.9797442423605807, 50.6704676508524], [-2.8892375284835707, 50.69192551535132], [-2.7986446680652426, 50.71330643333906], [-2.7079658271675466, 50.734610277435394]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -2.7079658&lt;dd&gt;Longitude: 50.73461&lt;dd&gt;Azimuth: 185.29737\u00b0&lt;dd&gt;Altitude: 79.63889\u00b0&lt;dd&gt;Slant Range: 483.38796km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.7079658271675466, 50.734610277435394]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.160498575058603, 50.62732159275386], [-3.0701646454003946, 50.64893296740546], [-2.9797442423605807, 50.6704676508524], [-2.8892375284835707, 50.69192551535132], [-2.7986446680652426, 50.71330643333906], [-2.7079658271675466, 50.734610277435394], [-2.6172011735999323, 50.75583692044636]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -2.6172012&lt;dd&gt;Longitude: 50.755837&lt;dd&gt;Azimuth: 180.77788\u00b0&lt;dd&gt;Altitude: 79.977688\u00b0&lt;dd&gt;Slant Range: 482.91631km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.6172011735999323, 50.75583692044636]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-3.0701646454003946, 50.64893296740546], [-2.9797442423605807, 50.6704676508524], [-2.8892375284835707, 50.69192551535132], [-2.7986446680652426, 50.71330643333906], [-2.7079658271675466, 50.734610277435394], [-2.6172011735999323, 50.75583692044636], [-2.5263508769429595, 50.7769862353665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5011&lt;dd&gt;Latitude: -2.5263509&lt;dd&gt;Longitude: 50.776986&lt;dd&gt;Azimuth: 175.96813\u00b0&lt;dd&gt;Altitude: 80.251585\u00b0&lt;dd&gt;Slant Range: 482.5481km&quot;, &quot;name&quot;: &quot;STARLINK-5011&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.5263508769429595, 50.7769862353665]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;STARLINK-5165&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[3.178146179634831, 46.13291896120546]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;http://icons.iconarchive.com/icons/google/noto-emoji-travel-places/1024/42597-satellite-icon.png&quot;, &quot;iconSize&quot;: [24, 24], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Satellite: STARLINK-5165&lt;dd&gt;Latitude: 3.1781462&lt;dd&gt;Longitude: 46.132919&lt;dd&gt;Azimuth: 142.15264\u00b0&lt;dd&gt;Altitude: 28.197028\u00b0&lt;dd&gt;Slant Range: 884.33602km&quot;, &quot;name&quot;: &quot;STARLINK-5165&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[3.178146179634831, 46.13291896120546]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;purple&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;orange&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;darkred&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0909FF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F70D1A&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FF6700&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;lightgreen&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#0AFFFF&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#12AD2B&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#E2F516&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#FFFF00&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;#F52887&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;red&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;blue&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;, &quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;, &quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;, &quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;, &quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;, &quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;, &quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;, &quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;, &quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;, &quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;, &quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;, &quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;, &quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;, &quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;, &quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;, &quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;, &quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;, &quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;, &quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;, &quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;, &quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;, &quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;, &quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;, &quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;, &quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;, &quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;, &quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;, &quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;, &quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;, &quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;, &quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;, &quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;, &quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;, &quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;, &quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;, &quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;, &quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;, &quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;, &quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;, &quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;, &quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;, &quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;, &quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;, &quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;, &quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;, &quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;, &quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;, &quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;, &quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;, &quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;, &quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;, &quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;, &quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;, &quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;, &quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;, &quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;, &quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;, &quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;, &quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;, &quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:04:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;, &quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:00&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;, &quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:01&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;, &quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:02&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;, &quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:03&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;, &quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:04&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;, &quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:05&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;, &quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:06&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;, &quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:07&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;, &quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:08&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;, &quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:09&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;, &quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:10&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;, &quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:11&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;, &quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:12&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;, &quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:13&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;, &quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:14&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;, &quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:15&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;, &quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:16&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;, &quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:17&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;, &quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:18&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;, &quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:19&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;, &quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:20&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;, &quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:21&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;, &quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:22&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;, &quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:23&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;, &quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:24&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;, &quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:25&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;, &quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:26&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;, &quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.4587289966574], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:27&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;, &quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:28&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;, &quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:29&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;, &quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:30&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;, &quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:31&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;, &quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:32&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;, &quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:33&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;, &quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:34&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;, &quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:35&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;, &quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:36&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;, &quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:37&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;, &quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:38&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;, &quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:39&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;, &quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:40&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;, &quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:41&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;, &quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:42&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;, &quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:43&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;, &quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:44&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;, &quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:45&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;, &quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:46&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;, &quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:47&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;, &quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:48&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;, &quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:49&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;, &quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:50&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;, &quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:51&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;, &quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:52&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;, &quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:53&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;, &quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:54&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;, &quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:55&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;, &quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:56&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;, &quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657406], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:57&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665742]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;, &quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:58&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665744]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;green&quot;, &quot;weight&quot;: 6}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;, &quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;LineString&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665741], [-2.602153000000031, 51.45872899665743], [-2.602153000000031, 51.45872899665742], [-2.602153000000031, 51.45872899665744], [-2.602153000000031, 51.458728996657435]]}}, {&quot;type&quot;: &quot;Feature&quot;, &quot;properties&quot;: {&quot;icon&quot;: &quot;marker&quot;, &quot;iconstyle&quot;: {&quot;iconUrl&quot;: &quot;https://www.bristol.ac.uk/media-library/sites/physics/new-images/501_10013623.jpg&quot;, &quot;iconSize&quot;: [64, 32], &quot;fillOpacity&quot;: 1, &quot;popupAnchor&quot;: [1, -17]}, &quot;popup&quot;: &quot;Ground Station at Bristol Physics Observatory&lt;dd&gt;Latitude: -2.602153&lt;dd&gt;Longitude: 51.458729&lt;dd&gt;Azimuth: 0.0\u00b0&lt;dd&gt;Altitude: 0.0\u00b0&lt;dd&gt;Slant Range: 0.0km&quot;, &quot;name&quot;: &quot;Ground Station at Bristol Physics Observatory&quot;, &quot;style&quot;: {&quot;color&quot;: &quot;black&quot;, &quot;weight&quot;: 2}, &quot;times&quot;: [&quot;2022-12-15 13:05:59&quot;]}, &quot;geometry&quot;: {&quot;type&quot;: &quot;MultiPoint&quot;, &quot;coordinates&quot;: [[-2.602153000000031, 51.458728996657435]]}}]}, {
                        pointToLayer: function (feature, latLng) {
                            if (feature.properties.icon == &#x27;marker&#x27;) {
                                if(feature.properties.iconstyle){
                                    return new L.Marker(latLng, {
                                        icon: L.icon(feature.properties.iconstyle)});
                                }
                                //else
                                return new L.Marker(latLng);
                            }
                            if (feature.properties.icon == &#x27;circle&#x27;) {
                                if (feature.properties.iconstyle) {
                                    return new L.circleMarker(latLng, feature.properties.iconstyle)
                                    };
                                //else
                                return new L.circleMarker(latLng);
                            }
                            //else

                            return new L.Marker(latLng);
                        },
                        style: function (feature) {
                            return feature.properties.style;
                        },
                        onEachFeature: function(feature, layer) {
                            if (feature.properties.popup) {
                            layer.bindPopup(feature.properties.popup);
                            }
                            if (feature.properties.tooltip) {
                            layer.bindTooltip(feature.properties.tooltip);
                            }
                        }
                    })

                var timestamped_geo_json_2729cc216e87ebc7faeaab9b7700fc4f = L.timeDimension.layer.geoJson(
                    geoJsonLayer,
                    {
                        updateTimeDimension: true,
                        addlastPoint: false,
                        duration: &quot;PT0S&quot;,
                    }
                ).addTo(map_e013d3d35704f37c274470336957f0ae);
        
    &lt;/script&gt;
    &lt;/html&gt;" style="position:absolute;width:100%;height:100%;left:0;top:0;border:none !important;" allowfullscreen webkitallowfullscreen mozallowfullscreen></iframe></div></div>
    </div>
    <br />
    <br />


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  10.024 seconds)


.. _sphx_glr_download_auto_examples_09_satellite_channel_modelling.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example


    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: 09_satellite_channel_modelling.py <09_satellite_channel_modelling.py>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: 09_satellite_channel_modelling.ipynb <09_satellite_channel_modelling.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
